!******************************************************************************!
!                                                                              !
!    class_vertices.f90                                                        !
!    is part of RECOLA2 (REcursive Computation of One Loop Amplitudes)2        !
!                                                                              !
!    Copyright (C) 2016-2018 Ansgar Denner, Jean-Nicolas Lang and              !
!                            Sandro Uccirati                                   !
!                                                                              !
!    RECOLA2 is licenced under the GNU GPL version 3,                          !
!    see COPYING for details.                                                  !
!                                                                              !
!******************************************************************************!
!                                                           .---.              !
!                                                          /  .  \             !
!                                                         |\_/|   |            !
!                                                         |   |  /|            !
!          .----------------------------------------------------' |            !
!         /  .-.   class_vertices.f90                             |            !
!        |  /   \  This code was generated with REPT1L.           |            !
!        | |\_.  | Change this file and you get what you deserve. |            !
!        |\|  | /| Author: J.-N. Lang                             |            !
!        | `---' | UFO date: 27.11.2018                           |            !
!        |       | UFO version: 1.1                               |            !
!        |       | Generation date: 2018-11-28 17:35             /             !
!        |       |----------------------------------------------'              !
!        \       |                                                             !
!         \     /                                                              !
!          `---'                                                               !
!******************************************************************************!
module class_vertices
  use fill_couplings
  use class_particles
  use class_ctparameters
  use fill_ctparameters, only: init_CTparameters_mdl
  use particle_keys, only: createParticleConfig
  use dictionary, only: dict,dict_get_value,dict_init
  use constants_mdl, only: Nc
  implicit none
  save

  interface get_vertex_mdl
    module procedure get_vertex3_mdl, get_vertex4_mdl, get_vertexN_mdl
  end interface

  type Branch
    integer :: lorentz_id
    integer :: perm
    integer, allocatable :: couplings(:)
    integer, dimension(n_orders) :: coupling_order
    integer :: color_id
    integer :: colorfac_id
    ! Propagator extension (only supported for massive vectors)
    ! 0: Usual propagator
    ! 1: Rxi-propagator part with pole @ M_V^2
    ! 2: Rxi-propagator part with pole @ \xi*M_V^2
    integer :: pext
  end type

  type Vertex
    type(Branch), allocatable :: branch(:)
    type(Branch), allocatable :: branchCT(:)
    type(Branch), allocatable :: branchR2(:)
  end type

  logical :: vertices_init = .false.
  logical :: vertices_filled = .false.
    interface createCurrent
      module procedure createCurrent2, createCurrent3, createCurrent4,         &
      createCurrent5, createCurrent6, createCurrent7, createCurrent8
    end interface 
  integer, parameter :: n_vertices = 5268
  type(Vertex) :: vertices(0:n_vertices-1)

  ! Defines the maximum allowed number of legs participating at a vertex
  integer, parameter :: max_leg_multiplicity = 4

  integer, parameter :: FFaS0 = 1
  integer, parameter :: FFaS1 = 2
  integer, parameter :: FFaS2 = 3
  integer, parameter :: UaVUV0 = 4
  integer, parameter :: VFaF0 = 5
  integer, parameter :: VFaF1 = 6
  integer, parameter :: SVVS0 = 7
  integer, parameter :: UaSSU0 = 8
  integer, parameter :: VVVV0 = 9
  integer, parameter :: VVVV1 = 10
  integer, parameter :: UUaS0 = 11
  integer, parameter :: UUaV0 = 12
  integer, parameter :: UUaV1 = 13
  integer, parameter :: SUSUa0 = 14
  integer, parameter :: SUUaS0 = 15
  integer, parameter :: SUUa0 = 16
  integer, parameter :: SSUUa0 = 17
  integer, parameter :: VVSS0 = 18
  integer, parameter :: VUaUV0 = 19
  integer, parameter :: UaSU0 = 20
  integer, parameter :: VVS0 = 21
  integer, parameter :: SUaSU0 = 22
  integer, parameter :: VVV0 = 23
  integer, parameter :: VVV1 = 24
  integer, parameter :: VVV2 = 25
  integer, parameter :: VVV3 = 26
  integer, parameter :: VVV4 = 27
  integer, parameter :: FSFa0 = 28
  integer, parameter :: FSFa1 = 29
  integer, parameter :: FSFa2 = 30
  integer, parameter :: UaUSS0 = 31
  integer, parameter :: VVUUa0 = 32
  integer, parameter :: FaVF0 = 33
  integer, parameter :: FaVF1 = 34
  integer, parameter :: UUaVV0 = 35
  integer, parameter :: UaVU0 = 36
  integer, parameter :: FaF0 = 37
  integer, parameter :: FaF1 = 38
  integer, parameter :: FaF2 = 39
  integer, parameter :: SUaUS0 = 40
  integer, parameter :: FVFa0 = 41
  integer, parameter :: FVFa1 = 42
  integer, parameter :: UaSUS0 = 43
  integer, parameter :: VUaU0 = 44
  integer, parameter :: VUaU1 = 45
  integer, parameter :: USUa0 = 46
  integer, parameter :: VUVUa0 = 47
  integer, parameter :: VV0 = 48
  integer, parameter :: VV1 = 49
  integer, parameter :: VV2 = 50
  integer, parameter :: VV3 = 51
  integer, parameter :: UaVVU0 = 52
  integer, parameter :: SVSV0 = 53
  integer, parameter :: VUUaV0 = 54
  integer, parameter :: FaFS0 = 55
  integer, parameter :: FaFS1 = 56
  integer, parameter :: FaFS2 = 57
  integer, parameter :: FFa0 = 58
  integer, parameter :: FFa1 = 59
  integer, parameter :: FFa2 = 60
  integer, parameter :: FaFV0 = 61
  integer, parameter :: FaFV1 = 62
  integer, parameter :: SSSS0 = 63
  integer, parameter :: VSVS0 = 64
  integer, parameter :: UVVUa0 = 65
  integer, parameter :: VS0 = 66
  integer, parameter :: VS1 = 67
  integer, parameter :: SFFa0 = 68
  integer, parameter :: SFFa1 = 69
  integer, parameter :: SFFa2 = 70
  integer, parameter :: VUUa0 = 71
  integer, parameter :: VUUa1 = 72
  integer, parameter :: SFaF0 = 73
  integer, parameter :: SFaF1 = 74
  integer, parameter :: SFaF2 = 75
  integer, parameter :: SV0 = 76
  integer, parameter :: SV1 = 77
  integer, parameter :: SVV0 = 78
  integer, parameter :: FaSF0 = 79
  integer, parameter :: FaSF1 = 80
  integer, parameter :: FaSF2 = 81
  integer, parameter :: SVS0 = 82
  integer, parameter :: SVS1 = 83
  integer, parameter :: VVUaU0 = 84
  integer, parameter :: USUaS0 = 85
  integer, parameter :: UaUVV0 = 86
  integer, parameter :: VSS0 = 87
  integer, parameter :: VSS1 = 88
  integer, parameter :: VSS2 = 89
  integer, parameter :: VSV0 = 90
  integer, parameter :: SS0 = 91
  integer, parameter :: SS1 = 92
  integer, parameter :: SS2 = 93
  integer, parameter :: SS3 = 94
  integer, parameter :: SSVV0 = 95
  integer, parameter :: SSV0 = 96
  integer, parameter :: SSV1 = 97
  integer, parameter :: SSV2 = 98
  integer, parameter :: FFaV0 = 99
  integer, parameter :: FFaV1 = 100
  integer, parameter :: UVUaV0 = 101
  integer, parameter :: SSS0 = 102
  integer, parameter :: UVUa0 = 103
  integer, parameter :: SSUaU0 = 104
  integer, parameter :: VSSV0 = 105
  integer, parameter :: SUaU0 = 106
  integer, parameter :: USSUa0 = 107
  integer, parameter :: UaUS0 = 108
  integer, parameter :: VFFa0 = 109
  integer, parameter :: VFFa1 = 110
  integer, parameter :: UUaSS0 = 111
  integer, parameter :: VUaVU0 = 112
  integer, parameter :: UaUV0 = 113
  integer, parameter :: UaUV1 = 114
  complex(dp), parameter :: c1 = cmplx(1d0, 0d0, kind=dp)
  character(len=20), parameter :: c1f = "1"
  complex(dp), parameter :: c2 = cmplx(sq2/2d0, 0d0, kind=dp)
  character(len=20), parameter :: c2f = "sq2/2"
  complex(dp), parameter :: c3 = cmplx(-sq2/(2d0*Nc), 0d0, kind=dp)
  character(len=20), parameter :: c3f = "-sq2/(2*Nc)"
  complex(dp), parameter :: c4 = cmplx(1d0/2d0, 0d0, kind=dp)
  character(len=20), parameter :: c4f = "1/2"
  complex(dp), parameter :: c5 = cmplx(-1d0/2d0, 0d0, kind=dp)
  character(len=20), parameter :: c5f = "-1/2"
  complex(dp), parameter :: c6 = cmplx(0d0, sq2/2d0, kind=dp)
  character(len=20), parameter :: c6f = "i_*sq2/2"
  complex(dp), parameter :: c7 = cmplx(0d0, -sq2/2d0, kind=dp)
  character(len=20), parameter :: c7f = "-i_*sq2/2"
  complex(dp), parameter :: c8 = cmplx(-1d0/Nc, 0d0, kind=dp)
  character(len=20), parameter :: c8f = "-1/Nc"
  complex(dp), dimension(1:8) :: colorcoeffs = (/c1, c2, c3, c4, c5, c6, c7, c8&
                                               /)
  character(len=20), dimension(1:8) :: colorcoeffs_form = (/c1f, c2f, c3f, c4f &
                 , c5f, c6f, c7f, c8f/)
  integer, dimension(1:114) :: lorentz_rank = (/0, 0, 0, 0, 1, 1, 0, 0, 0, 0, 0&
                                              , 1, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0&
                                              , 1, 1, 1, 1, -1, 1, 1, 1, 0, 0, &
                                              1, 1, 0, 1, -1, -1, -1, 0, 1, 1, &
                                              0, 1, 1, 0, 0, -1, -1, -1, -1, 0 &
                                              , 0, 0, 0, 0, 0, -1, -1, -1, 0, 0&
                                              , 0, 0, 0, -1, -1, 1, 1, 1, 1, 1 &
                                              , 1, 1, 1, -1, -1, 0, 1, 1, 1, 1 &
                                              , 1, 0, 0, 0, 1, 1, 1, 0, -1, -1 &
                                              , -1, -1, 0, 1, 1, 1, 0, 0, 0, 0 &
                                              , 1, 0, 0, 0, 0, 0, 1, 1, 0, 0, 1&
                                              , 1/)
  integer, dimension(1:114) :: recola_base = (/7, 5, 9, -14, 53, 58, -2, -1, - &
                                             11, -111, 1, 161, 0, -1, -1, 1, -1&
                                             , -4, -13, 1, 2, -1, 0, 12, 0, 160&
                                             , 0, 21, 25, 27, -1, -4, 57, 51, -&
                                             12, 0, 0, 0, 0, -1, 35, 31, -1,   &
                                             162, 0, 1, -3, 0, 0, 0, 0, -2, -14&
                                             , -13, 6, 10, 8, 0, 0, 0, 18, 16  &
                                             , -1, -3, -2, 0, 0, 23, 26, 28, 0 &
                                             , 163, 43, 48, 46, 0, 0, 13, 41,  &
                                             47, 45, 0, 3, -4, -1, -12, 4, 0, 0&
                                             , 14, 0, 0, 0, 0, -12, 0, 11, 0,  &
                                             15, 17, -14, 1, 0, -1, -13, 1, -1 &
                                             , 1, 33, 36, -1, -3, 0, 164/)
  integer, dimension(1:114) :: propagator_extension = (/0, 0, 0, 0, 0, 0, 0, 0 &
                                                      , 0, 0, 0, 0, 0, 0, 0, 0 &
                                                      , 0, 0, 0, 0, 0, 0, 0, 0 &
                                                      , 0, 0, 0, 0, 0, 0, 0, 0 &
                                                      , 0, 0, 0, 0, 0, 0, 0, 0 &
                                                      , 0, 0, 0, 0, 0, 0, 0, 0 &
                                                      , 0, 0, 0, 0, 0, 0, 0, 0 &
                                                      , 0, 0, 0, 0, 0, 0, 0, 0 &
                                                      , 0, 0, 0, 0, 0, 0, 0, 0 &
                                                      , 0, 0, 0, 0, 0, 0, 0, 0 &
                                                      , 0, 0, 0, 0, 0, 0, 0, 0 &
                                                      , 0, 0, 0, 0, 0, 0, 0, 0 &
                                                      , 0, 0, 0, 0, 0, 0, 0, 0 &
                                                      , 0, 0, 0, 0, 0, 0, 0, 0 &
                                                      , 0, 0/)
  character(len=*), parameter :: model_timestamp = "Wed Nov 28 17:20:30 2018"

  contains
    function get_timestamp_mdl() result(ret_timestamp)
      character(len=len(model_timestamp)) :: ret_timestamp
      ret_timestamp = model_timestamp
    end function get_timestamp_mdl

    function get_lorentz_rank_mdl(l_id) result(ret_lorentz_rank)
      integer, intent(in) :: l_id
      integer :: ret_lorentz_rank
      ret_lorentz_rank = lorentz_rank(l_id)
    end function get_lorentz_rank_mdl

    function get_propagator_extension_mdl(l_id) result(ret_pext)
      integer, intent(in) :: l_id
      integer :: ret_pext
      ret_pext = propagator_extension(l_id)
    end function get_propagator_extension_mdl

    function get_max_leg_multiplicity_mdl() result(ret_max_leg_multiplicity)
      integer :: ret_max_leg_multiplicity
      ret_max_leg_multiplicity = max_leg_multiplicity
    end function get_max_leg_multiplicity_mdl

    function is_model_init_mdl() result(ret_init)
      logical :: ret_init
      ret_init = vertices_init
    end function is_model_init_mdl

    function is_model_filled_mdl() result(ret_init)
      logical :: ret_init
      ret_init = vertices_filled
    end function is_model_filled_mdl

    subroutine get_vertex3_mdl(p1, p2, p3, vertex_ret)
      integer, intent(out) :: vertex_ret
      integer, intent(in)  :: p1, p2, p3
      integer(kind=8)      :: config
      integer              :: address
      logical              :: found_vertex

      call createParticleConfig(p1, p2, p3, config)
      call dict(config, 1, address, found_vertex, 0)
      if(found_vertex) then
        vertex_ret = dict_get_value(address)
      else
        vertex_ret = -1
      end if

    end subroutine get_vertex3_mdl

    subroutine get_vertex4_mdl(p1, p2, p3, p4, vertex_ret)
      integer, intent(out) :: vertex_ret
      integer, intent(in)  :: p1, p2, p3, p4
      integer(kind=8)      :: config
      integer              :: address
      logical              :: found_vertex

      call createParticleConfig(p1, p2, p3, p4, config)
      call dict(config, 1, address, found_vertex, 0)
      if(found_vertex) then
        vertex_ret = dict_get_value(address)
      else
        vertex_ret = -1
      end if
    end subroutine get_vertex4_mdl

    subroutine get_vertexN_mdl(particles, particleOut, vertex_ret)
      integer, intent(out)              :: vertex_ret
      integer, dimension(:), intent(in) :: particles
      integer, intent(in)               :: particleOut
      integer(kind=8)                   :: config
      integer                           :: address
      logical                           :: found_vertex

      call createParticleConfig(particles, particleOut, config)
      call dict(config, 1, address, found_vertex, 0)
      if(found_vertex) then
        vertex_ret = dict_get_value(address)
      else
        vertex_ret = -1
      end if

    end subroutine get_vertexN_mdl

    subroutine av(vid,bid,cid,cfid,pext,lid,perm,co,cop)
      integer, intent(in) :: vid,bid,cid,cfid,pext,lid,perm
      integer, dimension(0:), intent(in) :: co, cop
      integer scop,i
      vertices(vid)%branch(bid)%color_id = cid
      vertices(vid)%branch(bid)%colorfac_id = cfid
      vertices(vid)%branch(bid)%pext = pext
      vertices(vid)%branch(bid)%lorentz_id = lid
      vertices(vid)%branch(bid)%perm = perm
      vertices(vid)%branch(bid)%coupling_order = co
      scop = size(cop)
      allocate(vertices(vid)%branch(bid)%couplings(0:scop-1))
      do i = 0, scop-1
        vertices(vid)%branch(bid)%couplings(i) = cop(i)
      end do
    end subroutine av

    subroutine avCT(vid,bid,cid,cfid,pext,lid,perm,co,cop)
      integer, intent(in) :: vid,bid,cid,cfid,pext,lid,perm
      integer, dimension(0:), intent(in) :: co, cop
      integer scop,i
      vertices(vid)%branchCT(bid)%color_id = cid
      vertices(vid)%branchCT(bid)%colorfac_id = cfid
      vertices(vid)%branchCT(bid)%pext = pext
      vertices(vid)%branchCT(bid)%lorentz_id = lid
      vertices(vid)%branchCT(bid)%perm = perm
      vertices(vid)%branchCT(bid)%coupling_order = co
      scop = size(cop)
      allocate(vertices(vid)%branchCT(bid)%couplings(0:scop-1))
      do i = 0, scop-1
        vertices(vid)%branchCT(bid)%couplings(i) = cop(i)
      end do
    end subroutine avCT

    subroutine avR2(vid,bid,cid,cfid,pext,lid,perm,co,cop)
      integer, intent(in) :: vid,bid,cid,cfid,pext,lid,perm
      integer, dimension(0:), intent(in) :: co, cop
      integer scop,i
      vertices(vid)%branchR2(bid)%color_id = cid
      vertices(vid)%branchR2(bid)%colorfac_id = cfid
      vertices(vid)%branchR2(bid)%pext = pext
      vertices(vid)%branchR2(bid)%lorentz_id = lid
      vertices(vid)%branchR2(bid)%perm = perm
      vertices(vid)%branchR2(bid)%coupling_order = co
      scop = size(cop)
      allocate(vertices(vid)%branchR2(bid)%couplings(0:scop-1))
      do i = 0, scop-1
        vertices(vid)%branchR2(bid)%couplings(i) = cop(i)
      end do
    end subroutine avR2

    function get_colourfac_mdl(cfid)
      integer, intent(in) :: cfid
      complex(dp) :: get_colourfac_mdl
      get_colourfac_mdl = colorcoeffs(cfid)
    end function get_colourfac_mdl

    function get_colourfac_form_mdl(cfid)
      integer, intent(in) :: cfid
      character(len=20) :: get_colourfac_form_mdl
      get_colourfac_form_mdl = colorcoeffs_form(cfid)
    end function get_colourfac_form_mdl

  function get_recola_base_mdl(l_id) result(ret_rb)
      integer, intent(in) :: l_id
      integer :: ret_rb
      ret_rb = recola_base(l_id)
    end function get_recola_base_mdl

  subroutine get_vertex_branch_status_mdl(vx,xlp,branch_exists)
    integer, intent(in)  :: vx,xlp
    logical, intent(out) ::branch_exists
    select case (xlp)
    case(TreeBranch:LoopBranch)
      branch_exists = allocated(vertices(vx)%branch)
    case(CTBranch)
      branch_exists = allocated(vertices(vx)%branchCT)
    case(R2Branch)
      branch_exists = allocated(vertices(vx)%branchR2)
    end select
  end subroutine get_vertex_branch_status_mdl

  subroutine get_vertex_colour_branches_mdl(vx,xlp,cfids,nbranches)
    integer, allocatable, intent(out) :: cfids(:)
    integer, intent(out) :: nbranches
    integer, intent(in)  :: vx,xlp
    select case (xlp)
    case (TreeBranch:LoopBranch)
      allocate(cfids(size(vertices(vx)%branch)))
      cfids(:) = vertices(vx)%branch(0:)%color_id
      nbranches = size(vertices(vx)%branch)
    case(CTBranch)
      allocate(cfids(size(vertices(vx)%branchCT)))
      cfids(:) = vertices(vx)%branchCT(0:)%color_id
      nbranches = size(vertices(vx)%branchCT)
    case(R2Branch)
      allocate(cfids(size(vertices(vx)%branchR2)))
      cfids(:) = vertices(vx)%branchR2(0:)%color_id
      nbranches = size(vertices(vx)%branchR2)
    end select
  end subroutine get_vertex_colour_branches_mdl

  subroutine get_vertex_pext_mdl(vx,xlp,br,pext)
    integer, intent(in) :: vx,xlp,br
    integer, intent(out) :: pext
    select case (xlp)
    case (TreeBranch:LoopBranch)
      pext = vertices(vx)%branch(br)%pext
    case(CTBranch)
      pext = vertices(vx)%branchCT(br)%pext
    case(R2Branch)
      pext = vertices(vx)%branchR2(br)%pext
    end select
  end subroutine get_vertex_pext_mdl

  subroutine get_vertex_order_increase_mdl(vx,xlp,br,orderInc)
    integer, intent(in) :: vx,xlp,br
    integer, dimension(:), intent(out) :: orderInc
    select case (xlp)
    case (TreeBranch:LoopBranch)
      orderInc = vertices(vx)%branch(br)%coupling_order
    case(CTBranch)
      orderInc = vertices(vx)%branchCT(br)%coupling_order
    case(R2Branch)
      orderInc = vertices(vx)%branchR2(br)%coupling_order
    end select
  end subroutine get_vertex_order_increase_mdl

  subroutine get_vertex_lorentz_type_mdl(vx,xlp,br,lid)
    integer, intent(in)  :: vx,xlp,br
    integer, intent(out) :: lid
    select case (xlp)
    case (TreeBranch:LoopBranch)
      lid = vertices(vx)%branch(br)%lorentz_id
    case(CTBranch)
      lid = vertices(vx)%branchCT(br)%lorentz_id
    case(R2Branch)
      lid = vertices(vx)%branchR2(br)%lorentz_id
    end select
  end subroutine get_vertex_lorentz_type_mdl

  subroutine get_vertex_perm_mdl(vx,xlp,br,perm)
    integer, intent(in)  :: vx,xlp,br
    integer, intent(out) :: perm
    select case (xlp)
    case (TreeBranch:LoopBranch)
      perm = vertices(vx)%branch(br)%perm
    case(CTBranch)
      perm = vertices(vx)%branchCT(br)%perm
    case(R2Branch)
      perm = vertices(vx)%branchR2(br)%perm
    end select
  end subroutine get_vertex_perm_mdl

  subroutine get_vertex_colour_id_mdl(vx,xlp,br,cid)
    integer, intent(in)  :: vx,xlp,br
    integer, intent(out) :: cid
    select case (xlp)
    case (TreeBranch:LoopBranch)
      cid = vertices(vx)%branch(br)%colorfac_id
    case(CTBranch)
      cid = vertices(vx)%branchCT(br)%colorfac_id
    case(R2Branch)
      cid = vertices(vx)%branchR2(br)%colorfac_id
    end select
  end subroutine get_vertex_colour_id_mdl

  function is_zero_coupling_vertex_mdl(vx,xlp,br) result(zero)
    use class_couplings, only: get_coupling_value_mdl
    use input_mdl, only: zerocut
    integer, intent(in)  :: vx,xlp,br
    logical              :: zero
    real(dp)             :: maxvalue
    integer              :: i

    zero = .false.
    select case (xlp)
    case (TreeBranch:LoopBranch)
      maxvalue = 0d0
      do i = 1,size(vertices(vx)%branch(br)%couplings)
        maxvalue = maxvalue + &
                abs(get_coupling_value_mdl(vertices(vx)%branch(br)%couplings(i-&
                1)))
      end do
      if (maxvalue/zerocut .lt. 100d0) then
        zero = .true.
      end if
    case(CTBranch)
      maxvalue = 0d0
      do i = 1,size(vertices(vx)%branchCT(br)%couplings)
        maxvalue = maxvalue + &
                abs(get_coupling_value_mdl(vertices(vx)%branchCT(br)%couplings(&
                i-1)))
      end do
      if (maxvalue/zerocut .lt. 100d0) then
        zero = .true.
      end if
    case(R2Branch)
      maxvalue = 0d0
      do i = 1,size(vertices(vx)%branchR2(br)%couplings)
        maxvalue = maxvalue + &
                abs(get_coupling_value_mdl(vertices(vx)%branchR2(br)%couplings(&
                i-1)))
      end do
      if (maxvalue/zerocut .lt. 100d0) then
        zero = .true.
      end if
    end select
  end function is_zero_coupling_vertex_mdl

  subroutine get_vertex_ncouplings_mdl(vx,xlp,br,ncouplings)
    integer, intent(in)  :: vx,xlp,br
    integer, intent(out) :: ncouplings
    select case(xlp)
    case(TreeBranch, LoopBranch)
      ncouplings = size(vertices(vx)%branch(br)%couplings)
    case (CTBranch)
      ncouplings = size(vertices(vx)%branchCT(br)%couplings)
    case (R2Branch)
      ncouplings = size(vertices(vx)%branchR2(br)%couplings)
    end select
  end subroutine get_vertex_ncouplings_mdl

  subroutine get_vertex_coupling_ids_mdl(vx,xlp,br,cids)
    integer, intent(in)  :: vx,xlp,br
    integer, intent(out) :: cids(:)
    select case(xlp)
    case(TreeBranch, LoopBranch)
      cids(:) = vertices(vx)%branch(br)%couplings(:)
    case (CTBranch)
      cids(:) = vertices(vx)%branchCT(br)%couplings(:)
    case (R2Branch)
      cids(:) = vertices(vx)%branchR2(br)%couplings(:)
    end select
  end subroutine get_vertex_coupling_ids_mdl

    subroutine createCurrent2(P1, P2, id, check)
      integer, intent(in) :: P1, P2, id
      logical, intent(in) :: check
      integer(kind=8) :: key
      integer :: res,address
      logical :: found
      call createParticleConfig(P1, P2, key)
      if (.not. check) then
        call dict(key, 2, address, found, id)
      else
        call dict(key, 1, address, found, 0)
        res = dict_get_value(address)
        write (*,*) "out=", res, found, address, "shouldbe = ", id
        if (res /= id) then
          stop 9
        end if 
      end if 
    end subroutine createCurrent2

    subroutine createCurrent3(P1, P2, P3, id, check)
      integer, intent(in) :: P1, P2, P3, id
      logical, intent(in) :: check
      integer(kind=8) :: key
      integer :: res,address
      logical :: found
      call createParticleConfig(P1, P2, P3, key)
      if (.not. check) then
        call dict(key, 2, address, found, id)
      else
        call dict(key, 1, address, found, 0)
        res = dict_get_value(address)
        write (*,*) "out=", res, found, address, "shouldbe = ", id
        if (res /= id) then
          stop 9
        end if 
      end if 
    end subroutine createCurrent3

    subroutine createCurrent4(P1, P2, P3, P4, id, check)
      integer, intent(in) :: P1, P2, P3, P4, id
      logical, intent(in) :: check
      integer(kind=8) :: key
      integer :: res,address
      logical :: found
      call createParticleConfig(P1, P2, P3, P4, key)
      if (.not. check) then
        call dict(key, 2, address, found, id)
      else
        call dict(key, 1, address, found, 0)
        res = dict_get_value(address)
        write (*,*) "out=", res, found, address, "shouldbe = ", id
        if (res /= id) then
          stop 9
        end if 
      end if 
    end subroutine createCurrent4

    subroutine createCurrent5(P1, P2, P3, P4, P5, id, check)
      integer, intent(in) :: P1, P2, P3, P4, P5, id
      logical, intent(in) :: check
      integer(kind=8) :: key
      integer :: res,address
      logical :: found
      call createParticleConfig(P1, P2, P3, P4, P5, key)
      if (.not. check) then
        call dict(key, 2, address, found, id)
      else
        call dict(key, 1, address, found, 0)
        res = dict_get_value(address)
        write (*,*) "out=", res, found, address, "shouldbe = ", id
        if (res /= id) then
          stop 9
        end if 
      end if 
    end subroutine createCurrent5

    subroutine createCurrent6(P1, P2, P3, P4, P5, P6, id, check)
      integer, intent(in) :: P1, P2, P3, P4, P5, P6, id
      logical, intent(in) :: check
      integer(kind=8) :: key
      integer :: res,address
      logical :: found
      call createParticleConfig(P1, P2, P3, P4, P5, P6, key)
      if (.not. check) then
        call dict(key, 2, address, found, id)
      else
        call dict(key, 1, address, found, 0)
        res = dict_get_value(address)
        write (*,*) "out=", res, found, address, "shouldbe = ", id
        if (res /= id) then
          stop 9
        end if 
      end if 
    end subroutine createCurrent6

    subroutine createCurrent7(P1, P2, P3, P4, P5, P6, P7, id, check)
      integer, intent(in) :: P1, P2, P3, P4, P5, P6, P7, id
      logical, intent(in) :: check
      integer(kind=8) :: key
      integer :: res,address
      logical :: found
      call createParticleConfig(P1, P2, P3, P4, P5, P6, P7, key)
      if (.not. check) then
        call dict(key, 2, address, found, id)
      else
        call dict(key, 1, address, found, 0)
        res = dict_get_value(address)
        write (*,*) "out=", res, found, address, "shouldbe = ", id
        if (res /= id) then
          stop 9
        end if 
      end if 
    end subroutine createCurrent7

    subroutine createCurrent8(P1, P2, P3, P4, P5, P6, P7, P8, id, check)
      integer, intent(in) :: P1, P2, P3, P4, P5, P6, P7, P8, id
      logical, intent(in) :: check
      integer(kind=8) :: key
      integer :: res,address
      logical :: found
      call createParticleConfig(P1, P2, P3, P4, P5, P6, P7, P8, key)
      if (.not. check) then
        call dict(key, 2, address, found, id)
      else
        call dict(key, 1, address, found, 0)
        res = dict_get_value(address)
        write (*,*) "out=", res, found, address, "shouldbe = ", id
        if (res /= id) then
          stop 9
        end if 
      end if 
    end subroutine createCurrent8

    subroutine init_vertices_mdl()
      use constants_mdl
      use input_mdl, only: nx, error_mdl

      ! check if modelfile is compatible to drivers
      if (model_timestamp .ne. driver_timestamp) then
        call error_mdl("Model corrupted. Driver timestamp mismatch.", &
                      where='init_vertices')
      end if

      vertices_init = .true.
      call fill_couplings_mdl
      call init_CTparameters_mdl(.true.)
      call fill_CTcouplings_mdl
      call dict_init(10531)
      call createCurrents(.false.)

    end subroutine init_vertices_mdl

    subroutine createCurrents(check)
      logical, intent(in) :: check
      call createCurrent(P_HhQ, P_Hl, P_Z, P_ZQ, 1331, check)
      call createCurrent(P_GMinus, P_G0, P_A, P_WPlus, 2574, check)
      call createCurrent(P_WPlus, P_GPlus, P_GMinus, P_WMinus, 260, check)
      call createCurrent(P_ghWm, P_Hh, P_ghWmAnti, P_Hl, 3800, check)
      call createCurrent(P_GQ0, P_ghWmAnti, P_Hl, P_ghWm, 4176, check)
      call createCurrent(P_HlQ, P_GPlus, P_ghZ, P_ghWpAnti, 2376, check)
      call createCurrent(P_GMinus, P_ghAAnti, P_ghZ, P_GPlus, 4183, check)
      call createCurrent(P_WQMinus, P_WPlus, P_ghZAnti, P_ghA, 3116, check)
      call createCurrent(P_ghWp, P_ghZAnti, P_GMinus, P_G0, 3392, check)
      call createCurrent(P_ghG, P_g, P_g, P_ghGAnti, 4919, check)
      call createCurrent(P_HhQ, P_Hl, P_WMinus, P_WQPlus, 1578, check)
      call createCurrent(P_Hh, P_A, P_G0, 5098, check)
      call createCurrent(P_ghWmAnti, P_A, P_ghWm, P_AQ, 413, check)
      call createCurrent(P_GQ0, P_ghWpAnti, P_Hh, P_ghWp, 926, check)
      call createCurrent(P_ghA, P_Hl, P_ghWpAnti, P_GQPlus, 3779, check)
      call createCurrent(P_Z, P_Hl, P_GPlus, P_WMinus, 1498, check)
      call createCurrent(P_GPlus, P_Hl, P_GMinus, 1226, check)
      call createCurrent(P_GPlus, P_b, P_tAnti, 3852, check)
      call createCurrent(P_ghAAnti, P_WPlus, P_ghA, P_WQMinus, 953, check)
      call createCurrent(P_GQ0, P_Hh, P_G0, P_HlQ, 1602, check)
      call createCurrent(P_ghZAnti, P_Hh, P_ghZ, P_Hh, 559, check)
      call createCurrent(P_Hl, P_WMinus, P_A, P_GPlus, 2580, check)
      call createCurrent(P_WQMinus, P_Hl, P_Z, P_GQPlus, 2993, check)
      call createCurrent(P_ePlus, P_eMinus, P_Z, 4115, check)
      call createCurrent(P_Hl, P_A, P_Z, P_Hl, 5058, check)
      call createCurrent(P_ghZ, P_ghWmAnti, P_GMinus, P_Hh, 4690, check)
      call createCurrent(P_ghZAnti, P_G0, P_GPlus, P_ghWm, 2408, check)
      call createCurrent(P_g, P_Hl, P_Hh, P_g, 5155, check)
      call createCurrent(P_ghZAnti, P_ghWm, P_A, P_WPlus, 4592, check)
      call createCurrent(P_ghWpAnti, P_ghA, P_A, P_WPlus, 503, check)
      call createCurrent(P_GQ0, P_ghWm, P_Hl, P_ghWmAnti, 4205, check)
      call createCurrent(P_GQ0, P_GPlus, P_Hl, P_GQMinus, 4219, check)
      call createCurrent(P_ghWp, P_GMinus, P_G0, P_ghZAnti, 4609, check)
      call createCurrent(P_AQ, P_WPlus, P_WMinus, P_AQ, 4160, check)
      call createCurrent(P_GQPlus, P_ghA, P_GMinus, P_ghZAnti, 2304, check)
      call createCurrent(P_Hh, P_cAnti, P_c, 79, check)
      call createCurrent(P_GQPlus, P_WMinus, P_HhQ, 3236, check)
      call createCurrent(P_ghA, P_ghWmAnti, P_Hh, P_GQMinus, 1679, check)
      call createCurrent(P_G0, P_G0, P_G0, P_G0, 2255, check)
      call createCurrent(P_Z, P_Hh, P_A, 5117, check)
      call createCurrent(P_ghZ, P_G0, P_ghWpAnti, P_GPlus, 1489, check)
      call createCurrent(P_ghWp, P_GMinus, P_ghAAnti, P_Hl, 4635, check)
      call createCurrent(P_ghAAnti, P_ghA, P_WPlus, P_WMinus, 2165, check)
      call createCurrent(P_ghA, P_ghAAnti, P_GPlus, P_GMinus, 2422, check)
      call createCurrent(P_GQMinus, P_Z, P_WPlus, P_GQ0, 3406, check)
      call createCurrent(P_GMinus, P_ghWmAnti, P_ghWm, P_GPlus, 1372, check)
      call createCurrent(P_ghA, P_ghWpAnti, P_GPlus, P_Hh, 204, check)
      call createCurrent(P_muMinus, P_muPlus, P_GQ0, 4326, check)
      call createCurrent(P_GPlus, P_GMinus, P_ghZAnti, P_ghZ, 1781, check)
      call createCurrent(P_ghA, P_GMinus, P_GPlus, P_ghAAnti, 4745, check)
      call createCurrent(P_ZQ, P_ghZAnti, P_WMinus, P_ghWp, 406, check)
      call createCurrent(P_ghZAnti, P_GMinus, P_ghZ, P_GPlus, 3697, check)
      call createCurrent(P_ghAAnti, P_WMinus, P_A, P_ghWp, 4902, check)
      call createCurrent(P_GPlus, P_Hl, P_GMinus, P_Hl, 1580, check)
      call createCurrent(P_g, P_cAnti, P_c, 3951, check)
      call createCurrent(P_g, P_g, P_g, P_A, 5154, check)
      call createCurrent(P_WMinus, P_G0, P_G0, P_WPlus, 2143, check)
      call createCurrent(P_GMinus, P_ghWp, P_G0, P_ghAAnti, 1648, check)
      call createCurrent(P_Hl, P_Z, P_Z, 4284, check)
      call createCurrent(P_WPlus, P_WMinus, P_Z, P_A, 4155, check)
      call createCurrent(P_ghZ, P_GMinus, P_ghZAnti, P_GQPlus, 118, check)
      call createCurrent(P_ghZAnti, P_GPlus, P_ghWm, P_HlQ, 4649, check)
      call createCurrent(P_ghWm, P_ghWmAnti, P_A, P_AQ, 2792, check)
      call createCurrent(P_A, P_ghWmAnti, P_ghWm, 4064, check)
      call createCurrent(P_GQ0, P_WMinus, P_WPlus, P_GQ0, 1200, check)
      call createCurrent(P_Z, P_WMinus, P_WPlus, 2393, check)
      call createCurrent(P_HlQ, P_tauMinus, P_tauPlus, 1511, check)
      call createCurrent(P_GQPlus, P_WMinus, P_Hl, P_AQ, 4784, check)
      call createCurrent(P_Z, P_ghAAnti, P_ghWp, P_WMinus, 4184, check)
      call createCurrent(P_ghZAnti, P_ghWp, P_GMinus, P_GQ0, 2133, check)
      call createCurrent(P_Hl, P_G0, P_G0, P_Hh, 796, check)
      call createCurrent(P_GPlus, P_A, P_Z, P_GMinus, 2118, check)
      call createCurrent(P_muPlus, P_muMinus, P_HhQ, 4724, check)
      call createCurrent(P_Z, P_GPlus, P_GMinus, P_A, 2991, check)
      call createCurrent(P_WQMinus, P_u, P_dAnti, 3393, check)
      call createCurrent(P_G0, P_WMinus, P_WPlus, P_G0, 3351, check)
      call createCurrent(P_ghWp, P_Hh, P_ghWpAnti, 2560, check)
      call createCurrent(P_tauPlus, P_tauMinus, P_GQ0, 4928, check)
      call createCurrent(P_eMinus, P_ePlus, P_ZQ, 718, check)
      call createCurrent(P_GPlus, P_ghZAnti, P_ghWm, 2795, check)
      call createCurrent(P_WQPlus, P_A, P_WQMinus, 400, check)
      call createCurrent(P_Z, P_A, P_Z, P_Z, 5183, check)
      call createCurrent(P_Hl, P_GPlus, P_ghA, P_ghWpAnti, 2952, check)
      call createCurrent(P_AQ, P_GPlus, P_Hl, P_WQMinus, 4028, check)
      call createCurrent(P_GPlus, P_ghWm, P_ghZAnti, P_Hh, 3043, check)
      call createCurrent(P_ghWmAnti, P_ghA, P_Z, P_WMinus, 4832, check)
      call createCurrent(P_WMinus, P_ghZAnti, P_ghWp, P_A, 2195, check)
      call createCurrent(P_ghWpAnti, P_ghZ, P_Hh, P_GPlus, 2300, check)
      call createCurrent(P_GQ0, P_Z, P_HhQ, 2663, check)
      call createCurrent(P_Hh, P_ghWmAnti, P_GMinus, P_ghA, 3233, check)
      call createCurrent(P_ZQ, P_GPlus, P_WMinus, P_HhQ, 337, check)
      call createCurrent(P_ghZ, P_WPlus, P_WMinus, P_ghZAnti, 506, check)
      call createCurrent(P_ghWm, P_ghWpAnti, P_WPlus, P_WQPlus, 1923, check)
      call createCurrent(P_GQPlus, P_Hh, P_ghWpAnti, P_ghZ, 2688, check)
      call createCurrent(P_GQ0, P_G0, P_G0, P_GQ0, 1644, check)
      call createCurrent(P_WPlus, P_ghZ, P_WMinus, P_ghZAnti, 2640, check)
      call createCurrent(P_ghWm, P_Z, P_WPlus, P_ghAAnti, 2054, check)
      call createCurrent(P_GQ0, P_G0, P_Hh, P_HhQ, 3922, check)
      call createCurrent(P_ghZAnti, P_ghZ, P_GMinus, P_GQPlus, 72, check)
      call createCurrent(P_g, P_Hh, P_g, P_Hl, 5223, check)
      call createCurrent(P_WQPlus, P_Hh, P_WMinus, P_HhQ, 1902, check)
      call createCurrent(P_muMinus, P_WPlus, P_nu_muAnti, 4492, check)
      call createCurrent(P_ghWmAnti, P_ghWm, P_Hl, P_GQ0, 2254, check)
      call createCurrent(P_WMinus, P_GPlus, P_Z, P_Hh, 439, check)
      call createCurrent(P_ghWp, P_G0, P_ghWpAnti, P_HlQ, 3156, check)
      call createCurrent(P_ghA, P_WPlus, P_ghAAnti, P_WMinus, 1598, check)
      call createCurrent(P_WPlus, P_A, P_ghZAnti, P_ghWm, 20, check)
      call createCurrent(P_nu_eAnti, P_eMinus, P_GPlus, 1185, check)
      call createCurrent(P_ZQ, P_WMinus, P_ghWp, P_ghZAnti, 1204, check)
      call createCurrent(P_GPlus, P_Hl, P_Z, P_WMinus, 1587, check)
      call createCurrent(P_ghZAnti, P_ghWm, P_Hh, P_GPlus, 4432, check)
      call createCurrent(P_Hh, P_ghWp, P_Hh, P_ghWpAnti, 2718, check)
      call createCurrent(P_Z, P_tauPlus, P_tauMinus, 827, check)
      call createCurrent(P_tauMinus, P_nu_tauAnti, P_WPlus, 280, check)
      call createCurrent(P_ZQ, P_Hh, P_GPlus, P_WQMinus, 4116, check)
      call createCurrent(P_GQ0, P_G0, P_Hl, P_HhQ, 4610, check)
      call createCurrent(P_eMinus, P_ePlus, P_HlQ, 2849, check)
      call createCurrent(P_ghWmAnti, P_WPlus, P_WMinus, P_ghWm, 1318, check)
      call createCurrent(P_WMinus, P_dAnti, P_u, 390, check)
      call createCurrent(P_ghA, P_GMinus, P_ghZAnti, P_GPlus, 2685, check)
      call createCurrent(P_muPlus, P_muMinus, P_Hh, 4384, check)
      call createCurrent(P_ghZAnti, P_Z, P_ghWp, P_WMinus, 1151, check)
      call createCurrent(P_cAnti, P_s, P_WQPlus, 51, check)
      call createCurrent(P_A, P_GPlus, P_WMinus, P_Hl, 3444, check)
      call createCurrent(P_Hh, P_Hh, P_ghWpAnti, P_ghWp, 4553, check)
      call createCurrent(P_HhQ, P_GMinus, P_GPlus, P_HlQ, 2781, check)
      call createCurrent(P_WMinus, P_ghWmAnti, P_ghA, 708, check)
      call createCurrent(P_Z, P_A, P_Z, P_A, 5132, check)
      call createCurrent(P_Z, P_WPlus, P_A, P_WMinus, 4338, check)
      call createCurrent(P_GQPlus, P_ghZAnti, P_ghWm, 3074, check)
      call createCurrent(P_GPlus, P_WPlus, P_WMinus, P_GMinus, 4750, check)
      call createCurrent(P_nu_muAnti, P_muMinus, P_GQPlus, 4094, check)
      call createCurrent(P_Hl, P_ghWp, P_ghWpAnti, P_Hl, 4035, check)
      call createCurrent(P_ghZAnti, P_Hh, P_ghZ, P_HhQ, 2905, check)
      call createCurrent(P_GQPlus, P_ghA, P_ghWpAnti, 4366, check)
      call createCurrent(P_WQPlus, P_cAnti, P_s, 2358, check)
      call createCurrent(P_tauPlus, P_tauMinus, 5111, check)
      call createCurrent(P_Z, P_Hh, P_WPlus, P_GMinus, 87, check)
      call createCurrent(P_G0, P_GPlus, P_Z, P_WMinus, 1412, check)
      call createCurrent(P_ghAAnti, P_ghA, P_WMinus, P_WPlus, 3823, check)
      call createCurrent(P_ghA, P_WMinus, P_WPlus, P_ghAAnti, 3375, check)
      call createCurrent(P_ghA, P_ghWmAnti, P_GMinus, P_Hl, 1193, check)
      call createCurrent(P_d, P_dAnti, 5071, check)
      call createCurrent(P_GMinus, P_Hh, P_WPlus, 1874, check)
      call createCurrent(P_ghWp, P_GMinus, P_Hl, P_ghZAnti, 790, check)
      call createCurrent(P_GPlus, P_ghWpAnti, P_ghA, P_Hl, 1025, check)
      call createCurrent(P_GQ0, P_Hl, P_GMinus, P_GQPlus, 3200, check)
      call createCurrent(P_WPlus, P_GMinus, P_A, P_Hl, 1720, check)
      call createCurrent(P_ghZ, P_ghWmAnti, P_WMinus, P_Z, 4821, check)
      call createCurrent(P_GQMinus, P_ghWp, P_G0, P_ghZAnti, 2570, check)
      call createCurrent(P_GPlus, P_Z, P_Hh, P_WMinus, 1252, check)
      call createCurrent(P_GQ0, P_WMinus, P_GQPlus, 3688, check)
      call createCurrent(P_ghZAnti, P_GPlus, P_ghA, P_GMinus, 1532, check)
      call createCurrent(P_GQ0, P_A, P_GMinus, P_WQPlus, 4286, check)
      call createCurrent(P_ghAAnti, P_A, P_ghWp, P_WMinus, 2938, check)
      call createCurrent(P_ghAAnti, P_ghWm, P_GPlus, P_Hh, 833, check)
      call createCurrent(P_Hl, P_ghZAnti, P_ghWm, P_GPlus, 2374, check)
      call createCurrent(P_WPlus, P_ghZAnti, P_ghWm, P_A, 2604, check)
      call createCurrent(P_ghZ, P_ghZAnti, P_GPlus, P_GQMinus, 4306, check)
      call createCurrent(P_ghZ, P_WMinus, P_ghWmAnti, P_A, 7, check)
      call createCurrent(P_ghWp, P_WMinus, P_ghZAnti, P_Z, 3877, check)
      call createCurrent(P_ghZ, P_Hl, P_ghZAnti, P_HhQ, 3062, check)
      call createCurrent(P_ghWmAnti, P_ghA, P_G0, P_GMinus, 2481, check)
      call createCurrent(P_A, P_WMinus, P_ghWp, P_ghZAnti, 4667, check)
      call createCurrent(P_GMinus, P_GPlus, P_Hl, P_Hl, 1098, check)
      call createCurrent(P_A, P_ghWm, P_ghWmAnti, 161, check)
      call createCurrent(P_WPlus, P_ghZAnti, P_WMinus, P_ghA, 2337, check)
      call createCurrent(P_dAnti, P_d, P_Hl, 2259, check)
      call createCurrent(P_ghWpAnti, P_GPlus, P_ghA, P_G0, 4774, check)
      call createCurrent(P_d, P_g, P_dAnti, 2571, check)
      call createCurrent(P_HlQ, P_bAnti, P_b, 1862, check)
      call createCurrent(P_HlQ, P_Hh, P_WPlus, P_WQMinus, 2754, check)
      call createCurrent(P_bAnti, P_b, P_g, 3038, check)
      call createCurrent(P_cAnti, P_Z, P_c, 1971, check)
      call createCurrent(P_ghWpAnti, P_A, P_ghA, P_WPlus, 2313, check)
      call createCurrent(P_ghAAnti, P_WMinus, P_ghZ, P_WPlus, 3195, check)
      call createCurrent(P_ghZAnti, P_G0, P_ghWp, P_GMinus, 576, check)
      call createCurrent(P_ghZAnti, P_WMinus, P_ghWp, P_AQ, 2020, check)
      call createCurrent(P_nu_eAnti, P_WPlus, P_eMinus, 4587, check)
      call createCurrent(P_ghAAnti, P_GMinus, P_ghWp, 3348, check)
      call createCurrent(P_Hl, P_ghAAnti, P_GPlus, P_ghWm, 3466, check)
      call createCurrent(P_ghAAnti, P_ghWp, P_GMinus, P_Hl, 1447, check)
      call createCurrent(P_ZQ, P_Hl, P_GMinus, P_WQPlus, 50, check)
      call createCurrent(P_s, P_sAnti, 5031, check)
      call createCurrent(P_ghWmAnti, P_GMinus, P_G0, P_ghA, 2375, check)
      call createCurrent(P_Z, P_ePlus, P_eMinus, 211, check)
      call createCurrent(P_ghAAnti, P_G0, P_GPlus, P_ghWm, 1822, check)
      call createCurrent(P_WQMinus, P_A, P_ghWmAnti, P_ghZ, 2049, check)
      call createCurrent(P_HlQ, P_s, P_sAnti, 1460, check)
      call createCurrent(P_ghWm, P_GPlus, P_G0, P_ghAAnti, 1601, check)
      call createCurrent(P_WQPlus, P_WMinus, P_AQ, 1982, check)
      call createCurrent(P_ZQ, P_WMinus, P_ghZAnti, P_ghWp, 706, check)
      call createCurrent(P_A, P_ghWmAnti, P_WMinus, P_ghA, 3187, check)
      call createCurrent(P_WQPlus, P_Hl, P_WMinus, P_HhQ, 792, check)
      call createCurrent(P_Hh, P_ghWp, P_ghZAnti, P_GMinus, 3247, check)
      call createCurrent(P_Z, P_WPlus, P_WMinus, P_Z, 4829, check)
      call createCurrent(P_Z, P_GPlus, P_WMinus, P_Hl, 4778, check)
      call createCurrent(P_WMinus, P_ghWp, P_A, P_ghZAnti, 3065, check)
      call createCurrent(P_ghWmAnti, P_ghWm, P_GMinus, P_GQPlus, 4416, check)
      call createCurrent(P_HhQ, P_tAnti, P_t, 2770, check)
      call createCurrent(P_ePlus, P_eMinus, P_ZQ, 3952, check)
      call createCurrent(P_ghZAnti, P_ghWm, P_GPlus, P_HlQ, 323, check)
      call createCurrent(P_G0, P_dAnti, P_d, 800, check)
      call createCurrent(P_ghZAnti, P_GMinus, P_ghWp, 254, check)
      call createCurrent(P_GPlus, P_Hl, P_A, P_WMinus, 2443, check)
      call createCurrent(P_GPlus, P_G0, P_ghWpAnti, P_ghZ, 3125, check)
      call createCurrent(P_Hl, P_GPlus, P_A, P_WMinus, 4000, check)
      call createCurrent(P_ghA, P_WPlus, P_Z, P_ghWpAnti, 1423, check)
      call createCurrent(P_s, P_Z, P_sAnti, 3212, check)
      call createCurrent(P_ghZ, P_WMinus, P_WPlus, P_ghZAnti, 4079, check)
      call createCurrent(P_Hl, P_muMinus, P_muPlus, 1365, check)
      call createCurrent(P_ghAAnti, P_WMinus, P_ghA, P_WQPlus, 3132, check)
      call createCurrent(P_ghWm, P_ghWmAnti, P_WMinus, P_WQPlus, 3372, check)
      call createCurrent(P_Hl, P_ghZ, P_GMinus, P_ghWmAnti, 29, check)
      call createCurrent(P_nu_e, P_WMinus, P_ePlus, 2483, check)
      call createCurrent(P_GPlus, P_ghZ, P_Hl, P_ghWpAnti, 1121, check)
      call createCurrent(P_ghZAnti, P_ghWp, P_WMinus, P_AQ, 4325, check)
      call createCurrent(P_ghZAnti, P_ghWm, P_WQPlus, 4515, check)
      call createCurrent(P_WQPlus, P_A, P_WMinus, P_ZQ, 4584, check)
      call createCurrent(P_WQMinus, P_Hl, P_Hl, P_WQPlus, 574, check)
      call createCurrent(P_eMinus, P_Hh, P_ePlus, 4477, check)
      call createCurrent(P_GPlus, P_Hh, P_ghAAnti, P_ghWm, 826, check)
      call createCurrent(P_ghZAnti, P_ghZ, P_Hh, P_Hh, 1914, check)
      call createCurrent(P_ghWp, P_ghAAnti, P_GMinus, P_Hh, 3459, check)
      call createCurrent(P_GQPlus, P_ghZ, P_ghWpAnti, 405, check)
      call createCurrent(P_Hh, P_Hl, P_Hh, P_Hh, 3666, check)
      call createCurrent(P_ghWpAnti, P_WPlus, P_ghZ, 3831, check)
      call createCurrent(P_GMinus, P_WPlus, P_G0, P_Z, 1495, check)
      call createCurrent(P_ghZAnti, P_Hl, P_ghZ, P_Hh, 671, check)
      call createCurrent(P_ghZAnti, P_Hl, P_ghZ, P_HhQ, 2074, check)
      call createCurrent(P_GQ0, P_GMinus, P_ghWp, P_ghAAnti, 1248, check)
      call createCurrent(P_GQ0, P_ghZAnti, P_GMinus, P_ghWp, 1663, check)
      call createCurrent(P_ZQ, P_A, P_GMinus, P_GQPlus, 4203, check)
      call createCurrent(P_HlQ, P_A, P_GMinus, P_WQPlus, 2744, check)
      call createCurrent(P_t, P_Hl, P_tAnti, 3443, check)
      call createCurrent(P_Hl, P_Z, P_G0, 2934, check)
      call createCurrent(P_HlQ, P_GMinus, P_ghZ, P_ghWmAnti, 3758, check)
      call createCurrent(P_ghWp, P_A, P_WMinus, P_ghZAnti, 1769, check)
      call createCurrent(P_GQ0, P_G0, P_WPlus, P_WQMinus, 3847, check)
      call createCurrent(P_A, P_muPlus, P_muMinus, 57, check)
      call createCurrent(P_WMinus, P_GMinus, P_GPlus, P_WPlus, 3005, check)
      call createCurrent(P_Z, P_ghWp, P_WMinus, P_ghAAnti, 985, check)
      call createCurrent(P_GQ0, P_ghWpAnti, P_ghWp, 2265, check)
      call createCurrent(P_WQPlus, P_ghWpAnti, P_ghZ, 4260, check)
      call createCurrent(P_GQ0, P_t, P_tAnti, 3975, check)
      call createCurrent(P_ghA, P_WMinus, P_ghWmAnti, P_A, 1148, check)
      call createCurrent(P_G0, P_uAnti, P_u, 3555, check)
      call createCurrent(P_HlQ, P_Hh, P_ghWpAnti, P_ghWp, 3401, check)
      call createCurrent(P_ghGAnti, P_ghG, P_g, P_g, 3861, check)
      call createCurrent(P_HlQ, P_G0, P_Hh, P_GQ0, 4469, check)
      call createCurrent(P_GPlus, P_G0, P_A, P_WMinus, 4771, check)
      call createCurrent(P_HlQ, P_Hl, P_HlQ, 1315, check)
      call createCurrent(P_G0, P_c, P_cAnti, 99, check)
      call createCurrent(P_GQMinus, P_WPlus, P_WMinus, P_GQPlus, 4953, check)
      call createCurrent(P_WMinus, P_ghZ, P_Z, P_ghWmAnti, 804, check)
      call createCurrent(P_G0, P_GMinus, P_ghWmAnti, P_ghZ, 4738, check)
      call createCurrent(P_g, P_g, P_Hl, P_Hl, 5257, check)
      call createCurrent(P_HhQ, P_Hl, P_GPlus, P_GQMinus, 3228, check)
      call createCurrent(P_GPlus, P_Hh, P_WMinus, P_A, 2524, check)
      call createCurrent(P_GQMinus, P_Hl, P_GPlus, P_HhQ, 3804, check)
      call createCurrent(P_Z, P_ghZAnti, P_WMinus, P_ghWp, 1345, check)
      call createCurrent(P_ghWpAnti, P_ghZ, P_Hl, P_GQPlus, 3928, check)
      call createCurrent(P_WQMinus, P_G0, P_WPlus, P_HlQ, 2828, check)
      call createCurrent(P_HlQ, P_Hh, P_HhQ, 3293, check)
      call createCurrent(P_A, P_G0, P_Z, P_G0, 5028, check)
      call createCurrent(P_ghWmAnti, P_G0, P_ghZ, P_GQMinus, 996, check)
      call createCurrent(P_Z, P_WPlus, P_ghWpAnti, P_ghZ, 286, check)
      call createCurrent(P_GMinus, P_WPlus, P_G0, 1404, check)
      call createCurrent(P_nu_mu, P_nu_muAnti, P_Z, 1660, check)
      call createCurrent(P_ghWm, P_GPlus, P_ghZAnti, P_G0, 3473, check)
      call createCurrent(P_GQ0, P_ghWmAnti, P_ghWm, 4957, check)
      call createCurrent(P_GPlus, P_A, P_WMinus, P_G0, 3596, check)
      call createCurrent(P_WQPlus, P_G0, P_GQMinus, 1539, check)
      call createCurrent(P_AQ, P_A, P_ghWp, P_ghWpAnti, 3943, check)
      call createCurrent(P_GQPlus, P_ghWm, P_Hh, P_ghZAnti, 1324, check)
      call createCurrent(P_nu_tau, P_nu_tauAnti, P_A, 5049, check)
      call createCurrent(P_ghAAnti, P_GMinus, P_GPlus, P_ghA, 1448, check)
      call createCurrent(P_ZQ, P_ghWm, P_Z, P_ghWmAnti, 23, check)
      call createCurrent(P_Hl, P_Hh, P_Hh, 4287, check)
      call createCurrent(P_ghWpAnti, P_GPlus, P_ghA, 2764, check)
      call createCurrent(P_ghWm, P_Hh, P_ghZAnti, P_GQPlus, 2879, check)
      call createCurrent(P_GMinus, P_GMinus, P_GPlus, P_GPlus, 1367, check)
      call createCurrent(P_Z, P_GPlus, P_WMinus, P_Hh, 3385, check)
      call createCurrent(P_WMinus, P_g, P_WPlus, P_g, 5135, check)
      call createCurrent(P_Z, P_WMinus, P_GPlus, P_Hh, 2804, check)
      call createCurrent(P_Hl, P_G0, P_Z, 586, check)
      call createCurrent(P_GMinus, P_WPlus, P_Z, P_Hh, 1027, check)
      call createCurrent(P_A, P_WMinus, P_Hh, P_GPlus, 2168, check)
      call createCurrent(P_WQMinus, P_WPlus, P_HhQ, 1041, check)
      call createCurrent(P_G0, P_G0, P_ghWm, P_ghWmAnti, 2218, check)
      call createCurrent(P_muMinus, P_nu_muAnti, P_WPlus, 3997, check)
      call createCurrent(P_WQPlus, P_WMinus, P_ghA, P_ghAAnti, 4281, check)
      call createCurrent(P_u, P_uAnti, P_Hh, 2412, check)
      call createCurrent(P_GQMinus, P_WMinus, P_WPlus, P_GQPlus, 4648, check)
      call createCurrent(P_Hh, P_ghWp, P_ghWpAnti, 4126, check)
      call createCurrent(P_WQPlus, P_GMinus, P_Hh, P_ZQ, 3388, check)
      call createCurrent(P_ghWpAnti, P_ghZ, P_WPlus, P_A, 3736, check)
      call createCurrent(P_ghWm, P_ghWmAnti, P_GMinus, P_GQPlus, 2014, check)
      call createCurrent(P_ghWm, P_ghZAnti, P_Hl, P_GPlus, 3170, check)
      call createCurrent(P_HhQ, P_u, P_uAnti, 1210, check)
      call createCurrent(P_GQMinus, P_Z, P_Z, P_GQPlus, 3911, check)
      call createCurrent(P_HlQ, P_A, P_WMinus, P_GQPlus, 2288, check)
      call createCurrent(P_GMinus, P_nu_tau, P_tauPlus, 1687, check)
      call createCurrent(P_ghA, P_ghWpAnti, P_GPlus, P_Hl, 4604, check)
      call createCurrent(P_Hl, P_Hl, P_ghZAnti, P_ghZ, 4752, check)
      call createCurrent(P_ghWpAnti, P_ghZ, P_GPlus, P_G0, 1021, check)
      call createCurrent(P_ghG, P_g, P_ghGAnti, P_g, 3145, check)
      call createCurrent(P_dAnti, P_d, P_A, 1870, check)
      call createCurrent(P_Z, P_WPlus, P_GMinus, P_Hh, 3202, check)
      call createCurrent(P_g, P_g, P_Z, P_Z, 5234, check)
      call createCurrent(P_HhQ, P_Hl, P_Hl, P_HhQ, 3192, check)
      call createCurrent(P_Z, P_uAnti, P_u, 3472, check)
      call createCurrent(P_GPlus, P_GMinus, P_A, P_Z, 2839, check)
      call createCurrent(P_Hl, P_Hl, P_Hl, 2457, check)
      call createCurrent(P_ghWm, P_A, P_ghAAnti, P_WPlus, 3241, check)
      call createCurrent(P_tauMinus, P_tauPlus, P_Hh, 2550, check)
      call createCurrent(P_WPlus, P_ghA, P_Z, P_ghWpAnti, 4233, check)
      call createCurrent(P_Z, P_WMinus, P_G0, P_GPlus, 3021, check)
      call createCurrent(P_AQ, P_WMinus, P_GQPlus, 1674, check)
      call createCurrent(P_Hh, P_Hl, 5032, check)
      call createCurrent(P_muMinus, P_GPlus, P_nu_muAnti, 1803, check)
      call createCurrent(P_ghWm, P_Hh, P_ghWmAnti, P_HlQ, 134, check)
      call createCurrent(P_HhQ, P_ghZ, P_GMinus, P_ghWmAnti, 1696, check)
      call createCurrent(P_Z, P_Z, 5053, check)
      call createCurrent(P_tauMinus, P_nu_tauAnti, P_WQPlus, 1438, check)
      call createCurrent(P_ghA, P_ghWpAnti, P_GQPlus, 2263, check)
      call createCurrent(P_g, P_g, 5116, check)
      call createCurrent(P_Hl, P_A, P_WPlus, P_GMinus, 3077, check)
      call createCurrent(P_dAnti, P_g, P_d, 821, check)
      call createCurrent(P_ghWp, P_Hl, P_ghWpAnti, P_HhQ, 1608, check)
      call createCurrent(P_Hh, P_Hl, P_GPlus, P_GMinus, 1754, check)
      call createCurrent(P_ghWpAnti, P_ghWp, P_Z, P_A, 3400, check)
      call createCurrent(P_ghWm, P_A, P_ghWmAnti, P_A, 3780, check)
      call createCurrent(P_Hl, P_Hl, P_WMinus, P_WPlus, 4063, check)
      call createCurrent(P_ePlus, P_eMinus, P_HhQ, 2015, check)
      call createCurrent(P_ghWp, P_WMinus, P_ghWmAnti, P_WQMinus, 2464, check)
      call createCurrent(P_AQ, P_ghAAnti, P_WMinus, P_ghWp, 1101, check)
      call createCurrent(P_WPlus, P_ghAAnti, P_A, P_ghWm, 1680, check)
      call createCurrent(P_GQMinus, P_A, P_GPlus, P_AQ, 3937, check)
      call createCurrent(P_c, P_cAnti, P_A, 1698, check)
      call createCurrent(P_ghWp, P_G0, P_G0, P_ghWpAnti, 4398, check)
      call createCurrent(P_ghWpAnti, P_A, P_ghWp, P_A, 1360, check)
      call createCurrent(P_ghWp, P_G0, P_GMinus, P_ghAAnti, 3660, check)
      call createCurrent(P_AQ, P_ghZAnti, P_WMinus, P_ghWp, 1274, check)
      call createCurrent(P_ZQ, P_G0, P_G0, P_ZQ, 2163, check)
      call createCurrent(P_G0, P_GMinus, P_ghZAnti, P_ghWp, 1892, check)
      call createCurrent(P_ghZ, P_ghWpAnti, P_WPlus, P_A, 3008, check)
      call createCurrent(P_ghWpAnti, P_WPlus, P_ghA, P_A, 4973, check)
      call createCurrent(P_GQ0, P_A, P_GPlus, P_WQMinus, 3983, check)
      call createCurrent(P_WPlus, P_Hl, P_Hl, P_WMinus, 3395, check)
      call createCurrent(P_WMinus, P_ghWp, P_A, P_ghAAnti, 3653, check)
      call createCurrent(P_ghZAnti, P_ghWm, P_GPlus, P_HhQ, 4545, check)
      call createCurrent(P_ZQ, P_Z, P_HlQ, 1441, check)
      call createCurrent(P_GMinus, P_ghWmAnti, P_ghA, P_Hl, 2750, check)
      call createCurrent(P_ghWmAnti, P_ghWm, P_ZQ, 1157, check)
      call createCurrent(P_dAnti, P_d, P_HhQ, 1127, check)
      call createCurrent(P_WPlus, P_g, P_WMinus, P_g, 5178, check)
      call createCurrent(P_g, P_Hh, P_g, 5166, check)
      call createCurrent(P_ghZ, P_ghZAnti, P_Hl, P_HlQ, 369, check)
      call createCurrent(P_ghWpAnti, P_G0, P_ghWp, P_HhQ, 1072, check)
      call createCurrent(P_GQPlus, P_GMinus, P_G0, P_HhQ, 80, check)
      call createCurrent(P_ZQ, P_Z, P_WPlus, P_WQMinus, 92, check)
      call createCurrent(P_Z, P_ghZAnti, P_WPlus, P_ghWm, 3693, check)
      call createCurrent(P_ghZ, P_Z, P_ghWpAnti, P_WPlus, 4629, check)
      call createCurrent(P_Hl, P_ghZAnti, P_ghWp, P_GMinus, 1132, check)
      call createCurrent(P_WQMinus, P_WPlus, P_WPlus, P_WQMinus, 916, check)
      call createCurrent(P_Hl, P_Z, P_A, P_Hl, 5047, check)
      call createCurrent(P_WMinus, P_WPlus, P_Hl, 2487, check)
      call createCurrent(P_ghWp, P_WMinus, P_ghZAnti, P_AQ, 3177, check)
      call createCurrent(P_HlQ, P_Hh, P_ghWm, P_ghWmAnti, 4193, check)
      call createCurrent(P_ghZAnti, P_ghWm, P_GPlus, 4070, check)
      call createCurrent(P_ZQ, P_WMinus, P_WQPlus, 649, check)
      call createCurrent(P_ghWm, P_Hl, P_ghWmAnti, P_HhQ, 3278, check)
      call createCurrent(P_HhQ, P_Hh, P_HlQ, 4397, check)
      call createCurrent(P_ghWp, P_GMinus, P_ghWpAnti, P_GPlus, 3422, check)
      call createCurrent(P_WMinus, P_ghWp, P_WPlus, P_ghWpAnti, 4684, check)
      call createCurrent(P_GQPlus, P_Z, P_WMinus, P_HlQ, 4072, check)
      call createCurrent(P_GMinus, P_WPlus, P_Z, P_Hl, 2730, check)
      call createCurrent(P_ghWm, P_ghAAnti, P_GPlus, 3028, check)
      call createCurrent(P_ghWm, P_G0, P_GPlus, P_ghZAnti, 377, check)
      call createCurrent(P_ghZ, P_GPlus, P_Hl, P_ghWpAnti, 4540, check)
      call createCurrent(P_WMinus, P_Hl, P_WPlus, P_Hl, 3713, check)
      call createCurrent(P_c, P_sAnti, P_WMinus, 4016, check)
      call createCurrent(P_Hh, P_A, P_WMinus, P_GPlus, 4400, check)
      call createCurrent(P_ZQ, P_sAnti, P_s, 3848, check)
      call createCurrent(P_ghWm, P_GPlus, P_Hl, P_ghAAnti, 3884, check)
      call createCurrent(P_GMinus, P_GPlus, P_ghAAnti, P_ghZ, 1727, check)
      call createCurrent(P_t, P_bAnti, P_WMinus, 2299, check)
      call createCurrent(P_GPlus, P_tauMinus, P_nu_tauAnti, 4238, check)
      call createCurrent(P_ePlus, P_Hh, P_eMinus, 856, check)
      call createCurrent(P_WQMinus, P_ghWmAnti, P_A, P_ghA, 33, check)
      call createCurrent(P_ghZ, P_A, P_WPlus, P_ghWpAnti, 379, check)
      call createCurrent(P_Z, P_g, P_Z, P_g, 5125, check)
      call createCurrent(P_WPlus, P_ghZ, P_ghWpAnti, 2509, check)
      call createCurrent(P_muPlus, P_nu_mu, P_WMinus, 1487, check)
      call createCurrent(P_GQ0, P_d, P_dAnti, 3914, check)
      call createCurrent(P_WQMinus, P_A, P_ghZ, P_ghWmAnti, 4410, check)
      call createCurrent(P_GQPlus, P_cAnti, P_s, 4538, check)
      call createCurrent(P_WQMinus, P_A, P_GPlus, P_HhQ, 1120, check)
      call createCurrent(P_GPlus, P_GMinus, P_ghWpAnti, P_ghWp, 3638, check)
      call createCurrent(P_c, P_cAnti, P_gQ, 1000, check)
      call createCurrent(P_HlQ, P_Z, P_Hh, P_ZQ, 4692, check)
      call createCurrent(P_GQPlus, P_Hl, P_ghWpAnti, P_ghA, 1934, check)
      call createCurrent(P_Hl, P_GPlus, P_WMinus, P_Z, 2874, check)
      call createCurrent(P_ghWmAnti, P_G0, P_ghWm, P_GQ0, 1143, check)
      call createCurrent(P_ZQ, P_WMinus, P_G0, P_GQPlus, 4357, check)
      call createCurrent(P_WQMinus, P_WPlus, P_A, P_AQ, 879, check)
      call createCurrent(P_nu_muAnti, P_Z, P_nu_mu, 3279, check)
      call createCurrent(P_Z, P_G0, P_WMinus, P_GPlus, 1165, check)
      call createCurrent(P_G0, P_GMinus, P_ghA, P_ghWmAnti, 4187, check)
      call createCurrent(P_ghWmAnti, P_Hh, P_ghA, P_GQMinus, 264, check)
      call createCurrent(P_ghWpAnti, P_Hl, P_GPlus, P_ghA, 3178, check)
      call createCurrent(P_ghZAnti, P_ghZ, P_GPlus, P_GQMinus, 1909, check)
      call createCurrent(P_AQ, P_eMinus, P_ePlus, 2214, check)
      call createCurrent(P_ghZAnti, P_ghWp, P_Hh, P_GQMinus, 2462, check)
      call createCurrent(P_WPlus, P_A, P_ghWm, P_ghAAnti, 1776, check)
      call createCurrent(P_sAnti, P_A, P_s, 1376, check)
      call createCurrent(P_WMinus, P_ghWp, P_ghZAnti, P_A, 1704, check)
      call createCurrent(P_GPlus, P_WMinus, P_A, P_G0, 1528, check)
      call createCurrent(P_ghWm, P_ghWmAnti, P_HlQ, 1190, check)
      call createCurrent(P_ZQ, P_Hl, P_Z, P_HhQ, 85, check)
      call createCurrent(P_GQ0, P_WPlus, P_Hh, P_WQMinus, 4345, check)
      call createCurrent(P_WMinus, P_GPlus, P_WPlus, P_GMinus, 3872, check)
      call createCurrent(P_WPlus, P_Z, P_ghZAnti, P_ghWm, 2798, check)
      call createCurrent(P_A, P_Hl, P_Z, P_Hl, 4990, check)
      call createCurrent(P_Hh, P_Hl, P_WPlus, P_WMinus, 3961, check)
      call createCurrent(P_ZQ, P_WMinus, P_A, P_WQPlus, 4220, check)
      call createCurrent(P_WPlus, P_Hh, P_A, P_GMinus, 1500, check)
      call createCurrent(P_cAnti, P_c, P_gQ, 1556, check)
      call createCurrent(P_A, P_ghWmAnti, P_Z, P_ghWm, 2743, check)
      call createCurrent(P_bAnti, P_t, P_GQMinus, 2729, check)
      call createCurrent(P_GPlus, P_Hh, P_GMinus, 201, check)
      call createCurrent(P_ghWpAnti, P_ghZ, P_A, P_WQPlus, 470, check)
      call createCurrent(P_HhQ, P_ghWp, P_GMinus, P_ghZAnti, 1419, check)
      call createCurrent(P_WQPlus, P_ghZAnti, P_ghWm, 4547, check)
      call createCurrent(P_Hh, P_Z, P_Hl, P_A, 5017, check)
      call createCurrent(P_ghA, P_ghWpAnti, P_Hl, P_GPlus, 394, check)
      call createCurrent(P_ZQ, P_Z, P_Hl, P_HhQ, 1966, check)
      call createCurrent(P_WQMinus, P_nu_tau, P_tauPlus, 2005, check)
      call createCurrent(P_GQPlus, P_nu_eAnti, P_eMinus, 3987, check)
      call createCurrent(P_Z, P_WPlus, P_ghZ, P_ghWpAnti, 1829, check)
      call createCurrent(P_GQPlus, P_d, P_uAnti, 1962, check)
      call createCurrent(P_GMinus, P_WPlus, P_A, P_Hh, 3211, check)
      call createCurrent(P_Hh, P_WMinus, P_GPlus, P_A, 3843, check)
      call createCurrent(P_AQ, P_G0, P_WMinus, P_GQPlus, 2596, check)
      call createCurrent(P_HlQ, P_Hl, P_Hh, P_HhQ, 1080, check)
      call createCurrent(P_G0, P_A, P_A, P_G0, 5193, check)
      call createCurrent(P_ghWmAnti, P_WMinus, P_WPlus, P_ghWm, 4817, check)
      call createCurrent(P_GMinus, P_Hh, P_ghAAnti, P_ghWp, 3791, check)
      call createCurrent(P_AQ, P_GPlus, P_WQMinus, 3703, check)
      call createCurrent(P_A, P_nu_muAnti, P_nu_mu, 5024, check)
      call createCurrent(P_ghWmAnti, P_Hh, P_ghZ, P_GQMinus, 831, check)
      call createCurrent(P_GQ0, P_Z, P_GPlus, P_WQMinus, 4807, check)
      call createCurrent(P_HlQ, P_ghWmAnti, P_G0, P_ghWm, 1875, check)
      call createCurrent(P_GPlus, P_ghA, P_ghWpAnti, 4135, check)
      call createCurrent(P_Z, P_WPlus, P_ghZAnti, P_ghWm, 1746, check)
      call createCurrent(P_ghWpAnti, P_ghA, P_WPlus, P_A, 2931, check)
      call createCurrent(P_GMinus, P_ghZAnti, P_ghWp, 2206, check)
      call createCurrent(P_u, P_uAnti, P_HhQ, 4113, check)
      call createCurrent(P_WPlus, P_ghA, P_ghWpAnti, P_A, 3171, check)
      call createCurrent(P_GMinus, P_ghWpAnti, P_ghWp, P_GPlus, 2260, check)
      call createCurrent(P_Z, P_nu_mu, P_nu_muAnti, 2051, check)
      call createCurrent(P_Hh, P_Hl, P_ghWm, P_ghWmAnti, 2684, check)
      call createCurrent(P_WMinus, P_A, P_GPlus, P_G0, 215, check)
      call createCurrent(P_A, P_ePlus, P_eMinus, 4831, check)
      call createCurrent(P_uAnti, P_u, P_g, 3463, check)
      call createCurrent(P_HlQ, P_eMinus, P_ePlus, 3938, check)
      call createCurrent(P_Z, P_A, P_Hl, 5025, check)
      call createCurrent(P_AQ, P_GPlus, P_A, P_GQMinus, 4965, check)
      call createCurrent(P_ghWmAnti, P_G0, P_ghWm, P_G0, 829, check)
      call createCurrent(P_G0, P_ghWpAnti, P_ghZ, P_GPlus, 1884, check)
      call createCurrent(P_ePlus, P_eMinus, P_G0, 4530, check)
      call createCurrent(P_g, P_ghG, P_g, P_ghGAnti, 305, check)
      call createCurrent(P_G0, P_A, P_WPlus, P_GMinus, 3273, check)
      call createCurrent(P_WPlus, P_ghWm, P_A, P_ghZAnti, 3651, check)
      call createCurrent(P_ZQ, P_GMinus, P_GPlus, P_AQ, 2139, check)
      call createCurrent(P_ghA, P_ghZAnti, P_WMinus, P_WPlus, 1044, check)
      call createCurrent(P_HhQ, P_GMinus, P_G0, P_GQPlus, 1276, check)
      call createCurrent(P_s, P_g, P_sAnti, 2722, check)
      call createCurrent(P_WQPlus, P_Hl, P_GMinus, P_AQ, 3498, check)
      call createCurrent(P_G0, P_G0, P_Z, P_A, 5008, check)
      call createCurrent(P_u, P_uAnti, 4999, check)
      call createCurrent(P_ghZAnti, P_Hl, P_ghWp, P_GQMinus, 2292, check)
      call createCurrent(P_HhQ, P_Hh, P_ghWmAnti, P_ghWm, 4010, check)
      call createCurrent(P_ghWp, P_ghWpAnti, P_G0, P_GQ0, 897, check)
      call createCurrent(P_gQ, P_g, P_gQ, 4347, check)
      call createCurrent(P_A, P_GMinus, P_WPlus, 1810, check)
      call createCurrent(P_A, P_WPlus, P_ghWm, P_ghAAnti, 1816, check)
      call createCurrent(P_HlQ, P_Hh, P_GPlus, P_GQMinus, 2199, check)
      call createCurrent(P_ghWpAnti, P_Hh, P_ghWp, 499, check)
      call createCurrent(P_ZQ, P_Z, P_ghWpAnti, P_ghWp, 3153, check)
      call createCurrent(P_ghA, P_Hl, P_GPlus, P_ghWpAnti, 4501, check)
      call createCurrent(P_ghZAnti, P_G0, P_ghWm, P_GQPlus, 4222, check)
      call createCurrent(P_HlQ, P_WPlus, P_GMinus, P_ZQ, 3363, check)
      call createCurrent(P_ZQ, P_Hl, P_GPlus, P_WQMinus, 4464, check)
      call createCurrent(P_G0, P_Hh, P_G0, 388, check)
      call createCurrent(P_AQ, P_tauPlus, P_tauMinus, 4800, check)
      call createCurrent(P_ghZ, P_Hl, P_ghZAnti, 589, check)
      call createCurrent(P_GPlus, P_Hl, P_Hl, P_GMinus, 1286, check)
      call createCurrent(P_GQMinus, P_WPlus, P_Hh, P_ZQ, 4589, check)
      call createCurrent(P_cAnti, P_c, P_ZQ, 1831, check)
      call createCurrent(P_HlQ, P_WMinus, P_GQPlus, 1560, check)
      call createCurrent(P_ghWmAnti, P_ghWm, P_HhQ, 318, check)
      call createCurrent(P_AQ, P_A, P_WMinus, P_WQPlus, 1713, check)
      call createCurrent(P_GQMinus, P_ghZAnti, P_Hl, P_ghWp, 1201, check)
      call createCurrent(P_tAnti, P_t, P_Z, 983, check)
      call createCurrent(P_gQ, P_g, P_g, P_gQ, 4498, check)
      call createCurrent(P_ghWm, P_GPlus, P_GMinus, P_ghWmAnti, 2865, check)
      call createCurrent(P_WQMinus, P_Hl, P_GQPlus, 561, check)
      call createCurrent(P_GPlus, P_ghWm, P_ghWmAnti, P_GMinus, 4732, check)
      call createCurrent(P_WPlus, P_ghWm, P_A, P_ghAAnti, 1374, check)
      call createCurrent(P_WPlus, P_GMinus, P_WMinus, P_GPlus, 1775, check)
      call createCurrent(P_ghWp, P_WMinus, P_ghAAnti, P_AQ, 163, check)
      call createCurrent(P_ghWm, P_GPlus, P_G0, P_ghZAnti, 2411, check)
      call createCurrent(P_GMinus, P_A, P_Hl, P_WPlus, 3440, check)
      call createCurrent(P_Hl, P_A, P_Hh, P_Z, 5087, check)
      call createCurrent(P_GPlus, P_A, P_WMinus, P_Hl, 2763, check)
      call createCurrent(P_G0, P_Z, P_WPlus, P_GMinus, 4804, check)
      call createCurrent(P_Z, P_GMinus, P_WPlus, P_G0, 4951, check)
      call createCurrent(P_WQMinus, P_GPlus, P_ZQ, 2963, check)
      call createCurrent(P_ZQ, P_WPlus, P_GMinus, P_HlQ, 2314, check)
      call createCurrent(P_AQ, P_Hl, P_WMinus, P_GQPlus, 2421, check)
      call createCurrent(P_HhQ, P_ghWm, P_GPlus, P_ghAAnti, 442, check)
      call createCurrent(P_ghWp, P_Hl, P_ghZAnti, P_GQMinus, 982, check)
      call createCurrent(P_ghAAnti, P_GPlus, P_ghWm, P_GQ0, 3838, check)
      call createCurrent(P_ghWp, P_ghWpAnti, P_A, P_A, 3604, check)
      call createCurrent(P_WPlus, P_A, P_ghZ, P_ghWpAnti, 3209, check)
      call createCurrent(P_muMinus, P_nu_muAnti, P_WQPlus, 3316, check)
      call createCurrent(P_ghA, P_G0, P_ghWmAnti, P_GQMinus, 4328, check)
      call createCurrent(P_WQMinus, P_ghAAnti, P_ghWp, 4261, check)
      call createCurrent(P_ghWmAnti, P_Z, P_ghWm, 263, check)
      call createCurrent(P_GPlus, P_tAnti, P_b, 2348, check)
      call createCurrent(P_WPlus, P_ghWpAnti, P_ghZ, P_A, 3925, check)
      call createCurrent(P_Hh, P_Hh, P_ghZAnti, P_ghZ, 3792, check)
      call createCurrent(P_ghGAnti, P_g, P_ghG, P_gQ, 955, check)
      call createCurrent(P_ghZAnti, P_ghZ, P_HlQ, 199, check)
      call createCurrent(P_Z, P_Hl, P_Z, P_Hh, 2593, check)
      call createCurrent(P_ghZ, P_WPlus, P_ghAAnti, P_WMinus, 43, check)
      call createCurrent(P_WQPlus, P_Hh, P_Z, P_GQMinus, 1994, check)
      call createCurrent(P_ghWpAnti, P_GPlus, P_ghA, P_Hh, 1158, check)
      call createCurrent(P_G0, P_ghA, P_ghWmAnti, P_GMinus, 27, check)
      call createCurrent(P_ghWmAnti, P_ghA, P_GMinus, P_Hh, 4273, check)
      call createCurrent(P_WMinus, P_ghWmAnti, P_A, P_ghZ, 2776, check)
      call createCurrent(P_WQPlus, P_ghZ, P_ghWpAnti, 941, check)
      call createCurrent(P_GQPlus, P_G0, P_Z, P_WQMinus, 90, check)
      call createCurrent(P_ghWmAnti, P_ghWm, P_A, P_AQ, 3219, check)
      call createCurrent(P_GQPlus, P_A, P_WMinus, P_HlQ, 865, check)
      call createCurrent(P_ghAAnti, P_ghWp, P_GMinus, P_G0, 4075, check)
      call createCurrent(P_Hh, P_ghZAnti, P_ghZ, 481, check)
      call createCurrent(P_Z, P_ghWmAnti, P_ghWm, 3529, check)
      call createCurrent(P_WPlus, P_uAnti, P_d, 4709, check)
      call createCurrent(P_GQPlus, P_GMinus, P_ghZAnti, P_ghA, 3704, check)
      call createCurrent(P_A, P_Z, P_WPlus, P_WMinus, 1152, check)
      call createCurrent(P_WQPlus, P_GMinus, P_Hl, P_ZQ, 1289, check)
      call createCurrent(P_ghWm, P_ghAAnti, P_WPlus, P_ZQ, 4646, check)
      call createCurrent(P_Hh, P_Hh, P_WPlus, P_WMinus, 3992, check)
      call createCurrent(P_muMinus, P_muPlus, P_AQ, 2507, check)
      call createCurrent(P_WMinus, P_Hl, P_Hh, P_WPlus, 3403, check)
      call createCurrent(P_ghZAnti, P_ghWm, P_Hl, P_GQPlus, 1253, check)
      call createCurrent(P_ghWm, P_A, P_WPlus, P_ghAAnti, 2386, check)
      call createCurrent(P_Z, P_A, P_ghWp, P_ghWpAnti, 244, check)
      call createCurrent(P_GMinus, P_ghAAnti, P_G0, P_ghWp, 4665, check)
      call createCurrent(P_ghZ, P_GPlus, P_ghWpAnti, P_Hl, 4291, check)
      call createCurrent(P_c, P_cAnti, P_G0, 4152, check)
      call createCurrent(P_GQMinus, P_ghA, P_Hl, P_ghWmAnti, 1522, check)
      call createCurrent(P_ghZ, P_ghAAnti, P_WPlus, P_WQMinus, 2813, check)
      call createCurrent(P_WQMinus, P_ghA, P_WPlus, P_ghAAnti, 835, check)
      call createCurrent(P_GPlus, P_eMinus, P_nu_eAnti, 3493, check)
      call createCurrent(P_G0, P_Z, P_Hh, 1520, check)
      call createCurrent(P_ghAAnti, P_WMinus, P_ghWp, P_AQ, 688, check)
      call createCurrent(P_WMinus, P_Z, P_ghA, P_ghWmAnti, 1849, check)
      call createCurrent(P_ghZAnti, P_WPlus, P_ghZ, P_WQMinus, 2936, check)
      call createCurrent(P_ghWpAnti, P_ghWp, P_ZQ, 1135, check)
      call createCurrent(P_AQ, P_tauMinus, P_tauPlus, 1389, check)
      call createCurrent(P_HhQ, P_GPlus, P_ghZ, P_ghWpAnti, 2940, check)
      call createCurrent(P_A, P_Z, P_ghWm, P_ghWmAnti, 3044, check)
      call createCurrent(P_G0, P_tAnti, P_t, 2385, check)
      call createCurrent(P_AQ, P_WPlus, P_ghWm, P_ghAAnti, 3445, check)
      call createCurrent(P_Z, P_Hh, P_Hl, P_A, 5122, check)
      call createCurrent(P_Z, P_G0, P_Z, P_G0, 2360, check)
      call createCurrent(P_ghWp, P_Z, P_ghZAnti, P_WMinus, 1216, check)
      call createCurrent(P_uAnti, P_u, P_HhQ, 4246, check)
      call createCurrent(P_s, P_GPlus, P_cAnti, 2994, check)
      call createCurrent(P_GMinus, P_Hl, P_GPlus, P_Hh, 2633, check)
      call createCurrent(P_Hl, P_Z, P_GMinus, P_WPlus, 2177, check)
      call createCurrent(P_HlQ, P_ghZ, P_GPlus, P_ghWpAnti, 2442, check)
      call createCurrent(P_ghWp, P_Hh, P_GMinus, P_ghZAnti, 46, check)
      call createCurrent(P_GMinus, P_ghZ, P_ghWmAnti, P_Hh, 3457, check)
      call createCurrent(P_Hh, P_ghWm, P_GPlus, P_ghZAnti, 2316, check)
      call createCurrent(P_ghWmAnti, P_ghA, P_GQMinus, 936, check)
      call createCurrent(P_ghZ, P_ghWpAnti, P_G0, P_GQPlus, 1502, check)
      call createCurrent(P_A, P_ghWp, P_Z, P_ghWpAnti, 2997, check)
      call createCurrent(P_ghWmAnti, P_ghWm, P_Hh, 3050, check)
      call createCurrent(P_ghWpAnti, P_ghA, P_Hl, P_GPlus, 3684, check)
      call createCurrent(P_ZQ, P_WMinus, P_ghWp, P_ghAAnti, 2511, check)
      call createCurrent(P_HlQ, P_G0, P_GQ0, 1896, check)
      call createCurrent(P_WMinus, P_G0, P_A, P_GPlus, 1396, check)
      call createCurrent(P_ghWpAnti, P_WPlus, P_Z, P_ghZ, 1187, check)
      call createCurrent(P_Z, P_Hl, P_Z, 395, check)
      call createCurrent(P_WPlus, P_ghWpAnti, P_ghWm, P_WPlus, 2587, check)
      call createCurrent(P_GPlus, P_G0, P_ghZAnti, P_ghWm, 3616, check)
      call createCurrent(P_ghA, P_ghWmAnti, P_GQMinus, 2459, check)
      call createCurrent(P_ghWp, P_GMinus, P_ghZAnti, P_Hh, 3358, check)
      call createCurrent(P_GQMinus, P_G0, P_ghZ, P_ghWmAnti, 3069, check)
      call createCurrent(P_WMinus, P_WPlus, P_ghZAnti, P_ghA, 2950, check)
      call createCurrent(P_WQMinus, P_ghWp, P_WPlus, P_ghWpAnti, 3301, check)
      call createCurrent(P_ePlus, P_eMinus, P_Hh, 4885, check)
      call createCurrent(P_ghWpAnti, P_ghWp, P_A, P_AQ, 4682, check)
      call createCurrent(P_WQMinus, P_GPlus, P_G0, P_AQ, 1209, check)
      call createCurrent(P_Hh, P_GPlus, P_WMinus, P_A, 35, check)
      call createCurrent(P_Z, P_g, P_g, P_A, 5253, check)
      call createCurrent(P_Z, P_GPlus, P_Hl, P_WMinus, 598, check)
      call createCurrent(P_GMinus, P_A, P_A, P_GPlus, 2466, check)
      call createCurrent(P_GPlus, P_s, P_cAnti, 2984, check)
      call createCurrent(P_ZQ, P_A, P_ghWpAnti, P_ghWp, 4058, check)
      call createCurrent(P_GPlus, P_ghA, P_ghAAnti, P_GMinus, 2704, check)
      call createCurrent(P_ghWmAnti, P_Z, P_Z, P_ghWm, 4901, check)
      call createCurrent(P_WQMinus, P_ghWmAnti, P_WMinus, P_ghWp, 4748, check)
      call createCurrent(P_WPlus, P_ghAAnti, P_WMinus, P_ghA, 2107, check)
      call createCurrent(P_uAnti, P_GPlus, P_d, 1903, check)
      call createCurrent(P_A, P_WMinus, P_Hl, P_GPlus, 2699, check)
      call createCurrent(P_GPlus, P_G0, P_ghWm, P_ghZAnti, 4271, check)
      call createCurrent(P_ghWm, P_Z, P_ghZAnti, P_WPlus, 2834, check)
      call createCurrent(P_s, P_sAnti, P_Hl, 3285, check)
      call createCurrent(P_ghWmAnti, P_ghWm, P_Hl, P_HlQ, 1629, check)
      call createCurrent(P_ghWm, P_ghWmAnti, P_ZQ, 4687, check)
      call createCurrent(P_ghAAnti, P_GPlus, P_ghWm, P_Hl, 3715, check)
      call createCurrent(P_GQMinus, P_ghWp, P_Hl, P_ghZAnti, 2430, check)
      call createCurrent(P_Hh, P_Hh, P_A, P_Z, 5043, check)
      call createCurrent(P_GQMinus, P_WMinus, P_GPlus, P_WQPlus, 1030, check)
      call createCurrent(P_GMinus, P_Hl, P_Z, P_WPlus, 753, check)
      call createCurrent(P_ghWpAnti, P_ghA, P_WPlus, 2225, check)
      call createCurrent(P_WMinus, P_ghWmAnti, P_ghZ, P_Z, 273, check)
      call createCurrent(P_HlQ, P_WPlus, P_WMinus, P_HhQ, 130, check)
      call createCurrent(P_ghWm, P_WMinus, P_WPlus, P_ghWmAnti, 816, check)
      call createCurrent(P_A, P_Hh, P_Z, P_Hh, 5077, check)
      call createCurrent(P_Hh, P_tAnti, P_t, 2880, check)
      call createCurrent(P_ghAAnti, P_ghZ, P_GMinus, P_GQPlus, 4362, check)
      call createCurrent(P_GMinus, P_ghWmAnti, P_G0, P_ghZ, 455, check)
      call createCurrent(P_G0, P_Hh, P_Z, 3751, check)
      call createCurrent(P_Hl, P_s, P_sAnti, 3643, check)
      call createCurrent(P_GPlus, P_GMinus, P_ghZAnti, P_ghA, 1709, check)
      call createCurrent(P_GPlus, P_A, P_GMinus, 3190, check)
      call createCurrent(P_ghZAnti, P_WMinus, P_ghWp, P_ZQ, 4560, check)
      call createCurrent(P_GQMinus, P_nu_e, P_ePlus, 2597, check)
      call createCurrent(P_ghWp, P_ghAAnti, P_A, P_WMinus, 1271, check)
      call createCurrent(P_ghZ, P_ghZAnti, P_GPlus, P_GMinus, 1484, check)
      call createCurrent(P_u, P_dAnti, P_GMinus, 3867, check)
      call createCurrent(P_HlQ, P_Hh, P_ghZ, P_ghZAnti, 3141, check)
      call createCurrent(P_HhQ, P_Hh, P_WPlus, P_WQMinus, 3309, check)
      call createCurrent(P_HhQ, P_ghZ, P_Hh, P_ghZAnti, 4593, check)
      call createCurrent(P_Hh, P_A, P_Z, P_Hl, 5103, check)
      call createCurrent(P_t, P_Hh, P_tAnti, 127, check)
      call createCurrent(P_nu_e, P_ePlus, P_WMinus, 156, check)
      call createCurrent(P_Hh, P_ghWp, P_ghWpAnti, P_Hh, 1943, check)
      call createCurrent(P_ghZ, P_ghWpAnti, P_GQPlus, 4611, check)
      call createCurrent(P_ghWm, P_Z, P_ghWmAnti, P_A, 492, check)
      call createCurrent(P_ghZ, P_ghWmAnti, P_GMinus, P_GQ0, 2553, check)
      call createCurrent(P_WQMinus, P_A, P_A, P_WQPlus, 4166, check)
      call createCurrent(P_WPlus, P_ghZAnti, P_ghZ, P_WMinus, 2584, check)
      call createCurrent(P_ghAAnti, P_GMinus, P_GPlus, P_ghZ, 713, check)
      call createCurrent(P_t, P_tAnti, P_ZQ, 4027, check)
      call createCurrent(P_ghWmAnti, P_Z, P_WMinus, P_ghA, 3064, check)
      call createCurrent(P_Hl, P_Hh, P_ghZ, P_ghZAnti, 1981, check)
      call createCurrent(P_WMinus, P_WPlus, P_Hl, P_Hl, 2161, check)
      call createCurrent(P_ghWp, P_GMinus, P_ghAAnti, P_GQ0, 2736, check)
      call createCurrent(P_ghWmAnti, P_ghWp, P_WMinus, P_WMinus, 3945, check)
      call createCurrent(P_A, P_WPlus, P_G0, P_GMinus, 2935, check)
      call createCurrent(P_ghZ, P_GPlus, P_ghZAnti, P_GMinus, 705, check)
      call createCurrent(P_Z, P_A, P_A, P_Z, 5245, check)
      call createCurrent(P_ghZ, P_GPlus, P_ghWpAnti, P_GQ0, 1995, check)
      call createCurrent(P_GQ0, P_G0, P_ghWp, P_ghWpAnti, 1665, check)
      call createCurrent(P_Z, P_ghWmAnti, P_ghWm, P_A, 626, check)
      call createCurrent(P_ghWm, P_ghZAnti, P_GPlus, P_HhQ, 3129, check)
      call createCurrent(P_ghZAnti, P_WMinus, P_ghWp, P_Z, 1046, check)
      call createCurrent(P_G0, P_G0, P_A, P_A, 5240, check)
      call createCurrent(P_HlQ, P_Hl, P_HhQ, 883, check)
      call createCurrent(P_ghZAnti, P_GPlus, P_ghWm, P_Hh, 170, check)
      call createCurrent(P_HlQ, P_ghAAnti, P_GPlus, P_ghWm, 496, check)
      call createCurrent(P_ghZAnti, P_GMinus, P_ghA, P_GPlus, 3519, check)
      call createCurrent(P_WMinus, P_ghA, P_ghWmAnti, P_A, 854, check)
      call createCurrent(P_Hl, P_b, P_bAnti, 3920, check)
      call createCurrent(P_GQ0, P_WMinus, P_G0, P_WQPlus, 4600, check)
      call createCurrent(P_ghZAnti, P_GPlus, P_GMinus, P_ghA, 8, check)
      call createCurrent(P_ghAAnti, P_ghWp, P_WMinus, P_Z, 4442, check)
      call createCurrent(P_WQMinus, P_Z, P_ghWmAnti, P_ghA, 3423, check)
      call createCurrent(P_Hh, P_g, P_g, P_Hl, 5266, check)
      call createCurrent(P_HlQ, P_WPlus, P_G0, P_WQMinus, 866, check)
      call createCurrent(P_tAnti, P_t, 5060, check)
      call createCurrent(P_A, P_A, P_Hh, P_Hl, 5162, check)
      call createCurrent(P_G0, P_G0, P_Hl, P_Hh, 3347, check)
      call createCurrent(P_G0, P_d, P_dAnti, 4320, check)
      call createCurrent(P_bAnti, P_G0, P_b, 3455, check)
      call createCurrent(P_WMinus, P_ghZAnti, P_A, P_ghWp, 2123, check)
      call createCurrent(P_GQ0, P_Hh, P_Hl, P_GQ0, 4146, check)
      call createCurrent(P_GQPlus, P_WMinus, P_A, P_GQ0, 4318, check)
      call createCurrent(P_GQ0, P_ghWp, P_Hh, P_ghWpAnti, 1999, check)
      call createCurrent(P_HlQ, P_ghWm, P_GPlus, P_ghZAnti, 1860, check)
      call createCurrent(P_dAnti, P_u, P_GQMinus, 1694, check)
      call createCurrent(P_ghWpAnti, P_G0, P_ghA, P_GPlus, 4389, check)
      call createCurrent(P_G0, P_G0, P_Hh, P_Hh, 2805, check)
      call createCurrent(P_ghA, P_Z, P_WPlus, P_ghWpAnti, 1349, check)
      call createCurrent(P_HhQ, P_Hh, P_GPlus, P_GQMinus, 910, check)
      call createCurrent(P_u, P_uAnti, P_A, 2581, check)
      call createCurrent(P_ghA, P_ghZAnti, P_GPlus, P_GMinus, 3941, check)
      call createCurrent(P_AQ, P_d, P_dAnti, 4897, check)
      call createCurrent(P_ghWp, P_ghAAnti, P_Z, P_WMinus, 3517, check)
      call createCurrent(P_HlQ, P_cAnti, P_c, 344, check)
      call createCurrent(P_Z, P_WMinus, P_ghAAnti, P_ghWp, 4881, check)
      call createCurrent(P_HlQ, P_ghWp, P_GMinus, P_ghZAnti, 2588, check)
      call createCurrent(P_ghWm, P_ghZAnti, P_Hh, P_GQPlus, 1454, check)
      call createCurrent(P_A, P_Hh, P_G0, 5037, check)
      call createCurrent(P_HlQ, P_GPlus, P_GMinus, P_HhQ, 1440, check)
      call createCurrent(P_GPlus, P_ghA, P_GMinus, P_ghAAnti, 3935, check)
      call createCurrent(P_ghWp, P_ghZAnti, P_GMinus, P_HlQ, 3544, check)
      call createCurrent(P_bAnti, P_Z, P_b, 1004, check)
      call createCurrent(P_G0, P_A, P_Hh, 5012, check)
      call createCurrent(P_WQMinus, P_WPlus, P_ghA, P_ghZAnti, 3921, check)
      call createCurrent(P_GQMinus, P_Z, P_WQPlus, 4959, check)
      call createCurrent(P_Z, P_GMinus, P_Hh, P_WPlus, 2339, check)
      call createCurrent(P_Hh, P_Hh, P_G0, P_G0, 188, check)
      call createCurrent(P_WQPlus, P_Z, P_Z, P_WQMinus, 3501, check)
      call createCurrent(P_G0, P_tauPlus, P_tauMinus, 4339, check)
      call createCurrent(P_GQ0, P_Hl, P_ghWmAnti, P_ghWm, 4939, check)
      call createCurrent(P_GQMinus, P_GPlus, P_A, P_ZQ, 2425, check)
      call createCurrent(P_ghWmAnti, P_Hh, P_ghWm, P_Hh, 1104, check)
      call createCurrent(P_d, P_dAnti, P_A, 252, check)
      call createCurrent(P_ghWm, P_GMinus, P_ghWmAnti, P_GQPlus, 1475, check)
      call createCurrent(P_ghZ, P_G0, P_GPlus, P_ghWpAnti, 2172, check)
      call createCurrent(P_WMinus, P_Z, P_Hl, P_GPlus, 1868, check)
      call createCurrent(P_Hh, P_ghWpAnti, P_ghZ, P_GPlus, 3268, check)
      call createCurrent(P_G0, P_G0, P_Hl, 4899, check)
      call createCurrent(P_GMinus, P_ghAAnti, P_Hh, P_ghWp, 1978, check)
      call createCurrent(P_ghG, P_ghGAnti, P_gQ, 2734, check)
      call createCurrent(P_ghWmAnti, P_Hh, P_ghWm, P_GQ0, 4884, check)
      call createCurrent(P_WPlus, P_ghAAnti, P_ghWm, P_A, 4008, check)
      call createCurrent(P_AQ, P_Hh, P_WPlus, P_GQMinus, 3365, check)
      call createCurrent(P_tAnti, P_t, P_HhQ, 4484, check)
      call createCurrent(P_u, P_uAnti, P_HlQ, 4402, check)
      call createCurrent(P_GQMinus, P_GPlus, P_Z, P_AQ, 2951, check)
      call createCurrent(P_Hh, P_ghWpAnti, P_Hl, P_ghWp, 4714, check)
      call createCurrent(P_WQMinus, P_A, P_WQPlus, 3991, check)
      call createCurrent(P_AQ, P_Z, P_GMinus, P_GQPlus, 1285, check)
      call createCurrent(P_WPlus, P_WMinus, P_WMinus, P_WPlus, 3438, check)
      call createCurrent(P_Hl, P_A, P_G0, 4997, check)
      call createCurrent(P_Hl, P_ghA, P_GMinus, P_ghWmAnti, 1437, check)
      call createCurrent(P_A, P_ghWm, P_WPlus, P_ghAAnti, 3936, check)
      call createCurrent(P_WQPlus, P_GMinus, P_HlQ, 1959, check)
      call createCurrent(P_g, P_g, P_g, P_Z, 5187, check)
      call createCurrent(P_GQMinus, P_G0, P_GPlus, P_GQ0, 952, check)
      call createCurrent(P_Z, P_G0, P_Hl, 2902, check)
      call createCurrent(P_HlQ, P_GMinus, P_A, P_WQPlus, 2512, check)
      call createCurrent(P_ghA, P_Hh, P_ghWpAnti, P_GPlus, 1038, check)
      call createCurrent(P_GQMinus, P_ghWmAnti, P_Hl, P_ghA, 4080, check)
      call createCurrent(P_WPlus, P_ghZ, P_ghAAnti, P_WMinus, 4091, check)
      call createCurrent(P_HlQ, P_WMinus, P_WPlus, P_HhQ, 1988, check)
      call createCurrent(P_GQ0, P_ghZAnti, P_G0, P_ghZ, 1751, check)
      call createCurrent(P_GQPlus, P_Hh, P_GMinus, P_HlQ, 538, check)
      call createCurrent(P_ghWp, P_ghWpAnti, P_GMinus, P_GPlus, 4696, check)
      call createCurrent(P_WPlus, P_WMinus, 5023, check)
      call createCurrent(P_ghAAnti, P_WPlus, P_WMinus, P_ghA, 3892, check)
      call createCurrent(P_Hl, P_A, P_GMinus, P_WPlus, 2668, check)
      call createCurrent(P_WMinus, P_ghWmAnti, P_WPlus, P_ghWm, 3494, check)
      call createCurrent(P_GQMinus, P_Hh, P_ghWmAnti, P_ghZ, 2607, check)
      call createCurrent(P_ghWp, P_GMinus, P_ghZAnti, P_HhQ, 3566, check)
      call createCurrent(P_eMinus, P_Hl, P_ePlus, 361, check)
      call createCurrent(P_Z, P_nu_tauAnti, P_nu_tau, 2896, check)
      call createCurrent(P_tauPlus, P_GMinus, P_nu_tau, 4123, check)
      call createCurrent(P_g, P_GPlus, P_GMinus, P_g, 5175, check)
      call createCurrent(P_nu_e, P_A, P_nu_eAnti, 5097, check)
      call createCurrent(P_Z, P_ghWp, P_A, P_ghWpAnti, 1772, check)
      call createCurrent(P_HhQ, P_Hh, P_G0, P_GQ0, 3986, check)
      call createCurrent(P_HhQ, P_Hl, P_ghWp, P_ghWpAnti, 2042, check)
      call createCurrent(P_ghZAnti, P_WPlus, P_A, P_ghWm, 1804, check)
      call createCurrent(P_GMinus, P_ghZAnti, P_GPlus, P_ghZ, 322, check)
      call createCurrent(P_muPlus, P_muMinus, P_A, 4533, check)
      call createCurrent(P_c, P_cAnti, 5096, check)
      call createCurrent(P_ZQ, P_GMinus, P_Hh, P_WQPlus, 4702, check)
      call createCurrent(P_muPlus, P_Hh, P_muMinus, 1678, check)
      call createCurrent(P_ghWpAnti, P_G0, P_GPlus, P_ghA, 1358, check)
      call createCurrent(P_A, P_A, P_GMinus, P_GPlus, 775, check)
      call createCurrent(P_Hl, P_A, P_Hh, P_A, 5208, check)
      call createCurrent(P_ghWmAnti, P_Hh, P_ghWm, P_Hl, 2236, check)
      call createCurrent(P_ghWmAnti, P_ghA, P_A, P_WMinus, 4218, check)
      call createCurrent(P_ghWpAnti, P_ghWp, P_Hh, P_HhQ, 2852, check)
      call createCurrent(P_ghWp, P_G0, P_ghWpAnti, P_HhQ, 4139, check)
      call createCurrent(P_HhQ, P_Z, P_Hl, P_ZQ, 2854, check)
      call createCurrent(P_Hl, P_ghZ, P_ghZAnti, P_Hl, 2721, check)
      call createCurrent(P_muPlus, P_A, P_muMinus, 3224, check)
      call createCurrent(P_WMinus, P_A, P_G0, P_GPlus, 4077, check)
      call createCurrent(P_tauMinus, P_tauPlus, 5040, check)
      call createCurrent(P_G0, P_GMinus, P_WPlus, P_A, 2779, check)
      call createCurrent(P_GPlus, P_A, P_A, P_GMinus, 3023, check)
      call createCurrent(P_ghZAnti, P_GPlus, P_ghWm, P_GQ0, 2681, check)
      call createCurrent(P_ghWm, P_G0, P_G0, P_ghWmAnti, 4940, check)
      call createCurrent(P_eMinus, P_GPlus, P_nu_eAnti, 735, check)
      call createCurrent(P_GMinus, P_ghA, P_ghWmAnti, P_G0, 208, check)
      call createCurrent(P_HhQ, P_GPlus, P_ghWm, P_ghAAnti, 1173, check)
      call createCurrent(P_WPlus, P_Z, P_A, P_WMinus, 473, check)
      call createCurrent(P_AQ, P_WMinus, P_G0, P_GQPlus, 3563, check)
      call createCurrent(P_A, P_ghWm, P_A, P_ghWmAnti, 3972, check)
      call createCurrent(P_d, P_uAnti, P_WQPlus, 2882, check)
      call createCurrent(P_ghA, P_GMinus, P_ghAAnti, P_GQPlus, 1508, check)
      call createCurrent(P_ghWm, P_GMinus, P_ghWmAnti, P_GPlus, 1844, check)
      call createCurrent(P_GQ0, P_GPlus, P_WQMinus, 2414, check)
      call createCurrent(P_d, P_G0, P_dAnti, 140, check)
      call createCurrent(P_HlQ, P_d, P_dAnti, 4489, check)
      call createCurrent(P_GMinus, P_ghA, P_GPlus, P_ghZAnti, 532, check)
      call createCurrent(P_s, P_WPlus, P_cAnti, 45, check)
      call createCurrent(P_WQPlus, P_WMinus, P_Hl, P_HlQ, 3796, check)
      call createCurrent(P_GMinus, P_ghWp, P_ghAAnti, 2004, check)
      call createCurrent(P_t, P_tAnti, P_AQ, 4717, check)
      call createCurrent(P_ghWp, P_ghAAnti, P_Hl, P_GMinus, 918, check)
      call createCurrent(P_WQMinus, P_Hh, P_Z, P_GQPlus, 890, check)
      call createCurrent(P_WPlus, P_G0, P_G0, P_WMinus, 954, check)
      call createCurrent(P_ghWm, P_A, P_Z, P_ghWmAnti, 2135, check)
      call createCurrent(P_ghWm, P_ghAAnti, P_GPlus, P_Hh, 3602, check)
      call createCurrent(P_GPlus, P_GMinus, P_GMinus, P_GPlus, 4307, check)
      call createCurrent(P_GQPlus, P_ghZ, P_Hl, P_ghWpAnti, 733, check)
      call createCurrent(P_Hh, P_GMinus, P_ghA, P_ghWmAnti, 3126, check)
      call createCurrent(P_GMinus, P_ghZAnti, P_ghWp, P_Hl, 2846, check)
      call createCurrent(P_ghWm, P_ghAAnti, P_WPlus, P_A, 1076, check)
      call createCurrent(P_ghWmAnti, P_A, P_ghZ, P_WQMinus, 4034, check)
      call createCurrent(P_ghWp, P_G0, P_ghWpAnti, P_G0, 327, check)
      call createCurrent(P_ZQ, P_A, P_WPlus, P_WQMinus, 4628, check)
      call createCurrent(P_ghA, P_GPlus, P_Hl, P_ghWpAnti, 4069, check)
      call createCurrent(P_G0, P_ghWpAnti, P_ghA, P_GPlus, 3364, check)
      call createCurrent(P_g, P_WMinus, P_g, P_WPlus, 5213, check)
      call createCurrent(P_HlQ, P_WMinus, P_GPlus, P_ZQ, 2521, check)
      call createCurrent(P_HlQ, P_G0, P_GMinus, P_GQPlus, 307, check)
      call createCurrent(P_GQ0, P_ePlus, P_eMinus, 3822, check)
      call createCurrent(P_ghZAnti, P_WPlus, P_ghZ, P_WMinus, 3079, check)
      call createCurrent(P_GQ0, P_WPlus, P_G0, P_WQMinus, 4925, check)
      call createCurrent(P_dAnti, P_d, P_Hh, 3900, check)
      call createCurrent(P_ghAAnti, P_WMinus, P_ghWp, P_Z, 3533, check)
      call createCurrent(P_WQMinus, P_Hl, P_GPlus, P_AQ, 511, check)
      call createCurrent(P_GPlus, P_ghAAnti, P_ghWm, P_Hh, 823, check)
      call createCurrent(P_Z, P_Hh, P_Z, 1637, check)
      call createCurrent(P_GPlus, P_Hh, P_ghWpAnti, P_ghA, 2420, check)
      call createCurrent(P_GQMinus, P_ghA, P_ghWmAnti, 2019, check)
      call createCurrent(P_WPlus, P_WMinus, P_ghZAnti, P_ghZ, 1456, check)
      call createCurrent(P_Z, P_A, P_ghWpAnti, P_ghWp, 1887, check)
      call createCurrent(P_sAnti, P_s, P_gQ, 2979, check)
      call createCurrent(P_HhQ, P_ghWpAnti, P_GPlus, P_ghZ, 4616, check)
      call createCurrent(P_AQ, P_Z, P_GPlus, P_GQMinus, 3196, check)
      call createCurrent(P_GQPlus, P_WMinus, P_A, P_HlQ, 2980, check)
      call createCurrent(P_nu_muAnti, P_nu_mu, P_A, 5062, check)
      call createCurrent(P_ghWpAnti, P_A, P_ghWp, 3151, check)
      call createCurrent(P_g, P_g, P_Hh, 5147, check)
      call createCurrent(P_sAnti, P_c, P_WMinus, 3477, check)
      call createCurrent(P_ghWp, P_G0, P_ghZAnti, P_GMinus, 1379, check)
      call createCurrent(P_ghWmAnti, P_ghWm, P_WMinus, P_WQPlus, 758, check)
      call createCurrent(P_GPlus, P_ghZAnti, P_ghWm, P_Hl, 2396, check)
      call createCurrent(P_ghA, P_ghZAnti, P_GMinus, P_GPlus, 1794, check)
      call createCurrent(P_WMinus, P_Z, P_ghWmAnti, P_ghZ, 3462, check)
      call createCurrent(P_Hh, P_Z, P_GPlus, P_WMinus, 1953, check)
      call createCurrent(P_HhQ, P_Hl, P_ghWmAnti, P_ghWm, 2106, check)
      call createCurrent(P_ghA, P_ghWmAnti, P_WMinus, P_A, 4631, check)
      call createCurrent(P_GQMinus, P_G0, P_ghWp, P_ghZAnti, 901, check)
      call createCurrent(P_g, P_g, P_A, P_Z, 5186, check)
      call createCurrent(P_AQ, P_WMinus, P_Hl, P_GQPlus, 3787, check)
      call createCurrent(P_WQPlus, P_b, P_tAnti, 1872, check)
      call createCurrent(P_HlQ, P_GPlus, P_ghWm, P_ghZAnti, 2990, check)
      call createCurrent(P_nu_muAnti, P_nu_mu, 5019, check)
      call createCurrent(P_GPlus, P_g, P_GMinus, P_g, 5150, check)
      call createCurrent(P_ghWpAnti, P_A, P_A, P_ghWp, 2122, check)
      call createCurrent(P_Hh, P_G0, P_Hh, P_G0, 3181, check)
      call createCurrent(P_GPlus, P_ghWmAnti, P_ghWm, P_GMinus, 3115, check)
      call createCurrent(P_ghZ, P_Hl, P_ghZAnti, P_HlQ, 4640, check)
      call createCurrent(P_A, P_Z, P_WMinus, P_WPlus, 2690, check)
      call createCurrent(P_ghA, P_G0, P_GPlus, P_ghWpAnti, 594, check)
      call createCurrent(P_ZQ, P_Z, P_ghWm, P_ghWmAnti, 3263, check)
      call createCurrent(P_ghZ, P_Z, P_ghWpAnti, P_WQPlus, 3737, check)
      call createCurrent(P_G0, P_Hl, P_G0, P_Hl, 3453, check)
      call createCurrent(P_ghWmAnti, P_Hl, P_ghWm, P_Hl, 1774, check)
      call createCurrent(P_ghWpAnti, P_GPlus, P_ghZ, P_G0, 2595, check)
      call createCurrent(P_ghWpAnti, P_Z, P_ghZ, P_WPlus, 1397, check)
      call createCurrent(P_WMinus, P_A, P_ghWp, P_ghZAnti, 1565, check)
      call createCurrent(P_G0, P_ghWmAnti, P_ghZ, P_GMinus, 1543, check)
      call createCurrent(P_ghZAnti, P_GMinus, P_Hl, P_ghWp, 4862, check)
      call createCurrent(P_Z, P_ghWpAnti, P_Z, P_ghWp, 3674, check)
      call createCurrent(P_Hl, P_Hh, P_Z, P_Z, 210, check)
      call createCurrent(P_WMinus, P_ghWm, P_ghWmAnti, P_WPlus, 1471, check)
      call createCurrent(P_ghWm, P_ghZAnti, P_WPlus, P_Z, 2397, check)
      call createCurrent(P_GQMinus, P_WPlus, P_A, P_HlQ, 4313, check)
      call createCurrent(P_A, P_g, P_g, P_A, 5195, check)
      call createCurrent(P_ghWpAnti, P_ghWp, P_GQ0, 4382, check)
      call createCurrent(P_ghWp, P_ghZAnti, P_G0, P_GQMinus, 268, check)
      call createCurrent(P_GQPlus, P_Hh, P_Hl, P_GQMinus, 4906, check)
      call createCurrent(P_A, P_WMinus, P_Z, P_WPlus, 3454, check)
      call createCurrent(P_GQMinus, P_GPlus, P_HlQ, 1141, check)
      call createCurrent(P_HhQ, P_GMinus, P_ghZ, P_ghWmAnti, 3019, check)
      call createCurrent(P_ghA, P_WPlus, P_ghAAnti, P_WQMinus, 1468, check)
      call createCurrent(P_AQ, P_ghWp, P_WMinus, P_ghAAnti, 4499, check)
      call createCurrent(P_ghWm, P_ghZAnti, P_GQPlus, 4258, check)
      call createCurrent(P_GQMinus, P_ePlus, P_nu_e, 2405, check)
      call createCurrent(P_A, P_Hl, P_A, P_Hl, 5227, check)
      call createCurrent(P_g, P_t, P_tAnti, 2021, check)
      call createCurrent(P_G0, P_Z, P_G0, P_Z, 483, check)
      call createCurrent(P_WQPlus, P_Z, P_GQMinus, 4379, check)
      call createCurrent(P_WQMinus, P_Hl, P_WQPlus, 1047, check)
      call createCurrent(P_s, P_sAnti, P_AQ, 4898, check)
      call createCurrent(P_tAnti, P_t, P_ZQ, 1859, check)
      call createCurrent(P_c, P_cAnti, P_HhQ, 2076, check)
      call createCurrent(P_Hl, P_Hl, P_Z, P_A, 5030, check)
      call createCurrent(P_ghWp, P_Hh, P_ghAAnti, P_GMinus, 301, check)
      call createCurrent(P_ghZAnti, P_ghWp, P_GMinus, P_HlQ, 1758, check)
      call createCurrent(P_Hh, P_ghA, P_ghWmAnti, P_GMinus, 1904, check)
      call createCurrent(P_A, P_Z, P_Z, P_A, 5176, check)
      call createCurrent(P_HhQ, P_WMinus, P_GPlus, P_ZQ, 2692, check)
      call createCurrent(P_Hh, P_Hl, P_Hh, P_Hl, 1652, check)
      call createCurrent(P_HhQ, P_d, P_dAnti, 809, check)
      call createCurrent(P_WPlus, P_WMinus, P_Hl, P_Hh, 645, check)
      call createCurrent(P_G0, P_GPlus, P_ghAAnti, P_ghWm, 3136, check)
      call createCurrent(P_GQ0, P_tAnti, P_t, 1464, check)
      call createCurrent(P_ghWpAnti, P_Hl, P_ghA, P_GPlus, 2072, check)
      call createCurrent(P_WMinus, P_Z, P_ghAAnti, P_ghWp, 4393, check)
      call createCurrent(P_WQPlus, P_G0, P_G0, P_WQMinus, 387, check)
      call createCurrent(P_GMinus, P_A, P_WPlus, 412, check)
      call createCurrent(P_GQ0, P_WPlus, P_Z, P_GQMinus, 454, check)
      call createCurrent(P_WPlus, P_GMinus, P_Hh, P_Z, 840, check)
      call createCurrent(P_c, P_cAnti, P_g, 3766, check)
      call createCurrent(P_A, P_G0, P_WPlus, P_GMinus, 520, check)
      call createCurrent(P_nu_e, P_nu_eAnti, P_ZQ, 880, check)
      call createCurrent(P_Hl, P_GMinus, P_ghWmAnti, P_ghA, 4073, check)
      call createCurrent(P_A, P_Hl, P_A, P_Hh, 5228, check)
      call createCurrent(P_ghWpAnti, P_GPlus, P_ghWp, P_GMinus, 4485, check)
      call createCurrent(P_u, P_uAnti, P_Z, 724, check)
      call createCurrent(P_ghWp, P_ghWpAnti, P_A, P_ZQ, 942, check)
      call createCurrent(P_WMinus, P_Hh, P_A, P_GPlus, 2653, check)
      call createCurrent(P_Z, P_ghWm, P_A, P_ghWmAnti, 3754, check)
      call createCurrent(P_ghWpAnti, P_ghZ, P_GPlus, P_HhQ, 3587, check)
      call createCurrent(P_u, P_G0, P_uAnti, 104, check)
      call createCurrent(P_ghZ, P_ghZAnti, P_Hh, P_Hh, 1519, check)
      call createCurrent(P_GQMinus, P_bAnti, P_t, 2082, check)
      call createCurrent(P_GQMinus, P_ghWmAnti, P_ghA, 1463, check)
      call createCurrent(P_WQPlus, P_ghZ, P_WMinus, P_ghAAnti, 4929, check)
      call createCurrent(P_GQPlus, P_GMinus, P_GQ0, 1168, check)
      call createCurrent(P_GQ0, P_ghWm, P_Hh, P_ghWmAnti, 3899, check)
      call createCurrent(P_ghZ, P_WPlus, P_ghWpAnti, P_A, 4051, check)
      call createCurrent(P_HlQ, P_Z, P_Z, P_HhQ, 249, check)
      call createCurrent(P_GQ0, P_ghWmAnti, P_G0, P_ghWm, 1823, check)
      call createCurrent(P_g, P_g, P_GMinus, P_GPlus, 5141, check)
      call createCurrent(P_Hl, P_G0, P_G0, P_Hl, 4150, check)
      call createCurrent(P_GQPlus, P_GMinus, P_Hh, P_HlQ, 4295, check)
      call createCurrent(P_WQPlus, P_ghAAnti, P_WMinus, P_ghZ, 4663, check)
      call createCurrent(P_WQPlus, P_WMinus, P_ghWm, P_ghWmAnti, 979, check)
      call createCurrent(P_ghWmAnti, P_Z, P_ghWm, P_A, 4368, check)
      call createCurrent(P_ghA, P_WMinus, P_A, P_ghWmAnti, 3138, check)
      call createCurrent(P_G0, P_G0, 5115, check)
      call createCurrent(P_g, P_b, P_bAnti, 4158, check)
      call createCurrent(P_GPlus, P_G0, P_ghZ, P_ghWpAnti, 2273, check)
      call createCurrent(P_A, P_b, P_bAnti, 1057, check)
      call createCurrent(P_WMinus, P_ghWp, P_Z, P_ghZAnti, 1625, check)
      call createCurrent(P_GPlus, P_Hl, P_ghZ, P_ghWpAnti, 30, check)
      call createCurrent(P_Hh, P_Hl, P_Hh, 4602, check)
      call createCurrent(P_ghZAnti, P_Hh, P_Hh, P_ghZ, 655, check)
      call createCurrent(P_Hl, P_GMinus, P_Z, P_WPlus, 3442, check)
      call createCurrent(P_WPlus, P_WMinus, P_Z, 2625, check)
      call createCurrent(P_ghWp, P_WMinus, P_Z, P_ghAAnti, 2088, check)
      call createCurrent(P_ghZ, P_ghWmAnti, P_A, P_WMinus, 320, check)
      call createCurrent(P_c, P_cAnti, P_GQ0, 2796, check)
      call createCurrent(P_HlQ, P_WMinus, P_Z, P_GQPlus, 154, check)
      call createCurrent(P_ghZ, P_WPlus, P_ghWpAnti, P_Z, 3245, check)
      call createCurrent(P_WQMinus, P_Z, P_GQPlus, 551, check)
      call createCurrent(P_HhQ, P_GMinus, P_ghWp, P_ghAAnti, 2707, check)
      call createCurrent(P_GMinus, P_ghAAnti, P_ghWp, P_G0, 4859, check)
      call createCurrent(P_Hl, P_ghWmAnti, P_ghA, P_GMinus, 336, check)
      call createCurrent(P_g, P_Z, P_Z, P_g, 5231, check)
      call createCurrent(P_ZQ, P_Z, P_ghWp, P_ghWpAnti, 4214, check)
      call createCurrent(P_HhQ, P_G0, P_ghWp, P_ghWpAnti, 4451, check)
      call createCurrent(P_ghZAnti, P_ghWp, P_GQMinus, 1171, check)
      call createCurrent(P_cAnti, P_A, P_c, 4596, check)
      call createCurrent(P_HhQ, P_Z, P_WPlus, P_GQMinus, 617, check)
      call createCurrent(P_WQPlus, P_GMinus, P_AQ, 2937, check)
      call createCurrent(P_ghA, P_WMinus, P_ghZAnti, P_WQPlus, 4697, check)
      call createCurrent(P_ghWpAnti, P_Z, P_Z, P_ghWp, 1385, check)
      call createCurrent(P_WQPlus, P_ghZ, P_WMinus, P_ghZAnti, 4038, check)
      call createCurrent(P_g, P_Hh, P_g, P_Hh, 5222, check)
      call createCurrent(P_ghWp, P_Hh, P_Hl, P_ghWpAnti, 265, check)
      call createCurrent(P_ghA, P_Hh, P_GMinus, P_ghWmAnti, 2820, check)
      call createCurrent(P_WPlus, P_ghWpAnti, P_WMinus, P_ghWp, 4467, check)
      call createCurrent(P_ghWpAnti, P_A, P_Z, P_ghWp, 187, check)
      call createCurrent(P_ghZAnti, P_ghWm, P_GPlus, P_G0, 440, check)
      call createCurrent(P_WQPlus, P_GMinus, P_HhQ, 3353, check)
      call createCurrent(P_GPlus, P_ghAAnti, P_GMinus, P_ghA, 1655, check)
      call createCurrent(P_HhQ, P_GMinus, P_Hh, P_GQPlus, 392, check)
      call createCurrent(P_Hh, P_ghAAnti, P_ghWp, P_GMinus, 563, check)
      call createCurrent(P_ZQ, P_Hh, P_WMinus, P_GQPlus, 2434, check)
      call createCurrent(P_ghAAnti, P_ghWm, P_GPlus, P_G0, 2948, check)
      call createCurrent(P_ghZ, P_ghZAnti, P_GMinus, P_GPlus, 98, check)
      call createCurrent(P_ghA, P_WPlus, P_ghWpAnti, P_Z, 1857, check)
      call createCurrent(P_ghWpAnti, P_ghWp, P_A, P_Z, 1645, check)
      call createCurrent(P_AQ, P_WMinus, P_Hh, P_GQPlus, 3314, check)
      call createCurrent(P_tauMinus, P_tauPlus, P_Hl, 4321, check)
      call createCurrent(P_ghWpAnti, P_G0, P_ghWp, P_G0, 278, check)
      call createCurrent(P_A, P_GMinus, P_Hh, P_WPlus, 2034, check)
      call createCurrent(P_GQPlus, P_GMinus, P_WPlus, P_WQMinus, 489, check)
      call createCurrent(P_WQMinus, P_GPlus, P_A, P_GQ0, 1811, check)
      call createCurrent(P_GPlus, P_ghWpAnti, P_ghWp, P_GMinus, 1705, check)
      call createCurrent(P_WMinus, P_ghAAnti, P_ghWp, P_A, 4762, check)
      call createCurrent(P_WQMinus, P_GPlus, P_Hl, P_ZQ, 4470, check)
      call createCurrent(P_WQMinus, P_ghA, P_Z, P_ghWmAnti, 2615, check)
      call createCurrent(P_ghWp, P_Hh, P_ghWpAnti, P_HlQ, 4794, check)
      call createCurrent(P_Hl, P_GPlus, P_Hh, P_GMinus, 3814, check)
      call createCurrent(P_GQMinus, P_Hh, P_ghWmAnti, P_ghA, 3433, check)
      call createCurrent(P_u, P_uAnti, P_ZQ, 2561, check)
      call createCurrent(P_ghWm, P_Hl, P_ghWmAnti, P_GQ0, 863, check)
      call createCurrent(P_WQPlus, P_s, P_cAnti, 887, check)
      call createCurrent(P_HhQ, P_G0, P_G0, P_HlQ, 275, check)
      call createCurrent(P_Hh, P_ghWpAnti, P_Hh, P_ghWp, 2840, check)
      call createCurrent(P_ghWm, P_ghWmAnti, P_G0, P_HlQ, 3281, check)
      call createCurrent(P_gQ, P_ghGAnti, P_g, P_ghG, 2052, check)
      call createCurrent(P_WMinus, P_WPlus, P_GPlus, P_GMinus, 528, check)
      call createCurrent(P_GPlus, P_ghWm, P_ghAAnti, P_Hl, 3965, check)
      call createCurrent(P_G0, P_A, P_G0, P_Z, 4984, check)
      call createCurrent(P_GQMinus, P_Z, P_WPlus, P_HhQ, 1167, check)
      call createCurrent(P_AQ, P_muPlus, P_muMinus, 4232, check)
      call createCurrent(P_A, P_Z, P_ghWpAnti, P_ghWp, 4259, check)
      call createCurrent(P_GPlus, P_ghAAnti, P_Hl, P_ghWm, 1583, check)
      call createCurrent(P_ghWm, P_A, P_ghZAnti, P_WPlus, 1377, check)
      call createCurrent(P_WMinus, P_ghAAnti, P_WPlus, P_ghZ, 3078, check)
      call createCurrent(P_ghA, P_ghWmAnti, P_GMinus, P_Hh, 3850, check)
      call createCurrent(P_WQMinus, P_ghA, P_WPlus, P_ghZAnti, 4769, check)
      call createCurrent(P_ghWmAnti, P_ghA, P_Hh, P_GQMinus, 587, check)
      call createCurrent(P_sAnti, P_s, P_G0, 4179, check)
      call createCurrent(P_ghAAnti, P_GPlus, P_ghA, P_GQMinus, 949, check)
      call createCurrent(P_WPlus, P_GMinus, P_A, P_Hh, 3128, check)
      call createCurrent(P_Hh, P_GPlus, P_ghZAnti, P_ghWm, 3218, check)
      call createCurrent(P_ghZ, P_GPlus, P_ghWpAnti, P_G0, 1213, check)
      call createCurrent(P_b, P_Hl, P_bAnti, 3760, check)
      call createCurrent(P_ghWpAnti, P_ghZ, P_G0, P_GQPlus, 2079, check)
      call createCurrent(P_HhQ, P_ghWp, P_G0, P_ghWpAnti, 714, check)
      call createCurrent(P_AQ, P_Z, P_ghWp, P_ghWpAnti, 997, check)
      call createCurrent(P_ghAAnti, P_ghWm, P_GPlus, P_Hl, 3313, check)
      call createCurrent(P_Hl, P_ghWm, P_Hh, P_ghWmAnti, 3535, check)
      call createCurrent(P_Z, P_Hh, P_Hh, P_A, 4986, check)
      call createCurrent(P_ghGAnti, P_ghG, P_gQ, 1254, check)
      call createCurrent(P_WQMinus, P_t, P_bAnti, 207, check)
      call createCurrent(P_ghA, P_GMinus, P_Hh, P_ghWmAnti, 1636, check)
      call createCurrent(P_gQ, P_tAnti, P_t, 3014, check)
      call createCurrent(P_HhQ, P_GPlus, P_WQMinus, 2274, check)
      call createCurrent(P_GMinus, P_Z, P_Hh, P_WPlus, 2609, check)
      call createCurrent(P_AQ, P_u, P_uAnti, 1413, check)
      call createCurrent(P_GQPlus, P_GMinus, P_GMinus, P_GQPlus, 1634, check)
      call createCurrent(P_GMinus, P_GPlus, P_Hl, P_Hh, 542, check)
      call createCurrent(P_Hl, P_GMinus, P_ghAAnti, P_ghWp, 1011, check)
      call createCurrent(P_GPlus, P_ghWpAnti, P_Hl, P_ghZ, 3144, check)
      call createCurrent(P_A, P_G0, P_G0, P_Z, 5061, check)
      call createCurrent(P_WPlus, P_WMinus, P_ghWp, P_ghWpAnti, 616, check)
      call createCurrent(P_G0, P_sAnti, P_s, 465, check)
      call createCurrent(P_AQ, P_ghWm, P_WPlus, P_ghZAnti, 2503, check)
      call createCurrent(P_ghWp, P_ghWpAnti, P_Hh, P_Hh, 399, check)
      call createCurrent(P_ghWpAnti, P_G0, P_ghZ, P_GQPlus, 2916, check)
      call createCurrent(P_G0, P_ghWpAnti, P_GPlus, P_ghA, 2735, check)
      call createCurrent(P_AQ, P_WMinus, P_A, P_WQPlus, 3714, check)
      call createCurrent(P_WQPlus, P_G0, P_GMinus, P_AQ, 2780, check)
      call createCurrent(P_WPlus, P_A, P_Hh, P_GMinus, 2301, check)
      call createCurrent(P_ghWp, P_A, P_ghWpAnti, P_Z, 478, check)
      call createCurrent(P_WQMinus, P_ghA, P_ghWmAnti, 1855, check)
      call createCurrent(P_Z, P_Hl, P_WPlus, P_GMinus, 1146, check)
      call createCurrent(P_ghAAnti, P_ghWp, P_GMinus, P_Hh, 687, check)
      call createCurrent(P_WPlus, P_A, P_WMinus, 2495, check)
      call createCurrent(P_HhQ, P_Z, P_WMinus, P_GQPlus, 862, check)
      call createCurrent(P_eMinus, P_ePlus, P_A, 604, check)
      call createCurrent(P_WQPlus, P_WMinus, P_ghZAnti, P_ghA, 4459, check)
      call createCurrent(P_HhQ, P_WMinus, P_A, P_GQPlus, 3352, check)
      call createCurrent(P_ghZ, P_ghWmAnti, P_Hh, P_GMinus, 1616, check)
      call createCurrent(P_WMinus, P_WPlus, P_GMinus, P_GPlus, 3979, check)
      call createCurrent(P_ZQ, P_nu_eAnti, P_nu_e, 4197, check)
      call createCurrent(P_nu_eAnti, P_nu_e, P_Z, 4329, check)
      call createCurrent(P_G0, P_ghA, P_GMinus, P_ghWmAnti, 3330, check)
      call createCurrent(P_Hl, P_Hh, P_ghWm, P_ghWmAnti, 3655, check)
      call createCurrent(P_GMinus, P_WPlus, P_A, P_G0, 3761, check)
      call createCurrent(P_HlQ, P_WMinus, P_A, P_GQPlus, 623, check)
      call createCurrent(P_HhQ, P_WPlus, P_WQMinus, 4620, check)
      call createCurrent(P_Z, P_WPlus, P_ghWm, P_ghZAnti, 4839, check)
      call createCurrent(P_WQPlus, P_GPlus, P_WMinus, P_GQMinus, 228, check)
      call createCurrent(P_ZQ, P_WPlus, P_A, P_WQMinus, 2062, check)
      call createCurrent(P_ghWp, P_ghZAnti, P_Hh, P_GQMinus, 4623, check)
      call createCurrent(P_GQMinus, P_ghA, P_GPlus, P_ghAAnti, 4341, check)
      call createCurrent(P_ghWp, P_ghWpAnti, P_Hh, P_Hl, 3470, check)
      call createCurrent(P_ghWpAnti, P_ghWp, P_GMinus, P_GPlus, 2121, check)
      call createCurrent(P_A, P_Hl, P_Hh, P_A, 5206, check)
      call createCurrent(P_ghWm, P_GPlus, P_ghAAnti, 3826, check)
      call createCurrent(P_d, P_GPlus, P_uAnti, 1035, check)
      call createCurrent(P_GMinus, P_Hh, P_ghZAnti, P_ghWp, 2116, check)
      call createCurrent(P_GQMinus, P_c, P_sAnti, 2237, check)
      call createCurrent(P_A, P_ghWp, P_WMinus, P_ghAAnti, 1054, check)
      call createCurrent(P_Z, P_GMinus, P_Z, P_GPlus, 3206, check)
      call createCurrent(P_ghWp, P_ghZAnti, P_WMinus, P_AQ, 2873, check)
      call createCurrent(P_GMinus, P_GPlus, P_Z, 4221, check)
      call createCurrent(P_dAnti, P_u, P_WQMinus, 2090, check)
      call createCurrent(P_ZQ, P_ghWmAnti, P_Z, P_ghWm, 1744, check)
      call createCurrent(P_WQPlus, P_A, P_GMinus, P_HlQ, 2324, check)
      call createCurrent(P_ghA, P_GMinus, P_ghWmAnti, P_G0, 3998, check)
      call createCurrent(P_WPlus, P_A, P_GMinus, 1570, check)
      call createCurrent(P_ghWmAnti, P_GPlus, P_GMinus, P_ghWm, 1311, check)
      call createCurrent(P_ghWpAnti, P_A, P_WPlus, P_ghZ, 2369, check)
      call createCurrent(P_Hh, P_A, P_Hh, P_A, 5207, check)
      call createCurrent(P_HlQ, P_WMinus, P_G0, P_WQPlus, 1370, check)
      call createCurrent(P_cAnti, P_WPlus, P_s, 4801, check)
      call createCurrent(P_WMinus, P_WPlus, P_WMinus, P_WPlus, 4607, check)
      call createCurrent(P_uAnti, P_u, P_Hl, 1939, check)
      call createCurrent(P_GPlus, P_WMinus, P_Hh, P_Z, 572, check)
      call createCurrent(P_GPlus, P_G0, P_WMinus, P_Z, 414, check)
      call createCurrent(P_ghZAnti, P_Hl, P_ghZ, P_Hl, 431, check)
      call createCurrent(P_Hh, P_GMinus, P_GPlus, P_Hh, 2807, check)
      call createCurrent(P_ghWm, P_ghZAnti, P_WPlus, 1789, check)
      call createCurrent(P_ghZAnti, P_ghA, P_GMinus, P_GQPlus, 632, check)
      call createCurrent(P_ghAAnti, P_GMinus, P_ghA, P_GQPlus, 1449, check)
      call createCurrent(P_Hh, P_ghZAnti, P_ghZ, P_Hh, 4475, check)
      call createCurrent(P_WQPlus, P_GMinus, P_GQ0, 1452, check)
      call createCurrent(P_ghWp, P_GMinus, P_ghZAnti, P_Hl, 2166, check)
      call createCurrent(P_GPlus, P_GMinus, P_WPlus, P_WMinus, 3257, check)
      call createCurrent(P_WMinus, P_Z, P_ghWp, P_ghZAnti, 4781, check)
      call createCurrent(P_tauPlus, P_tauMinus, P_HlQ, 166, check)
      call createCurrent(P_GQ0, P_ghAAnti, P_GPlus, P_ghWm, 4311, check)
      call createCurrent(P_ghA, P_ghWpAnti, P_A, P_WPlus, 3656, check)
      call createCurrent(P_Hh, P_uAnti, P_u, 2830, check)
      call createCurrent(P_Hl, P_Hh, P_g, P_g, 5252, check)
      call createCurrent(P_HlQ, P_tauPlus, P_tauMinus, 3750, check)
      call createCurrent(P_Z, P_A, 5068, check)
      call createCurrent(P_GPlus, P_ghZAnti, P_GMinus, P_ghA, 222, check)
      call createCurrent(P_GPlus, P_Hl, P_ghA, P_ghWpAnti, 1482, check)
      call createCurrent(P_Z, P_eMinus, P_ePlus, 929, check)
      call createCurrent(P_AQ, P_WMinus, P_WQPlus, 4938, check)
      call createCurrent(P_ghZ, P_ghZAnti, P_WPlus, P_WMinus, 4211, check)
      call createCurrent(P_Z, P_ghWp, P_ghAAnti, P_WMinus, 4491, check)
      call createCurrent(P_nu_tauAnti, P_A, P_nu_tau, 5070, check)
      call createCurrent(P_ghWm, P_Z, P_WPlus, P_ghZAnti, 2867, check)
      call createCurrent(P_ghWpAnti, P_ghWp, P_Hl, P_GQ0, 3091, check)
      call createCurrent(P_cAnti, P_s, P_GQPlus, 3346, check)
      call createCurrent(P_GQPlus, P_ghA, P_Hh, P_ghWpAnti, 663, check)
      call createCurrent(P_WMinus, P_Hh, P_WPlus, P_Hh, 1724, check)
      call createCurrent(P_ghWmAnti, P_ghA, P_Z, P_WQMinus, 3896, check)
      call createCurrent(P_ghWm, P_A, P_ghWmAnti, 3242, check)
      call createCurrent(P_G0, P_GPlus, P_WMinus, P_Z, 449, check)
      call createCurrent(P_ghAAnti, P_GPlus, P_Hl, P_ghWm, 2022, check)
      call createCurrent(P_WQMinus, P_GPlus, P_AQ, 2346, check)
      call createCurrent(P_Z, P_WPlus, P_G0, P_GMinus, 1657, check)
      call createCurrent(P_muPlus, P_GMinus, P_nu_mu, 375, check)
      call createCurrent(P_ghA, P_ghAAnti, P_WPlus, P_WQMinus, 1432, check)
      call createCurrent(P_ghZ, P_WMinus, P_ghAAnti, P_WPlus, 749, check)
      call createCurrent(P_GPlus, P_Hh, P_WMinus, P_Z, 2706, check)
      call createCurrent(P_ghZAnti, P_ghWp, P_GMinus, 1801, check)
      call createCurrent(P_d, P_uAnti, P_GPlus, 3104, check)
      call createCurrent(P_muMinus, P_muPlus, 4980, check)
      call createCurrent(P_GQ0, P_WMinus, P_Hh, P_WQPlus, 3289, check)
      call createCurrent(P_Hh, P_Hl, P_Hl, P_Hh, 4097, check)
      call createCurrent(P_ghWpAnti, P_Hl, P_GPlus, P_ghZ, 2365, check)
      call createCurrent(P_ghWmAnti, P_GMinus, P_ghA, P_G0, 122, check)
      call createCurrent(P_HlQ, P_Hh, P_ghZAnti, P_ghZ, 3637, check)
      call createCurrent(P_ghA, P_WPlus, P_WMinus, P_ghAAnti, 1145, check)
      call createCurrent(P_GQMinus, P_G0, P_Z, P_WQPlus, 3305, check)
      call createCurrent(P_ghWm, P_ghZAnti, P_A, P_WPlus, 3859, check)
      call createCurrent(P_ghWmAnti, P_Hl, P_Hh, P_ghWm, 2009, check)
      call createCurrent(P_HhQ, P_WMinus, P_GQPlus, 1930, check)
      call createCurrent(P_ZQ, P_nu_e, P_nu_eAnti, 42, check)
      call createCurrent(P_tauMinus, P_tauPlus, P_G0, 3321, check)
      call createCurrent(P_Hh, P_Hh, P_Hl, P_Hl, 9, check)
      call createCurrent(P_WQPlus, P_Z, P_WMinus, P_ZQ, 4854, check)
      call createCurrent(P_Z, P_ghA, P_ghWmAnti, P_WMinus, 4188, check)
      call createCurrent(P_Z, P_WMinus, P_GPlus, P_Hl, 2182, check)
      call createCurrent(P_GMinus, P_WPlus, P_A, 2183, check)
      call createCurrent(P_GMinus, P_A, P_G0, P_WPlus, 2016, check)
      call createCurrent(P_HhQ, P_G0, P_GQ0, 1973, check)
      call createCurrent(P_GPlus, P_Z, P_WMinus, 2924, check)
      call createCurrent(P_ghAAnti, P_ghWp, P_GMinus, P_HhQ, 3105, check)
      call createCurrent(P_ghWm, P_Z, P_A, P_ghWmAnti, 3639, check)
      call createCurrent(P_HhQ, P_GPlus, P_ghWpAnti, P_ghZ, 487, check)
      call createCurrent(P_c, P_Z, P_cAnti, 2545, check)
      call createCurrent(P_tauMinus, P_nu_tauAnti, P_GQPlus, 11, check)
      call createCurrent(P_Hh, P_c, P_cAnti, 4944, check)
      call createCurrent(P_GQMinus, P_ghWpAnti, P_GPlus, P_ghWp, 2969, check)
      call createCurrent(P_G0, P_bAnti, P_b, 4947, check)
      call createCurrent(P_AQ, P_G0, P_WPlus, P_GQMinus, 3320, check)
      call createCurrent(P_ghWp, P_Hh, P_ghWpAnti, P_Hh, 1837, check)
      call createCurrent(P_HlQ, P_ghWmAnti, P_Hh, P_ghWm, 4591, check)
      call createCurrent(P_WPlus, P_ghAAnti, P_ghZ, P_WMinus, 3725, check)
      call createCurrent(P_WQMinus, P_GPlus, P_GQ0, 3465, check)
      call createCurrent(P_Z, P_Z, P_A, P_Z, 5189, check)
      call createCurrent(P_GPlus, P_GMinus, P_ghWm, P_ghWmAnti, 3103, check)
      call createCurrent(P_G0, P_GMinus, P_WPlus, P_Z, 348, check)
      call createCurrent(P_ghAAnti, P_WPlus, P_Z, P_ghWm, 3652, check)
      call createCurrent(P_tauPlus, P_tauMinus, P_Hl, 1651, check)
      call createCurrent(P_GQ0, P_eMinus, P_ePlus, 3788, check)
      call createCurrent(P_t, P_tAnti, P_gQ, 2240, check)
      call createCurrent(P_ghZAnti, P_Hh, P_ghWp, P_GMinus, 1096, check)
      call createCurrent(P_ghAAnti, P_Hh, P_ghWp, P_GMinus, 2913, check)
      call createCurrent(P_Z, P_c, P_cAnti, 3955, check)
      call createCurrent(P_GPlus, P_GMinus, 5102, check)
      call createCurrent(P_ghWm, P_Hh, P_ghZAnti, P_GPlus, 3718, check)
      call createCurrent(P_GQ0, P_Hl, P_ghWm, P_ghWmAnti, 450, check)
      call createCurrent(P_G0, P_G0, P_Hh, 2256, check)
      call createCurrent(P_Hh, P_ghZ, P_ghWpAnti, P_GPlus, 386, check)
      call createCurrent(P_G0, P_ghWmAnti, P_GMinus, P_ghA, 1987, check)
      call createCurrent(P_WQPlus, P_Hh, P_GQMinus, 3012, check)
      call createCurrent(P_G0, P_ghWpAnti, P_ghWp, P_G0, 552, check)
      call createCurrent(P_ghZAnti, P_GPlus, P_GMinus, P_ghZ, 10, check)
      call createCurrent(P_GQMinus, P_Hh, P_GPlus, P_GQ0, 843, check)
      call createCurrent(P_GMinus, P_ghZ, P_GPlus, P_ghZAnti, 3383, check)
      call createCurrent(P_WMinus, P_ghZ, P_ghWmAnti, 602, check)
      call createCurrent(P_HlQ, P_Z, P_WPlus, P_GQMinus, 3264, check)
      call createCurrent(P_WPlus, P_nu_eAnti, P_eMinus, 1321, check)
      call createCurrent(P_WPlus, P_A, P_G0, P_GMinus, 4961, check)
      call createCurrent(P_Hl, P_A, P_WMinus, P_GPlus, 3041, check)
      call createCurrent(P_AQ, P_ghWmAnti, P_Z, P_ghWm, 984, check)
      call createCurrent(P_ghAAnti, P_GMinus, P_ghZ, P_GPlus, 1708, check)
      call createCurrent(P_ghWpAnti, P_ghWp, P_AQ, 3002, check)
      call createCurrent(P_HlQ, P_WPlus, P_A, P_GQMinus, 3310, check)
      call createCurrent(P_Hh, P_GMinus, P_WPlus, 1310, check)
      call createCurrent(P_ghA, P_ghZAnti, P_GPlus, P_GQMinus, 466, check)
      call createCurrent(P_HhQ, P_ghZAnti, P_Hh, P_ghZ, 4032, check)
      call createCurrent(P_G0, P_GMinus, P_ghWp, P_ghZAnti, 1913, check)
      call createCurrent(P_ghWpAnti, P_Hl, P_ghWp, P_HlQ, 4301, check)
      call createCurrent(P_GPlus, P_GMinus, P_ghA, P_ghAAnti, 1699, check)
      call createCurrent(P_GQPlus, P_ghWpAnti, P_G0, P_ghZ, 994, check)
      call createCurrent(P_ghWp, P_Hh, P_ghZAnti, P_GQMinus, 1281, check)
      call createCurrent(P_WPlus, P_ghA, P_ghWpAnti, 1061, check)
      call createCurrent(P_GQMinus, P_Hl, P_GPlus, P_GQ0, 3783, check)
      call createCurrent(P_WMinus, P_WPlus, P_A, P_A, 613, check)
      call createCurrent(P_c, P_cAnti, P_Hh, 2712, check)
      call createCurrent(P_Z, P_WPlus, P_ghAAnti, P_ghWm, 2335, check)
      call createCurrent(P_ghWmAnti, P_GMinus, P_Hl, P_ghZ, 448, check)
      call createCurrent(P_ghZ, P_ghZAnti, P_GMinus, P_GQPlus, 810, check)
      call createCurrent(P_GPlus, P_GMinus, P_g, P_g, 5225, check)
      call createCurrent(P_G0, P_G0, P_Hl, P_Hl, 4350, check)
      call createCurrent(P_u, P_uAnti, P_g, 3731, check)
      call createCurrent(P_A, P_Hl, P_GMinus, P_WPlus, 2863, check)
      call createCurrent(P_Hh, P_ghWmAnti, P_Hl, P_ghWm, 1192, check)
      call createCurrent(P_GPlus, P_ghWpAnti, P_ghA, 2407, check)
      call createCurrent(P_WMinus, P_ghWmAnti, P_ghWm, P_WPlus, 3297, check)
      call createCurrent(P_ePlus, P_nu_e, P_GMinus, 3699, check)
      call createCurrent(P_Z, P_ghWp, P_ghWpAnti, P_A, 1239, check)
      call createCurrent(P_AQ, P_GPlus, P_Hh, P_WQMinus, 3716, check)
      call createCurrent(P_WQMinus, P_GPlus, P_G0, P_ZQ, 2031, check)
      call createCurrent(P_ZQ, P_t, P_tAnti, 373, check)
      call createCurrent(P_ghAAnti, P_WPlus, P_WMinus, P_ghZ, 3870, check)
      call createCurrent(P_ghAAnti, P_Hl, P_GMinus, P_ghWp, 4173, check)
      call createCurrent(P_ghZAnti, P_Hl, P_Hh, P_ghZ, 4775, check)
      call createCurrent(P_GQPlus, P_ghZAnti, P_GMinus, P_ghA, 4958, check)
      call createCurrent(P_ghZAnti, P_WMinus, P_WPlus, P_ghZ, 2204, check)
      call createCurrent(P_Z, P_A, P_Hl, P_Hh, 5100, check)
      call createCurrent(P_HlQ, P_G0, P_ghWm, P_ghWmAnti, 3720, check)
      call createCurrent(P_Hh, P_ghWm, P_GPlus, P_ghAAnti, 4385, check)
      call createCurrent(P_ghWpAnti, P_Z, P_ghWp, P_AQ, 3665, check)
      call createCurrent(P_GQ0, P_WMinus, P_GPlus, P_ZQ, 704, check)
      call createCurrent(P_Hh, P_ghA, P_GMinus, P_ghWmAnti, 2783, check)
      call createCurrent(P_WPlus, P_A, P_Hl, P_GMinus, 239, check)
      call createCurrent(P_ghG, P_ghGAnti, P_g, P_g, 3707, check)
      call createCurrent(P_A, P_G0, P_WMinus, P_GPlus, 436, check)
      call createCurrent(P_GQPlus, P_tauMinus, P_nu_tauAnti, 789, check)
      call createCurrent(P_ghWpAnti, P_Hh, P_Hh, P_ghWp, 731, check)
      call createCurrent(P_WMinus, P_ghWmAnti, P_ghWp, P_WMinus, 482, check)
      call createCurrent(P_GQPlus, P_GMinus, P_ghZAnti, P_ghZ, 1230, check)
      call createCurrent(P_ghWmAnti, P_A, P_ghZ, P_WMinus, 3175, check)
      call createCurrent(P_GQ0, P_ghWp, P_GMinus, P_ghAAnti, 4114, check)
      call createCurrent(P_WQMinus, P_WPlus, P_ghA, P_ghAAnti, 3895, check)
      call createCurrent(P_GPlus, P_G0, P_Z, P_WMinus, 2961, check)
      call createCurrent(P_A, P_g, P_A, P_g, 5254, check)
      call createCurrent(P_Z, P_Hh, P_GPlus, P_WMinus, 2563, check)
      call createCurrent(P_A, P_WPlus, P_Hh, P_GMinus, 756, check)
      call createCurrent(P_WMinus, P_A, P_ghZAnti, P_ghWp, 267, check)
      call createCurrent(P_Hh, P_g, P_g, 5259, check)
      call createCurrent(P_ghWpAnti, P_ghWp, P_Hl, P_Hl, 2469, check)
      call createCurrent(P_ZQ, P_uAnti, P_u, 480, check)
      call createCurrent(P_ghWm, P_ghWmAnti, P_Hh, P_HlQ, 1843, check)
      call createCurrent(P_WMinus, P_Hl, P_WPlus, P_Hh, 1927, check)
      call createCurrent(P_ghWpAnti, P_WPlus, P_WPlus, P_ghWm, 4448, check)
      call createCurrent(P_Hl, P_ghZ, P_Hh, P_ghZAnti, 3152, check)
      call createCurrent(P_WQMinus, P_Z, P_WPlus, P_ZQ, 4449, check)
      call createCurrent(P_GQMinus, P_Hh, P_Hl, P_GQPlus, 2693, check)
      call createCurrent(P_Hh, P_Hl, P_ghWmAnti, P_ghWm, 1262, check)
      call createCurrent(P_WPlus, P_ghZAnti, P_A, P_ghWm, 2197, check)
      call createCurrent(P_nu_tauAnti, P_GPlus, P_tauMinus, 4751, check)
      call createCurrent(P_ghWpAnti, P_GPlus, P_Hl, P_ghZ, 3389, check)
      call createCurrent(P_ZQ, P_A, P_ghWp, P_ghWpAnti, 4374, check)
      call createCurrent(P_ghWpAnti, P_ghZ, P_GPlus, P_HlQ, 3034, check)
      call createCurrent(P_Hl, P_G0, P_G0, 1562, check)
      call createCurrent(P_ePlus, P_eMinus, P_A, 1819, check)
      call createCurrent(P_WQPlus, P_GMinus, P_GPlus, P_WQMinus, 3776, check)
      call createCurrent(P_Z, P_Hl, P_A, 5114, check)
      call createCurrent(P_Z, P_ghZAnti, P_ghWp, P_WMinus, 4083, check)
      call createCurrent(P_WMinus, P_A, P_WPlus, P_A, 2671, check)
      call createCurrent(P_ghZAnti, P_GMinus, P_ghZ, P_GQPlus, 334, check)
      call createCurrent(P_ghZ, P_WMinus, P_ghWmAnti, P_Z, 4093, check)
      call createCurrent(P_GQMinus, P_Hh, P_ghA, P_ghWmAnti, 2973, check)
      call createCurrent(P_cAnti, P_c, 5054, check)
      call createCurrent(P_ghWpAnti, P_ghZ, P_GQPlus, 125, check)
      call createCurrent(P_Hl, P_GMinus, P_GPlus, P_Hl, 680, check)
      call createCurrent(P_A, P_Hl, P_Z, P_Hh, 5000, check)
      call createCurrent(P_ghWpAnti, P_ghA, P_Hh, P_GQPlus, 168, check)
      call createCurrent(P_HhQ, P_dAnti, P_d, 4074, check)
      call createCurrent(P_Hh, P_ghA, P_GPlus, P_ghWpAnti, 1052, check)
      call createCurrent(P_ghWp, P_Hh, P_ghWpAnti, P_Hl, 3476, check)
      call createCurrent(P_GQMinus, P_Hl, P_ghA, P_ghWmAnti, 2634, check)
      call createCurrent(P_Hl, P_GMinus, P_ghWp, P_ghAAnti, 4878, check)
      call createCurrent(P_Hh, P_Hh, P_ghWp, P_ghWpAnti, 3182, check)
      call createCurrent(P_HhQ, P_Hl, P_HlQ, 1980, check)
      call createCurrent(P_ghZAnti, P_ghWm, P_G0, P_GPlus, 1991, check)
      call createCurrent(P_A, P_Hl, P_Z, 5007, check)
      call createCurrent(P_GQMinus, P_G0, P_GPlus, P_HlQ, 3249, check)
      call createCurrent(P_ghWp, P_WMinus, P_ghAAnti, 814, check)
      call createCurrent(P_HhQ, P_GMinus, P_ghWp, P_ghZAnti, 3538, check)
      call createCurrent(P_GQ0, P_Z, P_Z, P_GQ0, 4346, check)
      call createCurrent(P_WQPlus, P_ghA, P_WMinus, P_ghZAnti, 1036, check)
      call createCurrent(P_muMinus, P_nu_muAnti, P_GPlus, 1259, check)
      call createCurrent(P_ZQ, P_ghWmAnti, P_A, P_ghWm, 2332, check)
      call createCurrent(P_ghA, P_ghZAnti, P_WPlus, P_WMinus, 3328, check)
      call createCurrent(P_ZQ, P_tAnti, P_t, 1233, check)
      call createCurrent(P_GQMinus, P_GPlus, P_G0, P_HhQ, 2850, check)
      call createCurrent(P_ghWm, P_Hl, P_ghWmAnti, P_Hl, 173, check)
      call createCurrent(P_WPlus, P_G0, P_GMinus, 4380, check)
      call createCurrent(P_ghWmAnti, P_Hl, P_ghWm, P_GQ0, 783, check)
      call createCurrent(P_WPlus, P_GMinus, P_G0, P_Z, 672, check)
      call createCurrent(P_ghAAnti, P_ghWp, P_Hh, P_GMinus, 2426, check)
      call createCurrent(P_GPlus, P_ghWm, P_ghAAnti, P_Hh, 2864, check)
      call createCurrent(P_Hl, P_Hh, P_Z, P_A, 5038, check)
      call createCurrent(P_t, P_tAnti, P_A, 3903, check)
      call createCurrent(P_Hh, P_ghZ, P_GMinus, P_ghWmAnti, 517, check)
      call createCurrent(P_ghZAnti, P_GPlus, P_ghZ, P_GMinus, 1620, check)
      call createCurrent(P_ghZAnti, P_GMinus, P_ghWp, P_GQ0, 3799, check)
      call createCurrent(P_AQ, P_Hl, P_WPlus, P_GQMinus, 2345, check)
      call createCurrent(P_sAnti, P_s, P_HlQ, 3977, check)
      call createCurrent(P_Hh, P_Z, P_WPlus, P_GMinus, 2238, check)
      call createCurrent(P_ZQ, P_Z, P_Hh, P_HhQ, 2303, check)
      call createCurrent(P_Hl, P_GPlus, P_ghWpAnti, P_ghZ, 2257, check)
      call createCurrent(P_A, P_ghWm, P_Z, P_ghWmAnti, 3283, check)
      call createCurrent(P_GMinus, P_ghWmAnti, P_G0, P_ghA, 1260, check)
      call createCurrent(P_WMinus, P_ghWmAnti, P_ghA, P_A, 2664, check)
      call createCurrent(P_WMinus, P_Z, P_GPlus, P_G0, 255, check)
      call createCurrent(P_Hh, P_WMinus, P_A, P_GPlus, 3229, check)
      call createCurrent(P_ghZ, P_WPlus, P_ghZAnti, P_WMinus, 3562, check)
      call createCurrent(P_GPlus, P_ghWm, P_Hl, P_ghZAnti, 1380, check)
      call createCurrent(P_GMinus, P_G0, P_ghWmAnti, P_ghZ, 4453, check)
      call createCurrent(P_WMinus, P_GPlus, P_A, P_Hh, 165, check)
      call createCurrent(P_GPlus, P_A, P_GMinus, P_A, 1787, check)
      call createCurrent(P_Z, P_G0, P_G0, P_A, 4996, check)
      call createCurrent(P_Z, P_ghWm, P_ghWmAnti, P_Z, 4704, check)
      call createCurrent(P_HhQ, P_ghZAnti, P_GPlus, P_ghWm, 3486, check)
      call createCurrent(P_ghWm, P_ghWpAnti, P_WPlus, P_WPlus, 1107, check)
      call createCurrent(P_WPlus, P_ghWpAnti, P_A, P_ghZ, 4813, check)
      call createCurrent(P_AQ, P_WPlus, P_ghWm, P_ghZAnti, 4711, check)
      call createCurrent(P_WQMinus, P_Z, P_Z, P_WQPlus, 4204, check)
      call createCurrent(P_nu_tauAnti, P_tauMinus, P_GQPlus, 3919, check)
      call createCurrent(P_sAnti, P_s, P_Hh, 510, check)
      call createCurrent(P_HlQ, P_Hl, P_ghWm, P_ghWmAnti, 4256, check)
      call createCurrent(P_GPlus, P_GMinus, P_A, 4921, check)
      call createCurrent(P_A, P_ghWp, P_WMinus, P_ghZAnti, 1635, check)
      call createCurrent(P_HhQ, P_G0, P_GPlus, P_GQMinus, 2124, check)
      call createCurrent(P_GPlus, P_ghZAnti, P_GMinus, P_ghZ, 3527, check)
      call createCurrent(P_WMinus, P_ghWp, P_ghZAnti, P_Z, 4125, check)
      call createCurrent(P_GPlus, P_Z, P_Z, P_GMinus, 3071, check)
      call createCurrent(P_Z, P_WMinus, P_GPlus, P_G0, 3261, check)
      call createCurrent(P_Z, P_ghZ, P_WPlus, P_ghWpAnti, 3240, check)
      call createCurrent(P_t, P_tAnti, P_G0, 2844, check)
      call createCurrent(P_Hl, P_Hl, P_Z, P_Z, 2025, check)
      call createCurrent(P_HhQ, P_ghZ, P_GPlus, P_ghWpAnti, 4171, check)
      call createCurrent(P_WMinus, P_WPlus, P_Z, 1747, check)
      call createCurrent(P_WMinus, P_Z, P_ghZ, P_ghWmAnti, 2104, check)
      call createCurrent(P_G0, P_WPlus, P_Z, P_GMinus, 4288, check)
      call createCurrent(P_GPlus, P_GMinus, P_ghA, P_ghZAnti, 4406, check)
      call createCurrent(P_Hl, P_Hl, P_GMinus, P_GPlus, 1990, check)
      call createCurrent(P_ghWm, P_Hh, P_ghWmAnti, P_HhQ, 2147, check)
      call createCurrent(P_GQ0, P_GMinus, P_ghWp, P_ghZAnti, 788, check)
      call createCurrent(P_G0, P_ghWm, P_ghZAnti, P_GPlus, 110, check)
      call createCurrent(P_ghWmAnti, P_WMinus, P_Z, P_ghZ, 2057, check)
      call createCurrent(P_WQPlus, P_A, P_A, P_WQMinus, 3560, check)
      call createCurrent(P_WQPlus, P_Z, P_GMinus, P_HhQ, 1933, check)
      call createCurrent(P_HlQ, P_Hh, P_Hh, P_HhQ, 1001, check)
      call createCurrent(P_Hh, P_WPlus, P_Z, P_GMinus, 2319, check)
      call createCurrent(P_Hl, P_cAnti, P_c, 4310, check)
      call createCurrent(P_GQPlus, P_uAnti, P_d, 1088, check)
      call createCurrent(P_muMinus, P_Hh, P_muPlus, 2843, check)
      call createCurrent(P_GQ0, P_Hh, P_Hh, P_GQ0, 2100, check)
      call createCurrent(P_t, P_Z, P_tAnti, 3122, check)
      call createCurrent(P_ghWp, P_ghZAnti, P_GMinus, P_GQ0, 3495, check)
      call createCurrent(P_ghWm, P_G0, P_ghWmAnti, P_G0, 729, check)
      call createCurrent(P_gQ, P_sAnti, P_s, 1332, check)
      call createCurrent(P_GMinus, P_dAnti, P_u, 2268, check)
      call createCurrent(P_GMinus, P_GPlus, P_ghWm, P_ghWmAnti, 1985, check)
      call createCurrent(P_WPlus, P_Z, P_ghWpAnti, P_ghZ, 1948, check)
      call createCurrent(P_tauPlus, P_nu_tau, P_WQMinus, 3948, check)
      call createCurrent(P_g, P_Hl, P_g, P_Hl, 5210, check)
      call createCurrent(P_s, P_sAnti, P_HhQ, 1032, check)
      call createCurrent(P_b, P_bAnti, P_HlQ, 1714, check)
      call createCurrent(P_HlQ, P_G0, P_ghWmAnti, P_ghWm, 1119, check)
      call createCurrent(P_WQPlus, P_tAnti, P_b, 1513, check)
      call createCurrent(P_HhQ, P_ghWmAnti, P_GMinus, P_ghZ, 1049, check)
      call createCurrent(P_Hl, P_WMinus, P_WPlus, 2904, check)
      call createCurrent(P_WMinus, P_A, P_ghAAnti, P_ghWp, 1363, check)
      call createCurrent(P_WMinus, P_nu_mu, P_muPlus, 3331, check)
      call createCurrent(P_AQ, P_GMinus, P_Hl, P_WQPlus, 3009, check)
      call createCurrent(P_AQ, P_WPlus, P_ghZAnti, P_ghWm, 4315, check)
      call createCurrent(P_WPlus, P_Z, P_G0, P_GMinus, 2110, check)
      call createCurrent(P_ghWm, P_ghAAnti, P_Hh, P_GPlus, 4671, check)
      call createCurrent(P_c, P_WMinus, P_sAnti, 2413, check)
      call createCurrent(P_A, P_Hl, P_Hh, P_Z, 5088, check)
      call createCurrent(P_b, P_bAnti, P_gQ, 209, check)
      call createCurrent(P_G0, P_eMinus, P_ePlus, 4472, check)
      call createCurrent(P_WQMinus, P_WPlus, P_Hh, P_GQ0, 4138, check)
      call createCurrent(P_GQPlus, P_A, P_WMinus, P_GQ0, 1283, check)
      call createCurrent(P_Hh, P_ghZ, P_Hh, P_ghZAnti, 213, check)
      call createCurrent(P_ghWp, P_Z, P_ghWpAnti, P_A, 4551, check)
      call createCurrent(P_GPlus, P_A, P_WMinus, P_Hh, 3907, check)
      call createCurrent(P_GQPlus, P_ghWm, P_Hl, P_ghZAnti, 3687, check)
      call createCurrent(P_GMinus, P_ghA, P_ghZAnti, P_GPlus, 3040, check)
      call createCurrent(P_GPlus, P_GMinus, P_ghZ, P_ghAAnti, 2538, check)
      call createCurrent(P_ghAAnti, P_GPlus, P_ghA, P_GMinus, 948, check)
      call createCurrent(P_WPlus, P_Hh, P_Hh, P_WMinus, 811, check)
      call createCurrent(P_GMinus, P_ghWp, P_GPlus, P_ghWpAnti, 4960, check)
      call createCurrent(P_bAnti, P_b, P_HlQ, 567, check)
      call createCurrent(P_G0, P_G0, P_ghWmAnti, P_ghWm, 557, check)
      call createCurrent(P_ghWmAnti, P_ghA, P_Hl, P_GMinus, 2669, check)
      call createCurrent(P_ghZAnti, P_GPlus, P_Hh, P_ghWm, 3590, check)
      call createCurrent(P_ghWmAnti, P_WMinus, P_A, P_ghZ, 2232, check)
      call createCurrent(P_ghZAnti, P_Z, P_ghWm, P_WPlus, 1650, check)
      call createCurrent(P_ghA, P_Hl, P_ghWpAnti, P_GPlus, 4666, check)
      call createCurrent(P_Hl, P_ghZ, P_GPlus, P_ghWpAnti, 2533, check)
      call createCurrent(P_u, P_dAnti, P_WMinus, 422, check)
      call createCurrent(P_tAnti, P_GPlus, P_b, 4053, check)
      call createCurrent(P_WMinus, P_Z, P_ghZAnti, P_ghWp, 895, check)
      call createCurrent(P_GPlus, P_ghWmAnti, P_GMinus, P_ghWm, 3307, check)
      call createCurrent(P_ZQ, P_A, P_ghWm, P_ghWmAnti, 246, check)
      call createCurrent(P_Z, P_d, P_dAnti, 4879, check)
      call createCurrent(P_tauMinus, P_tauPlus, P_AQ, 2572, check)
      call createCurrent(P_ghWmAnti, P_WMinus, P_ghA, P_A, 4537, check)
      call createCurrent(P_G0, P_Hl, P_G0, 3806, check)
      call createCurrent(P_ghWmAnti, P_Hl, P_Hl, P_ghWm, 1490, check)
      call createCurrent(P_ghWm, P_ghAAnti, P_Z, P_WPlus, 296, check)
      call createCurrent(P_ghWm, P_ghWmAnti, P_Hl, P_Hl, 4021, check)
      call createCurrent(P_HhQ, P_tauPlus, P_tauMinus, 830, check)
      call createCurrent(P_GQMinus, P_ghZ, P_GPlus, P_ghZAnti, 385, check)
      call createCurrent(P_ghWp, P_ghWmAnti, P_WMinus, P_WQMinus, 1851, check)
      call createCurrent(P_WQPlus, P_GMinus, P_A, P_GQ0, 4868, check)
      call createCurrent(P_ghWpAnti, P_GPlus, P_ghA, P_Hl, 924, check)
      call createCurrent(P_ghZAnti, P_GPlus, P_G0, P_ghWm, 3262, check)
      call createCurrent(P_Hh, P_ghZAnti, P_GPlus, P_ghWm, 4490, check)
      call createCurrent(P_Hh, P_u, P_uAnti, 2111, check)
      call createCurrent(P_GQMinus, P_ghZ, P_Hl, P_ghWmAnti, 1149, check)
      call createCurrent(P_s, P_A, P_sAnti, 3492, check)
      call createCurrent(P_A, P_WPlus, P_GMinus, P_Hl, 1420, check)
      call createCurrent(P_GPlus, P_Hh, P_ghZAnti, P_ghWm, 231, check)
      call createCurrent(P_Z, P_A, P_A, P_A, 5258, check)
      call createCurrent(P_ghAAnti, P_ghWm, P_Hh, P_GPlus, 1653, check)
      call createCurrent(P_nu_eAnti, P_Z, P_nu_e, 3738, check)
      call createCurrent(P_WQPlus, P_WMinus, P_ghAAnti, P_ghA, 86, check)
      call createCurrent(P_G0, P_WMinus, P_Z, P_GPlus, 2727, check)
      call createCurrent(P_A, P_GMinus, P_WPlus, P_Hl, 4962, check)
      call createCurrent(P_Hl, P_A, P_Z, 5080, check)
      call createCurrent(P_ghWmAnti, P_GMinus, P_Hl, P_ghA, 2472, check)
      call createCurrent(P_Hl, P_GMinus, P_Hh, P_GPlus, 3611, check)
      call createCurrent(P_ZQ, P_WPlus, P_Z, P_WQMinus, 2245, check)
      call createCurrent(P_muPlus, P_muMinus, P_G0, 339, check)
      call createCurrent(P_tauPlus, P_nu_tau, P_GQMinus, 4860, check)
      call createCurrent(P_ghZ, P_ghZAnti, P_WMinus, P_WPlus, 2249, check)
      call createCurrent(P_ghA, P_ghWpAnti, P_Hh, P_GPlus, 4823, check)
      call createCurrent(P_ghA, P_ghWpAnti, P_Hh, P_GQPlus, 643, check)
      call createCurrent(P_tauPlus, P_G0, P_tauMinus, 4463, check)
      call createCurrent(P_A, P_WPlus, P_Hl, P_GMinus, 277, check)
      call createCurrent(P_ghA, P_WMinus, P_ghWmAnti, 773, check)
      call createCurrent(P_GMinus, P_GPlus, P_ghZAnti, P_ghZ, 4761, check)
      call createCurrent(P_A, P_Hh, P_Hl, P_A, 5194, check)
      call createCurrent(P_ghZAnti, P_ghA, P_WPlus, P_WQMinus, 4014, check)
      call createCurrent(P_ghWpAnti, P_Hl, P_ghZ, P_GPlus, 3499, check)
      call createCurrent(P_ghZ, P_ghWmAnti, P_GMinus, 4112, check)
      call createCurrent(P_ZQ, P_WPlus, P_ghZAnti, P_ghWm, 1972, check)
      call createCurrent(P_WQPlus, P_A, P_ghWpAnti, P_ghZ, 3627, check)
      call createCurrent(P_A, P_GPlus, P_WMinus, P_Hh, 4036, check)
      call createCurrent(P_A, P_Z, P_A, P_Z, 5146, check)
      call createCurrent(P_HhQ, P_muPlus, P_muMinus, 1589, check)
      call createCurrent(P_ghWp, P_A, P_ghWpAnti, P_ZQ, 906, check)
      call createCurrent(P_ghA, P_ghAAnti, P_WMinus, P_WQPlus, 1033, check)
      call createCurrent(P_WPlus, P_d, P_uAnti, 3755, check)
      call createCurrent(P_ghWp, P_Hl, P_ghWpAnti, P_GQ0, 805, check)
      call createCurrent(P_Z, P_A, P_G0, P_G0, 5013, check)
      call createCurrent(P_GMinus, P_bAnti, P_t, 3025, check)
      call createCurrent(P_A, P_ghAAnti, P_WMinus, P_ghWp, 4322, check)
      call createCurrent(P_Hl, P_A, P_A, 5139, check)
      call createCurrent(P_GPlus, P_Hh, P_ghA, P_ghWpAnti, 4111, check)
      call createCurrent(P_Z, P_ghA, P_WPlus, P_ghWpAnti, 4742, check)
      call createCurrent(P_ghWm, P_ghAAnti, P_WPlus, 2146, check)
      call createCurrent(P_GQMinus, P_Z, P_GPlus, P_AQ, 4853, check)
      call createCurrent(P_HhQ, P_ghWp, P_Hl, P_ghWpAnti, 3915, check)
      call createCurrent(P_ghA, P_GPlus, P_GMinus, P_ghAAnti, 3398, check)
      call createCurrent(P_tauPlus, P_Hl, P_tauMinus, 332, check)
      call createCurrent(P_Hh, P_GPlus, P_WMinus, P_Z, 1639, check)
      call createCurrent(P_muMinus, P_nu_muAnti, P_GQPlus, 1897, check)
      call createCurrent(P_WPlus, P_ghWm, P_ghWmAnti, P_WMinus, 620, check)
      call createCurrent(P_AQ, P_GMinus, P_G0, P_WQPlus, 1382, check)
      call createCurrent(P_ghWm, P_G0, P_ghZAnti, P_GPlus, 4186, check)
      call createCurrent(P_GPlus, P_WMinus, P_Hh, P_A, 3901, check)
      call createCurrent(P_G0, P_g, P_g, P_G0, 5188, check)
      call createCurrent(P_GMinus, P_GPlus, P_ghZ, P_ghZAnti, 2995, check)
      call createCurrent(P_ghZ, P_Hl, P_Hl, P_ghZAnti, 1411, check)
      call createCurrent(P_WQPlus, P_WMinus, P_Hh, P_HhQ, 4713, check)
      call createCurrent(P_Hl, P_ghWm, P_ghWmAnti, P_Hl, 4414, check)
      call createCurrent(P_GMinus, P_Hh, P_Hl, P_GPlus, 1103, check)
      call createCurrent(P_ghWpAnti, P_GMinus, P_ghWp, P_GPlus, 3865, check)
      call createCurrent(P_WPlus, P_G0, P_GMinus, P_Z, 4686, check)
      call createCurrent(P_WMinus, P_ghWp, P_Z, P_ghAAnti, 1010, check)
      call createCurrent(P_Hl, P_A, P_A, P_Hl, 5129, check)
      call createCurrent(P_WQMinus, P_Z, P_GPlus, P_HlQ, 2305, check)
      call createCurrent(P_tauMinus, P_WPlus, P_nu_tauAnti, 846, check)
      call createCurrent(P_A, P_Hl, P_WPlus, P_GMinus, 1588, check)
      call createCurrent(P_nu_mu, P_muPlus, P_GQMinus, 3515, check)
      call createCurrent(P_AQ, P_ePlus, P_eMinus, 2083, check)
      call createCurrent(P_AQ, P_WPlus, P_G0, P_GQMinus, 292, check)
      call createCurrent(P_GPlus, P_ghA, P_ghZAnti, P_GMinus, 2657, check)
      call createCurrent(P_GQPlus, P_Hh, P_GMinus, P_GQ0, 1530, check)
      call createCurrent(P_A, P_GPlus, P_WMinus, P_G0, 1279, check)
      call createCurrent(P_WPlus, P_ghWm, P_ghZAnti, P_A, 298, check)
      call createCurrent(P_ghWpAnti, P_WPlus, P_A, P_ghZ, 1524, check)
      call createCurrent(P_nu_e, P_nu_eAnti, P_Z, 3630, check)
      call createCurrent(P_AQ, P_s, P_sAnti, 2949, check)
      call createCurrent(P_HlQ, P_Hh, P_G0, P_GQ0, 2773, check)
      call createCurrent(P_HlQ, P_ghZAnti, P_Hl, P_ghZ, 3343, check)
      call createCurrent(P_G0, P_ghZ, P_G0, P_ghZAnti, 1442, check)
      call createCurrent(P_ghAAnti, P_ghWp, P_Hl, P_GMinus, 1297, check)
      call createCurrent(P_ghZ, P_Hl, P_GMinus, P_ghWmAnti, 2504, check)
      call createCurrent(P_eMinus, P_ePlus, P_Hl, 743, check)
      call createCurrent(P_ghZAnti, P_Hh, P_GMinus, P_ghWp, 4190, check)
      call createCurrent(P_dAnti, P_d, P_HlQ, 4865, check)
      call createCurrent(P_ghWpAnti, P_Hh, P_ghWp, P_Hh, 1308, check)
      call createCurrent(P_ghWm, P_WPlus, P_ghAAnti, P_A, 4334, check)
      call createCurrent(P_ghA, P_ghAAnti, P_GMinus, P_GPlus, 4674, check)
      call createCurrent(P_ghZ, P_Hh, P_ghWmAnti, P_GMinus, 3452, check)
      call createCurrent(P_ghWmAnti, P_Z, P_A, P_ghWm, 4798, check)
      call createCurrent(P_GQ0, P_WPlus, P_GMinus, P_ZQ, 3267, check)
      call createCurrent(P_ghWmAnti, P_ghWm, P_Hh, P_GQ0, 2208, check)
      call createCurrent(P_WPlus, P_ghZAnti, P_WMinus, P_ghZ, 4915, check)
      call createCurrent(P_A, P_A, P_GPlus, P_GMinus, 873, check)
      call createCurrent(P_ghWp, P_WMinus, P_ghZAnti, P_ZQ, 742, check)
      call createCurrent(P_ghWmAnti, P_WMinus, P_WMinus, P_ghWp, 961, check)
      call createCurrent(P_bAnti, P_b, P_G0, 2683, check)
      call createCurrent(P_G0, P_ghA, P_ghWpAnti, P_GPlus, 2658, check)
      call createCurrent(P_ghAAnti, P_Z, P_WPlus, P_ghWm, 3572, check)
      call createCurrent(P_ghWm, P_ghZAnti, P_G0, P_GPlus, 330, check)
      call createCurrent(P_ghWm, P_ghWmAnti, P_Hl, P_GQ0, 3049, check)
      call createCurrent(P_GQ0, P_GMinus, P_Hl, P_GQPlus, 1466, check)
      call createCurrent(P_Z, P_nu_tau, P_nu_tauAnti, 2998, check)
      call createCurrent(P_GMinus, P_g, P_g, P_GPlus, 5130, check)
      call createCurrent(P_Hl, P_ghWp, P_ghZAnti, P_GMinus, 3785, check)
      call createCurrent(P_Hl, P_ghWp, P_ghAAnti, P_GMinus, 1815, check)
      call createCurrent(P_ghWpAnti, P_GPlus, P_ghZ, 3399, check)
      call createCurrent(P_GPlus, P_GMinus, P_Hh, P_Hl, 1839, check)
      call createCurrent(P_G0, P_G0, P_g, P_g, 5171, check)
      call createCurrent(P_WPlus, P_nu_muAnti, P_muMinus, 772, check)
      call createCurrent(P_muMinus, P_muPlus, P_A, 1784, check)
      call createCurrent(P_bAnti, P_b, P_AQ, 4088, check)
      call createCurrent(P_A, P_WMinus, P_GPlus, P_G0, 3277, check)
      call createCurrent(P_WQPlus, P_G0, P_GMinus, P_ZQ, 3609, check)
      call createCurrent(P_Z, P_WMinus, P_Hl, P_GPlus, 2842, check)
      call createCurrent(P_WQPlus, P_nu_tauAnti, P_tauMinus, 2308, check)
      call createCurrent(P_G0, P_Hh, P_Hl, P_G0, 677, check)
      call createCurrent(P_GQMinus, P_ghWmAnti, P_ghZ, 3362, check)
      call createCurrent(P_WMinus, P_c, P_sAnti, 1029, check)
      call createCurrent(P_WMinus, P_WPlus, P_Hl, P_Hh, 2519, check)
      call createCurrent(P_GQ0, P_ghWmAnti, P_GMinus, P_ghZ, 4873, check)
      call createCurrent(P_GMinus, P_Hl, P_A, P_WPlus, 464, check)
      call createCurrent(P_G0, P_ghWp, P_GMinus, P_ghZAnti, 3217, check)
      call createCurrent(P_A, P_Z, 5099, check)
      call createCurrent(P_ghWmAnti, P_A, P_ghA, P_WMinus, 136, check)
      call createCurrent(P_ghZ, P_ghWmAnti, P_A, P_WQMinus, 4950, check)
      call createCurrent(P_GQ0, P_ghWpAnti, P_Hl, P_ghWp, 2822, check)
      call createCurrent(P_ZQ, P_WMinus, P_GPlus, P_HlQ, 397, check)
      call createCurrent(P_sAnti, P_c, P_GQMinus, 2523, check)
      call createCurrent(P_Hh, P_Hl, P_Z, P_A, 5005, check)
      call createCurrent(P_HlQ, P_GPlus, P_Hh, P_GQMinus, 3811, check)
      call createCurrent(P_Hl, P_WPlus, P_Hl, P_WMinus, 2897, check)
      call createCurrent(P_WPlus, P_Hh, P_WMinus, 4031, check)
      call createCurrent(P_WMinus, P_GPlus, P_A, P_G0, 3168, check)
      call createCurrent(P_ghZAnti, P_GPlus, P_ghWm, P_Hl, 1710, check)
      call createCurrent(P_b, P_bAnti, P_AQ, 2555, check)
      call createCurrent(P_s, P_sAnti, P_Hh, 3797, check)
      call createCurrent(P_ghZ, P_WPlus, P_WMinus, P_ghAAnti, 3198, check)
      call createCurrent(P_G0, P_A, P_WMinus, P_GPlus, 4588, check)
      call createCurrent(P_b, P_bAnti, P_G0, 3860, check)
      call createCurrent(P_ghZ, P_GMinus, P_Hl, P_ghWmAnti, 682, check)
      call createCurrent(P_ghWp, P_ghWpAnti, P_WMinus, P_WPlus, 1366, check)
      call createCurrent(P_A, P_A, P_ghWmAnti, P_ghWm, 1765, check)
      call createCurrent(P_ghWp, P_GMinus, P_ghAAnti, P_G0, 4661, check)
      call createCurrent(P_ghWm, P_ghZAnti, P_G0, P_GQPlus, 1133, check)
      call createCurrent(P_Z, P_ghA, P_WMinus, P_ghWmAnti, 2179, check)
      call createCurrent(P_HhQ, P_sAnti, P_s, 4541, check)
      call createCurrent(P_ghAAnti, P_ghZ, P_GPlus, P_GMinus, 937, check)
      call createCurrent(P_GQMinus, P_ghZAnti, P_ghWp, 1777, check)
      call createCurrent(P_tauPlus, P_A, P_tauMinus, 3743, check)
      call createCurrent(P_GQPlus, P_G0, P_ghA, P_ghWpAnti, 3271, check)
      call createCurrent(P_Z, P_Z, P_GPlus, P_GMinus, 3818, check)
      call createCurrent(P_WMinus, P_Hl, P_Z, P_GPlus, 3429, check)
      call createCurrent(P_ghWm, P_ghAAnti, P_WQPlus, 2210, check)
      call createCurrent(P_GQ0, P_WPlus, P_Hl, P_WQMinus, 799, check)
      call createCurrent(P_Hl, P_G0, P_Hl, P_G0, 2895, check)
      call createCurrent(P_gQ, P_uAnti, P_u, 2869, check)
      call createCurrent(P_bAnti, P_WMinus, P_t, 4208, check)
      call createCurrent(P_GQMinus, P_G0, P_ghWmAnti, P_ghA, 4317, check)
      call createCurrent(P_WMinus, P_GPlus, P_A, 2585, check)
      call createCurrent(P_Hh, P_GMinus, P_A, P_WPlus, 3795, check)
      call createCurrent(P_HhQ, P_GMinus, P_ghWmAnti, P_ghZ, 2115, check)
      call createCurrent(P_nu_tauAnti, P_nu_tau, P_Z, 4445, check)
      call createCurrent(P_Hl, P_ghWp, P_Hh, P_ghWpAnti, 2419, check)
      call createCurrent(P_ZQ, P_WPlus, P_WQMinus, 4720, check)
      call createCurrent(P_WPlus, P_Hl, P_WMinus, 1690, check)
      call createCurrent(P_WPlus, P_A, P_WMinus, P_A, 945, check)
      call createCurrent(P_ghWmAnti, P_ghWm, P_G0, P_GQ0, 4473, check)
      call createCurrent(P_dAnti, P_Hl, P_d, 4726, check)
      call createCurrent(P_GPlus, P_ghZ, P_ghWpAnti, P_Hl, 2013, check)
      call createCurrent(P_A, P_GPlus, P_WMinus, 1353, check)
      call createCurrent(P_ghWm, P_WPlus, P_ghAAnti, 3732, check)
      call createCurrent(P_G0, P_ghZAnti, P_GPlus, P_ghWm, 3084, check)
      call createCurrent(P_GQ0, P_c, P_cAnti, 764, check)
      call createCurrent(P_ghWmAnti, P_Hh, P_ghWm, P_HhQ, 3974, check)
      call createCurrent(P_Hh, P_GMinus, P_GPlus, 2130, check)
      call createCurrent(P_A, P_ghZAnti, P_WPlus, P_ghWm, 1632, check)
      call createCurrent(P_HhQ, P_Hh, P_WMinus, P_WQPlus, 200, check)
      call createCurrent(P_GQPlus, P_GMinus, P_Z, P_AQ, 1501, check)
      call createCurrent(P_ghAAnti, P_GMinus, P_ghZ, P_GQPlus, 2488, check)
      call createCurrent(P_ghGAnti, P_g, P_ghG, 595, check)
      call createCurrent(P_ghA, P_GPlus, P_G0, P_ghWpAnti, 3556, check)
      call createCurrent(P_HlQ, P_GMinus, P_WPlus, P_ZQ, 3721, check)
      call createCurrent(P_s, P_cAnti, P_WPlus, 1406, check)
      call createCurrent(P_Hl, P_WPlus, P_Z, P_GMinus, 3978, check)
      call createCurrent(P_tauPlus, P_tauMinus, P_HhQ, 4225, check)
      call createCurrent(P_A, P_GMinus, P_WPlus, P_G0, 779, check)
      call createCurrent(P_GPlus, P_ghWp, P_ghWpAnti, P_GMinus, 3227, check)
      call createCurrent(P_ghWp, P_Hl, P_ghWpAnti, P_HlQ, 3723, check)
      call createCurrent(P_ZQ, P_eMinus, P_ePlus, 2947, check)
      call createCurrent(P_GMinus, P_ghZ, P_GPlus, P_ghAAnti, 2558, check)
      call createCurrent(P_u, P_uAnti, P_AQ, 3469, check)
      call createCurrent(P_A, P_WMinus, P_WPlus, 3662, check)
      call createCurrent(P_HhQ, P_WPlus, P_G0, P_WQMinus, 4506, check)
      call createCurrent(P_Hh, P_Hl, P_Hl, P_Hl, 2753, check)
      call createCurrent(P_ghWm, P_WPlus, P_ghWmAnti, P_WMinus, 2925, check)
      call createCurrent(P_WMinus, P_Hl, P_WPlus, 1917, check)
      call createCurrent(P_ghA, P_ghWpAnti, P_G0, P_GQPlus, 2621, check)
      call createCurrent(P_Z, P_WMinus, P_ghA, P_ghWmAnti, 4693, check)
      call createCurrent(P_ghWmAnti, P_Hl, P_ghA, P_GMinus, 1842, check)
      call createCurrent(P_Hh, P_G0, P_G0, P_Hl, 4272, check)
      call createCurrent(P_WQMinus, P_G0, P_Z, P_GQPlus, 2003, check)
      call createCurrent(P_Z, P_Z, P_WPlus, P_WMinus, 126, check)
      call createCurrent(P_Hl, P_Z, P_WMinus, P_GPlus, 2790, check)
      call createCurrent(P_ghWp, P_ghZAnti, P_GQMinus, 3296, check)
      call createCurrent(P_Hh, P_ghZAnti, P_GMinus, P_ghWp, 4517, check)
      call createCurrent(P_WPlus, P_b, P_tAnti, 1245, check)
      call createCurrent(P_A, P_GMinus, P_GPlus, P_A, 807, check)
      call createCurrent(P_Hl, P_bAnti, P_b, 1, check)
      call createCurrent(P_WQMinus, P_ghWp, P_ghAAnti, 523, check)
      call createCurrent(P_ghA, P_GPlus, P_ghWpAnti, 2576, check)
      call createCurrent(P_GQMinus, P_sAnti, P_c, 3768, check)
      call createCurrent(P_HhQ, P_Z, P_GQ0, 1269, check)
      call createCurrent(P_ghWm, P_GPlus, P_ghZAnti, P_GQ0, 1752, check)
      call createCurrent(P_WPlus, P_WMinus, P_Hh, 4422, check)
      call createCurrent(P_WPlus, P_ghWm, P_ghZAnti, 3982, check)
      call createCurrent(P_GPlus, P_ghAAnti, P_GMinus, P_ghZ, 605, check)
      call createCurrent(P_GQMinus, P_GPlus, P_HhQ, 2297, check)
      call createCurrent(P_G0, P_Z, 5110, check)
      call createCurrent(P_WQPlus, P_Z, P_ghA, P_ghWpAnti, 1919, check)
      call createCurrent(P_WMinus, P_ghWmAnti, P_A, P_ghA, 1964, check)
      call createCurrent(P_d, P_Hl, P_dAnti, 2194, check)
      call createCurrent(P_GQPlus, P_WMinus, P_Z, P_GQ0, 3513, check)
      call createCurrent(P_nu_muAnti, P_A, P_nu_mu, 5078, check)
      call createCurrent(P_ghZ, P_ghZAnti, P_HlQ, 1147, check)
      call createCurrent(P_Hh, P_A, P_Hl, P_A, 5192, check)
      call createCurrent(P_GQ0, P_GMinus, P_ghAAnti, P_ghWp, 1292, check)
      call createCurrent(P_GQMinus, P_Hl, P_WQPlus, 2700, check)
      call createCurrent(P_Hh, P_ghWpAnti, P_ghWp, P_Hh, 3471, check)
      call createCurrent(P_HhQ, P_Hl, P_G0, P_GQ0, 2486, check)
      call createCurrent(P_Hl, P_ghZ, P_ghZAnti, P_Hh, 4165, check)
      call createCurrent(P_WMinus, P_Z, P_A, P_WPlus, 1516, check)
      call createCurrent(P_ghZ, P_GMinus, P_ghWmAnti, P_HhQ, 4914, check)
      call createCurrent(P_ghWp, P_ghWpAnti, P_Hl, P_Hl, 4643, check)
      call createCurrent(P_GMinus, P_ghZAnti, P_Hh, P_ghWp, 1223, check)
      call createCurrent(P_Hh, P_GPlus, P_ghWpAnti, P_ghA, 141, check)
      call createCurrent(P_Hh, P_ghZ, P_ghWmAnti, P_GMinus, 3073, check)
      call createCurrent(P_ghWp, P_ghWpAnti, P_Z, P_AQ, 4066, check)
      call createCurrent(P_ghZAnti, P_ghA, P_WPlus, P_WMinus, 2242, check)
      call createCurrent(P_GMinus, P_muPlus, P_nu_mu, 4365, check)
      call createCurrent(P_Hl, P_GPlus, P_GMinus, 1417, check)
      call createCurrent(P_WQPlus, P_WMinus, P_WMinus, P_WQPlus, 3904, check)
      call createCurrent(P_WQMinus, P_G0, P_WPlus, P_GQ0, 1824, check)
      call createCurrent(P_HlQ, P_dAnti, P_d, 261, check)
      call createCurrent(P_ghZ, P_Hh, P_GMinus, P_ghWmAnti, 2340, check)
      call createCurrent(P_GMinus, P_Z, P_Hl, P_WPlus, 1256, check)
      call createCurrent(P_nu_mu, P_A, P_nu_muAnti, 5018, check)
      call createCurrent(P_A, P_WPlus, P_WMinus, P_A, 3586, check)
      call createCurrent(P_Hl, P_Hl, P_Hh, P_Hh, 462, check)
      call createCurrent(P_HlQ, P_b, P_bAnti, 1130, check)
      call createCurrent(P_ghZAnti, P_ghWm, P_WPlus, P_AQ, 2465, check)
      call createCurrent(P_ghWm, P_ghWmAnti, P_Z, P_ZQ, 160, check)
      call createCurrent(P_muPlus, P_muMinus, P_ZQ, 4803, check)
      call createCurrent(P_WPlus, P_ghZAnti, P_ghA, P_WMinus, 787, check)
      call createCurrent(P_G0, P_ghAAnti, P_GPlus, P_ghWm, 1334, check)
      call createCurrent(P_GQ0, P_muPlus, P_muMinus, 3461, check)
      call createCurrent(P_Hh, P_Hh, P_Hl, P_Hh, 3194, check)
      call createCurrent(P_ghWp, P_A, P_A, P_ghWpAnti, 609, check)
      call createCurrent(P_WQPlus, P_ghZ, P_Z, P_ghWpAnti, 1908, check)
      call createCurrent(P_ghWm, P_GPlus, P_ghAAnti, P_Hl, 852, check)
      call createCurrent(P_HhQ, P_GPlus, P_GQMinus, 3230, check)
      call createCurrent(P_Z, P_Z, P_Hl, P_Hl, 4458, check)
      call createCurrent(P_ghAAnti, P_ghWp, P_GMinus, 4198, check)
      call createCurrent(P_GPlus, P_ghZ, P_GMinus, P_ghZAnti, 1290, check)
      call createCurrent(P_GMinus, P_WPlus, P_Hl, P_A, 3741, check)
      call createCurrent(P_Z, P_WPlus, P_WMinus, P_A, 4095, check)
      call createCurrent(P_AQ, P_ghWmAnti, P_ghWm, 2489, check)
      call createCurrent(P_WQMinus, P_ghWmAnti, P_ghZ, 4539, check)
      call createCurrent(P_HlQ, P_ghZ, P_Hl, P_ghZAnti, 3509, check)
      call createCurrent(P_A, P_WPlus, P_ghWm, P_ghZAnti, 1003, check)
      call createCurrent(P_ghZAnti, P_GMinus, P_ghWp, P_Hl, 1628, check)
      call createCurrent(P_ghWpAnti, P_Hl, P_ghWp, P_Hl, 585, check)
      call createCurrent(P_GQ0, P_G0, P_HlQ, 627, check)
      call createCurrent(P_AQ, P_ghWm, P_A, P_ghWmAnti, 81, check)
      call createCurrent(P_GPlus, P_ghWpAnti, P_Hl, P_ghA, 710, check)
      call createCurrent(P_GPlus, P_ghAAnti, P_ghWm, P_Hl, 2837, check)
      call createCurrent(P_ghZ, P_ghWpAnti, P_Z, P_WPlus, 4370, check)
      call createCurrent(P_ghZ, P_WMinus, P_A, P_ghWmAnti, 1154, check)
      call createCurrent(P_GMinus, P_tauPlus, P_nu_tau, 624, check)
      call createCurrent(P_A, P_GPlus, P_Hl, P_WMinus, 2974, check)
      call createCurrent(P_ghZAnti, P_Hh, P_Hl, P_ghZ, 4776, check)
      call createCurrent(P_WPlus, P_WMinus, P_A, P_Z, 1051, check)
      call createCurrent(P_HlQ, P_WPlus, P_Hh, P_WQMinus, 2682, check)
      call createCurrent(P_G0, P_muPlus, P_muMinus, 3083, check)
      call createCurrent(P_Z, P_Z, P_ghWpAnti, P_ghWp, 185, check)
      call createCurrent(P_G0, P_ghA, P_GPlus, P_ghWpAnti, 1005, check)
      call createCurrent(P_A, P_ghWpAnti, P_WPlus, P_ghZ, 782, check)
      call createCurrent(P_WPlus, P_WMinus, P_ghWmAnti, P_ghWm, 3111, check)
      call createCurrent(P_WMinus, P_Z, P_GPlus, P_Hh, 1364, check)
      call createCurrent(P_ghWmAnti, P_ghA, P_WMinus, P_A, 1344, check)
      call createCurrent(P_WPlus, P_Z, P_GMinus, P_G0, 1050, check)
      call createCurrent(P_sAnti, P_s, P_GQ0, 3265, check)
      call createCurrent(P_ghAAnti, P_ghWm, P_GPlus, P_HhQ, 3275, check)
      call createCurrent(P_GQ0, P_ghZ, P_G0, P_ghZAnti, 1759, check)
      call createCurrent(P_WQMinus, P_G0, P_GQPlus, 4169, check)
      call createCurrent(P_A, P_GMinus, P_G0, P_WPlus, 3502, check)
      call createCurrent(P_ghWm, P_ghWmAnti, P_Z, P_AQ, 1016, check)
      call createCurrent(P_HhQ, P_GPlus, P_GMinus, P_HlQ, 4431, check)
      call createCurrent(P_Hh, P_Hh, P_WMinus, P_WPlus, 1231, check)
      call createCurrent(P_Z, P_b, P_bAnti, 3000, check)
      call createCurrent(P_WQPlus, P_WPlus, P_ghWpAnti, P_ghWm, 1808, check)
      call createCurrent(P_ghAAnti, P_WPlus, P_ghWm, P_ZQ, 2815, check)
      call createCurrent(P_GQPlus, P_WMinus, P_Z, P_HhQ, 3490, check)
      call createCurrent(P_Z, P_Hl, P_G0, 3762, check)
      call createCurrent(P_ghWp, P_GMinus, P_Hh, P_ghZAnti, 2039, check)
      call createCurrent(P_GQPlus, P_G0, P_WMinus, P_ZQ, 1126, check)
      call createCurrent(P_WMinus, P_A, P_A, P_WPlus, 3174, check)
      call createCurrent(P_G0, P_GMinus, P_ghZ, P_ghWmAnti, 3092, check)
      call createCurrent(P_G0, P_Hl, P_G0, P_Hh, 2569, check)
      call createCurrent(P_ghWmAnti, P_Hl, P_ghWm, P_Hh, 2794, check)
      call createCurrent(P_ghWpAnti, P_Hh, P_ghWp, P_GQ0, 2226, check)
      call createCurrent(P_eMinus, P_ePlus, P_GQ0, 578, check)
      call createCurrent(P_nu_eAnti, P_nu_e, 4977, check)
      call createCurrent(P_d, P_dAnti, P_gQ, 1237, check)
      call createCurrent(P_WPlus, P_GMinus, P_Hh, 3607, check)
      call createCurrent(P_WQMinus, P_muPlus, P_nu_mu, 2243, check)
      call createCurrent(P_HhQ, P_WMinus, P_WPlus, P_HlQ, 1013, check)
      call createCurrent(P_GQ0, P_GPlus, P_ghZAnti, P_ghWm, 2801, check)
      call createCurrent(P_g, P_A, P_g, P_Z, 5143, check)
      call createCurrent(P_WPlus, P_tAnti, P_b, 1458, check)
      call createCurrent(P_AQ, P_Hh, P_GMinus, P_WQPlus, 124, check)
      call createCurrent(P_nu_tauAnti, P_nu_tau, 5002, check)
      call createCurrent(P_ghGAnti, P_g, P_ghG, P_g, 2153, check)
      call createCurrent(P_GQ0, P_Hh, P_ghWp, P_ghWpAnti, 3845, check)
      call createCurrent(P_ghZ, P_GMinus, P_ghWmAnti, P_G0, 1392, check)
      call createCurrent(P_ghWp, P_Hl, P_Hh, P_ghWpAnti, 153, check)
      call createCurrent(P_WQPlus, P_Hh, P_GMinus, P_ZQ, 472, check)
      call createCurrent(P_GQMinus, P_GPlus, P_ghWp, P_ghWpAnti, 3063, check)
      call createCurrent(P_ghAAnti, P_ghWp, P_WMinus, P_AQ, 3578, check)
      call createCurrent(P_Hh, P_Z, P_G0, 429, check)
      call createCurrent(P_WQMinus, P_WPlus, P_Hl, P_GQ0, 4408, check)
      call createCurrent(P_GPlus, P_Hh, P_Hl, P_GMinus, 3592, check)
      call createCurrent(P_muMinus, P_Hl, P_muPlus, 3131, check)
      call createCurrent(P_ghZAnti, P_GPlus, P_ghWm, P_G0, 712, check)
      call createCurrent(P_Z, P_WMinus, P_Z, P_WPlus, 2789, check)
      call createCurrent(P_g, P_G0, P_G0, P_g, 5177, check)
      call createCurrent(P_ZQ, P_ghWp, P_ghWpAnti, 4257, check)
      call createCurrent(P_Hl, P_Hh, P_A, P_A, 5133, check)
      call createCurrent(P_G0, P_Z, P_Hl, 3869, check)
      call createCurrent(P_tauPlus, P_tauMinus, P_ZQ, 1630, check)
      call createCurrent(P_Z, P_ghZ, P_WMinus, P_ghWmAnti, 236, check)
      call createCurrent(P_GQ0, P_G0, P_ghWm, P_ghWmAnti, 175, check)
      call createCurrent(P_WQMinus, P_Z, P_ghWmAnti, P_ghZ, 3350, check)
      call createCurrent(P_ghAAnti, P_WPlus, P_ghWm, P_AQ, 3650, check)
      call createCurrent(P_Z, P_GMinus, P_G0, P_WPlus, 4792, check)
      call createCurrent(P_HhQ, P_Hh, P_ghWpAnti, P_ghWp, 2498, check)
      call createCurrent(P_WPlus, P_WMinus, P_Hl, P_Hl, 4157, check)
      call createCurrent(P_WPlus, P_WMinus, P_Hl, 4300, check)
      call createCurrent(P_nu_mu, P_nu_muAnti, P_A, 5034, check)
      call createCurrent(P_ZQ, P_A, P_ghWmAnti, P_ghWm, 4941, check)
      call createCurrent(P_Hl, P_WPlus, P_GMinus, 2423, check)
      call createCurrent(P_Hl, P_ghWm, P_ghZAnti, P_GPlus, 2534, check)
      call createCurrent(P_WQPlus, P_ghWm, P_WPlus, P_ghWpAnti, 3467, check)
      call createCurrent(P_WMinus, P_Hh, P_GPlus, P_Z, 2547, check)
      call createCurrent(P_ZQ, P_bAnti, P_b, 4228, check)
      call createCurrent(P_WQMinus, P_Hh, P_WPlus, P_GQ0, 1506, check)
      call createCurrent(P_HhQ, P_WPlus, P_WMinus, P_HlQ, 2200, check)
      call createCurrent(P_HlQ, P_GMinus, P_ghAAnti, P_ghWp, 55, check)
      call createCurrent(P_ghWmAnti, P_Z, P_ghWm, P_ZQ, 4367, check)
      call createCurrent(P_GQPlus, P_ghWm, P_ghZAnti, 4733, check)
      call createCurrent(P_ghWp, P_Hl, P_GMinus, P_ghAAnti, 1879, check)
      call createCurrent(P_HhQ, P_GMinus, P_GPlus, P_HhQ, 4536, check)
      call createCurrent(P_WQMinus, P_Z, P_A, P_WQPlus, 1493, check)
      call createCurrent(P_Hl, P_Z, P_Hh, P_Z, 584, check)
      call createCurrent(P_G0, P_GMinus, P_ghWmAnti, P_ghA, 577, check)
      call createCurrent(P_Z, P_GPlus, P_WMinus, 4297, check)
      call createCurrent(P_ghZ, P_ghZAnti, P_Hh, P_Hl, 4037, check)
      call createCurrent(P_dAnti, P_d, P_GQ0, 1760, check)
      call createCurrent(P_g, P_Z, P_g, P_A, 5153, check)
      call createCurrent(P_ghWm, P_ghWmAnti, P_A, 4428, check)
      call createCurrent(P_GMinus, P_G0, P_WPlus, P_A, 1227, check)
      call createCurrent(P_Z, P_u, P_uAnti, 3588, check)
      call createCurrent(P_WMinus, P_ghA, P_WPlus, P_ghZAnti, 4360, check)
      call createCurrent(P_ghZAnti, P_ghA, P_WMinus, P_WPlus, 2058, check)
      call createCurrent(P_Hh, P_WMinus, P_WPlus, P_Hh, 288, check)
      call createCurrent(P_Z, P_WPlus, P_WMinus, 2579, check)
      call createCurrent(P_GPlus, P_ghWm, P_ghAAnti, 3323, check)
      call createCurrent(P_ZQ, P_u, P_uAnti, 2035, check)
      call createCurrent(P_ghWpAnti, P_ghA, P_WPlus, P_Z, 516, check)
      call createCurrent(P_Hh, P_A, P_Z, 5041, check)
      call createCurrent(P_WQMinus, P_WPlus, P_ghWpAnti, P_ghWp, 4675, check)
      call createCurrent(P_GMinus, P_ghZ, P_Hh, P_ghWmAnti, 2156, check)
      call createCurrent(P_A, P_Hl, P_Hl, P_A, 5126, check)
      call createCurrent(P_ghWm, P_GPlus, P_ghWmAnti, P_GMinus, 2167, check)
      call createCurrent(P_ghZ, P_ghWmAnti, P_WMinus, P_A, 631, check)
      call createCurrent(P_A, P_Z, P_Hl, P_Hh, 5120, check)
      call createCurrent(P_WMinus, P_WPlus, P_ghZ, P_ghZAnti, 4554, check)
      call createCurrent(P_ghWp, P_ghZAnti, P_WMinus, P_A, 410, check)
      call createCurrent(P_GQMinus, P_ghZAnti, P_Hh, P_ghWp, 4170, check)
      call createCurrent(P_WQMinus, P_WPlus, P_Z, P_AQ, 1474, check)
      call createCurrent(P_ghZ, P_GMinus, P_ghAAnti, P_GPlus, 184, check)
      call createCurrent(P_WMinus, P_GPlus, P_Hh, P_Z, 2248, check)
      call createCurrent(P_ghWp, P_GMinus, P_ghZAnti, 1582, check)
      call createCurrent(P_ghWpAnti, P_ghWp, P_Z, 279, check)
      call createCurrent(P_s, P_sAnti, P_GQ0, 2900, check)
      call createCurrent(P_ghWpAnti, P_ghWp, P_Hl, P_HhQ, 2103, check)
      call createCurrent(P_ghWm, P_Hl, P_ghWmAnti, P_HlQ, 2573, check)
      call createCurrent(P_GPlus, P_GMinus, P_Z, P_Z, 4573, check)
      call createCurrent(P_ghWpAnti, P_ghZ, P_GPlus, P_Hl, 1833, check)
      call createCurrent(P_u, P_g, P_uAnti, 4349, check)
      call createCurrent(P_Hl, P_Z, P_Hh, P_A, 5073, check)
      call createCurrent(P_GQ0, P_GPlus, P_ghWm, P_ghZAnti, 1952, check)
      call createCurrent(P_Z, P_g, P_g, P_g, 5179, check)
      call createCurrent(P_WQMinus, P_Hl, P_WPlus, P_HlQ, 2059, check)
      call createCurrent(P_Hh, P_WPlus, P_GMinus, P_A, 2145, check)
      call createCurrent(P_ghWmAnti, P_GPlus, P_ghWm, P_GMinus, 1247, check)
      call createCurrent(P_GQPlus, P_WMinus, P_G0, P_AQ, 4555, check)
      call createCurrent(P_Hh, P_Hh, P_Z, P_A, 5119, check)
      call createCurrent(P_GQMinus, P_GPlus, P_ghAAnti, P_ghA, 2513, check)
      call createCurrent(P_ghA, P_WPlus, P_ghWpAnti, P_A, 991, check)
      call createCurrent(P_ghA, P_GMinus, P_G0, P_ghWmAnti, 606, check)
      call createCurrent(P_uAnti, P_A, P_u, 709, check)
      call createCurrent(P_Z, P_ghWp, P_WMinus, P_ghZAnti, 3381, check)
      call createCurrent(P_GQPlus, P_Hh, P_ghZ, P_ghWpAnti, 428, check)
      call createCurrent(P_g, P_ghG, P_ghGAnti, P_g, 3770, check)
      call createCurrent(P_GQ0, P_GPlus, P_ghWm, P_ghAAnti, 2759, check)
      call createCurrent(P_ghZ, P_ghZAnti, P_G0, P_G0, 899, check)
      call createCurrent(P_uAnti, P_WPlus, P_d, 2944, check)
      call createCurrent(P_Z, P_A, P_GMinus, P_GPlus, 3887, check)
      call createCurrent(P_GMinus, P_Hl, P_ghZAnti, P_ghWp, 3449, check)
      call createCurrent(P_WPlus, P_Hl, P_Z, P_GMinus, 169, check)
      call createCurrent(P_ghWpAnti, P_G0, P_ghZ, P_GPlus, 3127, check)
      call createCurrent(P_AQ, P_tAnti, P_t, 485, check)
      call createCurrent(P_GQPlus, P_ghWpAnti, P_ghZ, 178, check)
      call createCurrent(P_GPlus, P_ghZAnti, P_ghA, P_GMinus, 4793, check)
      call createCurrent(P_GQPlus, P_eMinus, P_nu_eAnti, 4963, check)
      call createCurrent(P_Hl, P_ghWm, P_ghWmAnti, 1975, check)
      call createCurrent(P_ghZAnti, P_Hl, P_ghZ, 2933, check)
      call createCurrent(P_ghWp, P_ghAAnti, P_WMinus, P_AQ, 2808, check)
      call createCurrent(P_WMinus, P_ghAAnti, P_Z, P_ghWp, 1330, check)
      call createCurrent(P_HhQ, P_Hh, P_Z, P_ZQ, 4255, check)
      call createCurrent(P_g, P_g, P_A, P_g, 5233, check)
      call createCurrent(P_AQ, P_Z, P_WMinus, P_WQPlus, 566, check)
      call createCurrent(P_Z, P_ghZ, P_ghWpAnti, P_WPlus, 4333, check)
      call createCurrent(P_sAnti, P_c, P_GMinus, 971, check)
      call createCurrent(P_ZQ, P_GPlus, P_Hh, P_WQMinus, 3312, check)
      call createCurrent(P_A, P_GMinus, P_GPlus, P_Z, 762, check)
      call createCurrent(P_A, P_Z, P_Hl, P_Hl, 5104, check)
      call createCurrent(P_WMinus, P_t, P_bAnti, 1867, check)
      call createCurrent(P_ghWm, P_ghZAnti, P_WPlus, P_A, 3250, check)
      call createCurrent(P_WQMinus, P_ghWmAnti, P_ghA, 4127, check)
      call createCurrent(P_A, P_G0, P_Hh, 5069, check)
      call createCurrent(P_ghWmAnti, P_ghZ, P_G0, P_GMinus, 1820, check)
      call createCurrent(P_bAnti, P_b, P_ZQ, 2170, check)
      call createCurrent(P_WMinus, P_Z, P_GPlus, 1719, check)
      call createCurrent(P_GPlus, P_ghAAnti, P_ghZ, P_GMinus, 858, check)
      call createCurrent(P_A, P_nu_eAnti, P_nu_e, 5065, check)
      call createCurrent(P_c, P_cAnti, P_Hl, 4852, check)
      call createCurrent(P_b, P_bAnti, P_HhQ, 2342, check)
      call createCurrent(P_G0, P_Hl, P_Hl, P_G0, 974, check)
      call createCurrent(P_HhQ, P_ghWm, P_G0, P_ghWmAnti, 4060, check)
      call createCurrent(P_HlQ, P_GPlus, P_Z, P_WQMinus, 4195, check)
      call createCurrent(P_A, P_Hh, P_Hh, P_Z, 5121, check)
      call createCurrent(P_ghAAnti, P_GMinus, P_ghWp, P_G0, 3119, check)
      call createCurrent(P_ghAAnti, P_WMinus, P_WPlus, P_ghZ, 2999, check)
      call createCurrent(P_WPlus, P_Hh, P_GMinus, P_Z, 2497, check)
      call createCurrent(P_GMinus, P_Hh, P_ghWmAnti, P_ghZ, 2476, check)
      call createCurrent(P_AQ, P_GMinus, P_GPlus, P_ZQ, 4888, check)
      call createCurrent(P_GPlus, P_WMinus, P_Z, P_Hl, 4226, check)
      call createCurrent(P_ghAAnti, P_ghWp, P_WMinus, P_ZQ, 2976, check)
      call createCurrent(P_ghWmAnti, P_ghA, P_GMinus, P_G0, 2117, check)
      call createCurrent(P_GQPlus, P_ghWm, P_GMinus, P_ghWmAnti, 2872, check)
      call createCurrent(P_ghWmAnti, P_ghZ, P_Hl, P_GMinus, 230, check)
      call createCurrent(P_HlQ, P_ghWmAnti, P_ghWm, 1026, check)
      call createCurrent(P_Hl, P_ghWp, P_GMinus, P_ghAAnti, 715, check)
      call createCurrent(P_GMinus, P_ghAAnti, P_ghWp, P_Hh, 4480, check)
      call createCurrent(P_A, P_Z, P_Z, P_Z, 5167, check)
      call createCurrent(P_ghWp, P_ghWpAnti, P_Z, 417, check)
      call createCurrent(P_ghAAnti, P_GMinus, P_ghWp, P_Hh, 3507, check)
      call createCurrent(P_GQMinus, P_GPlus, P_Hl, P_GQ0, 2221, check)
      call createCurrent(P_HlQ, P_WMinus, P_WQPlus, 2403, check)
      call createCurrent(P_GQPlus, P_Hh, P_ghWm, P_ghZAnti, 4735, check)
      call createCurrent(P_Hl, P_ghZAnti, P_ghZ, P_Hl, 61, check)
      call createCurrent(P_sAnti, P_Hl, P_s, 4512, check)
      call createCurrent(P_HhQ, P_GMinus, P_ghZAnti, P_ghWp, 2401, check)
      call createCurrent(P_Hh, P_Z, P_A, P_Hh, 5081, check)
      call createCurrent(P_G0, P_GMinus, P_ghWp, P_ghAAnti, 2188, check)
      call createCurrent(P_Hl, P_dAnti, P_d, 3098, check)
      call createCurrent(P_b, P_Z, P_bAnti, 250, check)
      call createCurrent(P_WQPlus, P_Z, P_Hh, P_GQMinus, 1756, check)
      call createCurrent(P_d, P_dAnti, P_G0, 32, check)
      call createCurrent(P_HlQ, P_ghWm, P_Hh, P_ghWmAnti, 2191, check)
      call createCurrent(P_G0, P_ghWp, P_ghZAnti, P_GMinus, 4109, check)
      call createCurrent(P_G0, P_ghWp, P_ghAAnti, P_GMinus, 4012, check)
      call createCurrent(P_ghAAnti, P_WMinus, P_ghWp, 3173, check)
      call createCurrent(P_ZQ, P_ghWm, P_ghWmAnti, 4185, check)
      call createCurrent(P_GQ0, P_ghZ, P_GMinus, P_ghWmAnti, 2806, check)
      call createCurrent(P_GMinus, P_GPlus, P_A, P_A, 1856, check)
      call createCurrent(P_WQPlus, P_A, P_GMinus, P_GQ0, 1865, check)
      call createCurrent(P_d, P_uAnti, P_WPlus, 2252, check)
      call createCurrent(P_ghWm, P_ghWmAnti, P_A, P_Z, 4964, check)
      call createCurrent(P_Hl, P_Hh, P_GPlus, P_GMinus, 3933, check)
      call createCurrent(P_HlQ, P_Hh, P_ghWmAnti, P_ghWm, 3237, check)
      call createCurrent(P_Hl, P_GMinus, P_A, P_WPlus, 2436, check)
      call createCurrent(P_ghWp, P_GMinus, P_GPlus, P_ghWpAnti, 1592, check)
      call createCurrent(P_GPlus, P_WPlus, P_GMinus, P_WMinus, 212, check)
      call createCurrent(P_tauPlus, P_WMinus, P_nu_tau, 3272, check)
      call createCurrent(P_b, P_tAnti, P_WPlus, 3659, check)
      call createCurrent(P_HlQ, P_A, P_WPlus, P_GQMinus, 2205, check)
      call createCurrent(P_WPlus, P_ghWpAnti, P_Z, P_ghZ, 4932, check)
      call createCurrent(P_Hl, P_ghWm, P_Hl, P_ghWmAnti, 3137, check)
      call createCurrent(P_ghWpAnti, P_ghZ, P_Hl, P_GPlus, 4121, check)
      call createCurrent(P_GQPlus, P_GMinus, P_AQ, 3543, check)
      call createCurrent(P_WQMinus, P_GMinus, P_WPlus, P_GQPlus, 3959, check)
      call createCurrent(P_GQPlus, P_Z, P_WMinus, P_HhQ, 4276, check)
      call createCurrent(P_ghAAnti, P_ghWp, P_WMinus, 1386, check)
      call createCurrent(P_Z, P_ghWm, P_WPlus, P_ghZAnti, 3396, check)
      call createCurrent(P_WQPlus, P_WMinus, P_GPlus, P_GQMinus, 4369, check)
      call createCurrent(P_AQ, P_sAnti, P_s, 3701, check)
      call createCurrent(P_ghWm, P_WPlus, P_ghZAnti, 3671, check)
      call createCurrent(P_GPlus, P_Hl, P_WMinus, P_Z, 284, check)
      call createCurrent(P_ZQ, P_nu_tau, P_nu_tauAnti, 2603, check)
      call createCurrent(P_A, P_ghWmAnti, P_ghA, P_WMinus, 4217, check)
      call createCurrent(P_ghWmAnti, P_Hl, P_GMinus, P_ghZ, 2535, check)
      call createCurrent(P_WMinus, P_G0, P_GPlus, P_Z, 4856, check)
      call createCurrent(P_ghA, P_ghWmAnti, P_G0, P_GMinus, 218, check)
      call createCurrent(P_HlQ, P_ghWm, P_GPlus, P_ghAAnti, 1043, check)
      call createCurrent(P_HhQ, P_Hl, P_Hl, P_HlQ, 202, check)
      call createCurrent(P_ghWp, P_A, P_ghAAnti, P_WMinus, 838, check)
      call createCurrent(P_A, P_nu_mu, P_nu_muAnti, 5015, check)
      call createCurrent(P_A, P_G0, P_A, P_G0, 5157, check)
      call createCurrent(P_ghWmAnti, P_WMinus, P_ghWp, P_WQMinus, 3753, check)
      call createCurrent(P_ghZ, P_GPlus, P_Hh, P_ghWpAnti, 162, check)
      call createCurrent(P_ghA, P_Hl, P_ghWmAnti, P_GQMinus, 4004, check)
      call createCurrent(P_Z, P_ghWm, P_ghWmAnti, P_A, 597, check)
      call createCurrent(P_Hl, P_Z, P_WPlus, P_GMinus, 1325, check)
      call createCurrent(P_nu_eAnti, P_eMinus, P_GQPlus, 679, check)
      call createCurrent(P_G0, P_b, P_bAnti, 41, check)
      call createCurrent(P_ghWpAnti, P_ghWp, P_G0, P_G0, 4245, check)
      call createCurrent(P_ghAAnti, P_GMinus, P_G0, P_ghWp, 25, check)
      call createCurrent(P_Z, P_Z, P_A, P_A, 5198, check)
      call createCurrent(P_GPlus, P_ghWm, P_ghAAnti, P_G0, 1841, check)
      call createCurrent(P_ghWm, P_ghAAnti, P_Hl, P_GPlus, 2672, check)
      call createCurrent(P_WQPlus, P_Z, P_ghZ, P_ghWpAnti, 2427, check)
      call createCurrent(P_A, P_ghWpAnti, P_A, P_ghWp, 3189, check)
      call createCurrent(P_ZQ, P_Z, P_GPlus, P_GQMinus, 3608, check)
      call createCurrent(P_ghAAnti, P_WMinus, P_ghWp, P_A, 4481, check)
      call createCurrent(P_ghA, P_ghAAnti, P_WPlus, P_WMinus, 662, check)
      call createCurrent(P_ghWm, P_GPlus, P_ghZAnti, 76, check)
      call createCurrent(P_ghA, P_ghWpAnti, P_WPlus, P_Z, 4836, check)
      call createCurrent(P_WMinus, P_nu_tau, P_tauPlus, 3054, check)
      call createCurrent(P_Hh, P_ghWmAnti, P_ghWm, P_Hl, 4302, check)
      call createCurrent(P_WMinus, P_A, P_GPlus, P_Hh, 1251, check)
      call createCurrent(P_GQMinus, P_ghWp, P_GPlus, P_ghWpAnti, 1048, check)
      call createCurrent(P_WQMinus, P_WPlus, P_Hh, P_HlQ, 4773, check)
      call createCurrent(P_AQ, P_ghWpAnti, P_A, P_ghWp, 3700, check)
      call createCurrent(P_WQMinus, P_G0, P_GPlus, P_AQ, 2050, check)
      call createCurrent(P_GQPlus, P_Hl, P_Hh, P_GQMinus, 3891, check)
      call createCurrent(P_Hh, P_ghWmAnti, P_ghWm, 755, check)
      call createCurrent(P_WQPlus, P_WMinus, P_Z, P_ZQ, 4599, check)
      call createCurrent(P_ghAAnti, P_ghWm, P_WPlus, 812, check)
      call createCurrent(P_Hl, P_GPlus, P_ghWpAnti, P_ghA, 372, check)
      call createCurrent(P_ghWp, P_ghAAnti, P_WQMinus, 120, check)
      call createCurrent(P_WPlus, P_WMinus, P_WPlus, P_WMinus, 2761, check)
      call createCurrent(P_GMinus, P_G0, P_WPlus, 3337, check)
      call createCurrent(P_GQ0, P_GPlus, P_Hh, P_GQMinus, 1361, check)
      call createCurrent(P_ZQ, P_Hl, P_Z, P_HlQ, 891, check)
      call createCurrent(P_ghZAnti, P_ghWp, P_Hl, P_GQMinus, 4956, check)
      call createCurrent(P_ghZ, P_Hh, P_ghZAnti, P_HlQ, 3114, check)
      call createCurrent(P_ghZAnti, P_GMinus, P_GPlus, P_ghA, 251, check)
      call createCurrent(P_WPlus, P_Z, P_Hl, P_GMinus, 696, check)
      call createCurrent(P_WMinus, P_Hh, P_WPlus, P_Hl, 3677, check)
      call createCurrent(P_Hl, P_ghWpAnti, P_ghWp, 497, check)
      call createCurrent(P_nu_tau, P_Z, P_nu_tauAnti, 2590, check)
      call createCurrent(P_WQPlus, P_WMinus, P_WPlus, P_WQMinus, 4654, check)
      call createCurrent(P_Hh, P_ghZAnti, P_Hl, P_ghZ, 2286, check)
      call createCurrent(P_G0, P_Hl, P_Z, 2928, check)
      call createCurrent(P_Hh, P_ghWpAnti, P_ghWp, P_Hl, 2756, check)
      call createCurrent(P_WQPlus, P_ghZAnti, P_WMinus, P_ghA, 1312, check)
      call createCurrent(P_WPlus, P_Z, P_WMinus, P_A, 1668, check)
      call createCurrent(P_GQPlus, P_A, P_GMinus, P_AQ, 4417, check)
      call createCurrent(P_GQ0, P_WMinus, P_A, P_GQPlus, 4129, check)
      call createCurrent(P_gQ, P_ghG, P_g, P_ghGAnti, 2883, check)
      call createCurrent(P_HhQ, P_G0, P_ghWm, P_ghWmAnti, 190, check)
      call createCurrent(P_HhQ, P_G0, P_WPlus, P_WQMinus, 4085, check)
      call createCurrent(P_HlQ, P_G0, P_ZQ, 4495, check)
      call createCurrent(P_Hl, P_ghWm, P_GPlus, P_ghAAnti, 2921, check)
      call createCurrent(P_WMinus, P_ghZAnti, P_ghWp, P_Z, 4670, check)
      call createCurrent(P_ghWp, P_ghWpAnti, P_Z, P_Z, 1179, check)
      call createCurrent(P_A, P_nu_e, P_nu_eAnti, 4979, check)
      call createCurrent(P_WMinus, P_WPlus, P_ghWm, P_ghWmAnti, 570, check)
      call createCurrent(P_cAnti, P_c, P_Hh, 2715, check)
      call createCurrent(P_bAnti, P_t, P_WMinus, 1275, check)
      call createCurrent(P_Hl, P_Z, P_Hl, P_Z, 1172, check)
      call createCurrent(P_ghZAnti, P_ghWm, P_Z, P_WPlus, 3929, check)
      call createCurrent(P_GPlus, P_Z, P_WMinus, P_G0, 2647, check)
      call createCurrent(P_GQ0, P_tauMinus, P_tauPlus, 4411, check)
      call createCurrent(P_HhQ, P_ePlus, P_eMinus, 3708, check)
      call createCurrent(P_GQPlus, P_Z, P_GQMinus, 4182, check)
      call createCurrent(P_ghZ, P_WMinus, P_ghAAnti, P_WQPlus, 770, check)
      call createCurrent(P_Hl, P_ghWpAnti, P_GPlus, P_ghZ, 434, check)
      call createCurrent(P_WPlus, P_ghWpAnti, P_ghZ, P_Z, 4848, check)
      call createCurrent(P_ghWmAnti, P_A, P_A, P_ghWm, 2675, check)
      call createCurrent(P_ghWmAnti, P_WMinus, P_Z, P_ghA, 3631, check)
      call createCurrent(P_ghZ, P_Z, P_ghWmAnti, P_WQMinus, 1059, check)
      call createCurrent(P_ghWm, P_ghWmAnti, P_G0, P_HhQ, 433, check)
      call createCurrent(P_tAnti, P_WPlus, P_b, 242, check)
      call createCurrent(P_HhQ, P_Hh, P_Hh, P_HlQ, 2797, check)
      call createCurrent(P_WMinus, P_muPlus, P_nu_mu, 728, check)
      call createCurrent(P_GQMinus, P_Hl, P_GQPlus, 4202, check)
      call createCurrent(P_ghA, P_G0, P_ghWpAnti, P_GQPlus, 2516, check)
      call createCurrent(P_WQMinus, P_Hh, P_WPlus, P_HhQ, 2330, check)
      call createCurrent(P_ghWmAnti, P_Hl, P_ghWm, P_HlQ, 686, check)
      call createCurrent(P_GQ0, P_Z, P_WMinus, P_GQPlus, 4650, check)
      call createCurrent(P_A, P_A, P_Hl, 5256, check)
      call createCurrent(P_WMinus, P_ghAAnti, P_ghWp, 2127, check)
      call createCurrent(P_WMinus, P_ghAAnti, P_WPlus, P_ghA, 639, check)
      call createCurrent(P_GQPlus, P_GMinus, P_Hl, P_HlQ, 3832, check)
      call createCurrent(P_ghWp, P_ghWpAnti, P_Hh, P_HhQ, 3235, check)
      call createCurrent(P_ghWm, P_Hl, P_ghWmAnti, 4497, check)
      call createCurrent(P_GQPlus, P_ghWpAnti, P_Hh, P_ghA, 1407, check)
      call createCurrent(P_Hh, P_ghWm, P_ghZAnti, P_GPlus, 3636, check)
      call createCurrent(P_ghWp, P_ghZAnti, P_WMinus, 524, check)
      call createCurrent(P_Hh, P_ghWmAnti, P_ghA, P_GMinus, 2537, check)
      call createCurrent(P_muMinus, P_muPlus, P_ZQ, 1899, check)
      call createCurrent(P_s, P_sAnti, P_gQ, 1503, check)
      call createCurrent(P_nu_muAnti, P_nu_mu, P_ZQ, 3031, check)
      call createCurrent(P_WQPlus, P_Z, P_Hl, P_GQMinus, 3030, check)
      call createCurrent(P_g, P_Hl, P_g, P_Hh, 5212, check)
      call createCurrent(P_HlQ, P_Hl, P_ghWpAnti, P_ghWp, 3384, check)
      call createCurrent(P_ghA, P_GMinus, P_ghZAnti, P_GQPlus, 4569, check)
      call createCurrent(P_ghA, P_WPlus, P_ghZAnti, P_WQMinus, 3668, check)
      call createCurrent(P_ghWp, P_ghZAnti, P_WQMinus, 3518, check)
      call createCurrent(P_ghAAnti, P_ghZ, P_GPlus, P_GQMinus, 960, check)
      call createCurrent(P_AQ, P_ghAAnti, P_WPlus, P_ghWm, 3468, check)
      call createCurrent(P_HlQ, P_GPlus, P_ghZAnti, P_ghWm, 4851, check)
      call createCurrent(P_Hh, P_Z, P_WMinus, P_GPlus, 3583, check)
      call createCurrent(P_WPlus, P_ghWm, P_ghAAnti, P_A, 1480, check)
      call createCurrent(P_GQMinus, P_WPlus, P_Hh, P_AQ, 4614, check)
      call createCurrent(P_GQ0, P_bAnti, P_b, 4912, check)
      call createCurrent(P_Hh, P_GPlus, P_GMinus, P_Hl, 131, check)
      call createCurrent(P_GPlus, P_G0, P_ghWpAnti, P_ghA, 3051, check)
      call createCurrent(P_Hh, P_Hl, P_Hl, 4465, check)
      call createCurrent(P_GQPlus, P_nu_muAnti, P_muMinus, 3179, check)
      call createCurrent(P_ghWp, P_ghWpAnti, P_HhQ, 1429, check)
      call createCurrent(P_ghZ, P_A, P_WMinus, P_ghWmAnti, 3512, check)
      call createCurrent(P_WQMinus, P_ghWmAnti, P_Z, P_ghZ, 1672, check)
      call createCurrent(P_GQMinus, P_WPlus, P_Z, P_HhQ, 3185, check)
      call createCurrent(P_nu_eAnti, P_nu_e, P_A, 5014, check)
      call createCurrent(P_ghWmAnti, P_ghZ, P_GQMinus, 2530, check)
      call createCurrent(P_Hl, P_ghZ, P_Hl, P_ghZAnti, 2410, check)
      call createCurrent(P_WQMinus, P_Z, P_G0, P_GQPlus, 1232, check)
      call createCurrent(P_AQ, P_G0, P_GPlus, P_WQMinus, 3759, check)
      call createCurrent(P_HhQ, P_GMinus, P_Hl, P_GQPlus, 1599, check)
      call createCurrent(P_ghZAnti, P_GMinus, P_ghWp, P_HlQ, 2666, check)
      call createCurrent(P_GPlus, P_Hh, P_ghWm, P_ghZAnti, 3954, check)
      call createCurrent(P_nu_tauAnti, P_tauMinus, P_GPlus, 2017, check)
      call createCurrent(P_GPlus, P_Hh, P_ghWpAnti, P_ghZ, 1181, check)
      call createCurrent(P_Z, P_ghWmAnti, P_WMinus, P_ghA, 3858, check)
      call createCurrent(P_GQ0, P_ghWm, P_GPlus, P_ghZAnti, 2742, check)
      call createCurrent(P_GQMinus, P_A, P_WPlus, P_HhQ, 4844, check)
      call createCurrent(P_ghA, P_GMinus, P_GPlus, P_ghZAnti, 4712, check)
      call createCurrent(P_Hh, P_GMinus, P_ghWmAnti, P_ghZ, 3537, check)
      call createCurrent(P_A, P_ghWpAnti, P_ghWp, 2184, check)
      call createCurrent(P_WPlus, P_A, P_ghWpAnti, P_ghA, 3076, check)
      call createCurrent(P_WQPlus, P_A, P_ghWpAnti, P_ghA, 4729, check)
      call createCurrent(P_ghZAnti, P_Hh, P_ghZ, 963, check)
      call createCurrent(P_ghWmAnti, P_ghZ, P_Hh, P_GMinus, 1070, check)
      call createCurrent(P_ghWm, P_ghWmAnti, P_Z, P_Z, 3437, check)
      call createCurrent(P_WMinus, P_Hh, P_Hh, P_WPlus, 4946, check)
      call createCurrent(P_ghWmAnti, P_ghZ, P_A, P_WMinus, 3765, check)
      call createCurrent(P_ZQ, P_WPlus, P_GMinus, P_HhQ, 3504, check)
      call createCurrent(P_G0, P_ghZAnti, P_ghWp, P_GMinus, 4580, check)
      call createCurrent(P_ghWp, P_WPlus, P_ghWpAnti, P_WQMinus, 2731, check)
      call createCurrent(P_GPlus, P_d, P_uAnti, 571, check)
      call createCurrent(P_ghZAnti, P_WMinus, P_ghA, P_WPlus, 4627, check)
      call createCurrent(P_eMinus, P_ePlus, 5064, check)
      call createCurrent(P_GMinus, P_Z, P_WPlus, 3664, check)
      call createCurrent(P_GQPlus, P_Hh, P_GQMinus, 2137, check)
      call createCurrent(P_ZQ, P_ghWp, P_Z, P_ghWpAnti, 3640, check)
      call createCurrent(P_WQPlus, P_ghWm, P_ghZAnti, 4040, check)
      call createCurrent(P_Z, P_Hl, P_A, P_Hh, 4989, check)
      call createCurrent(P_ghWp, P_ghWmAnti, P_WMinus, P_WMinus, 2679, check)
      call createCurrent(P_ghWm, P_ghZAnti, P_WPlus, P_ZQ, 2819, check)
      call createCurrent(P_Hl, P_g, P_g, 5263, check)
      call createCurrent(P_ghWpAnti, P_Hh, P_ghZ, P_GQPlus, 262, check)
      call createCurrent(P_ghWm, P_Z, P_ghWmAnti, 498, check)
      call createCurrent(P_WQPlus, P_GMinus, P_Z, P_HlQ, 850, check)
      call createCurrent(P_AQ, P_ghWm, P_ghWmAnti, 4269, check)
      call createCurrent(P_A, P_WMinus, P_WPlus, P_Z, 1739, check)
      call createCurrent(P_Z, P_A, P_WMinus, P_WPlus, 94, check)
      call createCurrent(P_A, P_ghWp, P_ghAAnti, P_WMinus, 4213, check)
      call createCurrent(P_A, P_Z, P_GMinus, P_GPlus, 2091, check)
      call createCurrent(P_AQ, P_GPlus, P_Z, P_GQMinus, 3568, check)
      call createCurrent(P_ghWp, P_GPlus, P_ghWpAnti, P_GQMinus, 2836, check)
      call createCurrent(P_ghWpAnti, P_ghWp, P_Hl, P_Hh, 101, check)
      call createCurrent(P_ghWm, P_GPlus, P_ghAAnti, P_GQ0, 1773, check)
      call createCurrent(P_u, P_Hh, P_uAnti, 3376, check)
      call createCurrent(P_A, P_ghWm, P_ghZAnti, P_WPlus, 26, check)
      call createCurrent(P_HlQ, P_ghWm, P_ghWmAnti, 308, check)
      call createCurrent(P_GQ0, P_muMinus, P_muPlus, 88, check)
      call createCurrent(P_WMinus, P_ghA, P_ghZAnti, P_WPlus, 3678, check)
      call createCurrent(P_WQPlus, P_Z, P_GMinus, P_HlQ, 3944, check)
      call createCurrent(P_ghWm, P_Hh, P_ghWmAnti, 676, check)
      call createCurrent(P_WPlus, P_Hl, P_GMinus, 2086, check)
      call createCurrent(P_G0, P_GPlus, P_WMinus, 4934, check)
      call createCurrent(P_GQPlus, P_Hl, P_ghWm, P_ghZAnti, 2406, check)
      call createCurrent(P_ghWpAnti, P_Hl, P_ghWp, P_GQ0, 4619, check)
      call createCurrent(P_b, P_tAnti, P_GQPlus, 1735, check)
      call createCurrent(P_GPlus, P_nu_tauAnti, P_tauMinus, 884, check)
      call createCurrent(P_ghZAnti, P_ghZ, P_WMinus, P_WPlus, 2892, check)
      call createCurrent(P_ZQ, P_WPlus, P_WMinus, P_AQ, 3942, check)
      call createCurrent(P_ghWpAnti, P_GPlus, P_ghWp, P_GQMinus, 2171, check)
      call createCurrent(P_ghWm, P_Hl, P_ghAAnti, P_GPlus, 4352, check)
      call createCurrent(P_GMinus, P_ghWmAnti, P_Hh, P_ghA, 761, check)
      call createCurrent(P_Hh, P_A, P_Hh, P_Z, 5107, check)
      call createCurrent(P_GQMinus, P_Hl, P_Hl, P_GQPlus, 2224, check)
      call createCurrent(P_GPlus, P_Z, P_GMinus, P_A, 1371, check)
      call createCurrent(P_WMinus, P_Hh, P_GPlus, 1483, check)
      call createCurrent(P_WQPlus, P_Hl, P_Z, P_GQMinus, 1062, check)
      call createCurrent(P_Hl, P_GMinus, P_GPlus, P_Hh, 1576, check)
      call createCurrent(P_ghA, P_ghAAnti, P_GPlus, P_GQMinus, 31, check)
      call createCurrent(P_GQPlus, P_Z, P_GMinus, P_ZQ, 2927, check)
      call createCurrent(P_HlQ, P_GPlus, P_Hl, P_GQMinus, 1357, check)
      call createCurrent(P_GMinus, P_GPlus, P_ghWp, P_ghWpAnti, 2799, check)
      call createCurrent(P_ghZAnti, P_G0, P_ghWp, P_GQMinus, 2987, check)
      call createCurrent(P_WQMinus, P_Hl, P_Hh, P_WQPlus, 4783, check)
      call createCurrent(P_GMinus, P_Hl, P_ghA, P_ghWmAnti, 2187, check)
      call createCurrent(P_HlQ, P_Hl, P_WPlus, P_WQMinus, 3007, check)
      call createCurrent(P_ghWm, P_Hh, P_Hh, P_ghWmAnti, 1078, check)
      call createCurrent(P_G0, P_GPlus, P_A, P_WMinus, 3682, check)
      call createCurrent(P_Hh, P_ghWp, P_ghAAnti, P_GMinus, 3341, check)
      call createCurrent(P_ghAAnti, P_ghWm, P_WPlus, P_A, 2287, check)
      call createCurrent(P_AQ, P_WPlus, P_Z, P_WQMinus, 4434, check)
      call createCurrent(P_ghWpAnti, P_ghWm, P_WPlus, P_WQPlus, 1729, check)
      call createCurrent(P_GQPlus, P_G0, P_ghWm, P_ghZAnti, 4387, check)
      call createCurrent(P_uAnti, P_u, P_AQ, 4413, check)
      call createCurrent(P_Z, P_Z, P_Z, P_A, 5136, check)
      call createCurrent(P_HlQ, P_GMinus, P_ghWp, P_ghAAnti, 4229, check)
      call createCurrent(P_ghAAnti, P_G0, P_ghWp, P_GMinus, 4822, check)
      call createCurrent(P_A, P_WMinus, P_ghZ, P_ghWmAnti, 359, check)
      call createCurrent(P_GQPlus, P_G0, P_GMinus, P_HhQ, 1612, check)
      call createCurrent(P_ghWmAnti, P_Hl, P_GMinus, P_ghA, 3367, check)
      call createCurrent(P_AQ, P_ghWpAnti, P_Z, P_ghWp, 2559, check)
      call createCurrent(P_GMinus, P_ghZAnti, P_G0, P_ghWp, 329, check)
      call createCurrent(P_HlQ, P_ghWp, P_Hh, P_ghWpAnti, 2258, check)
      call createCurrent(P_WQPlus, P_WMinus, P_A, P_AQ, 2416, check)
      call createCurrent(P_ghA, P_WPlus, P_A, P_ghWpAnti, 115, check)
      call createCurrent(P_GPlus, P_ghZ, P_Hh, P_ghWpAnti, 767, check)
      call createCurrent(P_ghWp, P_ghAAnti, P_GMinus, P_G0, 1673, check)
      call createCurrent(P_WMinus, P_WPlus, P_WPlus, P_WMinus, 1929, check)
      call createCurrent(P_GMinus, P_c, P_sAnti, 1624, check)
      call createCurrent(P_GQMinus, P_Z, P_G0, P_WQPlus, 4023, check)
      call createCurrent(P_HhQ, P_ghWpAnti, P_G0, P_ghWp, 2599, check)
      call createCurrent(P_WPlus, P_ghWm, P_ghZAnti, P_Z, 853, check)
      call createCurrent(P_GQMinus, P_WPlus, P_G0, P_ZQ, 2982, check)
      call createCurrent(P_GQ0, P_Hl, P_WPlus, P_WQMinus, 877, check)
      call createCurrent(P_ghWpAnti, P_A, P_ghA, P_WQPlus, 2791, check)
      call createCurrent(P_ghWm, P_ghWmAnti, P_Hh, P_GQ0, 1115, check)
      call createCurrent(P_ghWpAnti, P_ghWp, P_A, 765, check)
      call createCurrent(P_ghWpAnti, P_ghA, P_Z, P_WQPlus, 3994, check)
      call createCurrent(P_ghA, P_ghWpAnti, P_WPlus, P_A, 1509, check)
      call createCurrent(P_Hh, P_Z, P_A, 5022, check)
      call createCurrent(P_GMinus, P_WPlus, P_Hh, 2323, check)
      call createCurrent(P_ghWp, P_WMinus, P_ghAAnti, P_ZQ, 2589, check)
      call createCurrent(P_GQPlus, P_Z, P_GMinus, P_AQ, 484, check)
      call createCurrent(P_WPlus, P_WMinus, P_GPlus, P_GMinus, 108, check)
      call createCurrent(P_g, P_A, P_A, P_g, 5134, check)
      call createCurrent(P_Hl, P_WPlus, P_A, P_GMinus, 1590, check)
      call createCurrent(P_GPlus, P_ghZ, P_ghWpAnti, P_G0, 3559, check)
      call createCurrent(P_cAnti, P_s, P_WPlus, 656, check)
      call createCurrent(P_Hl, P_A, P_Hl, P_A, 5124, check)
      call createCurrent(P_WQMinus, P_WPlus, P_A, P_ZQ, 75, check)
      call createCurrent(P_b, P_tAnti, P_WQPlus, 4336, check)
      call createCurrent(P_GQMinus, P_A, P_Z, P_GQPlus, 534, check)
      call createCurrent(P_WQMinus, P_ghAAnti, P_WPlus, P_ghZ, 3338, check)
      call createCurrent(P_g, P_g, P_WMinus, P_WPlus, 5140, check)
      call createCurrent(P_WPlus, P_GPlus, P_WMinus, P_GMinus, 3881, check)
      call createCurrent(P_ghA, P_ghWmAnti, P_A, P_WMinus, 3523, check)
      call createCurrent(P_ghWp, P_GPlus, P_ghWpAnti, P_GMinus, 411, check)
      call createCurrent(P_Hh, P_Hh, P_Hl, 1606, check)
      call createCurrent(P_HlQ, P_Hl, P_WMinus, P_WQPlus, 536, check)
      call createCurrent(P_Hh, P_dAnti, P_d, 1662, check)
      call createCurrent(P_dAnti, P_d, P_ZQ, 3080, check)
      call createCurrent(P_ghWmAnti, P_G0, P_G0, P_ghWm, 1402, check)
      call createCurrent(P_GQPlus, P_GMinus, P_Z, P_ZQ, 3995, check)
      call createCurrent(P_ZQ, P_GPlus, P_WMinus, P_GQ0, 2463, check)
      call createCurrent(P_Hh, P_WMinus, P_WPlus, 4527, check)
      call createCurrent(P_s, P_Hh, P_sAnti, 774, check)
      call createCurrent(P_tAnti, P_t, P_A, 1326, check)
      call createCurrent(P_ghZAnti, P_WMinus, P_ghWp, P_A, 4082, check)
      call createCurrent(P_G0, P_GPlus, P_G0, P_GMinus, 4108, check)
      call createCurrent(P_ghZ, P_Hl, P_ghZAnti, P_Hh, 565, check)
      call createCurrent(P_ghWmAnti, P_Z, P_ghZ, P_WQMinus, 2134, check)
      call createCurrent(P_WQPlus, P_Hl, P_GQMinus, 3581, check)
      call createCurrent(P_HlQ, P_G0, P_WPlus, P_WQMinus, 2676, check)
      call createCurrent(P_GMinus, P_G0, P_Z, P_WPlus, 3930, check)
      call createCurrent(P_WMinus, P_GPlus, 4993, check)
      call createCurrent(P_Z, P_GMinus, P_GPlus, P_Z, 2505, check)
      call createCurrent(P_Hh, P_Z, P_A, P_Hl, 5085, check)
      call createCurrent(P_ghZAnti, P_G0, P_ghZ, P_GQ0, 1567, check)
      call createCurrent(P_ghWp, P_ghWpAnti, P_Z, P_A, 3565, check)
      call createCurrent(P_WMinus, P_ghA, P_WPlus, P_ghAAnti, 1492, check)
      call createCurrent(P_WQMinus, P_WPlus, P_G0, P_HlQ, 1691, check)
      call createCurrent(P_Z, P_Hl, P_Hh, P_A, 5084, check)
      call createCurrent(P_ZQ, P_ghWpAnti, P_A, P_ghWp, 1207, check)
      call createCurrent(P_ePlus, P_nu_e, P_WMinus, 2739, check)
      call createCurrent(P_GMinus, P_WPlus, 5076, check)
      call createCurrent(P_nu_tauAnti, P_nu_tau, P_A, 4991, check)
      call createCurrent(P_ghWp, P_ghZAnti, P_GMinus, P_Hh, 4048, check)
      call createCurrent(P_ghZ, P_ghWpAnti, P_G0, P_GPlus, 3964, check)
      call createCurrent(P_ZQ, P_ghAAnti, P_WPlus, P_ghWm, 1611, check)
      call createCurrent(P_A, P_t, P_tAnti, 350, check)
      call createCurrent(P_ghZ, P_Z, P_WPlus, P_ghWpAnti, 4280, check)
      call createCurrent(P_ghWpAnti, P_G0, P_ghA, P_GQPlus, 1888, check)
      call createCurrent(P_b, P_G0, P_bAnti, 4834, check)
      call createCurrent(P_nu_tau, P_GMinus, P_tauPlus, 993, check)
      call createCurrent(P_Z, P_Hl, P_Hl, P_Z, 610, check)
      call createCurrent(P_GQMinus, P_WPlus, P_A, P_GQ0, 526, check)
      call createCurrent(P_WMinus, P_GPlus, P_Hl, P_A, 4383, check)
      call createCurrent(P_Hh, P_WMinus, P_GPlus, P_Z, 3876, check)
      call createCurrent(P_Hh, P_Z, P_GMinus, P_WPlus, 40, check)
      call createCurrent(P_ghWpAnti, P_Z, P_ghWp, 4468, check)
      call createCurrent(P_ghWm, P_ghWmAnti, P_WMinus, P_WPlus, 4242, check)
      call createCurrent(P_Hl, P_WMinus, P_GPlus, 2677, check)
      call createCurrent(P_ghZAnti, P_WMinus, P_ghZ, P_WQPlus, 2138, check)
      call createCurrent(P_WQMinus, P_Hh, P_Hh, P_WQPlus, 3155, check)
      call createCurrent(P_ghWpAnti, P_Hl, P_ghZ, P_GQPlus, 4247, check)
      call createCurrent(P_Z, P_s, P_sAnti, 245, check)
      call createCurrent(P_ghWm, P_Hh, P_Hl, P_ghWmAnti, 1106, check)
      call createCurrent(P_ghWpAnti, P_Hh, P_GPlus, P_ghA, 2757, check)
      call createCurrent(P_sAnti, P_g, P_s, 3274, check)
      call createCurrent(P_ghZ, P_ghAAnti, P_GMinus, P_GPlus, 4598, check)
      call createCurrent(P_HhQ, P_WMinus, P_Hh, P_WQPlus, 636, check)
      call createCurrent(P_GPlus, P_GMinus, P_GPlus, P_GMinus, 2211, check)
      call createCurrent(P_ghA, P_GPlus, P_ghAAnti, P_GMinus, 4705, check)
      call createCurrent(P_Hl, P_ghZAnti, P_GMinus, P_ghWp, 3037, check)
      call createCurrent(P_ghWp, P_ghAAnti, P_GMinus, 4395, check)
      call createCurrent(P_GPlus, P_GMinus, P_A, P_A, 3888, check)
      call createCurrent(P_Hl, P_A, P_A, P_Hh, 5239, check)
      call createCurrent(P_ZQ, P_Hl, P_WMinus, P_GQPlus, 4595, check)
      call createCurrent(P_sAnti, P_s, P_g, 4577, check)
      call createCurrent(P_G0, P_Hh, P_G0, P_Hh, 363, check)
      call createCurrent(P_A, P_sAnti, P_s, 3324, check)
      call createCurrent(P_GQPlus, P_G0, P_ghWpAnti, P_ghZ, 1352, check)
      call createCurrent(P_ghWm, P_ghWmAnti, P_HhQ, 2475, check)
      call createCurrent(P_GQMinus, P_Hh, P_GPlus, P_HhQ, 3259, check)
      call createCurrent(P_Hh, P_ghAAnti, P_GPlus, P_ghWm, 2701, check)
      call createCurrent(P_AQ, P_ghWmAnti, P_A, P_ghWm, 1989, check)
      call createCurrent(P_eMinus, P_WPlus, P_nu_eAnti, 4746, check)
      call createCurrent(P_GQMinus, P_GPlus, P_Hh, P_HhQ, 4062, check)
      call createCurrent(P_ghWmAnti, P_ghWm, P_Hl, P_Hl, 1544, check)
      call createCurrent(P_WPlus, P_WPlus, P_WMinus, P_WMinus, 741, check)
      call createCurrent(P_GPlus, P_WMinus, P_A, 1299, check)
      call createCurrent(P_ghWpAnti, P_Hh, P_ghWp, P_HlQ, 4419, check)
      call createCurrent(P_ghWpAnti, P_ghZ, P_WPlus, P_Z, 2922, check)
      call createCurrent(P_ghZ, P_GPlus, P_GMinus, P_ghZAnti, 3789, check)
      call createCurrent(P_eMinus, P_ePlus, P_HhQ, 1196, check)
      call createCurrent(P_Hh, P_GPlus, P_ghZ, P_ghWpAnti, 2612, check)
      call createCurrent(P_AQ, P_ghWm, P_Z, P_ghWmAnti, 4757, check)
      call createCurrent(P_ePlus, P_Hl, P_eMinus, 894, check)
      call createCurrent(P_HhQ, P_ghZ, P_ghZAnti, 3748, check)
      call createCurrent(P_WQMinus, P_GPlus, P_Z, P_GQ0, 1577, check)
      call createCurrent(P_ghWmAnti, P_WMinus, P_ghZ, 2957, check)
      call createCurrent(P_GMinus, P_ghZAnti, P_ghZ, P_GPlus, 1034, check)
      call createCurrent(P_WQMinus, P_GPlus, P_HhQ, 467, check)
      call createCurrent(P_ghWm, P_ghWmAnti, P_Hh, P_HhQ, 1928, check)
      call createCurrent(P_ghZAnti, P_Z, P_WMinus, P_ghWp, 4181, check)
      call createCurrent(P_ghWm, P_ghWmAnti, P_Hl, P_Hh, 3460, check)
      call createCurrent(P_ghWp, P_ghZAnti, P_GMinus, P_HhQ, 4722, check)
      call createCurrent(P_GQPlus, P_Z, P_Z, P_GQMinus, 4394, check)
      call createCurrent(P_ghWm, P_ghAAnti, P_GPlus, P_GQ0, 4824, check)
      call createCurrent(P_Hl, P_GPlus, P_GMinus, P_Hl, 2527, check)
      call createCurrent(P_GQMinus, P_Hl, P_ghWmAnti, P_ghZ, 1369, check)
      call createCurrent(P_WQMinus, P_A, P_GPlus, P_HlQ, 1273, check)
      call createCurrent(P_GPlus, P_ghZ, P_ghWpAnti, 1521, check)
      call createCurrent(P_ghWpAnti, P_ghWp, P_HlQ, 4041, check)
      call createCurrent(P_GMinus, P_Hh, P_GPlus, 4254, check)
      call createCurrent(P_GQ0, P_GPlus, P_A, P_WQMinus, 2310, check)
      call createCurrent(P_WPlus, P_ghWm, P_WPlus, P_ghWpAnti, 2241, check)
      call createCurrent(P_GMinus, P_ghWp, P_ghAAnti, P_G0, 3871, check)
      call createCurrent(P_GQMinus, P_ghWmAnti, P_Hl, P_ghZ, 146, check)
      call createCurrent(P_t, P_tAnti, P_Hl, 3482, check)
      call createCurrent(P_ghWpAnti, P_ghZ, P_Z, P_WQPlus, 1918, check)
      call createCurrent(P_AQ, P_GPlus, P_GMinus, P_AQ, 13, check)
      call createCurrent(P_HhQ, P_WPlus, P_GQMinus, 1518, check)
      call createCurrent(P_nu_e, P_ePlus, P_WQMinus, 2176, check)
      call createCurrent(P_HlQ, P_GPlus, P_ghAAnti, P_ghWm, 2881, check)
      call createCurrent(P_ghWpAnti, P_ghWp, P_Z, P_AQ, 539, check)
      call createCurrent(P_WPlus, P_A, P_ghWpAnti, P_ghZ, 3926, check)
      call createCurrent(P_g, P_g, P_WPlus, P_WMinus, 5160, check)
      call createCurrent(P_GPlus, P_ghWm, P_Hh, P_ghAAnti, 121, check)
      call createCurrent(P_GQPlus, P_ghAAnti, P_GMinus, P_ghZ, 2539, check)
      call createCurrent(P_ghWm, P_WPlus, P_WMinus, P_ghWmAnti, 2474, check)
      call createCurrent(P_WMinus, P_ghWp, P_ghZAnti, 1986, check)
      call createCurrent(P_GMinus, P_WPlus, P_GPlus, P_WMinus, 824, check)
      call createCurrent(P_eMinus, P_ePlus, P_G0, 123, check)
      call createCurrent(P_GQMinus, P_GPlus, P_ghZAnti, P_ghA, 2724, check)
      call createCurrent(P_WPlus, P_GMinus, P_A, P_G0, 1748, check)
      call createCurrent(P_ghWm, P_Hl, P_ghZAnti, P_GPlus, 4576, check)
      call createCurrent(P_ghZ, P_ghWpAnti, P_Z, P_WQPlus, 841, check)
      call createCurrent(P_s, P_sAnti, P_HlQ, 537, check)
      call createCurrent(P_g, P_g, P_g, 3705, check)
      call createCurrent(P_GPlus, P_WMinus, P_G0, 2108, check)
      call createCurrent(P_GPlus, P_Hl, P_ghWm, P_ghZAnti, 2956, check)
      call createCurrent(P_GMinus, P_ghWp, P_ghZAnti, P_Hh, 3291, check)
      call createCurrent(P_GQPlus, P_WPlus, P_WMinus, P_GQMinus, 1791, check)
      call createCurrent(P_tAnti, P_b, P_WQPlus, 2309, check)
      call createCurrent(P_ghZAnti, P_A, P_WMinus, P_ghWp, 3629, check)
      call createCurrent(P_ghZAnti, P_Hl, P_Hl, P_ghZ, 2600, check)
      call createCurrent(P_GQPlus, P_ghAAnti, P_GMinus, P_ghA, 119, check)
      call createCurrent(P_uAnti, P_u, P_Z, 1571, check)
      call createCurrent(P_ghZ, P_ghWpAnti, P_Hl, P_GQPlus, 3853, check)
      call createCurrent(P_GMinus, P_G0, P_GPlus, P_G0, 4013, check)
      call createCurrent(P_ghZ, P_ghZAnti, P_Hl, 3927, check)
      call createCurrent(P_ZQ, P_dAnti, P_d, 919, check)
      call createCurrent(P_Z, P_ghWp, P_ghZAnti, P_WMinus, 1802, check)
      call createCurrent(P_GMinus, P_g, P_GPlus, P_g, 5248, check)
      call createCurrent(P_GPlus, P_WMinus, P_Hh, 1944, check)
      call createCurrent(P_ghZAnti, P_WPlus, P_ghWm, P_ZQ, 3413, check)
      call createCurrent(P_ghAAnti, P_Z, P_ghWm, P_WPlus, 3253, check)
      call createCurrent(P_Hh, P_GPlus, P_ghAAnti, P_ghWm, 3124, check)
      call createCurrent(P_AQ, P_GPlus, P_GQMinus, 2453, check)
      call createCurrent(P_WMinus, P_ghZ, P_ghWmAnti, P_A, 2540, check)
      call createCurrent(P_GQPlus, P_s, P_cAnti, 2818, check)
      call createCurrent(P_HhQ, P_eMinus, P_ePlus, 2885, check)
      call createCurrent(P_ghWp, P_ghZAnti, P_GMinus, 303, check)
      call createCurrent(P_GQ0, P_GMinus, P_GQPlus, 4874, check)
      call createCurrent(P_HhQ, P_bAnti, P_b, 3344, check)
      call createCurrent(P_Z, P_WMinus, P_WPlus, P_Z, 382, check)
      call createCurrent(P_ZQ, P_WPlus, P_Hh, P_GQMinus, 1039, check)
      call createCurrent(P_WPlus, P_G0, P_A, P_GMinus, 3879, check)
      call createCurrent(P_Hl, P_Hh, P_ghWmAnti, P_ghWm, 922, check)
      call createCurrent(P_WPlus, P_ghWpAnti, P_ghA, 3990, check)
      call createCurrent(P_Hl, P_A, P_Hl, P_Z, 5109, check)
      call createCurrent(P_GQMinus, P_GPlus, P_Hh, P_HlQ, 2002, check)
      call createCurrent(P_gQ, P_ghGAnti, P_ghG, 3734, check)
      call createCurrent(P_nu_mu, P_Z, P_nu_muAnti, 4500, check)
      call createCurrent(P_ghAAnti, P_WPlus, P_ghA, P_WMinus, 1400, check)
      call createCurrent(P_GPlus, P_ghWp, P_GMinus, P_ghWpAnti, 416, check)
      call createCurrent(P_GPlus, P_ghA, P_ghWpAnti, P_Hh, 3598, check)
      call createCurrent(P_GPlus, P_ghZAnti, P_ghWm, P_G0, 3223, check)
      call createCurrent(P_Hh, P_ghWmAnti, P_ghZ, P_GMinus, 2617, check)
      call createCurrent(P_GMinus, P_GPlus, P_GPlus, P_GMinus, 2766, check)
      call createCurrent(P_GQ0, P_WMinus, P_WQPlus, 508, check)
      call createCurrent(P_ghZ, P_GMinus, P_ghWmAnti, P_Hl, 603, check)
      call createCurrent(P_ghZAnti, P_WPlus, P_WMinus, P_ghA, 3004, check)
      call createCurrent(P_u, P_WMinus, P_dAnti, 1707, check)
      call createCurrent(P_ZQ, P_GMinus, P_G0, P_WQPlus, 3605, check)
      call createCurrent(P_ghWmAnti, P_GMinus, P_ghZ, P_HhQ, 4024, check)
      call createCurrent(P_WPlus, P_ghZ, P_A, P_ghWpAnti, 2968, check)
      call createCurrent(P_Z, P_WMinus, P_GPlus, 934, check)
      call createCurrent(P_ghG, P_g, P_ghGAnti, 407, check)
      call createCurrent(P_ghZ, P_GPlus, P_ghWpAnti, P_Hh, 3201, check)
      call createCurrent(P_WQMinus, P_Hl, P_WPlus, P_GQ0, 1573, check)
      call createCurrent(P_WQPlus, P_Hl, P_Hh, P_WQMinus, 2501, check)
      call createCurrent(P_ghWpAnti, P_ghWp, P_G0, P_HhQ, 4223, check)
      call createCurrent(P_ghWpAnti, P_WMinus, P_ghWp, P_WPlus, 601, check)
      call createCurrent(P_ghWpAnti, P_Hh, P_ghWp, P_Hl, 2803, check)
      call createCurrent(P_Hh, P_GPlus, P_GMinus, P_Hh, 3254, check)
      call createCurrent(P_GQPlus, P_Hh, P_WQMinus, 793, check)
      call createCurrent(P_cAnti, P_c, P_g, 1961, check)
      call createCurrent(P_Z, P_G0, P_Hh, 3615, check)
      call createCurrent(P_ghWmAnti, P_WMinus, P_ghWp, P_WMinus, 4508, check)
      call createCurrent(P_GQMinus, P_GPlus, P_GQ0, 1681, check)
      call createCurrent(P_Z, P_WMinus, P_ghWp, P_ghZAnti, 1821, check)
      call createCurrent(P_HlQ, P_GMinus, P_GQPlus, 1533, check)
      call createCurrent(P_HlQ, P_c, P_cAnti, 2041, check)
      call createCurrent(P_Hh, P_Hh, P_ghZ, P_ghZAnti, 1434, check)
      call createCurrent(P_ghWpAnti, P_A, P_ghWp, P_AQ, 205, check)
      call createCurrent(P_tauPlus, P_Hh, P_tauMinus, 1100, check)
      call createCurrent(P_sAnti, P_s, P_HhQ, 2628, check)
      call createCurrent(P_tauMinus, P_Z, P_tauPlus, 1375, check)
      call createCurrent(P_GQMinus, P_GPlus, P_ghAAnti, P_ghZ, 739, check)
      call createCurrent(P_ghWp, P_A, P_ghWpAnti, P_A, 2962, check)
      call createCurrent(P_HlQ, P_WPlus, P_WMinus, P_HlQ, 4825, check)
      call createCurrent(P_WQMinus, P_c, P_sAnti, 4474, check)
      call createCurrent(P_ghWp, P_ghWpAnti, P_GPlus, P_GMinus, 3150, check)
      call createCurrent(P_WQPlus, P_Hh, P_WQMinus, 4392, check)
      call createCurrent(P_A, P_ghA, P_ghWpAnti, P_WPlus, 1319, check)
      call createCurrent(P_GMinus, P_nu_mu, P_muPlus, 4575, check)
      call createCurrent(P_WPlus, P_WMinus, P_GMinus, P_GPlus, 716, check)
      call createCurrent(P_A, P_WPlus, P_Z, P_WMinus, 3521, check)
      call createCurrent(P_GPlus, P_GMinus, P_ghAAnti, P_ghA, 1572, check)
      call createCurrent(P_A, P_tAnti, P_t, 1278, check)
      call createCurrent(P_ghZAnti, P_Z, P_WPlus, P_ghWm, 2230, check)
      call createCurrent(P_GQMinus, P_muPlus, P_nu_mu, 3258, check)
      call createCurrent(P_ghZ, P_ghWpAnti, P_Hl, P_GPlus, 2229, check)
      call createCurrent(P_GMinus, P_Hh, P_ghWmAnti, P_ghA, 2030, check)
      call createCurrent(P_ghGAnti, P_g, P_g, P_ghG, 886, check)
      call createCurrent(P_HhQ, P_G0, P_ghWmAnti, P_ghWm, 4290, check)
      call createCurrent(P_G0, P_G0, P_A, P_Z, 5039, check)
      call createCurrent(P_Hh, P_Z, P_Z, P_Hl, 48, check)
      call createCurrent(P_A, P_g, P_g, P_Z, 5197, check)
      call createCurrent(P_ePlus, P_eMinus, 4992, check)
      call createCurrent(P_AQ, P_G0, P_GMinus, P_WQPlus, 4423, check)
      call createCurrent(P_bAnti, P_t, P_WQMinus, 2875, check)
      call createCurrent(P_nu_tau, P_nu_tauAnti, P_Z, 2068, check)
      call createCurrent(P_ghWmAnti, P_WMinus, P_ghA, 4691, check)
      call createCurrent(P_GMinus, P_ghZ, P_ghWmAnti, 4909, check)
      call createCurrent(P_WQPlus, P_WMinus, P_ghZ, P_ghZAnti, 3868, check)
      call createCurrent(P_GQMinus, P_A, P_A, P_GQPlus, 2341, check)
      call createCurrent(P_WPlus, P_GMinus, P_Hl, P_Z, 463, check)
      call createCurrent(P_ghWp, P_Z, P_ghWpAnti, P_Z, 4945, check)
      call createCurrent(P_ghZAnti, P_ghWm, P_G0, P_GQPlus, 4523, check)
      call createCurrent(P_WQMinus, P_GMinus, P_GPlus, P_WQPlus, 1911, check)
      call createCurrent(P_ghWp, P_WMinus, P_ghZAnti, P_A, 1968, check)
      call createCurrent(P_ZQ, P_muPlus, P_muMinus, 1812, check)
      call createCurrent(P_A, P_Z, P_Hh, 5086, check)
      call createCurrent(P_HlQ, P_Hl, P_Hl, P_HhQ, 859, check)
      call createCurrent(P_A, P_WMinus, P_ghAAnti, P_ghWp, 1422, check)
      call createCurrent(P_ghWpAnti, P_ghA, P_Hh, P_GPlus, 4267, check)
      call createCurrent(P_ghWpAnti, P_ghZ, P_GPlus, 745, check)
      call createCurrent(P_t, P_bAnti, P_GMinus, 2081, check)
      call createCurrent(P_Hh, P_b, P_bAnti, 3298, check)
      call createCurrent(P_g, P_Z, P_g, P_g, 5219, check)
      call createCurrent(P_ghA, P_A, P_ghWmAnti, P_WQMinus, 3139, check)
      call createCurrent(P_ghZ, P_WMinus, P_Z, P_ghWmAnti, 3648, check)
      call createCurrent(P_WMinus, P_WPlus, P_ghZ, P_ghAAnti, 2515, check)
      call createCurrent(P_WPlus, P_WMinus, P_ghZ, P_ghAAnti, 2832, check)
      call createCurrent(P_ghWmAnti, P_A, P_ghA, P_WQMinus, 968, check)
      call createCurrent(P_HhQ, P_s, P_sAnti, 4659, check)
      call createCurrent(P_ghAAnti, P_GPlus, P_ghWm, P_HhQ, 1350, check)
      call createCurrent(P_ghZ, P_Hl, P_ghWmAnti, P_GQMinus, 4471, check)
      call createCurrent(P_ghWm, P_Hh, P_GPlus, P_ghAAnti, 3061, check)
      call createCurrent(P_GQMinus, P_Z, P_GPlus, P_ZQ, 2277, check)
      call createCurrent(P_ghWp, P_ghWpAnti, P_A, 4766, check)
      call createCurrent(P_ZQ, P_Hl, P_ZQ, 2097, check)
      call createCurrent(P_ghZAnti, P_ghA, P_GPlus, P_GMinus, 2439, check)
      call createCurrent(P_Z, P_A, P_WPlus, P_WMinus, 898, check)
      call createCurrent(P_G0, P_ghZ, P_ghWpAnti, P_GPlus, 4003, check)
      call createCurrent(P_ghWpAnti, P_WPlus, P_WMinus, P_ghWp, 4618, check)
      call createCurrent(P_nu_tau, P_tauPlus, P_GMinus, 2959, check)
      call createCurrent(P_GMinus, P_A, P_WPlus, P_G0, 362, check)
      call createCurrent(P_t, P_tAnti, P_Z, 1613, check)
      call createCurrent(P_Z, P_GPlus, P_G0, P_WMinus, 4005, check)
      call createCurrent(P_GQPlus, P_GMinus, P_GPlus, P_GQMinus, 1125, check)
      call createCurrent(P_GMinus, P_WPlus, P_Hh, P_A, 4143, check)
      call createCurrent(P_ghWp, P_ghZAnti, P_Hh, P_GMinus, 2098, check)
      call createCurrent(P_ghWpAnti, P_ghWp, P_G0, P_GQ0, 460, check)
      call createCurrent(P_ZQ, P_WMinus, P_Z, P_WQPlus, 3357, check)
      call createCurrent(P_HlQ, P_GMinus, P_Hl, P_GQPlus, 892, check)
      call createCurrent(P_GPlus, P_uAnti, P_d, 1507, check)
      call createCurrent(P_G0, P_GPlus, P_ghWm, P_ghZAnti, 3813, check)
      call createCurrent(P_Z, P_ghAAnti, P_ghWm, P_WPlus, 4479, check)
      call createCurrent(P_Z, P_ghWm, P_Z, P_ghWmAnti, 1963, check)
      call createCurrent(P_WMinus, P_Hh, P_GPlus, P_A, 366, check)
      call createCurrent(P_ghZ, P_ghWpAnti, P_WQPlus, 1229, check)
      call createCurrent(P_A, P_A, P_G0, P_G0, 5156, check)
      call createCurrent(P_ghZ, P_ghWmAnti, P_Z, P_WMinus, 4509, check)
      call createCurrent(P_Hl, P_Hh, P_Hl, 100, check)
      call createCurrent(P_G0, P_tauMinus, P_tauPlus, 1362, check)
      call createCurrent(P_ghA, P_GPlus, P_ghZAnti, P_GMinus, 1682, check)
      call createCurrent(P_GPlus, P_ghZ, P_ghWpAnti, P_Hh, 1444, check)
      call createCurrent(P_G0, P_s, P_sAnti, 1182, check)
      call createCurrent(P_ghZAnti, P_ghZ, P_WPlus, P_WMinus, 3434, check)
      call createCurrent(P_ghWpAnti, P_WPlus, P_ghWp, P_WQMinus, 2409, check)
      call createCurrent(P_AQ, P_muMinus, P_muPlus, 4101, check)
      call createCurrent(P_ghWm, P_ghWmAnti, P_Z, P_A, 569, check)
      call createCurrent(P_GQ0, P_ghZ, P_GPlus, P_ghWpAnti, 3439, check)
      call createCurrent(P_A, P_ghA, P_WMinus, P_ghWmAnti, 2525, check)
      call createCurrent(P_ghZ, P_ghWpAnti, P_A, P_WQPlus, 2926, check)
      call createCurrent(P_ghWpAnti, P_Hh, P_GPlus, P_ghZ, 2223, check)
      call createCurrent(P_ZQ, P_ghWmAnti, P_ghWm, 149, check)
      call createCurrent(P_bAnti, P_b, P_Hl, 2064, check)
      call createCurrent(P_WQMinus, P_Z, P_ghZ, P_ghWmAnti, 1527, check)
      call createCurrent(P_ZQ, P_G0, P_Z, P_GQ0, 198, check)
      call createCurrent(P_GQPlus, P_G0, P_G0, P_GQMinus, 1186, check)
      call createCurrent(P_WQMinus, P_Hh, P_GPlus, P_ZQ, 661, check)
      call createCurrent(P_HhQ, P_GPlus, P_GMinus, P_HhQ, 2227, check)
      call createCurrent(P_GQ0, P_WPlus, P_A, P_GQMinus, 4636, check)
      call createCurrent(P_nu_mu, P_muPlus, P_WQMinus, 4815, check)
      call createCurrent(P_g, P_s, P_sAnti, 2772, check)
      call createCurrent(P_GMinus, P_ghA, P_Hl, P_ghWmAnti, 1916, check)
      call createCurrent(P_muMinus, P_muPlus, P_Hl, 1920, check)
      call createCurrent(P_ghZ, P_ghWpAnti, P_GPlus, P_Hh, 698, check)
      call createCurrent(P_nu_tau, P_nu_tauAnti, 5045, check)
      call createCurrent(P_ghZAnti, P_WPlus, P_WMinus, P_ghZ, 573, check)
      call createCurrent(P_WMinus, P_Hl, P_GPlus, 113, check)
      call createCurrent(P_ghWmAnti, P_Z, P_ghZ, P_WMinus, 1957, check)
      call createCurrent(P_HlQ, P_t, P_tAnti, 4789, check)
      call createCurrent(P_A, P_A, P_Z, P_Z, 5172, check)
      call createCurrent(P_WPlus, P_ghA, P_ghZAnti, P_WMinus, 3567, check)
      call createCurrent(P_Z, P_g, P_A, P_g, 5215, check)
      call createCurrent(P_tAnti, P_t, P_G0, 2363, check)
      call createCurrent(P_HhQ, P_G0, P_GMinus, P_GQPlus, 1619, check)
      call createCurrent(P_HhQ, P_WPlus, P_WMinus, P_HhQ, 3553, check)
      call createCurrent(P_AQ, P_A, P_ghWm, P_ghWmAnti, 2028, check)
      call createCurrent(P_WPlus, P_Hl, P_A, P_GMinus, 354, check)
      call createCurrent(P_ghZ, P_ghWpAnti, P_GPlus, P_G0, 1676, check)
      call createCurrent(P_muMinus, P_A, P_muPlus, 4305, check)
      call createCurrent(P_Hh, P_G0, P_G0, P_Hh, 791, check)
      call createCurrent(P_ghWm, P_Z, P_Z, P_ghWmAnti, 1768, check)
      call createCurrent(P_HlQ, P_Hh, P_Z, P_ZQ, 1836, check)
      call createCurrent(P_b, P_bAnti, P_Hh, 234, check)
      call createCurrent(P_HlQ, P_GMinus, P_Hh, P_GQPlus, 4905, check)
      call createCurrent(P_s, P_G0, P_sAnti, 2686, check)
      call createCurrent(P_HhQ, P_muMinus, P_muPlus, 2317, check)
      call createCurrent(P_GQMinus, P_WPlus, P_G0, P_AQ, 1284, check)
      call createCurrent(P_Z, P_A, P_ghWmAnti, P_ghWm, 1156, check)
      call createCurrent(P_GQ0, P_Hl, P_G0, P_HhQ, 479, check)
      call createCurrent(P_GMinus, P_ghWp, P_ghZAnti, 2623, check)
      call createCurrent(P_Z, P_Z, P_Hh, P_Hh, 1359, check)
      call createCurrent(P_A, P_ghWm, P_ghAAnti, P_WPlus, 3402, check)
      call createCurrent(P_Hh, P_G0, P_G0, 353, check)
      call createCurrent(P_ghWmAnti, P_ghZ, P_GMinus, P_GQ0, 393, check)
      call createCurrent(P_GQ0, P_G0, P_Hh, P_HlQ, 3897, check)
      call createCurrent(P_WPlus, P_ghZ, P_ghWpAnti, P_A, 3130, check)
      call createCurrent(P_GQ0, P_Hh, P_ZQ, 3260, check)
      call createCurrent(P_nu_tauAnti, P_tauMinus, P_WPlus, 1084, check)
      call createCurrent(P_nu_e, P_nu_eAnti, P_A, 5113, check)
      call createCurrent(P_Hh, P_G0, P_Hl, P_G0, 786, check)
      call createCurrent(P_WQMinus, P_WPlus, P_Hl, P_HlQ, 2306, check)
      call createCurrent(P_WPlus, P_Hh, P_WMinus, P_Hl, 1790, check)
      call createCurrent(P_A, P_Z, P_GPlus, P_GMinus, 355, check)
      call createCurrent(P_Hl, P_Hh, P_ghWp, P_ghWpAnti, 986, check)
      call createCurrent(P_HhQ, P_WMinus, P_Hl, P_WQPlus, 2132, check)
      call createCurrent(P_A, P_Hh, P_A, P_Hh, 5236, check)
      call createCurrent(P_Hh, P_WPlus, P_GMinus, P_Z, 2958, check)
      call createCurrent(P_HhQ, P_G0, P_ghWpAnti, P_ghWp, 3231, check)
      call createCurrent(P_Hl, P_ghWpAnti, P_Hl, P_ghWp, 2089, check)
      call createCurrent(P_HlQ, P_Hl, P_GMinus, P_GQPlus, 4896, check)
      call createCurrent(P_GQPlus, P_A, P_GMinus, P_ZQ, 3118, check)
      call createCurrent(P_ghWp, P_ghWpAnti, P_Hl, P_Hh, 1470, check)
      call createCurrent(P_ghWmAnti, P_A, P_ghWm, P_Z, 2417, check)
      call createCurrent(P_GPlus, P_G0, P_WMinus, 1250, check)
      call createCurrent(P_GQ0, P_Z, P_G0, P_ZQ, 2698, check)
      call createCurrent(P_HhQ, P_Hl, P_ghZAnti, P_ghZ, 18, check)
      call createCurrent(P_GQPlus, P_Z, P_WQMinus, 3424, check)
      call createCurrent(P_Hl, P_GMinus, P_ghZAnti, P_ghWp, 3510, check)
      call createCurrent(P_c, P_cAnti, P_AQ, 3369, check)
      call createCurrent(P_WPlus, P_WPlus, P_ghWm, P_ghWpAnti, 3058, check)
      call createCurrent(P_ghWmAnti, P_ghZ, P_WQMinus, 3418, check)
      call createCurrent(P_GMinus, P_WPlus, P_Hl, P_Z, 1287, check)
      call createCurrent(P_GMinus, P_Hh, P_WPlus, P_A, 4579, check)
      call createCurrent(P_ghWm, P_WPlus, P_WPlus, P_ghWpAnti, 4653, check)
      call createCurrent(P_A, P_Hh, P_GMinus, P_WPlus, 2992, check)
      call createCurrent(P_ZQ, P_Hh, P_WPlus, P_GQMinus, 575, check)
      call createCurrent(P_GQPlus, P_GMinus, P_ghZ, P_ghZAnti, 319, check)
      call createCurrent(P_WMinus, P_GPlus, P_G0, P_Z, 3764, check)
      call createCurrent(P_Hh, P_ghWpAnti, P_GPlus, P_ghZ, 302, check)
      call createCurrent(P_ZQ, P_ePlus, P_eMinus, 1373, check)
      call createCurrent(P_HhQ, P_Hh, P_Hl, P_HhQ, 1737, check)
      call createCurrent(P_WPlus, P_ghAAnti, P_ghA, P_WMinus, 4430, check)
      call createCurrent(P_AQ, P_WPlus, P_A, P_WQMinus, 2649, check)
      call createCurrent(P_ghA, P_Hl, P_ghWmAnti, P_GMinus, 1537, check)
      call createCurrent(P_ghWmAnti, P_GMinus, P_ghZ, P_Hh, 2157, check)
      call createCurrent(P_A, P_Z, P_G0, P_G0, 4976, check)
      call createCurrent(P_ghWpAnti, P_WPlus, P_Z, P_ghA, 183, check)
      call createCurrent(P_ghWp, P_Z, P_Z, P_ghWpAnti, 4721, check)
      call createCurrent(P_Z, P_Z, P_Hl, P_Hh, 4084, check)
      call createCurrent(P_A, P_WPlus, P_WMinus, P_Z, 4529, check)
      call createCurrent(P_ghWp, P_ghWpAnti, P_Hl, P_HlQ, 4296, check)
      call createCurrent(P_Hl, P_Z, P_Z, P_Hh, 4177, check)
      call createCurrent(P_Hh, P_g, P_Hh, P_g, 5214, check)
      call createCurrent(P_AQ, P_b, P_bAnti, 726, check)
      call createCurrent(P_GQ0, P_tauPlus, P_tauMinus, 2877, check)
      call createCurrent(P_WQMinus, P_ghZ, P_A, P_ghWmAnti, 2077, check)
      call createCurrent(P_A, P_WPlus, P_GMinus, 1693, check)
      call createCurrent(P_ghWm, P_Hl, P_GPlus, P_ghZAnti, 1510, check)
      call createCurrent(P_ghZAnti, P_GMinus, P_ghWp, P_Hh, 4248, check)
      call createCurrent(P_ghWpAnti, P_Hl, P_ghWp, P_Hh, 1683, check)
      call createCurrent(P_Z, P_WMinus, P_ghZAnti, P_ghWp, 343, check)
      call createCurrent(P_GMinus, P_WPlus, P_A, P_Hl, 3082, check)
      call createCurrent(P_G0, P_ghWpAnti, P_G0, P_ghWp, 2289, check)
      call createCurrent(P_A, P_A, P_ghWp, P_ghWpAnti, 144, check)
      call createCurrent(P_nu_e, P_nu_eAnti, 5090, check)
      call createCurrent(P_WMinus, P_A, P_Hl, P_GPlus, 4056, check)
      call createCurrent(P_tAnti, P_A, P_t, 1221, check)
      call createCurrent(P_Z, P_G0, P_A, P_G0, 5033, check)
      call createCurrent(P_muMinus, P_muPlus, P_HhQ, 2384, check)
      call createCurrent(P_GQPlus, P_Hl, P_Hl, P_GQMinus, 3722, check)
      call createCurrent(P_ZQ, P_WPlus, P_ghWm, P_ghAAnti, 2302, check)
      call createCurrent(P_ZQ, P_tauPlus, P_tauMinus, 2291, check)
      call createCurrent(P_WQPlus, P_GMinus, P_Z, P_HhQ, 4791, check)
      call createCurrent(P_HlQ, P_GPlus, P_G0, P_GQMinus, 1163, check)
      call createCurrent(P_ghWm, P_WPlus, P_A, P_ghZAnti, 1138, check)
      call createCurrent(P_Hh, P_G0, P_A, 5056, check)
      call createCurrent(P_Z, P_A, P_Hl, P_Hl, 5006, check)
      call createCurrent(P_g, P_GPlus, P_g, P_GMinus, 5241, check)
      call createCurrent(P_HhQ, P_ghWpAnti, P_ghWp, 670, check)
      call createCurrent(P_muPlus, P_muMinus, P_HlQ, 3072, check)
      call createCurrent(P_Hh, P_GMinus, P_Z, P_WPlus, 3646, check)
      call createCurrent(P_Z, P_ghWp, P_ghWpAnti, 4404, check)
      call createCurrent(P_WPlus, P_GMinus, P_Hh, P_A, 3414, check)
      call createCurrent(P_s, P_sAnti, P_A, 4124, check)
      call createCurrent(P_ghZ, P_ghWpAnti, P_GPlus, P_HlQ, 4838, check)
      call createCurrent(P_GQPlus, P_Hh, P_GMinus, P_HhQ, 4564, check)
      call createCurrent(P_ghWmAnti, P_GMinus, P_ghA, P_Hl, 4216, check)
      call createCurrent(P_WPlus, P_ghWpAnti, P_A, P_ghA, 3906, check)
      call createCurrent(P_Z, P_A, P_ghWm, P_ghWmAnti, 3829, check)
      call createCurrent(P_uAnti, P_Z, P_u, 3647, check)
      call createCurrent(P_HhQ, P_Hh, P_GMinus, P_GQPlus, 2624, check)
      call createCurrent(P_t, P_tAnti, P_g, 137, check)
      call createCurrent(P_Z, P_GPlus, P_WMinus, P_G0, 3810, check)
      call createCurrent(P_WMinus, P_Hh, P_Hl, P_WPlus, 3093, check)
      call createCurrent(P_ghWm, P_ghZAnti, P_GPlus, P_G0, 4192, check)
      call createCurrent(P_ghWp, P_ghWpAnti, P_G0, P_HhQ, 2460, check)
      call createCurrent(P_AQ, P_WPlus, P_WQMinus, 1597, check)
      call createCurrent(P_WQMinus, P_A, P_WPlus, P_ZQ, 1614, check)
      call createCurrent(P_Hl, P_GMinus, P_WPlus, P_A, 815, check)
      call createCurrent(P_WQMinus, P_Hh, P_GPlus, P_AQ, 4071, check)
      call createCurrent(P_Hl, P_g, P_Hh, P_g, 5243, check)
      call createCurrent(P_WPlus, P_ghAAnti, P_WMinus, P_ghZ, 1069, check)
      call createCurrent(P_AQ, P_t, P_tAnti, 2193, check)
      call createCurrent(P_HlQ, P_GMinus, P_WQPlus, 2185, check)
      call createCurrent(P_Z, P_nu_muAnti, P_nu_mu, 2536, check)
      call createCurrent(P_Z, P_bAnti, P_b, 4849, check)
      call createCurrent(P_GQ0, P_G0, P_WMinus, P_WQPlus, 3006, check)
      call createCurrent(P_WPlus, P_Hl, P_GMinus, P_A, 1866, check)
      call createCurrent(P_tauMinus, P_tauPlus, P_HlQ, 1194, check)
      call createCurrent(P_ghWmAnti, P_ghWm, P_G0, P_G0, 4348, check)
      call createCurrent(P_GQ0, P_GPlus, P_Z, P_WQMinus, 721, check)
      call createCurrent(P_G0, P_WPlus, P_GMinus, P_A, 3204, check)
      call createCurrent(P_GQPlus, P_A, P_A, P_GQMinus, 2972, check)
      call createCurrent(P_GQMinus, P_ghZ, P_GPlus, P_ghAAnti, 1184, check)
      call createCurrent(P_GQMinus, P_GPlus, P_AQ, 2514, check)
      call createCurrent(P_WMinus, P_ghWp, P_ghWpAnti, P_WPlus, 4808, check)
      call createCurrent(P_Z, P_dAnti, P_d, 2203, check)
      call createCurrent(P_Hl, P_g, P_Hl, P_g, 5151, check)
      call createCurrent(P_WPlus, P_Z, P_ghA, P_ghWpAnti, 1131, check)
      call createCurrent(P_cAnti, P_c, P_HlQ, 4437, check)
      call createCurrent(P_A, P_WMinus, P_A, P_WPlus, 1553, check)
      call createCurrent(P_WPlus, P_WMinus, P_ghAAnti, P_ghZ, 3923, check)
      call createCurrent(P_ghWpAnti, P_ghWp, P_Hl, 634, check)
      call createCurrent(P_Hl, P_GMinus, P_Hl, P_GPlus, 740, check)
      call createCurrent(P_ghZAnti, P_ghWm, P_WPlus, P_Z, 4605, check)
      call createCurrent(P_bAnti, P_b, P_Z, 1293, check)
      call createCurrent(P_sAnti, P_Hh, P_s, 822, check)
      call createCurrent(P_HhQ, P_cAnti, P_c, 2418, check)
      call createCurrent(P_ghWpAnti, P_ghZ, P_Hh, P_GQPlus, 3855, check)
      call createCurrent(P_GPlus, P_Hh, P_ghWm, P_ghAAnti, 3109, check)
      call createCurrent(P_GPlus, P_GMinus, P_ghWp, P_ghWpAnti, 1114, check)
      call createCurrent(P_ghWp, P_A, P_ghZAnti, P_WMinus, 4372, check)
      call createCurrent(P_Hh, P_GMinus, P_WPlus, P_Z, 3913, check)
      call createCurrent(P_ghWm, P_G0, P_ghWmAnti, P_HlQ, 3573, check)
      call createCurrent(P_A, P_c, P_cAnti, 2564, check)
      call createCurrent(P_GMinus, P_GPlus, P_g, P_g, 5158, check)
      call createCurrent(P_A, P_ghWpAnti, P_ghWp, P_A, 1585, check)
      call createCurrent(P_ghZ, P_G0, P_G0, P_ghZAnti, 3575, check)
      call createCurrent(P_Z, P_Hh, P_G0, 4293, check)
      call createCurrent(P_HlQ, P_uAnti, P_u, 684, check)
      call createCurrent(P_g, P_dAnti, P_d, 1915, check)
      call createCurrent(P_Z, P_tauMinus, P_tauPlus, 3729, check)
      call createCurrent(P_ZQ, P_Z, P_ghWmAnti, P_ghWm, 3767, check)
      call createCurrent(P_GQPlus, P_GPlus, P_GMinus, P_GQMinus, 2380, check)
      call createCurrent(P_A, P_uAnti, P_u, 2048, check)
      call createCurrent(P_A, P_GPlus, P_GMinus, P_A, 4450, check)
      call createCurrent(P_GPlus, P_Z, P_GMinus, 1356, check)
      call createCurrent(P_GQMinus, P_WPlus, P_AQ, 1108, check)
      call createCurrent(P_ghZAnti, P_Hh, P_ghWm, P_GQPlus, 2502, check)
      call createCurrent(P_muPlus, P_muMinus, P_GQ0, 2178, check)
      call createCurrent(P_ghAAnti, P_ghZ, P_WMinus, P_WPlus, 3735, check)
      call createCurrent(P_ghZAnti, P_ghZ, P_HhQ, 4401, check)
      call createCurrent(P_WQMinus, P_ghZ, P_WPlus, P_ghZAnti, 1307, check)
      call createCurrent(P_HhQ, P_Z, P_Z, P_HlQ, 3790, check)
      call createCurrent(P_GMinus, P_Z, P_GPlus, P_Z, 3784, check)
      call createCurrent(P_Hl, P_Hl, 4994, check)
      call createCurrent(P_ZQ, P_Hh, P_ZQ, 607, check)
      call createCurrent(P_ghWp, P_ghZAnti, P_Z, P_WMinus, 133, check)
      call createCurrent(P_uAnti, P_u, 5027, check)
      call createCurrent(P_c, P_cAnti, P_HlQ, 1984, check)
      call createCurrent(P_ghWp, P_Hl, P_Hl, P_ghWpAnti, 4790, check)
      call createCurrent(P_Z, P_A, P_GPlus, P_GMinus, 2087, check)
      call createCurrent(P_GQPlus, P_tAnti, P_b, 1997, check)
      call createCurrent(P_ghWm, P_GPlus, P_ghZAnti, P_HhQ, 2552, check)
      call createCurrent(P_GQPlus, P_G0, P_ghWpAnti, P_ghA, 3816, check)
      call createCurrent(P_eMinus, P_nu_eAnti, P_WPlus, 531, check)
      call createCurrent(P_ghA, P_ghZAnti, P_WMinus, P_WQPlus, 1864, check)
      call createCurrent(P_WMinus, P_WPlus, P_ghAAnti, P_ghA, 4440, check)
      call createCurrent(P_WPlus, P_WMinus, P_g, P_g, 5148, check)
      call createCurrent(P_nu_tau, P_nu_tauAnti, P_ZQ, 468, check)
      call createCurrent(P_Hh, P_WMinus, P_WPlus, P_Hl, 657, check)
      call createCurrent(P_ghA, P_ghWmAnti, P_Hl, P_GMinus, 44, check)
      call createCurrent(P_G0, P_G0, P_Z, P_Z, 3696, check)
      call createCurrent(P_GMinus, P_G0, P_ghZAnti, P_ghWp, 1996, check)
      call createCurrent(P_GQMinus, P_ghAAnti, P_GPlus, P_ghA, 4133, check)
      call createCurrent(P_Hh, P_ghWm, P_ghWmAnti, P_Hl, 220, check)
      call createCurrent(P_A, P_ghWp, P_ghZAnti, P_WMinus, 1066, check)
      call createCurrent(P_GQ0, P_sAnti, P_s, 1202, check)
      call createCurrent(P_Hl, P_ghA, P_GPlus, P_ghWpAnti, 4744, check)
      call createCurrent(P_Hl, P_Hl, P_GPlus, P_GMinus, 2080, check)
      call createCurrent(P_ZQ, P_Z, P_G0, P_GQ0, 4698, check)
      call createCurrent(P_Z, P_GMinus, P_WPlus, 990, check)
      call createCurrent(P_Z, P_WMinus, P_ghWmAnti, P_ghA, 452, check)
      call createCurrent(P_Z, P_GMinus, P_Hl, P_WPlus, 1734, check)
      call createCurrent(P_g, P_Hh, P_Hl, P_g, 5180, check)
      call createCurrent(P_ghA, P_GMinus, P_ghWmAnti, P_Hl, 4907, check)
      call createCurrent(P_GQPlus, P_G0, P_ghZAnti, P_ghWm, 4020, check)
      call createCurrent(P_WQMinus, P_ghWmAnti, P_Z, P_ghA, 4174, check)
      call createCurrent(P_A, P_g, P_g, P_g, 5200, check)
      call createCurrent(P_Hl, P_ghWpAnti, P_GPlus, P_ghA, 2871, check)
      call createCurrent(P_g, P_c, P_cAnti, 1431, check)
      call createCurrent(P_ghZ, P_A, P_ghWpAnti, P_WQPlus, 2996, check)
      call createCurrent(P_s, P_cAnti, P_GQPlus, 4175, check)
      call createCurrent(P_WQPlus, P_A, P_ghA, P_ghWpAnti, 2357, check)
      call createCurrent(P_ghWpAnti, P_ghZ, P_GPlus, P_Hh, 4647, check)
      call createCurrent(P_Hl, P_GMinus, P_GPlus, 851, check)
      call createCurrent(P_AQ, P_ghWp, P_Z, P_ghWpAnti, 2862, check)
      call createCurrent(P_b, P_Hh, P_bAnti, 797, check)
      call createCurrent(P_Hh, P_A, P_A, P_Hh, 5205, check)
      call createCurrent(P_ghWp, P_ghZAnti, P_GMinus, P_Hl, 3710, check)
      call createCurrent(P_G0, P_Hh, P_Hh, P_G0, 3849, check)
      call createCurrent(P_ghWmAnti, P_WMinus, P_ghZ, P_Z, 3548, check)
      call createCurrent(P_GQPlus, P_WMinus, P_WPlus, P_GQMinus, 4708, check)
      call createCurrent(P_WPlus, P_ghWp, P_ghWpAnti, P_WMinus, 4145, check)
      call createCurrent(P_HhQ, P_A, P_WMinus, P_GQPlus, 4568, check)
      call createCurrent(P_A, P_ghZ, P_ghWpAnti, P_WPlus, 1607, check)
      call createCurrent(P_GMinus, P_GPlus, P_ghZ, P_ghAAnti, 3541, check)
      call createCurrent(P_GMinus, P_ghZ, P_ghWmAnti, P_G0, 1566, check)
      call createCurrent(P_WQMinus, P_Z, P_GPlus, P_GQ0, 3574, check)
      call createCurrent(P_ghWp, P_Hl, P_ghAAnti, P_GMinus, 2331, check)
      call createCurrent(P_dAnti, P_d, 5010, check)
      call createCurrent(P_ghWp, P_WMinus, P_ghWpAnti, P_WPlus, 219, check)
      call createCurrent(P_GMinus, P_WPlus, P_Z, P_G0, 1965, check)
      call createCurrent(P_GQ0, P_WPlus, P_WQMinus, 600, check)
      call createCurrent(P_s, P_sAnti, P_Z, 1258, check)
      call createCurrent(P_Z, P_Z, P_g, P_g, 5220, check)
      call createCurrent(P_HhQ, P_Hh, P_Hl, P_HlQ, 1764, check)
      call createCurrent(P_ghWp, P_ghWpAnti, P_WPlus, P_WQMinus, 3595, check)
      call createCurrent(P_ghWm, P_GPlus, P_ghAAnti, P_HhQ, 2733, check)
      call createCurrent(P_Z, P_ghWm, P_ghWmAnti, 1469, check)
      call createCurrent(P_HhQ, P_GPlus, P_A, P_WQMinus, 3749, check)
      call createCurrent(P_ZQ, P_GMinus, P_Z, P_GQPlus, 2605, check)
      call createCurrent(P_A, P_ghZAnti, P_ghWm, P_WPlus, 771, check)
      call createCurrent(P_GPlus, P_ghWpAnti, P_G0, P_ghZ, 1436, check)
      call createCurrent(P_Z, P_WPlus, P_GMinus, P_Hl, 808, check)
      call createCurrent(P_ghWp, P_ghZAnti, P_WMinus, P_Z, 861, check)
      call createCurrent(P_ZQ, P_GPlus, P_Hl, P_WQMinus, 1938, check)
      call createCurrent(P_Z, P_Hh, P_WMinus, P_GPlus, 893, check)
      call createCurrent(P_GPlus, P_Hh, P_WMinus, 2279, check)
      call createCurrent(P_g, P_d, P_dAnti, 1669, check)
      call createCurrent(P_ghWmAnti, P_ghWm, P_G0, P_HlQ, 4022, check)
      call createCurrent(P_ghAAnti, P_A, P_ghWm, P_WPlus, 1621, check)
      call createCurrent(P_WMinus, P_ghWmAnti, P_ghZ, P_A, 1453, check)
      call createCurrent(P_Hh, P_GMinus, P_ghWp, P_ghAAnti, 4396, check)
      call createCurrent(P_ZQ, P_GMinus, P_A, P_GQPlus, 730, check)
      call createCurrent(P_WQMinus, P_Z, P_ghA, P_ghWmAnti, 2920, check)
      call createCurrent(P_cAnti, P_g, P_c, 2479, check)
      call createCurrent(P_GQPlus, P_GMinus, P_Hl, P_HhQ, 4864, check)
      call createCurrent(P_A, P_cAnti, P_c, 1703, check)
      call createCurrent(P_WQPlus, P_WMinus, P_HlQ, 3366, check)
      call createCurrent(P_GPlus, P_ghZ, P_ghZAnti, P_GMinus, 4421, check)
      call createCurrent(P_u, P_dAnti, P_GQMinus, 1967, check)
      call createCurrent(P_ghGAnti, P_ghG, P_g, P_gQ, 4351, check)
      call createCurrent(P_ghZ, P_G0, P_ghZAnti, P_GQ0, 1188, check)
      call createCurrent(P_WPlus, P_ghA, P_A, P_ghWpAnti, 1863, check)
      call createCurrent(P_GMinus, P_Z, P_A, P_GPlus, 4405, check)
      call createCurrent(P_nu_eAnti, P_eMinus, P_WQPlus, 4633, check)
      call createCurrent(P_GQPlus, P_ghWpAnti, P_Hl, P_ghA, 2415, check)
      call createCurrent(P_GPlus, P_ghWm, P_Hl, P_ghAAnti, 592, check)
      call createCurrent(P_ghWpAnti, P_ghA, P_G0, P_GQPlus, 1403, check)
      call createCurrent(P_ghWpAnti, P_GPlus, P_GMinus, P_ghWp, 3634, check)
      call createCurrent(P_nu_tau, P_tauPlus, P_GQMinus, 1095, check)
      call createCurrent(P_WPlus, P_ghWpAnti, P_WPlus, P_ghWm, 3966, check)
      call createCurrent(P_GMinus, P_GPlus, P_ghZAnti, P_ghA, 4731, check)
      call createCurrent(P_HhQ, P_Hh, P_ghZAnti, P_ghZ, 128, check)
      call createCurrent(P_HlQ, P_GMinus, P_GPlus, P_HlQ, 2821, check)
      call createCurrent(P_g, P_tAnti, P_t, 1139, check)
      call createCurrent(P_GQPlus, P_GMinus, P_ghA, P_ghZAnti, 3947, check)
      call createCurrent(P_GQPlus, P_GMinus, P_ghAAnti, P_ghA, 4786, check)
      call createCurrent(P_HlQ, P_WMinus, P_Hl, P_WQPlus, 1921, check)
      call createCurrent(P_Hl, P_Hl, P_Hh, 4030, check)
      call createCurrent(P_Hl, P_ghZAnti, P_ghZ, P_Hh, 2517, check)
      call createCurrent(P_ghWp, P_Z, P_WMinus, P_ghZAnti, 3777, check)
      call createCurrent(P_cAnti, P_Hl, P_c, 1053, check)
      call createCurrent(P_WPlus, P_WMinus, P_G0, P_G0, 2782, check)
      call createCurrent(P_WQMinus, P_ghWmAnti, P_A, P_ghZ, 1203, check)
      call createCurrent(P_HhQ, P_GPlus, P_Hh, P_GQMinus, 2262, check)
      call createCurrent(P_ghWm, P_ghWmAnti, P_Hl, 3973, check)
      call createCurrent(P_Hh, P_WPlus, P_A, P_GMinus, 908, check)
      call createCurrent(P_ZQ, P_GMinus, P_WPlus, P_HhQ, 2350, check)
      call createCurrent(P_Z, P_Z, P_Z, P_Z, 5251, check)
      call createCurrent(P_GQ0, P_ghWp, P_ghWpAnti, 757, check)
      call createCurrent(P_Hh, P_Hl, P_A, P_Z, 5057, check)
      call createCurrent(P_ghWpAnti, P_Hh, P_ghA, P_GPlus, 3854, check)
      call createCurrent(P_AQ, P_Z, P_WPlus, P_WQMinus, 530, check)
      call createCurrent(P_ZQ, P_Hl, P_GQ0, 4018, check)
      call createCurrent(P_ZQ, P_Hh, P_Z, P_HhQ, 4875, check)
      call createCurrent(P_Z, P_A, P_g, P_g, 5217, check)
      call createCurrent(P_Hl, P_WPlus, P_WMinus, 3255, check)
      call createCurrent(P_ghWp, P_ghWpAnti, P_GQ0, 834, check)
      call createCurrent(P_WMinus, P_ghZ, P_WPlus, P_ghAAnti, 4098, check)
      call createCurrent(P_t, P_tAnti, P_HlQ, 4625, check)
      call createCurrent(P_Hh, P_WPlus, P_Hh, P_WMinus, 3719, check)
      call createCurrent(P_t, P_g, P_tAnti, 2066, check)
      call createCurrent(P_AQ, P_WPlus, P_Hl, P_GQMinus, 3333, check)
      call createCurrent(P_WMinus, P_GPlus, P_A, P_Hl, 2930, check)
      call createCurrent(P_GQPlus, P_ghA, P_GMinus, P_ghAAnti, 3589, check)
      call createCurrent(P_ghWm, P_Hh, P_ghAAnti, P_GPlus, 2266, check)
      call createCurrent(P_ghZAnti, P_GPlus, P_ghWm, P_HhQ, 316, check)
      call createCurrent(P_Z, P_Hh, P_Hh, P_Z, 2888, check)
      call createCurrent(P_ghWpAnti, P_G0, P_ghWp, P_HlQ, 3108, check)
      call createCurrent(P_ghWmAnti, P_ghA, P_GMinus, 1550, check)
      call createCurrent(P_ghAAnti, P_GPlus, P_Hh, P_ghWm, 3557, check)
      call createCurrent(P_ghWm, P_WPlus, P_ghWpAnti, P_WPlus, 1176, check)
      call createCurrent(P_WPlus, P_WMinus, P_ghA, P_ghAAnti, 4331, check)
      call createCurrent(P_Z, P_ghWp, P_Z, P_ghWpAnti, 415, check)
      call createCurrent(P_ghG, P_ghGAnti, P_g, 630, check)
      call createCurrent(P_WPlus, P_Hl, P_GMinus, P_Z, 1144, check)
      call createCurrent(P_G0, P_WMinus, P_GPlus, P_A, 4969, check)
      call createCurrent(P_ghZAnti, P_ghWm, P_Hl, P_GPlus, 1805, check)
      call createCurrent(P_ghWm, P_Hl, P_ghWmAnti, P_Hh, 1238, check)
      call createCurrent(P_ghAAnti, P_ghA, P_GPlus, P_GQMinus, 3284, check)
      call createCurrent(P_WPlus, P_ghAAnti, P_Z, P_ghWm, 1779, check)
      call createCurrent(P_ghWp, P_ghAAnti, P_GMinus, P_GQ0, 105, check)
      call createCurrent(P_HhQ, P_WPlus, P_A, P_GQMinus, 1116, check)
      call createCurrent(P_WPlus, P_A, P_A, P_WMinus, 2128, check)
      call createCurrent(P_nu_tau, P_A, P_nu_tauAnti, 5004, check)
      call createCurrent(P_WQPlus, P_WMinus, P_G0, P_GQ0, 4460, check)
      call createCurrent(P_ghWmAnti, P_ghA, P_WQMinus, 2468, check)
      call createCurrent(P_ghA, P_WPlus, P_ghWpAnti, 3621, check)
      call createCurrent(P_Z, P_ghWmAnti, P_ghWm, P_Z, 1979, check)
      call createCurrent(P_GPlus, P_GMinus, P_ghZ, P_ghZAnti, 2866, check)
      call createCurrent(P_G0, P_u, P_uAnti, 4630, check)
      call createCurrent(P_GQ0, P_Hl, P_GPlus, P_GQMinus, 2641, check)
      call createCurrent(P_GQPlus, P_WMinus, P_G0, P_ZQ, 4270, check)
      call createCurrent(P_Hl, P_d, P_dAnti, 4683, check)
      call createCurrent(P_ZQ, P_WPlus, P_G0, P_GQMinus, 973, check)
      call createCurrent(P_A, P_Hh, P_A, P_Hl, 5238, check)
      call createCurrent(P_ghWmAnti, P_ghWm, P_Hh, P_HhQ, 3673, check)
      call createCurrent(P_Hh, P_eMinus, P_ePlus, 593, check)
      call createCurrent(P_WQPlus, P_WMinus, P_G0, P_HhQ, 1926, check)
      call createCurrent(P_muPlus, P_muMinus, 5001, check)
      call createCurrent(P_ghWm, P_ghZAnti, P_GPlus, P_GQ0, 4407, check)
      call createCurrent(P_tauPlus, P_tauMinus, P_A, 1244, check)
      call createCurrent(P_WMinus, P_GPlus, P_Z, 3081, check)
      call createCurrent(P_Hh, P_ghZAnti, P_Hh, P_ghZ, 4513, check)
      call createCurrent(P_ghZAnti, P_ghZ, P_Hl, P_HlQ, 4546, check)
      call createCurrent(P_HlQ, P_G0, P_Hl, P_GQ0, 1983, check)
      call createCurrent(P_GQPlus, P_ghZAnti, P_Hh, P_ghWm, 581, check)
      call createCurrent(P_Hh, P_ghWmAnti, P_ghWm, P_Hh, 1684, check)
      call createCurrent(P_WMinus, P_A, P_GPlus, P_Hl, 192, check)
      call createCurrent(P_GMinus, P_Z, P_WPlus, P_Hl, 243, check)
      call createCurrent(P_uAnti, P_G0, P_u, 181, check)
      call createCurrent(P_ghWm, P_WPlus, P_ghAAnti, P_Z, 1847, check)
      call createCurrent(P_WPlus, P_WMinus, P_A, P_A, 1272, check)
      call createCurrent(P_WQMinus, P_WPlus, P_WMinus, P_WQPlus, 2217, check)
      call createCurrent(P_GQPlus, P_Hh, P_WMinus, P_ZQ, 4378, check)
      call createCurrent(P_dAnti, P_d, P_Z, 1351, check)
      call createCurrent(P_ghA, P_Z, P_ghWpAnti, P_WQPlus, 1083, check)
      call createCurrent(P_AQ, P_ghWp, P_WMinus, P_ghZAnti, 3763, check)
      call createCurrent(P_GMinus, P_ghZAnti, P_Hl, P_ghWp, 3689, check)
      call createCurrent(P_Hl, P_ghZAnti, P_Hh, P_ghZ, 4597, check)
      call createCurrent(P_Z, P_A, P_Hh, P_Hl, 5063, check)
      call createCurrent(P_GMinus, P_WPlus, P_Hl, 2053, check)
      call createCurrent(P_WMinus, P_GPlus, P_G0, P_A, 2878, check)
      call createCurrent(P_nu_eAnti, P_nu_e, P_ZQ, 2646, check)
      call createCurrent(P_ZQ, P_GMinus, P_Hl, P_WQPlus, 3594, check)
      call createCurrent(P_GQ0, P_GMinus, P_WPlus, P_ZQ, 2389, check)
      call createCurrent(P_GQMinus, P_GPlus, P_Z, P_ZQ, 2890, check)
      call createCurrent(P_ghWmAnti, P_ghWm, P_GMinus, P_GPlus, 1886, check)
      call createCurrent(P_Hl, P_ghZAnti, P_ghZ, 3844, check)
      call createCurrent(P_A, P_GPlus, P_Hh, P_WMinus, 3675, check)
      call createCurrent(P_ghZ, P_GPlus, P_ghAAnti, P_GQMinus, 697, check)
      call createCurrent(P_ghWmAnti, P_ghWm, P_HlQ, 4059, check)
      call createCurrent(P_ghWp, P_Z, P_ghAAnti, P_WMinus, 1218, check)
      call createCurrent(P_ghWmAnti, P_ghZ, P_WMinus, P_A, 4026, check)
      call createCurrent(P_Hl, P_u, P_uAnti, 294, check)
      call createCurrent(P_ghWmAnti, P_ghWm, P_A, 3039, check)
      call createCurrent(P_WQMinus, P_WPlus, P_Hh, P_HhQ, 3090, check)
      call createCurrent(P_ghZAnti, P_ghWp, P_GMinus, P_Hl, 3910, check)
      call createCurrent(P_WPlus, P_ghA, P_WMinus, P_ghAAnti, 501, check)
      call createCurrent(P_Z, P_G0, P_GPlus, P_WMinus, 2356, check)
      call createCurrent(P_Hl, P_ghWp, P_ghWpAnti, 1712, check)
      call createCurrent(P_ZQ, P_GPlus, P_GMinus, P_ZQ, 3620, check)
      call createCurrent(P_Z, P_ghWpAnti, P_ghWp, 3885, check)
      call createCurrent(P_ZQ, P_WMinus, P_WPlus, P_ZQ, 3939, check)
      call createCurrent(P_GMinus, P_ghWp, P_Hh, P_ghAAnti, 291, check)
      call createCurrent(P_AQ, P_GMinus, P_GQPlus, 2702, check)
      call createCurrent(P_HlQ, P_Hh, P_HlQ, 2826, check)
      call createCurrent(P_HhQ, P_G0, P_G0, P_HhQ, 989, check)
      call createCurrent(P_GMinus, P_G0, P_WPlus, P_Z, 444, check)
      call createCurrent(P_ghWpAnti, P_ghZ, P_A, P_WPlus, 1270, check)
      call createCurrent(P_A, P_Hh, P_A, 5201, check)
      call createCurrent(P_GMinus, P_A, P_GPlus, P_A, 2267, check)
      call createCurrent(P_WPlus, P_G0, P_Z, P_GMinus, 4141, check)
      call createCurrent(P_GMinus, P_WMinus, P_GPlus, P_WPlus, 3962, check)
      call createCurrent(P_HlQ, P_Hl, P_G0, P_GQ0, 3480, check)
      call createCurrent(P_GQPlus, P_WMinus, P_A, P_HhQ, 1242, check)
      call createCurrent(P_WMinus, P_A, P_ghA, P_ghWmAnti, 447, check)
      call createCurrent(P_ZQ, P_ghWm, P_A, P_ghWmAnti, 1093, check)
      call createCurrent(P_WMinus, P_nu_e, P_ePlus, 4446, check)
      call createCurrent(P_ghWp, P_A, P_ghWpAnti, 2174, check)
      call createCurrent(P_WMinus, P_GPlus, P_Hh, 1646, check)
      call createCurrent(P_Hl, P_ghWm, P_ghWmAnti, P_Hh, 4943, check)
      call createCurrent(P_ghZ, P_Hh, P_ghWpAnti, P_GPlus, 4086, check)
      call createCurrent(P_g, P_u, P_uAnti, 1249, check)
      call createCurrent(P_HlQ, P_G0, P_ghWp, P_ghWpAnti, 2366, check)
      call createCurrent(P_ghZAnti, P_ghWp, P_WMinus, P_A, 1395, check)
      call createCurrent(P_ghWp, P_Z, P_ghWpAnti, P_AQ, 2388, check)
      call createCurrent(P_AQ, P_GPlus, P_GMinus, P_ZQ, 69, check)
      call createCurrent(P_eMinus, P_A, P_ePlus, 3536, check)
      call createCurrent(P_Hl, P_Hh, P_Hl, P_Hl, 3679, check)
      call createCurrent(P_AQ, P_GMinus, P_A, P_GQPlus, 2526, check)
      call createCurrent(P_WMinus, P_G0, P_WPlus, P_G0, 194, check)
      call createCurrent(P_ghZ, P_Hl, P_ghZAnti, P_Hl, 4811, check)
      call createCurrent(P_A, P_ghWmAnti, P_ghZ, P_WMinus, 3600, check)
      call createCurrent(P_ghZ, P_ghWmAnti, P_G0, P_GMinus, 17, check)
      call createCurrent(P_GPlus, P_WMinus, P_Hl, P_Z, 3999, check)
      call createCurrent(P_ghAAnti, P_G0, P_GMinus, P_ghWp, 2622, check)
      call createCurrent(P_nu_tauAnti, P_Z, P_nu_tau, 977, check)
      call createCurrent(P_nu_muAnti, P_GPlus, P_muMinus, 1077, check)
      call createCurrent(P_ghZ, P_Hl, P_ghWpAnti, P_GQPlus, 4054, check)
      call createCurrent(P_WQPlus, P_Hl, P_GMinus, P_ZQ, 2703, check)
      call createCurrent(P_GMinus, P_ghWp, P_G0, P_ghZAnti, 2450, check)
      call createCurrent(P_ghZ, P_WPlus, P_Z, P_ghWpAnti, 1711, check)
      call createCurrent(P_WQPlus, P_Z, P_A, P_WQMinus, 139, check)
      call createCurrent(P_uAnti, P_d, P_GPlus, 2889, check)
      call createCurrent(P_GPlus, P_GMinus, P_Z, 2775, check)
      call createCurrent(P_Hl, P_Hh, P_WMinus, P_WPlus, 1263, check)
      call createCurrent(P_WQMinus, P_GPlus, P_Hh, P_ZQ, 3820, check)
      call createCurrent(P_HlQ, P_Hh, P_Hh, P_HlQ, 2983, check)
      call createCurrent(P_AQ, P_Hl, P_GMinus, P_WQPlus, 4424, check)
      call createCurrent(P_WMinus, P_GPlus, P_Hl, P_Z, 3540, check)
      call createCurrent(P_ghZ, P_GMinus, P_Hh, P_ghWmAnti, 95, check)
      call createCurrent(P_tauMinus, P_tauPlus, P_GQ0, 4096, check)
      call createCurrent(P_ghZAnti, P_ghA, P_GPlus, P_GQMinus, 4544, check)
      call createCurrent(P_GQ0, P_WPlus, P_GQMinus, 2164, check)
      call createCurrent(P_G0, P_GMinus, P_GPlus, P_G0, 1410, check)
      call createCurrent(P_A, P_GMinus, P_A, P_GPlus, 1878, check)
      call createCurrent(P_dAnti, P_u, P_GMinus, 3969, check)
      call createCurrent(P_WPlus, P_A, P_WMinus, P_Z, 4706, check)
      call createCurrent(P_Z, P_Hh, P_Z, P_Hh, 3436, check)
      call createCurrent(P_GPlus, P_ghAAnti, P_Hh, P_ghWm, 633, check)
      call createCurrent(P_GMinus, P_A, P_GPlus, P_Z, 4788, check)
      call createCurrent(P_sAnti, P_s, P_A, 3370, check)
      call createCurrent(P_ghAAnti, P_Hl, P_ghWp, P_GMinus, 4102, check)
      call createCurrent(P_ghZ, P_Hl, P_GPlus, P_ghWpAnti, 4044, check)
      call createCurrent(P_WQMinus, P_WPlus, P_ghZ, P_ghZAnti, 4100, check)
      call createCurrent(P_GQMinus, P_Z, P_Hh, P_WQPlus, 4332, check)
      call createCurrent(P_WQPlus, P_Hh, P_Hh, P_WQMinus, 1976, check)
      call createCurrent(P_GMinus, P_Hh, P_GPlus, P_Hh, 4532, check)
      call createCurrent(P_HlQ, P_A, P_GPlus, P_WQMinus, 3971, check)
      call createCurrent(P_Hl, P_ghZ, P_ghWmAnti, P_GMinus, 346, check)
      call createCurrent(P_GMinus, P_ghZAnti, P_GPlus, P_ghA, 2748, check)
      call createCurrent(P_HhQ, P_A, P_GMinus, P_WQPlus, 1082, check)
      call createCurrent(P_Z, P_WMinus, P_ghZ, P_ghWmAnti, 3100, check)
      call createCurrent(P_u, P_uAnti, P_GQ0, 1547, check)
      call createCurrent(P_ghZ, P_ghWmAnti, P_GQMinus, 1073, check)
      call createCurrent(P_eMinus, P_ePlus, P_Z, 966, check)
      call createCurrent(P_GQPlus, P_Z, P_WMinus, P_GQ0, 177, check)
      call createCurrent(P_ghWm, P_ghAAnti, P_GPlus, P_HlQ, 1291, check)
      call createCurrent(P_Hh, P_GPlus, P_GMinus, 2544, check)
      call createCurrent(P_G0, P_Z, P_GPlus, P_WMinus, 3133, check)
      call createCurrent(P_HlQ, P_ghWp, P_G0, P_ghWpAnti, 1605, check)
      call createCurrent(P_G0, P_G0, P_WPlus, P_WMinus, 2354, check)
      call createCurrent(P_GMinus, P_ePlus, P_nu_e, 269, check)
      call createCurrent(P_GQPlus, P_ghA, P_G0, P_ghWpAnti, 4061, check)
      call createCurrent(P_G0, P_A, P_GPlus, P_WMinus, 3958, check)
      call createCurrent(P_t, P_tAnti, P_Hh, 3585, check)
      call createCurrent(P_ZQ, P_G0, P_WMinus, P_GQPlus, 533, check)
      call createCurrent(P_HhQ, P_ghWm, P_ghWmAnti, 4033, check)
      call createCurrent(P_AQ, P_WMinus, P_ghAAnti, P_ghWp, 4759, check)
      call createCurrent(P_ghZ, P_GPlus, P_ghAAnti, P_GMinus, 4199, check)
      call createCurrent(P_WQPlus, P_A, P_GMinus, P_HhQ, 1786, check)
      call createCurrent(P_Z, P_WMinus, P_ghWp, P_ghAAnti, 4522, check)
      call createCurrent(P_ghA, P_Hh, P_ghWmAnti, P_GMinus, 912, check)
      call createCurrent(P_g, P_g, P_ghG, P_ghGAnti, 2233, check)
      call createCurrent(P_ghWmAnti, P_ghA, P_A, P_WQMinus, 2155, check)
      call createCurrent(P_GPlus, P_Hl, P_ghAAnti, P_ghWm, 4770, check)
      call createCurrent(P_ghZ, P_WMinus, P_ghZAnti, P_WQPlus, 2093, check)
      call createCurrent(P_Hh, P_Hh, P_GMinus, P_GPlus, 4920, check)
      call createCurrent(P_ZQ, P_WPlus, P_Hl, P_GQMinus, 64, check)
      call createCurrent(P_ZQ, P_GMinus, P_WPlus, P_GQ0, 1998, check)
      call createCurrent(P_A, P_A, P_Hh, P_Hh, 5161, check)
      call createCurrent(P_ghWmAnti, P_GMinus, P_ghZ, P_G0, 4444, check)
      call createCurrent(P_A, P_WPlus, P_ghWpAnti, P_ghA, 3531, check)
      call createCurrent(P_ghWmAnti, P_ghA, P_WMinus, 3107, check)
      call createCurrent(P_WPlus, P_ghAAnti, P_ghWm, 164, check)
      call createCurrent(P_WQPlus, P_G0, P_Z, P_GQMinus, 3641, check)
      call createCurrent(P_GMinus, P_ghAAnti, P_GPlus, P_ghZ, 2989, check)
      call createCurrent(P_WQPlus, P_WMinus, P_Hl, P_HhQ, 1742, check)
      call createCurrent(P_WQPlus, P_WMinus, P_Hh, P_GQ0, 1288, check)
      call createCurrent(P_ZQ, P_d, P_dAnti, 2455, check)
      call createCurrent(P_GQMinus, P_Hl, P_ghWmAnti, P_ghA, 3836, check)
      call createCurrent(P_ghAAnti, P_GMinus, P_Hl, P_ghWp, 4312, check)
      call createCurrent(P_ghAAnti, P_ghA, P_GMinus, P_GPlus, 2546, check)
      call createCurrent(P_dAnti, P_Hh, P_d, 4154, check)
      call createCurrent(P_WPlus, P_ghWm, P_ghAAnti, P_Z, 4882, check)
      call createCurrent(P_Hh, P_WPlus, P_GMinus, 3110, check)
      call createCurrent(P_GMinus, P_G0, P_G0, P_GPlus, 2285, check)
      call createCurrent(P_d, P_dAnti, P_GQ0, 2485, check)
      call createCurrent(P_ghZAnti, P_GPlus, P_ghWm, 3619, check)
      call createCurrent(P_HhQ, P_Z, P_GMinus, P_WQPlus, 727, check)
      call createCurrent(P_t, P_tAnti, P_HhQ, 837, check)
      call createCurrent(P_ghWpAnti, P_ghWp, P_Z, P_ZQ, 2970, check)
      call createCurrent(P_nu_muAnti, P_muMinus, P_GPlus, 4796, check)
      call createCurrent(P_WQMinus, P_GPlus, P_A, P_HhQ, 1191, check)
      call createCurrent(P_ghZAnti, P_ghWp, P_Hh, P_GMinus, 52, check)
      call createCurrent(P_ghAAnti, P_GMinus, P_ghWp, P_HhQ, 658, check)
      call createCurrent(P_GQ0, P_uAnti, P_u, 2723, check)
      call createCurrent(P_GQPlus, P_ghZAnti, P_GMinus, P_ghZ, 2673, check)
      call createCurrent(P_GMinus, P_ghWmAnti, P_ghZ, P_Hl, 4196, check)
      call createCurrent(P_ghZ, P_GMinus, P_GPlus, P_ghZAnti, 4505, check)
      call createCurrent(P_GQ0, P_G0, P_GMinus, P_GQPlus, 2578, check)
      call createCurrent(P_ghWm, P_G0, P_ghZAnti, P_GQPlus, 4210, check)
      call createCurrent(P_WQPlus, P_GPlus, P_GMinus, P_WQMinus, 2800, check)
      call createCurrent(P_ghA, P_ghWpAnti, P_Z, P_WQPlus, 1355, check)
      call createCurrent(P_ghWpAnti, P_Hl, P_ghA, P_GQPlus, 2853, check)
      call createCurrent(P_GPlus, P_Hl, P_Hh, P_GMinus, 4760, check)
      call createCurrent(P_ZQ, P_Hh, P_GQ0, 1092, check)
      call createCurrent(P_HlQ, P_Hl, P_Hl, P_HlQ, 2577, check)
      call createCurrent(P_GQPlus, P_WMinus, P_Hh, P_AQ, 4910, check)
      call createCurrent(P_ghA, P_GPlus, P_ghWpAnti, P_Hl, 2290, check)
      call createCurrent(P_Hl, P_ghWp, P_Hl, P_ghWpAnti, 525, check)
      call createCurrent(P_WPlus, P_ghWp, P_WMinus, P_ghWpAnti, 430, check)
      call createCurrent(P_Hh, P_GMinus, P_ghAAnti, P_ghWp, 3773, check)
      call createCurrent(P_ghA, P_ghWmAnti, P_Hh, P_GMinus, 3912, check)
      call createCurrent(P_ghA, P_ghWmAnti, P_Z, P_WQMinus, 3968, check)
      call createCurrent(P_Hh, P_Z, P_Hh, P_A, 5105, check)
      call createCurrent(P_GPlus, P_ghA, P_Hh, P_ghWpAnti, 2620, check)
      call createCurrent(P_WPlus, P_ghWpAnti, P_Z, P_ghA, 608, check)
      call createCurrent(P_Z, P_ghWpAnti, P_ghWp, P_A, 1234, check)
      call createCurrent(P_g, P_g, P_G0, P_G0, 5244, check)
      call createCurrent(P_ghWm, P_A, P_A, P_ghWmAnti, 2592, check)
      call createCurrent(P_ghWmAnti, P_GMinus, P_Hh, P_ghA, 3294, check)
      call createCurrent(P_ghWm, P_GPlus, P_ghAAnti, P_HlQ, 3698, check)
      call createCurrent(P_muMinus, P_Z, P_muPlus, 2911, check)
      call createCurrent(P_GQPlus, P_ghWpAnti, P_ghA, 4001, check)
      call createCurrent(P_ghA, P_WMinus, P_WPlus, P_ghZAnti, 3, check)
      call createCurrent(P_ZQ, P_Hh, P_Hh, P_ZQ, 2848, check)
      call createCurrent(P_ghWmAnti, P_Hh, P_ghWm, P_HlQ, 1563, check)
      call createCurrent(P_WPlus, P_A, P_ghWm, P_ghZAnti, 967, check)
      call createCurrent(P_GPlus, P_ghA, P_GMinus, P_ghZAnti, 3060, check)
      call createCurrent(P_AQ, P_GMinus, P_Z, P_GQPlus, 65, check)
      call createCurrent(P_WMinus, P_ghWmAnti, P_ghA, P_Z, 310, check)
      call createCurrent(P_Z, P_Hl, P_WMinus, P_GPlus, 1656, check)
      call createCurrent(P_ghZAnti, P_ghWp, P_Z, P_WMinus, 681, check)
      call createCurrent(P_Hh, P_d, P_dAnti, 4681, check)
      call createCurrent(P_GPlus, P_ghZAnti, P_G0, P_ghWm, 4948, check)
      call createCurrent(P_HlQ, P_ePlus, P_eMinus, 4740, check)
      call createCurrent(P_WQMinus, P_Z, P_GPlus, P_HhQ, 1741, check)
      call createCurrent(P_ghWm, P_G0, P_GPlus, P_ghAAnti, 2811, check)
      call createCurrent(P_AQ, P_A, P_ghWpAnti, P_ghWp, 4594, check)
      call createCurrent(P_A, P_Z, P_ghWmAnti, P_ghWm, 2785, check)
      call createCurrent(P_WQMinus, P_ghWpAnti, P_WPlus, P_ghWp, 3672, check)
      call createCurrent(P_ghWp, P_A, P_Z, P_ghWpAnti, 3154, check)
      call createCurrent(P_ghZAnti, P_A, P_ghWp, P_WMinus, 4194, check)
      call createCurrent(P_WPlus, P_ghWm, P_ghAAnti, 614, check)
      call createCurrent(P_Hl, P_Z, P_A, P_Hh, 4983, check)
      call createCurrent(P_WQMinus, P_nu_e, P_ePlus, 2281, check)
      call createCurrent(P_ghWmAnti, P_ghZ, P_Hh, P_GQMinus, 1891, check)
      call createCurrent(P_cAnti, P_s, P_GPlus, 4006, check)
      call createCurrent(P_A, P_Z, P_ghWp, P_ghWpAnti, 596, check)
      call createCurrent(P_G0, P_A, P_GMinus, P_WPlus, 4265, check)
      call createCurrent(P_Z, P_Hl, P_GMinus, P_WPlus, 3450, check)
      call createCurrent(P_u, P_Hl, P_uAnti, 1697, check)
      call createCurrent(P_GQPlus, P_ghZAnti, P_Hl, P_ghWm, 4795, check)
      call createCurrent(P_WMinus, P_ghA, P_ghWmAnti, P_Z, 24, check)
      call createCurrent(P_ghWm, P_WPlus, P_ghAAnti, P_AQ, 4802, check)
      call createCurrent(P_ZQ, P_G0, P_HhQ, 3967, check)
      call createCurrent(P_GQPlus, P_WMinus, P_HlQ, 3606, check)
      call createCurrent(P_Z, P_GMinus, P_A, P_GPlus, 3487, check)
      call createCurrent(P_GMinus, P_u, P_dAnti, 4019, check)
      call createCurrent(P_ghA, P_A, P_WPlus, P_ghWpAnti, 4356, check)
      call createCurrent(P_ghWpAnti, P_ghA, P_GPlus, P_G0, 1160, check)
      call createCurrent(P_Hh, P_WPlus, P_Hl, P_WMinus, 1086, check)
      call createCurrent(P_ghWp, P_ghAAnti, P_WMinus, P_Z, 794, check)
      call createCurrent(P_ghZAnti, P_WMinus, P_ghZ, P_WPlus, 1320, check)
      call createCurrent(P_b, P_bAnti, P_A, 4415, check)
      call createCurrent(P_ghWm, P_ghWmAnti, P_AQ, 356, check)
      call createCurrent(P_ghWp, P_ghWpAnti, P_Hh, P_GQ0, 819, check)
      call createCurrent(P_WQMinus, P_Z, P_WQPlus, 3508, check)
      call createCurrent(P_ZQ, P_Z, P_WMinus, P_WQPlus, 3530, check)
      call createCurrent(P_ghWp, P_WMinus, P_Z, P_ghZAnti, 1266, check)
      call createCurrent(P_GPlus, P_G0, P_ghAAnti, P_ghWm, 660, check)
      call createCurrent(P_A, P_Z, P_Hl, 5083, check)
      call createCurrent(P_Hh, P_Z, P_Hl, P_Z, 3306, check)
      call createCurrent(P_GQPlus, P_G0, P_WQMinus, 102, check)
      call createCurrent(P_HhQ, P_G0, P_Hh, P_GQ0, 1749, check)
      call createCurrent(P_WQMinus, P_WPlus, P_GQ0, 2910, check)
      call createCurrent(P_ghA, P_A, P_WMinus, P_ghWmAnti, 4191, check)
      call createCurrent(P_WPlus, P_Z, P_WMinus, P_Z, 1123, check)
      call createCurrent(P_g, P_WPlus, P_WMinus, P_g, 5165, check)
      call createCurrent(P_sAnti, P_G0, P_s, 259, check)
      call createCurrent(P_WQMinus, P_WPlus, P_ghAAnti, P_ghZ, 4377, check)
      call createCurrent(P_ghGAnti, P_ghG, P_g, 2751, check)
      call createCurrent(P_A, P_Z, P_Hh, P_Hl, 5108, check)
      call createCurrent(P_WQPlus, P_GMinus, P_Hl, P_AQ, 2112, check)
      call createCurrent(P_Hh, P_G0, P_Z, 4283, check)
      call createCurrent(P_ghWp, P_ghWpAnti, P_Hh, 4249, check)
      call createCurrent(P_ghZ, P_WPlus, P_ghZAnti, P_WQMinus, 2215, check)
      call createCurrent(P_G0, P_G0, P_WMinus, P_WPlus, 1002, check)
      call createCurrent(P_GMinus, P_Hh, P_WPlus, P_Z, 2632, check)
      call createCurrent(P_GQ0, P_WPlus, P_WMinus, P_GQ0, 956, check)
      call createCurrent(P_HlQ, P_Z, P_ZQ, 839, check)
      call createCurrent(P_ghWm, P_Hl, P_GPlus, P_ghAAnti, 3506, check)
      call createCurrent(P_ghWp, P_ghWpAnti, P_ZQ, 172, check)
      call createCurrent(P_GQMinus, P_WPlus, P_Z, P_HlQ, 723, check)
      call createCurrent(P_ZQ, P_tauMinus, P_tauPlus, 2906, check)
      call createCurrent(P_ghAAnti, P_GMinus, P_ghWp, P_GQ0, 3101, check)
      call createCurrent(P_Hh, P_Hh, P_Hh, P_Hl, 2445, check)
      call createCurrent(P_ZQ, P_WMinus, P_GPlus, P_HhQ, 1664, check)
      call createCurrent(P_ghWmAnti, P_Hl, P_ghZ, P_GMinus, 424, check)
      call createCurrent(P_A, P_G0, 4981, check)
      call createCurrent(P_Hh, P_ghWp, P_GMinus, P_ghAAnti, 4764, check)
      call createCurrent(P_ghWmAnti, P_ghWm, P_Z, P_ZQ, 1907, check)
      call createCurrent(P_GMinus, P_ghA, P_ghWmAnti, P_Hh, 2908, check)
      call createCurrent(P_WMinus, P_ghWmAnti, P_ghZ, 2562, check)
      call createCurrent(P_A, P_Z, P_Hh, P_Hh, 5016, check)
      call createCurrent(P_HhQ, P_Z, P_Hh, P_ZQ, 174, check)
      call createCurrent(P_ghZAnti, P_G0, P_G0, P_ghZ, 736, check)
      call createCurrent(P_HlQ, P_ghWpAnti, P_G0, P_ghWp, 1023, check)
      call createCurrent(P_ghZ, P_ghWmAnti, P_Hl, P_GMinus, 1089, check)
      call createCurrent(P_GQMinus, P_ghWmAnti, P_G0, P_ghZ, 4299, check)
      call createCurrent(P_Hh, P_ghWpAnti, P_ghA, P_GPlus, 2835, check)
      call createCurrent(P_HlQ, P_u, P_uAnti, 4890, check)
      call createCurrent(P_Hl, P_WMinus, P_WPlus, P_Hh, 3448, check)
      call createCurrent(P_WMinus, P_GPlus, P_GMinus, P_WPlus, 3889, check)
      call createCurrent(P_ghWp, P_A, P_ghWpAnti, P_AQ, 590, check)
      call createCurrent(P_WQMinus, P_WPlus, P_G0, P_HhQ, 1692, check)
      call createCurrent(P_GQ0, P_WMinus, P_Hl, P_WQPlus, 1217, check)
      call createCurrent(P_Hl, P_WMinus, P_Hh, P_WPlus, 4810, check)
      call createCurrent(P_ghWmAnti, P_Hl, P_ghZ, P_GQMinus, 1225, check)
      call createCurrent(P_GPlus, P_ghWpAnti, P_ghA, P_G0, 1838, check)
      call createCurrent(P_WPlus, P_ghZAnti, P_ghWm, 2978, check)
      call createCurrent(P_Hl, P_Hl, P_ghWmAnti, P_ghWm, 2966, check)
      call createCurrent(P_A, P_Hh, P_GPlus, P_WMinus, 241, check)
      call createCurrent(P_HhQ, P_WPlus, P_Z, P_GQMinus, 546, check)
      call createCurrent(P_G0, P_Hh, P_G0, P_Hl, 4638, check)
      call createCurrent(P_Hl, P_ghAAnti, P_ghWm, P_GPlus, 3120, check)
      call createCurrent(P_ghWpAnti, P_Hl, P_Hl, P_ghWp, 2696, check)
      call createCurrent(P_HhQ, P_A, P_WPlus, P_GQMinus, 3361, check)
      call createCurrent(P_GMinus, P_Hh, P_ghWp, P_ghZAnti, 285, check)
      call createCurrent(P_GMinus, P_Hl, P_WPlus, 4923, check)
      call createCurrent(P_ghWp, P_GMinus, P_Hh, P_ghAAnti, 2067, check)
      call createCurrent(P_HlQ, P_Hl, P_ghZAnti, P_ghZ, 648, check)
      call createCurrent(P_nu_eAnti, P_eMinus, P_WPlus, 4493, check)
      call createCurrent(P_HlQ, P_G0, P_WMinus, P_WQPlus, 3017, check)
      call createCurrent(P_ghWmAnti, P_ghWm, P_Hl, P_Hh, 4358, check)
      call createCurrent(P_ghWmAnti, P_WMinus, P_ghA, P_Z, 1949, check)
      call createCurrent(P_WPlus, P_ghWm, P_ghWpAnti, P_WPlus, 2716, check)
      call createCurrent(P_ghAAnti, P_WMinus, P_ghZ, P_WQPlus, 3010, check)
      call createCurrent(P_A, P_ghWp, P_ghWpAnti, P_Z, 4826, check)
      call createCurrent(P_ghZ, P_GMinus, P_ghZAnti, P_GPlus, 14, check)
      call createCurrent(P_GQPlus, P_Hl, P_WQMinus, 1540, check)
      call createCurrent(P_Z, P_g, P_g, P_Z, 5232, check)
      call createCurrent(P_A, P_GPlus, P_Z, P_GMinus, 488, check)
      call createCurrent(P_muMinus, P_muPlus, P_Hh, 274, check)
      call createCurrent(P_ePlus, P_eMinus, P_GQ0, 2637, check)
      call createCurrent(P_Z, P_ghWpAnti, P_A, P_ghWp, 3474, check)
      call createCurrent(P_ghZAnti, P_WMinus, P_ghWp, 2960, check)
      call createCurrent(P_Hl, P_Hl, P_G0, P_G0, 4664, check)
      call createCurrent(P_ghZ, P_ghWmAnti, P_GMinus, P_HhQ, 1753, check)
      call createCurrent(P_ghAAnti, P_ghWp, P_G0, P_GMinus, 1478, check)
      call createCurrent(P_WQMinus, P_G0, P_G0, P_WQPlus, 651, check)
      call createCurrent(P_ghZAnti, P_ghZ, P_Hl, P_HhQ, 1220, check)
      call createCurrent(P_t, P_WMinus, P_bAnti, 3368, check)
      call createCurrent(P_Hl, P_GPlus, P_GMinus, P_Hh, 340, check)
      call createCurrent(P_GPlus, P_nu_muAnti, P_muMinus, 4373, check)
      call createCurrent(P_Hl, P_c, P_cAnti, 550, check)
      call createCurrent(P_A, P_A, P_ghWpAnti, P_ghWp, 2774, check)
      call createCurrent(P_GPlus, P_WMinus, P_A, P_Hl, 725, check)
      call createCurrent(P_WMinus, P_G0, P_GPlus, 3088, check)
      call createCurrent(P_b, P_bAnti, P_Hl, 4559, check)
      call createCurrent(P_ghWpAnti, P_G0, P_GPlus, P_ghZ, 2186, check)
      call createCurrent(P_HlQ, P_ghZAnti, P_Hh, P_ghZ, 4972, check)
      call createCurrent(P_WMinus, P_ghAAnti, P_ghWp, P_Z, 2269, check)
      call createCurrent(P_ghWp, P_GMinus, P_Hl, P_ghAAnti, 324, check)
      call createCurrent(P_bAnti, P_b, P_HhQ, 1317, check)
      call createCurrent(P_ghAAnti, P_ghWm, P_GPlus, P_GQ0, 3342, check)
      call createCurrent(P_gQ, P_b, P_bAnti, 832, check)
      call createCurrent(P_WMinus, P_ghWp, P_ghAAnti, 2541, check)
      call createCurrent(P_GQPlus, P_GMinus, P_ZQ, 1659, check)
      call createCurrent(P_Hh, P_GMinus, P_WPlus, P_A, 1405, check)
      call createCurrent(P_GPlus, P_Hh, P_A, P_WMinus, 2741, check)
      call createCurrent(P_WQPlus, P_ghWpAnti, P_A, P_ghZ, 3379, check)
      call createCurrent(P_Z, P_WPlus, P_GMinus, P_G0, 12, check)
      call createCurrent(P_Hh, P_ghZ, P_ghZAnti, P_Hh, 2131, check)
      call createCurrent(P_ghWmAnti, P_ghWm, P_WMinus, P_WPlus, 4933, check)
      call createCurrent(P_G0, P_G0, P_ghZ, P_ghZAnti, 4438, check)
      call createCurrent(P_ghWm, P_WPlus, P_Z, P_ghAAnti, 4840, check)
      call createCurrent(P_ghWp, P_WMinus, P_A, P_ghAAnti, 1136, check)
      call createCurrent(P_ghZ, P_GPlus, P_ghZAnti, P_GQMinus, 54, check)
      call createCurrent(P_AQ, P_Z, P_ghWpAnti, P_ghWp, 3649, check)
      call createCurrent(P_WMinus, P_A, P_GPlus, 4478, check)
      call createCurrent(P_A, P_GPlus, P_GMinus, 1228, check)
      call createCurrent(P_ghWmAnti, P_G0, P_ghWm, P_HhQ, 3577, check)
      call createCurrent(P_GQMinus, P_GPlus, P_Hh, P_GQ0, 4743, check)
      call createCurrent(P_ghWp, P_ghWpAnti, P_G0, P_HlQ, 2370, check)
      call createCurrent(P_WPlus, P_Z, P_GMinus, 59, check)
      call createCurrent(P_GMinus, P_ghZ, P_Hl, P_ghWmAnti, 4212, check)
      call createCurrent(P_GQ0, P_GMinus, P_A, P_WQPlus, 3794, check)
      call createCurrent(P_A, P_g, P_Z, P_g, 5229, check)
      call createCurrent(P_g, P_g, P_g, P_g, 3121, check)
      call createCurrent(P_bAnti, P_A, P_b, 2648, check)
      call createCurrent(P_GMinus, P_ghWp, P_ghZAnti, P_Hl, 420, check)
      call createCurrent(P_ghZ, P_GMinus, P_GPlus, P_ghAAnti, 3603, check)
      call createCurrent(P_A, P_A, P_A, P_Z, 5226, check)
      call createCurrent(P_ghWp, P_ghZAnti, P_WMinus, P_ZQ, 435, check)
      call createCurrent(P_ghWmAnti, P_Hh, P_GMinus, P_ghA, 3035, check)
      call createCurrent(P_WQPlus, P_nu_muAnti, P_muMinus, 3143, check)
      call createCurrent(P_GMinus, P_GPlus, P_ghAAnti, P_ghA, 1817, check)
      call createCurrent(P_WQPlus, P_nu_eAnti, P_eMinus, 1177, check)
      call createCurrent(P_WPlus, P_WMinus, P_ghWpAnti, P_ghWp, 2329, check)
      call createCurrent(P_cAnti, P_c, P_G0, 1596, check)
      call createCurrent(P_tAnti, P_Hl, P_t, 229, check)
      call createCurrent(P_Hl, P_ghWp, P_GMinus, P_ghZAnti, 3528, check)
      call createCurrent(P_GMinus, P_ghWmAnti, P_ghZ, P_Hh, 3394, check)
      call createCurrent(P_ghZAnti, P_ghZ, P_Hh, 2626, check)
      call createCurrent(P_WQPlus, P_Z, P_WMinus, P_AQ, 3183, check)
      call createCurrent(P_ghAAnti, P_ghZ, P_WPlus, P_WMinus, 4971, check)
      call createCurrent(P_A, P_ghWpAnti, P_WPlus, P_ghA, 3702, check)
      call createCurrent(P_bAnti, P_g, P_b, 2660, check)
      call createCurrent(P_GMinus, P_ghAAnti, P_ghWp, P_Hl, 2382, check)
      call createCurrent(P_WQMinus, P_GPlus, P_Z, P_HlQ, 3458, check)
      call createCurrent(P_tAnti, P_b, P_WPlus, 2809, check)
      call createCurrent(P_ghZ, P_A, P_ghWpAnti, P_WPlus, 2975, check)
      call createCurrent(P_GQMinus, P_WPlus, P_HlQ, 2085, check)
      call createCurrent(P_Hh, P_GPlus, P_Hl, P_GMinus, 803, check)
      call createCurrent(P_GQMinus, P_Z, P_Hl, P_WQPlus, 4707, check)
      call createCurrent(P_WMinus, P_G0, P_Z, P_GPlus, 2383, check)
      call createCurrent(P_ghA, P_ghAAnti, P_WMinus, P_WPlus, 4359, check)
      call createCurrent(P_GMinus, P_A, P_GPlus, 1924, check)
      call createCurrent(P_tauMinus, P_tauPlus, P_ZQ, 4556, check)
      call createCurrent(P_GPlus, P_GPlus, P_GMinus, P_GMinus, 4634, check)
      call createCurrent(P_ghWm, P_ghWmAnti, P_WPlus, P_WMinus, 2201, check)
      call createCurrent(P_GQPlus, P_Hl, P_ghWpAnti, P_ghZ, 2711, check)
      call createCurrent(P_gQ, P_d, P_dAnti, 21, check)
      call createCurrent(P_G0, P_ghZAnti, P_ghWm, P_GPlus, 3774, check)
      call createCurrent(P_GPlus, P_ghAAnti, P_G0, P_ghWm, 4727, check)
      call createCurrent(P_WQPlus, P_ghWm, P_ghAAnti, 4730, check)
      call createCurrent(P_WMinus, P_WPlus, P_Z, P_Z, 1757, check)
      call createCurrent(P_ghWp, P_ghWpAnti, P_A, P_AQ, 825, check)
      call createCurrent(P_HhQ, P_ghWpAnti, P_Hl, P_ghWp, 3601, check)
      call createCurrent(P_Hh, P_ghWpAnti, P_ghWp, 3956, check)
      call createCurrent(P_ghWmAnti, P_ghWm, P_G0, P_HhQ, 189, check)
      call createCurrent(P_Z, P_WPlus, P_Z, P_WMinus, 4275, check)
      call createCurrent(P_ghZ, P_GMinus, P_ghWmAnti, P_Hh, 152, check)
      call createCurrent(P_ghZ, P_ghAAnti, P_WPlus, P_WMinus, 3214, check)
      call createCurrent(P_ghWmAnti, P_WMinus, P_A, P_ghA, 1399, check)
      call createCurrent(P_ghWpAnti, P_WPlus, P_ghA, 4525, check)
      call createCurrent(P_GMinus, P_GPlus, P_Hl, 4622, check)
      call createCurrent(P_GQMinus, P_tauPlus, P_nu_tau, 3711, check)
      call createCurrent(P_WQMinus, P_A, P_Z, P_WQPlus, 2075, check)
      call createCurrent(P_GPlus, P_Z, P_A, P_GMinus, 84, check)
      call createCurrent(P_g, P_uAnti, P_u, 2431, check)
      call createCurrent(P_ghWmAnti, P_GMinus, P_GPlus, P_ghWm, 2565, check)
      call createCurrent(P_ghWpAnti, P_Z, P_ghA, P_WQPlus, 3670, check)
      call createCurrent(P_Z, P_ghAAnti, P_WPlus, P_ghWm, 4441, check)
      call createCurrent(P_ZQ, P_ghWp, P_WMinus, P_ghAAnti, 179, check)
      call createCurrent(P_ghWm, P_GPlus, P_ghAAnti, P_G0, 335, check)
      call createCurrent(P_GQMinus, P_Hl, P_Z, P_WQPlus, 1557, check)
      call createCurrent(P_HhQ, P_GMinus, P_A, P_WQPlus, 4087, check)
      call createCurrent(P_ghWmAnti, P_GMinus, P_ghWm, P_GPlus, 2787, check)
      call createCurrent(P_ghWp, P_WMinus, P_ghAAnti, P_Z, 2986, check)
      call createCurrent(P_G0, P_Hl, P_A, 5118, check)
      call createCurrent(P_HlQ, P_GPlus, P_A, P_WQMinus, 3290, check)
      call createCurrent(P_muMinus, P_G0, P_muPlus, 921, check)
      call createCurrent(P_A, P_WMinus, P_GPlus, P_Hl, 513, check)
      call createCurrent(P_AQ, P_ghWm, P_WPlus, P_ghAAnti, 1701, check)
      call createCurrent(P_HlQ, P_sAnti, P_s, 4747, check)
      call createCurrent(P_GMinus, P_ghA, P_GPlus, P_ghAAnti, 1329, check)
      call createCurrent(P_Hh, P_ghZAnti, P_ghWp, P_GMinus, 548, check)
      call createCurrent(P_nu_mu, P_GMinus, P_muPlus, 1535, check)
      call createCurrent(P_GQPlus, P_Hl, P_GMinus, P_HlQ, 504, check)
      call createCurrent(P_d, P_dAnti, P_g, 4029, check)
      call createCurrent(P_GMinus, P_Hl, P_ghWmAnti, P_ghZ, 4866, check)
      call createCurrent(P_ghZAnti, P_GPlus, P_ghZ, P_GQMinus, 2429, check)
      call createCurrent(P_ghWp, P_ghAAnti, P_WMinus, 738, check)
      call createCurrent(P_G0, P_Z, P_GMinus, P_WPlus, 111, check)
      call createCurrent(P_HlQ, P_Hh, P_WMinus, P_WQPlus, 3478, check)
      call createCurrent(P_ghZAnti, P_ghWm, P_WPlus, 909, check)
      call createCurrent(P_Hh, P_bAnti, P_b, 3407, check)
      call createCurrent(P_ghZAnti, P_ghWm, P_GPlus, P_Hh, 2010, check)
      call createCurrent(P_tauPlus, P_tauMinus, P_G0, 2272, check)
      call createCurrent(P_Hh, P_Z, P_Z, P_Hh, 669, check)
      call createCurrent(P_ghWmAnti, P_A, P_WMinus, P_ghA, 1649, check)
      call createCurrent(P_bAnti, P_b, P_Hh, 4119, check)
      call createCurrent(P_Z, P_GMinus, P_GPlus, P_A, 4845, check)
      call createCurrent(P_AQ, P_ghWpAnti, P_ghWp, 360, check)
      call createCurrent(P_ghWm, P_A, P_WPlus, P_ghZAnti, 2362, check)
      call createCurrent(P_HhQ, P_GPlus, P_WMinus, P_ZQ, 2102, check)
      call createCurrent(P_ghWmAnti, P_ghZ, P_WMinus, P_Z, 1561, check)
      call createCurrent(P_g, P_Z, P_A, P_g, 5191, check)
      call createCurrent(P_muPlus, P_Z, P_muMinus, 2398, check)
      call createCurrent(P_Hl, P_Hl, P_A, P_Z, 5074, check)
      call createCurrent(P_WQPlus, P_GMinus, P_A, P_HlQ, 4641, check)
      call createCurrent(P_A, P_ghWpAnti, P_ghA, P_WPlus, 1174, check)
      call createCurrent(P_GPlus, P_ghWpAnti, P_ghZ, 547, check)
      call createCurrent(P_A, P_A, P_Z, P_A, 5173, check)
      call createCurrent(P_ghZAnti, P_ghWp, P_GMinus, P_G0, 3802, check)
      call createCurrent(P_ghZAnti, P_Hl, P_GMinus, P_ghWp, 4224, check)
      call createCurrent(P_ghWm, P_WPlus, P_ghZAnti, P_A, 4924, check)
      call createCurrent(P_g, P_WMinus, P_WPlus, P_g, 5202, check)
      call createCurrent(P_ghZAnti, P_ghWm, P_GPlus, P_Hl, 4586, check)
      call createCurrent(P_WQMinus, P_ghAAnti, P_WPlus, P_ghA, 780, check)
      call createCurrent(P_HlQ, P_ghZAnti, P_GPlus, P_ghWm, 1197, check)
      call createCurrent(P_d, P_Hh, P_dAnti, 1974, check)
      call createCurrent(P_ghWp, P_ghAAnti, P_GMinus, P_HhQ, 2520, check)
      call createCurrent(P_nu_tauAnti, P_nu_tau, P_ZQ, 368, check)
      call createCurrent(P_WPlus, P_ghWpAnti, P_ghA, P_Z, 2484, check)
      call createCurrent(P_ghWpAnti, P_ghWp, P_Hh, 1551, check)
      call createCurrent(P_Hh, P_Hh, P_g, P_g, 5190, check)
      call createCurrent(P_Hh, P_Hh, P_A, P_A, 5230, check)
      call createCurrent(P_A, P_Hh, P_Z, P_Hl, 5101, check)
      call createCurrent(P_Hh, P_Hh, P_ghWmAnti, P_ghWm, 1992, check)
      call createCurrent(P_ghWp, P_GMinus, P_ghAAnti, P_HhQ, 2105, check)
      call createCurrent(P_ghZAnti, P_ghA, P_GMinus, P_GPlus, 4206, check)
      call createCurrent(P_A, P_Z, P_A, P_A, 5242, check)
      call createCurrent(P_GMinus, P_GPlus, 5042, check)
      call createCurrent(P_ghWpAnti, P_ghA, P_WQPlus, 2847, check)
      call createCurrent(P_GQPlus, P_ghWpAnti, P_G0, P_ghA, 3419, check)
      call createCurrent(P_Hl, P_Hl, P_Hl, P_Hl, 876, check)
      call createCurrent(P_GPlus, P_Hh, P_GMinus, P_Hl, 703, check)
      call createCurrent(P_WPlus, P_Z, P_ghWpAnti, P_ghA, 3232, check)
      call createCurrent(P_ghZAnti, P_WPlus, P_ghA, P_WMinus, 2915, check)
      call createCurrent(P_A, P_ghA, P_ghWmAnti, P_WMinus, 1954, check)
      call createCurrent(P_A, P_Hl, P_Hl, P_Z, 5067, check)
      call createCurrent(P_HhQ, P_GPlus, P_ghZAnti, P_ghWm, 2293, check)
      call createCurrent(P_ghWmAnti, P_WMinus, P_ghZ, P_A, 3821, check)
      call createCurrent(P_Hl, P_ghZ, P_ghZAnti, 1730, check)
      call createCurrent(P_muPlus, P_G0, P_muMinus, 1497, check)
      call createCurrent(P_AQ, P_GMinus, P_Hh, P_WQPlus, 3113, check)
      call createCurrent(P_G0, P_GPlus, P_ghWpAnti, P_ghZ, 3300, check)
      call createCurrent(P_tauPlus, P_nu_tau, P_GMinus, 2855, check)
      call createCurrent(P_ghWmAnti, P_GMinus, P_ghZ, P_GQ0, 1559, check)
      call createCurrent(P_tauPlus, P_nu_tau, P_WMinus, 2043, check)
      call createCurrent(P_WQMinus, P_G0, P_WPlus, P_HhQ, 1012, check)
      call createCurrent(P_GMinus, P_ghWp, P_ghAAnti, P_Hh, 978, check)
      call createCurrent(P_Z, P_ghWmAnti, P_Z, P_ghWm, 1327, check)
      call createCurrent(P_ghWpAnti, P_Hh, P_ghZ, P_GPlus, 1623, check)
      call createCurrent(P_A, P_A, P_Hl, P_Hh, 5246, check)
      call createCurrent(P_Z, P_Hh, P_A, P_Hl, 4978, check)
      call createCurrent(P_Hh, P_GPlus, P_ghA, P_ghWpAnti, 3976, check)
      call createCurrent(P_Z, P_ghA, P_ghWpAnti, P_WPlus, 1496, check)
      call createCurrent(P_ghZAnti, P_A, P_WPlus, P_ghWm, 217, check)
      call createCurrent(P_g, P_A, P_g, P_A, 5209, check)
      call createCurrent(P_tAnti, P_t, P_g, 2714, check)
      call createCurrent(P_G0, P_ghZ, P_GPlus, P_ghWpAnti, 1348, check)
      call createCurrent(P_ghAAnti, P_Z, P_WMinus, P_ghWp, 4009, check)
      call createCurrent(P_Hh, P_ghWmAnti, P_GMinus, P_ghZ, 3308, check)
      call createCurrent(P_ghWm, P_WMinus, P_ghWmAnti, P_WPlus, 1007, check)
      call createCurrent(P_Z, P_Z, P_Hh, 1796, check)
      call createCurrent(P_ePlus, P_Z, P_eMinus, 3087, check)
      call createCurrent(P_WQMinus, P_WMinus, P_ghWp, P_ghWmAnti, 4756, check)
      call createCurrent(P_GPlus, P_ghZAnti, P_Hl, P_ghWm, 3075, check)
      call createCurrent(P_Hh, P_ghWp, P_Hl, P_ghWpAnti, 2652, check)
      call createCurrent(P_cAnti, P_c, P_A, 582, check)
      call createCurrent(P_WMinus, P_Hl, P_A, P_GPlus, 2250, check)
      call createCurrent(P_ghWpAnti, P_GPlus, P_ghZ, P_HhQ, 4240, check)
      call createCurrent(P_GPlus, P_ghWm, P_GMinus, P_ghWmAnti, 1401, check)
      call createCurrent(P_Z, P_ghWmAnti, P_WMinus, P_ghZ, 3624, check)
      call createCurrent(P_Hh, P_GMinus, P_ghWp, P_ghZAnti, 271, check)
      call createCurrent(P_WPlus, P_GMinus, P_Z, P_Hh, 3315, check)
      call createCurrent(P_Hh, P_WMinus, P_Hh, P_WPlus, 3409, check)
      call createCurrent(P_ghWpAnti, P_ghA, P_GQPlus, 1118, check)
      call createCurrent(P_ghZ, P_ghWpAnti, P_GPlus, P_Hl, 1880, check)
      call createCurrent(P_A, P_WMinus, P_GPlus, 1942, check)
      call createCurrent(P_Hl, P_Hl, P_A, P_A, 5170, check)
      call createCurrent(P_ghAAnti, P_WMinus, P_WPlus, P_ghA, 3654, check)
      call createCurrent(P_A, P_A, P_A, P_A, 5211, check)
      call createCurrent(P_WMinus, P_ghA, P_ghWmAnti, 331, check)
      call createCurrent(P_ghWpAnti, P_A, P_ghWp, P_Z, 2216, check)
      call createCurrent(P_GQ0, P_GMinus, P_WQPlus, 1797, check)
      call createCurrent(P_tauMinus, P_G0, P_tauPlus, 107, check)
      call createCurrent(P_WQPlus, P_A, P_ghZ, P_ghWpAnti, 3851, check)
      call createCurrent(P_ZQ, P_GPlus, P_GMinus, P_AQ, 2786, check)
      call createCurrent(P_Hh, P_WMinus, P_Hl, P_WPlus, 1825, check)
      call createCurrent(P_WQPlus, P_Hl, P_WMinus, P_HlQ, 4847, check)
      call createCurrent(P_ghWmAnti, P_ghZ, P_GMinus, P_Hh, 785, check)
      call createCurrent(P_s, P_cAnti, P_WQPlus, 2055, check)
      call createCurrent(P_ZQ, P_ghWm, P_WPlus, P_ghZAnti, 1835, check)
      call createCurrent(P_HlQ, P_ghWpAnti, P_ghWp, 766, check)
      call createCurrent(P_GMinus, P_ghWmAnti, P_ghA, P_G0, 1946, check)
      call createCurrent(P_GQ0, P_b, P_bAnti, 4156, check)
      call createCurrent(P_GMinus, P_nu_e, P_ePlus, 451, check)
      call createCurrent(P_ghZ, P_ghWpAnti, P_GPlus, P_GQ0, 4436, check)
      call createCurrent(P_ghAAnti, P_ghWm, P_G0, P_GPlus, 2810, check)
      call createCurrent(P_Z, P_Z, P_Hh, P_Hl, 3317, check)
      call createCurrent(P_ghWpAnti, P_Hl, P_Hh, P_ghWp, 2732, check)
      call createCurrent(P_Hl, P_Hh, P_Hl, P_Hh, 3479, check)
      call createCurrent(P_HhQ, P_GPlus, P_ghWm, P_ghZAnti, 1195, check)
      call createCurrent(P_ghAAnti, P_Z, P_ghWp, P_WMinus, 611, check)
      call createCurrent(P_ghWpAnti, P_ghWm, P_WPlus, P_WPlus, 806, check)
      call createCurrent(P_WPlus, P_G0, P_WMinus, P_G0, 3003, check)
      call createCurrent(P_A, P_d, P_dAnti, 4926, check)
      call createCurrent(P_WQPlus, P_Z, P_ghWpAnti, P_ghZ, 3340, check)
      call createCurrent(P_GQPlus, P_WMinus, P_ZQ, 878, check)
      call createCurrent(P_WPlus, P_Hh, P_WMinus, P_Hh, 1910, check)
      call createCurrent(P_t, P_tAnti, 5003, check)
      call createCurrent(P_HlQ, P_GPlus, P_GMinus, P_HlQ, 3883, check)
      call createCurrent(P_ghWm, P_ghWmAnti, P_Hh, P_Hh, 3989, check)
      call createCurrent(P_A, P_Hl, P_WMinus, P_GPlus, 3377, check)
      call createCurrent(P_WQPlus, P_ghA, P_Z, P_ghWpAnti, 2219, check)
      call createCurrent(P_GQ0, P_G0, P_GPlus, P_GQMinus, 1618, check)
      call createCurrent(P_eMinus, P_ePlus, P_AQ, 3726, check)
      call createCurrent(P_HhQ, P_Hl, P_ghWpAnti, P_ghWp, 4343, check)
      call createCurrent(P_Z, P_ghAAnti, P_WMinus, P_ghWp, 4466, check)
      call createCurrent(P_ZQ, P_nu_tauAnti, P_nu_tau, 3489, check)
      call createCurrent(P_ghWm, P_A, P_ghWmAnti, P_Z, 3322, check)
      call createCurrent(P_ghWmAnti, P_ghWm, P_WPlus, P_WMinus, 664, check)
      call createCurrent(P_WQMinus, P_Hl, P_WPlus, P_HhQ, 4046, check)
      call createCurrent(P_sAnti, P_s, P_ZQ, 3483, check)
      call createCurrent(P_ghA, P_ghZAnti, P_WPlus, P_WQMinus, 176, check)
      call createCurrent(P_ghWpAnti, P_GPlus, P_ghZ, P_GQ0, 1766, check)
      call createCurrent(P_ghAAnti, P_GPlus, P_ghZ, P_GMinus, 3613, check)
      call createCurrent(P_Hh, P_GMinus, P_Hl, P_GPlus, 2694, check)
      call createCurrent(P_Hh, P_GPlus, P_Hh, P_GMinus, 396, check)
      call createCurrent(P_WMinus, P_Z, P_ghWmAnti, P_ghA, 3808, check)
      call createCurrent(P_ghWpAnti, P_ghWp, P_HhQ, 3695, check)
      call createCurrent(P_GPlus, P_ghWm, P_Hh, P_ghZAnti, 928, check)
      call createCurrent(P_GQPlus, P_ghWpAnti, P_Hh, P_ghZ, 4787, check)
      call createCurrent(P_WQMinus, P_Hh, P_GQPlus, 1074, check)
      call createCurrent(P_WQMinus, P_ghWp, P_ghZAnti, 1485, check)
      call createCurrent(P_GQMinus, P_G0, P_WPlus, P_ZQ, 4263, check)
      call createCurrent(P_GQPlus, P_WMinus, P_GQ0, 1339, check)
      call createCurrent(P_nu_tau, P_tauPlus, P_WQMinus, 1426, check)
      call createCurrent(P_HlQ, P_Z, P_GQ0, 694, check)
      call createCurrent(P_HhQ, P_WPlus, P_Hl, P_WQMinus, 1170, check)
      call createCurrent(P_HlQ, P_ghWp, P_GMinus, P_ghAAnti, 2829, check)
      call createCurrent(P_HhQ, P_GPlus, P_ghAAnti, P_ghWm, 642, check)
      call createCurrent(P_cAnti, P_GPlus, P_s, 1075, check)
      call createCurrent(P_WMinus, P_WPlus, P_Hh, 4308, check)
      call createCurrent(P_ghWmAnti, P_GMinus, P_ghZ, P_Hl, 1969, check)
      call createCurrent(P_uAnti, P_u, P_A, 2336, check)
      call createCurrent(P_tAnti, P_G0, P_t, 2454, check)
      call createCurrent(P_HlQ, P_WPlus, P_Z, P_GQMinus, 668, check)
      call createCurrent(P_ghAAnti, P_ghWm, P_WPlus, P_Z, 1845, check)
      call createCurrent(P_GMinus, P_ghZ, P_ghWmAnti, P_Hl, 4364, check)
      call createCurrent(P_Hl, P_ghWmAnti, P_ghWm, 2180, check)
      call createCurrent(P_ghWpAnti, P_A, P_WPlus, P_ghA, 1180, check)
      call createCurrent(P_AQ, P_WMinus, P_WPlus, P_ZQ, 4017, check)
      call createCurrent(P_muPlus, P_nu_mu, P_GMinus, 83, check)
      call createCurrent(P_Z, P_Z, P_GMinus, P_GPlus, 66, check)
      call createCurrent(P_Z, P_nu_eAnti, P_nu_e, 1517, check)
      call createCurrent(P_WMinus, P_ghWp, P_ghWmAnti, P_WMinus, 2307, check)
      call createCurrent(P_WMinus, P_WPlus, P_Hh, P_Hh, 618, check)
      call createCurrent(P_ghZAnti, P_ghWp, P_WMinus, 3244, check)
      call createCurrent(P_tAnti, P_Z, P_t, 4930, check)
      call createCurrent(P_WMinus, P_ghZ, P_ghWmAnti, P_Z, 1785, check)
      call createCurrent(P_ghWmAnti, P_ghZ, P_GMinus, P_HlQ, 515, check)
      call createCurrent(P_ghWm, P_ghWmAnti, P_GMinus, P_GPlus, 1189, check)
      call createCurrent(P_Hh, P_Hh, 4982, check)
      call createCurrent(P_ghWp, P_WMinus, P_A, P_ghZAnti, 2594, check)
      call createCurrent(P_WMinus, P_u, P_dAnti, 2618, check)
      call createCurrent(P_ghAAnti, P_ghWp, P_Z, P_WMinus, 1670, check)
      call createCurrent(P_HlQ, P_GPlus, P_GQMinus, 4828, check)
      call createCurrent(P_G0, P_Z, P_Z, P_G0, 1853, check)
      call createCurrent(P_Hh, P_muMinus, P_muPlus, 3221, check)
      call createCurrent(P_GMinus, P_WPlus, P_Hh, P_Z, 3234, check)
      call createCurrent(P_A, P_A, 5112, check)
      call createCurrent(P_GQ0, P_Z, P_WPlus, P_GQMinus, 4753, check)
      call createCurrent(P_WMinus, P_Hh, P_Z, P_GPlus, 453, check)
      call createCurrent(P_ghAAnti, P_ghWm, P_WQPlus, 193, check)
      call createCurrent(P_Hl, P_A, P_GPlus, P_WMinus, 2372, check)
      call createCurrent(P_ghWpAnti, P_ghA, P_GPlus, P_Hh, 3846, check)
      call createCurrent(P_ghWpAnti, P_ghWp, P_A, P_ZQ, 2040, check)
      call createCurrent(P_GQPlus, P_Hh, P_WMinus, P_AQ, 1861, check)
      call createCurrent(P_GQPlus, P_GMinus, P_G0, P_GQ0, 2491, check)
      call createCurrent(P_tauMinus, P_tauPlus, P_Z, 2680, check)
      call createCurrent(P_G0, P_WPlus, P_WMinus, P_G0, 2769, check)
      call createCurrent(P_AQ, P_WMinus, P_ghWp, P_ghAAnti, 1094, check)
      call createCurrent(P_b, P_bAnti, P_g, 3215, check)
      call createCurrent(P_ghZAnti, P_ghA, P_WMinus, P_WQPlus, 2032, check)
      call createCurrent(P_Hl, P_Hh, P_ghZAnti, P_ghZ, 3828, check)
      call createCurrent(P_ghWp, P_ghZAnti, P_G0, P_GMinus, 849, check)
      call createCurrent(P_gQ, P_s, P_sAnti, 3057, check)
      call createCurrent(P_Z, P_WMinus, P_Hh, P_GPlus, 461, check)
      call createCurrent(P_A, P_ghZ, P_ghWmAnti, P_WMinus, 1294, check)
      call createCurrent(P_nu_mu, P_WMinus, P_muPlus, 2861, check)
      call createCurrent(P_ghZ, P_WMinus, P_WPlus, P_ghAAnti, 2120, check)
      call createCurrent(P_ghWm, P_Hh, P_GPlus, P_ghZAnti, 2244, check)
      call createCurrent(P_ghZAnti, P_ghWp, P_G0, P_GQMinus, 3857, check)
      call createCurrent(P_WQPlus, P_WMinus, P_ghZAnti, P_ghZ, 2092, check)
      call createCurrent(P_ghWp, P_GMinus, P_ghZAnti, P_G0, 1338, check)
      call createCurrent(P_G0, P_GMinus, P_ghAAnti, P_ghWp, 1257, check)
      call createCurrent(P_GQ0, P_ghWpAnti, P_G0, P_ghWp, 4461, check)
      call createCurrent(P_Hl, P_WMinus, P_WPlus, P_Hl, 3420, check)
      call createCurrent(P_ghZ, P_GPlus, P_GMinus, P_ghAAnti, 3924, check)
      call createCurrent(P_ZQ, P_s, P_sAnti, 521, check)
      call createCurrent(P_ghAAnti, P_GPlus, P_ghZ, P_GQMinus, 1178, check)
      call createCurrent(P_A, P_A, P_WMinus, P_WPlus, 147, check)
      call createCurrent(P_G0, P_WPlus, P_GMinus, P_Z, 763, check)
      call createCurrent(P_ghA, P_Z, P_ghWmAnti, P_WQMinus, 1977, check)
      call createCurrent(P_Hh, P_Hh, P_Z, P_Z, 1574, check)
      call createCurrent(P_Hl, P_WPlus, P_Hh, P_WMinus, 1771, check)
      call createCurrent(P_GMinus, P_G0, P_ghWmAnti, P_ghA, 3724, check)
      call createCurrent(P_WQMinus, P_A, P_ghA, P_ghWmAnti, 4168, check)
      call createCurrent(P_WQMinus, P_ghZ, P_Z, P_ghWmAnti, 2295, check)
      call createCurrent(P_GQ0, P_G0, P_ghZ, P_ghZAnti, 4872, check)
      call createCurrent(P_ZQ, P_ghWp, P_WMinus, P_ghZAnti, 203, check)
      call createCurrent(P_WMinus, P_WMinus, P_ghWmAnti, P_ghWp, 4151, check)
      call createCurrent(P_ghWm, P_WPlus, P_Z, P_ghZAnti, 665, check)
      call createCurrent(P_GQPlus, P_Hl, P_ghZ, P_ghWpAnti, 1947, check)
      call createCurrent(P_Hh, P_GMinus, P_ghZ, P_ghWmAnti, 2598, check)
      call createCurrent(P_ePlus, P_nu_e, P_WQMinus, 4734, check)
      call createCurrent(P_WMinus, P_ghZAnti, P_WPlus, P_ghA, 2449, check)
      call createCurrent(P_Z, P_Z, P_ghWp, P_ghWpAnti, 4952, check)
      call createCurrent(P_sAnti, P_Z, P_s, 3772, check)
      call createCurrent(P_ghWmAnti, P_ghZ, P_GMinus, 2767, check)
      call createCurrent(P_ghWpAnti, P_ghA, P_A, P_WQPlus, 1301, check)
      call createCurrent(P_A, P_nu_tau, P_nu_tauAnti, 5036, check)
      call createCurrent(P_Hl, P_G0, P_Hh, P_G0, 959, check)
      call createCurrent(P_ghZAnti, P_GMinus, P_Hh, P_ghWp, 678, check)
      call createCurrent(P_ghWp, P_Z, P_ghWpAnti, P_ZQ, 2315, check)
      call createCurrent(P_ZQ, P_Hh, P_Z, P_HlQ, 1063, check)
      call createCurrent(P_WPlus, P_ghZ, P_Z, P_ghWpAnti, 689, check)
      call createCurrent(P_AQ, P_WPlus, P_ghAAnti, P_ghWm, 19, check)
      call createCurrent(P_ghWmAnti, P_G0, P_GMinus, P_ghZ, 1970, check)
      call createCurrent(P_GMinus, P_ghZAnti, P_ghA, P_GPlus, 870, check)
      call createCurrent(P_WQMinus, P_GPlus, P_Hh, P_AQ, 3746, check)
      call createCurrent(P_Z, P_muMinus, P_muPlus, 1322, check)
      call createCurrent(P_GPlus, P_ghA, P_ghWpAnti, P_G0, 2738, check)
      call createCurrent(P_GPlus, P_ghA, P_G0, P_ghWpAnti, 3873, check)
      call createCurrent(P_ghZAnti, P_ghWm, P_GQPlus, 4768, check)
      call createCurrent(P_GPlus, P_ghZ, P_GMinus, P_ghAAnti, 2113, check)
      call createCurrent(P_WQPlus, P_ghWpAnti, P_Z, P_ghZ, 4830, check)
      call createCurrent(P_HlQ, P_Z, P_WMinus, P_GQPlus, 1306, check)
      call createCurrent(P_GQMinus, P_GPlus, P_WMinus, P_WQPlus, 3644, check)
      call createCurrent(P_ZQ, P_GPlus, P_GQMinus, 2150, check)
      call createCurrent(P_b, P_tAnti, P_GPlus, 1113, check)
      call createCurrent(P_GQ0, P_u, P_uAnti, 1166, check)
      call createCurrent(P_ghAAnti, P_GPlus, P_ghWm, P_G0, 3856, check)
      call createCurrent(P_GMinus, P_WPlus, P_G0, P_A, 4262, check)
      call createCurrent(P_ghAAnti, P_ghZ, P_WMinus, P_WQPlus, 2899, check)
      call createCurrent(P_G0, P_ghWmAnti, P_G0, P_ghWm, 3576, check)
      call createCurrent(P_ePlus, P_GMinus, P_nu_e, 4785, check)
      call createCurrent(P_ghA, P_WMinus, P_ghAAnti, P_WQPlus, 938, check)
      call createCurrent(P_ghZ, P_ghAAnti, P_WMinus, P_WPlus, 695, check)
      call createCurrent(P_dAnti, P_A, P_d, 3825, check)
      call createCurrent(P_ghWp, P_ghAAnti, P_WMinus, P_A, 2, check)
      call createCurrent(P_Hl, P_G0, P_A, 4985, check)
      call createCurrent(P_Hl, P_ghA, P_ghWmAnti, P_GMinus, 1615, check)
      call createCurrent(P_AQ, P_ghWp, P_A, P_ghWpAnti, 1826, check)
      call createCurrent(P_d, P_WPlus, P_uAnti, 4676, check)
      call createCurrent(P_GPlus, P_WMinus, 5050, check)
      call createCurrent(P_Z, P_tAnti, P_t, 2377, check)
      call createCurrent(P_WQMinus, P_WMinus, P_WPlus, P_WQPlus, 2379, check)
      call createCurrent(P_GQ0, P_Hl, P_G0, P_HlQ, 1593, check)
      call createCurrent(P_WPlus, P_ghA, P_ghWpAnti, P_Z, 1421, check)
      call createCurrent(P_Hl, P_ghWpAnti, P_ghA, P_GPlus, 3882, check)
      call createCurrent(P_GMinus, P_ghZ, P_G0, P_ghWmAnti, 4353, check)
      call createCurrent(P_A, P_ghAAnti, P_WPlus, P_ghWm, 3382, check)
      call createCurrent(P_muPlus, P_muMinus, P_Hl, 4669, check)
      call createCurrent(P_Hl, P_ghA, P_ghWpAnti, P_GPlus, 4758, check)
      call createCurrent(P_WPlus, P_Z, P_ghWm, P_ghZAnti, 3957, check)
      call createCurrent(P_tauMinus, P_GPlus, P_nu_tauAnti, 4268, check)
      call createCurrent(P_Hh, P_ghZ, P_GPlus, P_ghWpAnti, 4645, check)
      call createCurrent(P_Z, P_G0, P_WPlus, P_GMinus, 527, check)
      call createCurrent(P_g, P_g, P_Hl, P_Hh, 5203, check)
      call createCurrent(P_ghZAnti, P_Hl, P_ghZ, P_HlQ, 4613, check)
      call createCurrent(P_G0, P_ghZAnti, P_GMinus, P_ghWp, 2778, check)
      call createCurrent(P_GMinus, P_WPlus, P_Z, 2802, check)
      call createCurrent(P_Z, P_ghWmAnti, P_ghA, P_WMinus, 1451, check)
      call createCurrent(P_WQPlus, P_A, P_Z, P_WQMinus, 2667, check)
      call createCurrent(P_ghA, P_GPlus, P_GMinus, P_ghZAnti, 2568, check)
      call createCurrent(P_ghZ, P_G0, P_ghZAnti, P_G0, 1117, check)
      call createCurrent(P_Hh, P_ghWm, P_ghWmAnti, P_Hh, 4164, check)
      call createCurrent(P_Hl, P_Hl, P_WPlus, P_WMinus, 4514, check)
      call createCurrent(P_ghWmAnti, P_A, P_WMinus, P_ghZ, 2452, check)
      call createCurrent(P_ghZAnti, P_ghZ, P_Hh, P_HlQ, 3295, check)
      call createCurrent(P_ghWm, P_ghZAnti, P_Hh, P_GPlus, 2282, check)
      call createCurrent(P_A, P_ghZAnti, P_ghWp, P_WMinus, 3415, check)
      call createCurrent(P_GQMinus, P_Z, P_A, P_GQPlus, 2988, check)
      call createCurrent(P_WMinus, P_ghAAnti, P_ghZ, P_WPlus, 4089, check)
      call createCurrent(P_ghWpAnti, P_G0, P_G0, P_ghWp, 3386, check)
      call createCurrent(P_GQ0, P_ghWm, P_ghWmAnti, 842, check)
      call createCurrent(P_ghA, P_GMinus, P_ghWmAnti, P_Hh, 754, check)
      call createCurrent(P_ZQ, P_WMinus, P_WPlus, P_AQ, 3902, check)
      call createCurrent(P_ghWm, P_GMinus, P_GPlus, P_ghWmAnti, 2823, check)
      call createCurrent(P_WMinus, P_ghA, P_A, P_ghWmAnti, 3140, check)
      call createCurrent(P_ghAAnti, P_GMinus, P_ghA, P_GPlus, 3918, check)
      call createCurrent(P_WMinus, P_GPlus, P_Hl, 2720, check)
      call createCurrent(P_GPlus, P_ghWm, P_ghZAnti, P_Hl, 295, check)
      call createCurrent(P_d, P_dAnti, P_HhQ, 3691, check)
      call createCurrent(P_ghWpAnti, P_Z, P_WPlus, P_ghA, 2825, check)
      call createCurrent(P_ZQ, P_G0, P_HlQ, 456, check)
      call createCurrent(P_WMinus, P_ghWmAnti, P_WMinus, P_ghWp, 4617, check)
      call createCurrent(P_GMinus, P_GPlus, P_Z, P_Z, 4608, check)
      call createCurrent(P_GQMinus, P_G0, P_WQPlus, 2914, check)
      call createCurrent(P_HlQ, P_GMinus, P_ghWp, P_ghZAnti, 4250, check)
      call createCurrent(P_ghAAnti, P_ghA, P_WMinus, P_WQPlus, 3001, check)
      call createCurrent(P_A, P_nu_tauAnti, P_nu_tau, 4988, check)
      call createCurrent(P_ghWmAnti, P_Z, P_ghA, P_WMinus, 157, check)
      call createCurrent(P_WQMinus, P_GPlus, P_GMinus, P_WQPlus, 579, check)
      call createCurrent(P_ghZ, P_GMinus, P_ghWmAnti, P_HlQ, 1335, check)
      call createCurrent(P_GQMinus, P_Hl, P_ghWp, P_ghZAnti, 2870, check)
      call createCurrent(P_g, P_G0, P_g, P_G0, 5235, check)
      call createCurrent(P_ghWp, P_ghWpAnti, P_G0, P_G0, 781, check)
      call createCurrent(P_Z, P_ghWpAnti, P_ghWp, P_Z, 2567, check)
      call createCurrent(P_A, P_ghWm, P_WPlus, P_ghZAnti, 3086, check)
      call createCurrent(P_GPlus, P_Hl, P_ghZAnti, P_ghWm, 1850, check)
      call createCurrent(P_nu_muAnti, P_nu_mu, P_Z, 2162, check)
      call createCurrent(P_WPlus, P_A, P_Z, P_WMinus, 3089, check)
      call createCurrent(P_ghWm, P_ghWmAnti, P_A, P_ZQ, 2321, check)
      call createCurrent(P_ghWmAnti, P_ghWm, P_GQ0, 944, check)
      call createCurrent(P_Hh, P_Hl, P_ghZ, P_ghZAnti, 3148, check)
      call createCurrent(P_WQMinus, P_Hh, P_WQPlus, 93, check)
      call createCurrent(P_G0, P_t, P_tAnti, 4476, check)
      call createCurrent(P_Hh, P_ghWm, P_ghWmAnti, 47, check)
      call createCurrent(P_WQPlus, P_WMinus, P_Hl, P_GQ0, 4314, check)
      call createCurrent(P_WQMinus, P_sAnti, P_c, 3359, check)
      call createCurrent(P_G0, P_ghWm, P_GPlus, P_ghAAnti, 2467, check)
      call createCurrent(P_Z, P_ghZAnti, P_ghWm, P_WPlus, 333, check)
      call createCurrent(P_GQPlus, P_G0, P_GMinus, P_GQ0, 4105, check)
      call createCurrent(P_ghAAnti, P_WPlus, P_ghZ, P_WQMinus, 2708, check)
      call createCurrent(P_ghWmAnti, P_ghWm, P_GPlus, P_GMinus, 1124, check)
      call createCurrent(P_WPlus, P_Hl, P_Hh, P_WMinus, 4118, check)
      call createCurrent(P_bAnti, P_t, P_GMinus, 872, check)
      call createCurrent(P_ghWpAnti, P_WPlus, P_ghWm, P_WPlus, 91, check)
      call createCurrent(P_ghWp, P_ghWpAnti, P_Hh, P_HlQ, 999, check)
      call createCurrent(P_GQMinus, P_ghWp, P_ghZAnti, 1579, check)
      call createCurrent(P_ZQ, P_nu_muAnti, P_nu_mu, 3623, check)
      call createCurrent(P_ghWm, P_Hl, P_ghZAnti, P_GQPlus, 1695, check)
      call createCurrent(P_ghZ, P_ghWmAnti, P_Hl, P_GQMinus, 1792, check)
      call createCurrent(P_WQPlus, P_Z, P_ghWpAnti, P_ghA, 923, check)
      call createCurrent(P_G0, P_GPlus, P_ghZ, P_ghWpAnti, 1211, check)
      call createCurrent(P_A, P_WMinus, P_G0, P_GPlus, 2506, check)
      call createCurrent(P_GPlus, P_Hl, P_WMinus, 425, check)
      call createCurrent(P_WPlus, P_Hh, P_Z, P_GMinus, 2160, check)
      call createCurrent(P_HhQ, P_WPlus, P_Hh, P_WQMinus, 1099, check)
      call createCurrent(P_GQ0, P_Z, P_GMinus, P_WQPlus, 902, check)
      call createCurrent(P_GQ0, P_A, P_WPlus, P_GQMinus, 36, check)
      call createCurrent(P_GQ0, P_GMinus, P_ghZAnti, P_ghWp, 3117, check)
      call createCurrent(P_A, P_Hh, P_WMinus, P_GPlus, 283, check)
      call createCurrent(P_HhQ, P_WMinus, P_WQPlus, 4723, check)
      call createCurrent(P_dAnti, P_d, P_g, 3251, check)
      call createCurrent(P_A, P_A, P_ghWm, P_ghWmAnti, 2264, check)
      call createCurrent(P_WQPlus, P_WMinus, P_ghZ, P_ghAAnti, 2192, check)
      call createCurrent(P_WMinus, P_bAnti, P_t, 237, check)
      call createCurrent(P_ghAAnti, P_A, P_WMinus, P_ghWp, 2619, check)
      call createCurrent(P_ghWpAnti, P_Hh, P_ghWp, P_HhQ, 1390, check)
      call createCurrent(P_GMinus, P_GPlus, P_ghWpAnti, P_ghWp, 3875, check)
      call createCurrent(P_HlQ, P_WPlus, P_WQMinus, 3525, check)
      call createCurrent(P_GPlus, P_WMinus, P_Z, P_G0, 3335, check)
      call createCurrent(P_WQMinus, P_ghZAnti, P_WPlus, P_ghA, 2275, check)
      call createCurrent(P_GQ0, P_Hh, P_ghWm, P_ghWmAnti, 2024, check)
      call createCurrent(P_AQ, P_WMinus, P_Z, P_WQPlus, 3345, check)
      call createCurrent(P_ghAAnti, P_ghZ, P_GMinus, P_GPlus, 1873, check)
      call createCurrent(P_ZQ, P_WPlus, P_ghWm, P_ghZAnti, 1477, check)
      call createCurrent(P_GMinus, P_ghWmAnti, P_Hh, P_ghZ, 3172, check)
      call createCurrent(P_Hh, P_Hh, P_ghWm, P_ghWmAnti, 784, check)
      call createCurrent(P_ghWmAnti, P_A, P_ghWm, 4639, check)
      call createCurrent(P_G0, P_GMinus, P_WPlus, 1549, check)
      call createCurrent(P_Hl, P_g, P_g, P_Hl, 5127, check)
      call createCurrent(P_G0, P_ghZAnti, P_G0, P_ghZ, 1340, check)
      call createCurrent(P_WMinus, P_WPlus, P_G0, P_G0, 4719, check)
      call createCurrent(P_WMinus, P_WPlus, P_A, 2095, check)
      call createCurrent(P_Z, P_G0, P_GMinus, P_WPlus, 370, check)
      call createCurrent(P_GQ0, P_ghAAnti, P_GMinus, P_ghWp, 700, check)
      call createCurrent(P_gQ, P_dAnti, P_d, 345, check)
      call createCurrent(P_GQMinus, P_WPlus, P_HhQ, 2531, check)
      call createCurrent(P_GQMinus, P_GPlus, P_G0, P_HlQ, 3488, check)
      call createCurrent(P_HhQ, P_tauMinus, P_tauPlus, 4695, check)
      call createCurrent(P_Hh, P_GMinus, P_GPlus, P_Hl, 196, check)
      call createCurrent(P_HhQ, P_Hh, P_HhQ, 3052, check)
      call createCurrent(P_ghA, P_ghWmAnti, P_Z, P_WMinus, 1408, check)
      call createCurrent(P_GMinus, P_ghA, P_G0, P_ghWmAnti, 650, check)
      call createCurrent(P_sAnti, P_GMinus, P_c, 1153, check)
      call createCurrent(P_Hl, P_sAnti, P_s, 2745, check)
      call createCurrent(P_GPlus, P_cAnti, P_s, 1499, check)
      call createCurrent(P_ghWm, P_G0, P_ghWmAnti, P_GQ0, 3988, check)
      call createCurrent(P_ghWp, P_ghZAnti, P_Hl, P_GMinus, 654, check)
      call createCurrent(P_ghAAnti, P_WPlus, P_ghZ, P_WMinus, 282, check)
      call createCurrent(P_HlQ, P_ghWpAnti, P_Hl, P_ghWp, 4488, check)
      call createCurrent(P_ghWm, P_GPlus, P_Hh, P_ghAAnti, 2296, check)
      call createCurrent(P_ghWmAnti, P_Hh, P_ghWm, 2101, check)
      call createCurrent(P_WMinus, P_Hl, P_GPlus, P_A, 962, check)
      call createCurrent(P_ZQ, P_nu_mu, P_nu_muAnti, 1109, check)
      call createCurrent(P_Hl, P_WMinus, P_Hl, P_WPlus, 3032, check)
      call createCurrent(P_ghWmAnti, P_WPlus, P_ghWm, P_WMinus, 476, check)
      call createCurrent(P_Hh, P_ghZAnti, P_ghWm, P_GPlus, 4289, check)
      call createCurrent(P_GQ0, P_ghWp, P_GMinus, P_ghZAnti, 3520, check)
      call createCurrent(P_Hh, P_sAnti, P_s, 1302, check)
      call createCurrent(P_nu_muAnti, P_muMinus, P_WQPlus, 904, check)
      call createCurrent(P_WQPlus, P_G0, P_WMinus, P_HhQ, 3327, check)
      call createCurrent(P_HlQ, P_Z, P_Hl, P_ZQ, 3319, check)
      call createCurrent(P_A, P_ghA, P_WPlus, P_ghWpAnti, 3142, check)
      call createCurrent(P_ghWm, P_WPlus, P_ghWpAnti, P_WQPlus, 2000, check)
      call createCurrent(P_GQMinus, P_dAnti, P_u, 477, check)
      call createCurrent(P_u, P_GMinus, P_dAnti, 3387, check)
      call createCurrent(P_ghWpAnti, P_ghA, P_GPlus, 490, check)
      call createCurrent(P_Z, P_Z, P_ghWmAnti, P_ghWm, 2500, check)
      call createCurrent(P_GPlus, P_g, P_g, P_GMinus, 5261, check)
      call createCurrent(P_ghZAnti, P_Hl, P_ghWm, P_GQPlus, 4835, check)
      call createCurrent(P_ghZ, P_Hh, P_GPlus, P_ghWpAnti, 1883, check)
      call createCurrent(P_nu_eAnti, P_GPlus, P_eMinus, 4134, check)
      call createCurrent(P_GQ0, P_GMinus, P_ghWmAnti, P_ghZ, 2400, check)
      call createCurrent(P_ghA, P_WPlus, P_ghZAnti, P_WMinus, 2827, check)
      call createCurrent(P_ghWpAnti, P_ghWp, P_GPlus, P_GMinus, 186, check)
      call createCurrent(P_GQMinus, P_ghAAnti, P_GPlus, P_ghZ, 56, check)
      call createCurrent(P_Z, P_WMinus, P_WPlus, P_A, 911, check)
      call createCurrent(P_GPlus, P_ghWm, P_ghZAnti, 1337, check)
      call createCurrent(P_GQPlus, P_G0, P_GMinus, P_HlQ, 4337, check)
      call createCurrent(P_GMinus, P_GPlus, P_WPlus, P_WMinus, 3805, check)
      call createCurrent(P_GQPlus, P_ghZ, P_GMinus, P_ghZAnti, 4974, check)
      call createCurrent(P_GQMinus, P_Hh, P_Hh, P_GQPlus, 867, check)
      call createCurrent(P_tauMinus, P_Hh, P_tauPlus, 3597, check)
      call createCurrent(P_GQMinus, P_Hh, P_GPlus, P_HlQ, 3059, check)
      call createCurrent(P_GQPlus, P_WMinus, P_Hl, P_ZQ, 3874, check)
      call createCurrent(P_HhQ, P_WMinus, P_G0, P_WQPlus, 1733, check)
      call createCurrent(P_ghA, P_A, P_ghWpAnti, P_WPlus, 4837, check)
      call createCurrent(P_Hl, P_A, P_Z, P_Hh, 5072, check)
      call createCurrent(P_ghWmAnti, P_ghZ, P_Hl, P_GQMinus, 257, check)
      call createCurrent(P_g, P_bAnti, P_b, 2508, check)
      call createCurrent(P_WMinus, P_WPlus, P_ghAAnti, P_ghZ, 1514, check)
      call createCurrent(P_uAnti, P_u, P_HlQ, 445, check)
      call createCurrent(P_WQMinus, P_WPlus, P_AQ, 1418, check)
      call createCurrent(P_WQPlus, P_Hl, P_WQMinus, 4913, check)
      call createCurrent(P_ghZ, P_GPlus, P_G0, P_ghWpAnti, 2364, check)
      call createCurrent(P_WPlus, P_WMinus, P_ghAAnti, P_ghA, 4904, check)
      call createCurrent(P_ghWpAnti, P_ghZ, P_G0, P_GPlus, 2971, check)
      call createCurrent(P_HlQ, P_ghWmAnti, P_GMinus, P_ghZ, 4361, check)
      call createCurrent(P_muPlus, P_nu_mu, P_WQMinus, 1014, check)
      call createCurrent(P_GQMinus, P_WPlus, P_GQ0, 3167, check)
      call createCurrent(P_ghA, P_ghWmAnti, P_WMinus, P_Z, 2154, check)
      call createCurrent(P_G0, P_ghWp, P_G0, P_ghWpAnti, 882, check)
      call createCurrent(P_WPlus, P_ghZAnti, P_ghWm, P_Z, 3430, check)
      call createCurrent(P_WQPlus, P_eMinus, P_nu_eAnti, 4662, check)
      call createCurrent(P_WQMinus, P_Hl, P_GPlus, P_ZQ, 3184, check)
      call createCurrent(P_A, P_s, P_sAnti, 3863, check)
      call createCurrent(P_GQ0, P_A, P_WMinus, P_GQPlus, 744, check)
      call createCurrent(P_ghWp, P_A, P_WMinus, P_ghAAnti, 957, check)
      call createCurrent(P_ghA, P_GPlus, P_ghAAnti, P_GQMinus, 2175, check)
      call createCurrent(P_GQMinus, P_G0, P_GPlus, P_HhQ, 3390, check)
      call createCurrent(P_Hh, P_WPlus, P_WMinus, P_Hh, 1834, check)
      call createCurrent(P_ghA, P_ghWmAnti, P_GMinus, 4433, check)
      call createCurrent(P_ghZ, P_GMinus, P_ghAAnti, P_GQPlus, 2614, check)
      call createCurrent(P_GMinus, P_Z, P_WPlus, P_Hh, 3475, check)
      call createCurrent(P_GPlus, P_G0, P_ghA, P_ghWpAnti, 3618, check)
      call createCurrent(P_A, P_GPlus, P_G0, P_WMinus, 4439, check)
      call createCurrent(P_ghZAnti, P_ghWm, P_WPlus, P_A, 2061, check)
      call createCurrent(P_c, P_sAnti, P_WQMinus, 4894, check)
      call createCurrent(P_ghWm, P_GPlus, P_Hh, P_ghZAnti, 1472, check)
      call createCurrent(P_ghZ, P_ghZAnti, P_Hh, P_HlQ, 349, check)
      call createCurrent(P_ghWm, P_WPlus, P_ghZAnti, P_Z, 4936, check)
      call createCurrent(P_ghWp, P_G0, P_ghWpAnti, P_GQ0, 1642, check)
      call createCurrent(P_A, P_ghWpAnti, P_Z, P_ghWp, 1945, check)
      call createCurrent(P_WMinus, P_sAnti, P_c, 1208, check)
      call createCurrent(P_GQ0, P_Hh, P_ghWpAnti, P_ghWp, 15, check)
      call createCurrent(P_GPlus, P_ghWpAnti, P_GMinus, P_ghWp, 711, check)
      call createCurrent(P_Z, P_WPlus, P_ghWm, P_ghAAnti, 4741, check)
      call createCurrent(P_GMinus, P_GPlus, P_ghA, P_ghAAnti, 1481, check)
      call createCurrent(P_ghA, P_WPlus, P_WMinus, P_ghZAnti, 1960, check)
      call createCurrent(P_d, P_dAnti, P_AQ, 2343, check)
      call createCurrent(P_bAnti, P_b, P_A, 1931, check)
      call createCurrent(P_ghAAnti, P_GMinus, P_Hh, P_ghWp, 4673, check)
      call createCurrent(P_WQPlus, P_ghAAnti, P_ghWm, 4136, check)
      call createCurrent(P_WPlus, P_WMinus, P_ghA, P_ghZAnti, 223, check)
      call createCurrent(P_ghWmAnti, P_Hl, P_ghA, P_GQMinus, 1031, check)
      call createCurrent(P_GPlus, P_Hl, P_WMinus, P_A, 2691, check)
      call createCurrent(P_ghAAnti, P_ghA, P_GPlus, P_GMinus, 2446, check)
      call createCurrent(P_tAnti, P_t, P_AQ, 2784, check)
      call createCurrent(P_GQ0, P_Hh, P_WPlus, P_WQMinus, 408, check)
      call createCurrent(P_G0, P_G0, P_GPlus, P_GMinus, 371, check)
      call createCurrent(P_Hl, P_ghAAnti, P_GMinus, P_ghWp, 4857, check)
      call createCurrent(P_WPlus, P_WMinus, P_Hh, P_Hl, 1529, check)
      call createCurrent(P_Hl, P_ghWmAnti, P_Hl, P_ghWm, 3435, check)
      call createCurrent(P_GQPlus, P_GMinus, P_HhQ, 553, check)
      call createCurrent(P_AQ, P_Z, P_ghWmAnti, P_ghWm, 3771, check)
      call createCurrent(P_HhQ, P_Hl, P_ghWm, P_ghWmAnti, 505, check)
      call createCurrent(P_WQMinus, P_A, P_WPlus, P_AQ, 1638, check)
      call createCurrent(P_Z, P_WPlus, P_Hh, P_GMinus, 2056, check)
      call createCurrent(P_ghZAnti, P_ghWp, P_GMinus, P_Hh, 2549, check)
      call createCurrent(P_ghWmAnti, P_Hh, P_ghA, P_GMinus, 2665, check)
      call createCurrent(P_HhQ, P_Hh, P_ghWm, P_ghWmAnti, 1347, check)
      call createCurrent(P_nu_mu, P_nu_muAnti, P_ZQ, 1394, check)
      call createCurrent(P_WQPlus, P_ghAAnti, P_WMinus, P_ghA, 2114, check)
      call createCurrent(P_A, P_ghWmAnti, P_ghWm, P_Z, 338, check)
      call createCurrent(P_GMinus, P_Hl, P_WPlus, P_A, 1040, check)
      call createCurrent(P_GPlus, P_ghWm, P_G0, P_ghZAnti, 1807, check)
      call createCurrent(P_ghZ, P_G0, P_ghWpAnti, P_GQPlus, 2851, check)
      call createCurrent(P_ZQ, P_Hl, P_WPlus, P_GQMinus, 357, check)
      call createCurrent(P_ghWp, P_WPlus, P_WMinus, P_ghWpAnti, 1647, check)
      call createCurrent(P_ghWp, P_GMinus, P_ghZAnti, P_GQ0, 4658, check)
      call createCurrent(P_HlQ, P_Hh, P_GMinus, P_GQPlus, 2078, check)
      call createCurrent(P_Z, P_WPlus, P_ghA, P_ghWpAnti, 3451, check)
      call createCurrent(P_GPlus, P_A, P_WMinus, 3326, check)
      call createCurrent(P_ghZAnti, P_Hh, P_ghZ, P_HlQ, 2907, check)
      call createCurrent(P_ghZ, P_ghWmAnti, P_WQMinus, 293, check)
      call createCurrent(P_GMinus, P_ghWmAnti, P_Hl, P_ghA, 4970, check)
      call createCurrent(P_eMinus, P_nu_eAnti, P_GQPlus, 3329, check)
      call createCurrent(P_G0, P_G0, P_ghZAnti, P_ghZ, 1019, check)
      call createCurrent(P_ghWmAnti, P_ghZ, P_WMinus, 62, check)
      call createCurrent(P_ghWm, P_ghWmAnti, P_Hl, P_HlQ, 1137, check)
      call createCurrent(P_Z, P_ghWmAnti, P_A, P_ghWm, 4132, check)
      call createCurrent(P_ghZAnti, P_ghWp, P_G0, P_GMinus, 1387, check)
      call createCurrent(P_b, P_GPlus, P_tAnti, 4427, check)
      call createCurrent(P_GPlus, P_GMinus, P_ghAAnti, P_ghZ, 4045, check)
      call createCurrent(P_WMinus, P_ghZAnti, P_ghWp, 4590, check)
      call createCurrent(P_uAnti, P_d, P_WQPlus, 3996, check)
      call createCurrent(P_GPlus, P_ghA, P_ghWpAnti, P_Hl, 1936, check)
      call createCurrent(P_ghWmAnti, P_ghZ, P_Z, P_WQMinus, 1675, check)
      call createCurrent(P_HhQ, P_G0, P_Hl, P_GQ0, 3391, check)
      call createCurrent(P_HlQ, P_GMinus, P_Z, P_WQPlus, 4931, check)
      call createCurrent(P_g, P_ghGAnti, P_ghG, P_g, 3199, check)
      call createCurrent(P_GPlus, P_ghWm, P_ghZAnti, P_G0, 314, check)
      call createCurrent(P_A, P_WPlus, P_ghWpAnti, P_ghZ, 3840, check)
      call createCurrent(P_GQ0, P_GPlus, P_G0, P_GQMinus, 2351, check)
      call createCurrent(P_G0, P_WMinus, P_GPlus, P_Z, 4814, check)
      call createCurrent(P_ghWpAnti, P_ghWp, P_WPlus, P_WMinus, 389, check)
      call createCurrent(P_GQMinus, P_G0, P_ghWmAnti, P_ghZ, 4342, check)
      call createCurrent(P_WQMinus, P_WPlus, P_ghWp, P_ghWpAnti, 1087, check)
      call createCurrent(P_G0, P_ghWmAnti, P_ghA, P_GMinus, 2964, check)
      call createCurrent(P_WPlus, P_ghWpAnti, P_ghA, P_A, 1631, check)
      call createCurrent(P_GPlus, P_ghZ, P_ghAAnti, P_GMinus, 900, check)
      call createCurrent(P_HhQ, P_ghWpAnti, P_Hh, P_ghWp, 4324, check)
      call createCurrent(P_HhQ, P_Hl, P_WPlus, P_WQMinus, 568, check)
      call createCurrent(P_ghWp, P_ghWpAnti, P_WPlus, P_WMinus, 2492, check)
      call createCurrent(P_ghWmAnti, P_A, P_Z, P_ghWm, 4140, check)
      call createCurrent(P_ghA, P_GPlus, P_ghZAnti, P_GQMinus, 4637, check)
      call createCurrent(P_G0, P_GMinus, P_A, P_WPlus, 2271, check)
      call createCurrent(P_b, P_A, P_bAnti, 4699, check)
      call createCurrent(P_WMinus, P_A, P_Z, P_WPlus, 888, check)
      call createCurrent(P_ghAAnti, P_ghWm, P_Z, P_WPlus, 987, check)
      call createCurrent(P_ghAAnti, P_GPlus, P_ghWm, P_Hh, 3397, check)
      call createCurrent(P_WQMinus, P_Z, P_Hh, P_GQPlus, 3464, check)
      call createCurrent(P_s, P_sAnti, P_g, 4420, check)
      call createCurrent(P_b, P_WPlus, P_tAnti, 3146, check)
      call createCurrent(P_HlQ, P_ghZ, P_GMinus, P_ghWmAnti, 2747, check)
      call createCurrent(P_ghWp, P_GMinus, P_ghZAnti, P_HlQ, 4253, check)
      call createCurrent(P_GQ0, P_ghWpAnti, P_GPlus, P_ghZ, 3803, check)
      call createCurrent(P_Hh, P_g, P_Hl, P_g, 5184, check)
      call createCurrent(P_WMinus, P_A, P_ghWmAnti, P_ghZ, 925, check)
      call createCurrent(P_ghA, P_ghWmAnti, P_GMinus, P_G0, 1795, check)
      call createCurrent(P_HhQ, P_ghAAnti, P_GMinus, P_ghWp, 4117, check)
      call createCurrent(P_t, P_bAnti, P_GQMinus, 221, check)
      call createCurrent(P_Z, P_Hh, P_Z, P_Hl, 1641, check)
      call createCurrent(P_WMinus, P_ghZ, P_ghZAnti, P_WPlus, 4047, check)
      call createCurrent(P_HlQ, P_muPlus, P_muMinus, 1783, check)
      call createCurrent(P_GQPlus, P_ghWm, P_G0, P_ghZAnti, 3042, check)
      call createCurrent(P_GQMinus, P_ghA, P_Hh, P_ghWmAnti, 82, check)
      call createCurrent(P_GPlus, P_ghAAnti, P_ghWm, P_G0, 4601, check)
      call createCurrent(P_HlQ, P_Z, P_GMinus, P_WQPlus, 1476, check)
      call createCurrent(P_ghWmAnti, P_A, P_ghWm, P_A, 53, check)
      call createCurrent(P_GQPlus, P_GMinus, P_Hh, P_HhQ, 4922, check)
      call createCurrent(P_HhQ, P_ghWm, P_Hl, P_ghWmAnti, 3833, check)
      call createCurrent(P_ZQ, P_GMinus, P_WPlus, P_HlQ, 1813, check)
      call createCurrent(P_WQPlus, P_WMinus, P_ghAAnti, P_ghZ, 2499, check)
      call createCurrent(P_ghWpAnti, P_A, P_ghZ, P_WPlus, 2985, check)
      call createCurrent(P_Hh, P_GPlus, P_WMinus, 73, check)
      call createCurrent(P_Z, P_G0, 5095, check)
      call createCurrent(P_ghZ, P_G0, P_ghWmAnti, P_GMinus, 1343, check)
      call createCurrent(P_ZQ, P_Hl, P_Hl, P_ZQ, 4624, check)
      call createCurrent(P_GQ0, P_GMinus, P_GPlus, P_GQ0, 4672, check)
      call createCurrent(P_ZQ, P_Z, P_Hh, P_HlQ, 197, check)
      call createCurrent(P_ghZ, P_Hh, P_Hh, P_ghZAnti, 674, check)
      call createCurrent(P_tauMinus, P_A, P_tauPlus, 2635, check)
      call createCurrent(P_GMinus, P_WMinus, P_WPlus, P_GPlus, 3894, check)
      call createCurrent(P_ghA, P_G0, P_ghWpAnti, P_GPlus, 4391, check)
      call createCurrent(P_A, P_WMinus, P_ghWmAnti, P_ghA, 3147, check)
      call createCurrent(P_g, P_g, P_Hl, 5265, check)
      call createCurrent(P_HlQ, P_Hh, P_ghWp, P_ghWpAnti, 4816, check)
      call createCurrent(P_WQPlus, P_Hl, P_Hl, P_WQMinus, 2726, check)
      call createCurrent(P_GMinus, P_ghZAnti, P_ghWp, P_G0, 2918, check)
      call createCurrent(P_ghZ, P_Z, P_WMinus, P_ghWmAnti, 494, check)
      call createCurrent(P_u, P_dAnti, P_WQMinus, 3547, check)
      call createCurrent(P_ghWp, P_ghWpAnti, P_Hl, 195, check)
      call createCurrent(P_ghWmAnti, P_Hl, P_ghWm, 2656, check)
      call createCurrent(P_uAnti, P_g, P_u, 3238, check)
      call createCurrent(P_HlQ, P_GPlus, P_ghWpAnti, P_ghZ, 549, check)
      call createCurrent(P_ghZAnti, P_G0, P_ghWm, P_GPlus, 1723, check)
      call createCurrent(P_HhQ, P_GMinus, P_WQPlus, 540, check)
      call createCurrent(P_ghWm, P_Z, P_ghWmAnti, P_AQ, 4180, check)
      call createCurrent(P_GMinus, P_ghZ, P_ghZAnti, P_GPlus, 1542, check)
      call createCurrent(P_WMinus, P_A, P_ghZ, P_ghWmAnti, 3410, check)
      call createCurrent(P_ZQ, P_Z, P_GMinus, P_GQPlus, 457, check)
      call createCurrent(P_Hh, P_Z, P_Z, 1383, check)
      call createCurrent(P_GMinus, P_GPlus, P_G0, P_G0, 2518, check)
      call createCurrent(P_Hl, P_GPlus, P_Hl, P_GMinus, 3614, check)
      call createCurrent(P_WQPlus, P_ghA, P_ghWpAnti, 3246, check)
      call createCurrent(P_GMinus, P_ghAAnti, P_ghA, P_GPlus, 325, check)
      call createCurrent(P_ghWm, P_A, P_ghWmAnti, P_AQ, 946, check)
      call createCurrent(P_u, P_uAnti, P_gQ, 969, check)
      call createCurrent(P_GQPlus, P_Hl, P_WMinus, P_AQ, 2876, check)
      call createCurrent(P_G0, P_A, 5044, check)
      call createCurrent(P_G0, P_ghWp, P_ghWpAnti, P_G0, 4435, check)
      call createCurrent(P_ghZ, P_WMinus, P_ghZAnti, P_WPlus, 1950, check)
      call createCurrent(P_Hh, P_Hl, P_ghWp, P_ghWpAnti, 4316, check)
      call createCurrent(P_ghWpAnti, P_GPlus, P_ghZ, P_Hl, 1219, check)
      call createCurrent(P_Z, P_ghWpAnti, P_ghA, P_WPlus, 3742, check)
      call createCurrent(P_A, P_WPlus, P_ghAAnti, P_ghWm, 4710, check)
      call createCurrent(P_ePlus, P_A, P_eMinus, 4099, check)
      call createCurrent(P_Hh, P_ghWm, P_ghAAnti, P_GPlus, 2006, check)
      call createCurrent(P_GQMinus, P_GPlus, P_Hl, P_HhQ, 3029, check)
      call createCurrent(P_WQPlus, P_Z, P_WQMinus, 2719, check)
      call createCurrent(P_WQPlus, P_WMinus, P_G0, P_HlQ, 4644, check)
      call createCurrent(P_gQ, P_u, P_uAnti, 2142, check)
      call createCurrent(P_ghAAnti, P_WPlus, P_ghWm, P_A, 4935, check)
      call createCurrent(P_ghWmAnti, P_ghWm, P_Z, 299, check)
      call createCurrent(P_ghWpAnti, P_ghWp, P_WMinus, P_WPlus, 4615, check)
      call createCurrent(P_HlQ, P_ghWm, P_Hl, P_ghWmAnti, 3256, check)
      call createCurrent(P_GMinus, P_G0, P_ghWp, P_ghZAnti, 1215, check)
      call createCurrent(P_uAnti, P_Hl, P_u, 1175, check)
      call createCurrent(P_Hl, P_ghWmAnti, P_ghWm, P_Hh, 4565, check)
      call createCurrent(P_GQMinus, P_WPlus, P_A, P_HhQ, 1323, check)
      call createCurrent(P_Z, P_muPlus, P_muMinus, 615, check)
      call createCurrent(P_GQMinus, P_ghZAnti, P_GPlus, P_ghZ, 4562, check)
      call createCurrent(P_ghWpAnti, P_WPlus, P_A, P_ghA, 2662, check)
      call createCurrent(P_GPlus, P_Z, P_GMinus, P_Z, 3339, check)
      call createCurrent(P_GMinus, P_ghWp, P_Hl, P_ghZAnti, 4846, check)
      call createCurrent(P_ghWpAnti, P_ghA, P_Z, P_WPlus, 4535, check)
      call createCurrent(P_GPlus, P_A, P_Hh, P_WMinus, 4215, check)
      call createCurrent(P_d, P_uAnti, P_GQPlus, 3752, check)
      call createCurrent(P_Hl, P_Hh, P_ghWpAnti, P_ghWp, 4809, check)
      call createCurrent(P_ZQ, P_GPlus, P_G0, P_WQMinus, 1763, check)
      call createCurrent(P_GPlus, P_WMinus, P_G0, P_A, 2814, check)
      call createCurrent(P_Hh, P_GPlus, P_ghWm, P_ghZAnti, 4585, check)
      call createCurrent(P_ghWm, P_ghAAnti, P_GPlus, P_G0, 2220, check)
      call createCurrent(P_HlQ, P_ghZ, P_ghZAnti, 3097, check)
      call createCurrent(P_A, P_ghWm, P_ghWmAnti, P_A, 2650, check)
      call createCurrent(P_dAnti, P_d, P_G0, 2887, check)
      call createCurrent(P_ghAAnti, P_GPlus, P_ghWm, 4153, check)
      call createCurrent(P_G0, P_cAnti, P_c, 889, check)
      call createCurrent(P_GQ0, P_GMinus, P_Hh, P_GQPlus, 2151, check)
      call createCurrent(P_WQMinus, P_ghZ, P_WPlus, P_ghAAnti, 2129, check)
      call createCurrent(P_WPlus, P_A, P_GMinus, P_G0, 702, check)
      call createCurrent(P_WMinus, P_ghA, P_Z, P_ghWmAnti, 3186, check)
      call createCurrent(P_Z, P_ghWpAnti, P_ghZ, P_WPlus, 4078, check)
      call createCurrent(P_c, P_G0, P_cAnti, 4106, check)
      call createCurrent(P_ghWmAnti, P_ghWm, P_AQ, 3022, check)
      call createCurrent(P_ghZ, P_ghWmAnti, P_GMinus, P_G0, 4002, check)
      call createCurrent(P_ghZAnti, P_GMinus, P_ghWp, P_G0, 240, check)
      call createCurrent(P_WQMinus, P_ePlus, P_nu_e, 3717, check)
      call createCurrent(P_g, P_g, P_Z, P_A, 5247, check)
      call createCurrent(P_nu_mu, P_muPlus, P_GMinus, 519, check)
      call createCurrent(P_Z, P_ghWm, P_ghZAnti, P_WPlus, 2777, check)
      call createCurrent(P_GQ0, P_Z, P_HlQ, 1020, check)
      call createCurrent(P_ghZ, P_G0, P_GMinus, P_ghWmAnti, 3582, check)
      call createCurrent(P_eMinus, P_ePlus, P_Hh, 3984, check)
      call createCurrent(P_GMinus, P_ghWp, P_ghAAnti, P_Hl, 3160, check)
      call createCurrent(P_GQ0, P_ghWm, P_GPlus, P_ghAAnti, 3579, check)
      call createCurrent(P_ZQ, P_GMinus, P_WQPlus, 1079, check)
      call createCurrent(P_ghZAnti, P_GPlus, P_Hl, P_ghWm, 1393, check)
      call createCurrent(P_WPlus, P_WPlus, P_ghWpAnti, P_ghWm, 2477, check)
      call createCurrent(P_ghWm, P_ghZAnti, P_Z, P_WPlus, 4574, check)
      call createCurrent(P_HhQ, P_Hh, P_Hh, P_HhQ, 4656, check)
      call createCurrent(P_GQ0, P_GPlus, P_GQMinus, 988, check)
      call createCurrent(P_ghZAnti, P_ghZ, P_Hl, P_Hh, 4110, check)
      call createCurrent(P_ghWpAnti, P_Z, P_ghA, P_WPlus, 4563, check)
      call createCurrent(P_Hh, P_Hl, P_g, P_g, 5260, check)
      call createCurrent(P_ZQ, P_A, P_WMinus, P_WQPlus, 4303, check)
      call createCurrent(P_Hl, P_WMinus, P_Z, P_GPlus, 3663, check)
      call createCurrent(P_ghWpAnti, P_ghA, P_Hl, P_GQPlus, 4578, check)
      call createCurrent(P_g, P_GMinus, P_g, P_GPlus, 5131, check)
      call createCurrent(P_GQPlus, P_GMinus, P_A, P_ZQ, 4507, check)
      call createCurrent(P_ghWpAnti, P_ghWp, P_WPlus, P_WQMinus, 583, check)
      call createCurrent(P_GQPlus, P_Hl, P_GMinus, P_HhQ, 4763, check)
      call createCurrent(P_muMinus, P_muPlus, P_G0, 1280, check)
      call createCurrent(P_ghZAnti, P_ghWp, P_GMinus, P_HhQ, 4685, check)
      call createCurrent(P_ghZ, P_WMinus, P_ghWmAnti, 4090, check)
      call createCurrent(P_ghAAnti, P_ghA, P_WPlus, P_WQMinus, 365, check)
      call createCurrent(P_GQMinus, P_Hh, P_ghWp, P_ghZAnti, 351, check)
      call createCurrent(P_ghWm, P_GPlus, P_ghZAnti, P_Hl, 4, check)
      call createCurrent(P_ZQ, P_ghWpAnti, P_Z, P_ghWp, 4278, check)
      call createCurrent(P_A, P_A, P_Hl, P_Hl, 5145, check)
      call createCurrent(P_GQPlus, P_Z, P_A, P_GQMinus, 2857, check)
      call createCurrent(P_ghWm, P_ghZAnti, P_GPlus, P_Hh, 300, check)
      call createCurrent(P_s, P_Hl, P_sAnti, 1876, check)
      call createCurrent(P_GQMinus, P_ghZAnti, P_GPlus, P_ghA, 421, check)
      call createCurrent(P_ghWmAnti, P_A, P_ghWm, P_ZQ, 2817, check)
      call createCurrent(P_g, P_GMinus, P_GPlus, P_g, 5250, check)
      call createCurrent(P_ghZ, P_Z, P_ghWmAnti, P_WMinus, 1515, check)
      call createCurrent(P_WPlus, P_ghAAnti, P_ghWm, P_Z, 4292, check)
      call createCurrent(P_WQPlus, P_ghZAnti, P_WMinus, P_ghZ, 1809, check)
      call createCurrent(P_GMinus, P_A, P_WPlus, P_Hh, 1725, check)
      call createCurrent(P_Hh, P_A, P_A, 5221, check)
      call createCurrent(P_ghWp, P_ghAAnti, P_Hh, P_GMinus, 1622, check)
      call createCurrent(P_bAnti, P_b, P_gQ, 1546, check)
      call createCurrent(P_ghAAnti, P_Hl, P_GPlus, P_ghWm, 3239, check)
      call createCurrent(P_bAnti, P_Hh, P_b, 502, check)
      call createCurrent(P_Hh, P_A, P_GMinus, P_WPlus, 4779, check)
      call createCurrent(P_A, P_A, P_Hh, 5142, check)
      call createCurrent(P_ghWm, P_ghWmAnti, P_GQ0, 4457, check)
      call createCurrent(P_Hh, P_GPlus, P_ghWpAnti, P_ghZ, 4239, check)
      call createCurrent(P_Z, P_Hh, P_A, P_Hh, 5011, check)
      call createCurrent(P_uAnti, P_d, P_WPlus, 752, check)
      call createCurrent(P_GQPlus, P_Hl, P_Z, P_WQMinus, 1716, check)
      call createCurrent(P_A, P_GMinus, P_Z, P_GPlus, 2643, check)
      call createCurrent(P_ghAAnti, P_A, P_WPlus, P_ghWm, 1827, check)
      call createCurrent(P_GMinus, P_WPlus, P_WMinus, P_GPlus, 638, check)
      call createCurrent(P_ghG, P_ghGAnti, P_g, P_gQ, 341, check)
      call createCurrent(P_g, P_ghGAnti, P_g, P_ghG, 1940, check)
      call createCurrent(P_HlQ, P_GMinus, P_ghWmAnti, P_ghZ, 1159, check)
      call createCurrent(P_ghZ, P_Hh, P_ghZAnti, P_HhQ, 1898, check)
      call createCurrent(P_ghA, P_GPlus, P_ghWpAnti, P_Hh, 1762, check)
      call createCurrent(P_ghAAnti, P_ghWp, P_GMinus, P_GQ0, 3775, check)
      call createCurrent(P_WMinus, P_WMinus, P_ghWp, P_ghWmAnti, 4893, check)
      call createCurrent(P_ghAAnti, P_ghA, P_GMinus, P_GQPlus, 148, check)
      call createCurrent(P_GQ0, P_GMinus, P_ghZ, P_ghWmAnti, 612, check)
      call createCurrent(P_gQ, P_ghG, P_ghGAnti, 4612, check)
      call createCurrent(P_WQPlus, P_G0, P_WMinus, P_GQ0, 917, check)
      call createCurrent(P_Hh, P_ghWm, P_Hl, P_ghWmAnti, 1128, check)
      call createCurrent(P_WMinus, P_A, P_Hh, P_GPlus, 3617, check)
      call createCurrent(P_G0, P_ghWmAnti, P_ghWm, P_G0, 4375, check)
      call createCurrent(P_WQMinus, P_ghZ, P_ghWmAnti, 3157, check)
      call createCurrent(P_WMinus, P_ghZAnti, P_Z, P_ghWp, 931, check)
      call createCurrent(P_Hh, P_GMinus, P_ghWmAnti, P_ghA, 2838, check)
      call createCurrent(P_Hl, P_ghWmAnti, P_GMinus, P_ghZ, 719, check)
      call createCurrent(P_ghWpAnti, P_ghZ, P_GPlus, P_GQ0, 2196, check)
      call createCurrent(P_A, P_GMinus, P_GPlus, 1548, check)
      call createCurrent(P_GMinus, P_ghAAnti, P_Hl, P_ghWp, 2071, check)
      call createCurrent(P_A, P_dAnti, P_d, 3311, check)
      call createCurrent(P_A, P_bAnti, P_b, 2613, check)
      call createCurrent(P_HlQ, P_G0, P_G0, P_HhQ, 817, check)
      call createCurrent(P_ghWpAnti, P_Hl, P_ghWp, P_HhQ, 3728, check)
      call createCurrent(P_Hl, P_Z, P_Z, P_Hl, 304, check)
      call createCurrent(P_Hl, P_GPlus, P_ghWm, P_ghAAnti, 458, check)
      call createCurrent(P_sAnti, P_s, 5059, check)
      call createCurrent(P_ghAAnti, P_ghWm, P_A, P_WPlus, 3612, check)
      call createCurrent(P_A, P_ghAAnti, P_ghWp, P_WMinus, 905, check)
      call createCurrent(P_GMinus, P_ghA, P_ghWmAnti, P_Hl, 1017, check)
      call createCurrent(P_c, P_sAnti, P_GMinus, 2528, check)
      call createCurrent(P_ghA, P_ghWpAnti, P_A, P_WQPlus, 3632, check)
      call createCurrent(P_ghWp, P_Hh, P_ghWpAnti, P_GQ0, 3985, check)
      call createCurrent(P_GPlus, P_GMinus, P_Hl, 4543, check)
      call createCurrent(P_GQPlus, P_GMinus, P_G0, P_HlQ, 2391, check)
      call createCurrent(P_ghAAnti, P_Hl, P_ghWm, P_GPlus, 2654, check)
      call createCurrent(P_ghAAnti, P_ghWm, P_WPlus, P_ZQ, 2395, check)
      call createCurrent(P_GQPlus, P_Hl, P_GMinus, P_GQ0, 4042, check)
      call createCurrent(P_GPlus, P_GMinus, P_Hh, P_Hh, 3950, check)
      call createCurrent(P_cAnti, P_c, P_Hl, 981, check)
      call createCurrent(P_ghA, P_Z, P_ghWmAnti, P_WMinus, 4494, check)
      call createCurrent(P_ghWm, P_ghAAnti, P_G0, P_GPlus, 2856, check)
      call createCurrent(P_WMinus, P_Z, P_Hh, P_GPlus, 1277, check)
      call createCurrent(P_Z, P_Z, P_G0, P_G0, 1740, check)
      call createCurrent(P_Hh, P_Hl, P_GMinus, P_GPlus, 2456, check)
      call createCurrent(P_GQPlus, P_Hh, P_Z, P_WQMinus, 4700, check)
      call createCurrent(P_GPlus, P_ghWpAnti, P_ghZ, P_G0, 2399, check)
      call createCurrent(P_GMinus, P_Hl, P_ghWp, P_ghZAnti, 1534, check)
      call createCurrent(P_GQMinus, P_G0, P_ghA, P_ghWmAnti, 1806, check)
      call createCurrent(P_ghWp, P_ghWpAnti, P_Hl, P_HhQ, 3522, check)
      call createCurrent(P_GQMinus, P_Z, P_GQPlus, 2478, check)
      call createCurrent(P_WMinus, P_ghZ, P_ghAAnti, P_WPlus, 820, check)
      call createCurrent(P_gQ, P_c, P_cAnti, 2344, check)
      call createCurrent(P_d, P_dAnti, P_Hl, 640, check)
      call createCurrent(P_Z, P_Z, P_Hl, 2816, check)
      call createCurrent(P_GQMinus, P_u, P_dAnti, 3095, check)
      call createCurrent(P_Hl, P_ghWmAnti, P_Hh, P_ghWm, 4327, check)
      call createCurrent(P_ghZAnti, P_WMinus, P_Z, P_ghWp, 1199, check)
      call createCurrent(P_ghWp, P_Z, P_WMinus, P_ghAAnti, 3210, check)
      call createCurrent(P_tauMinus, P_Hl, P_tauPlus, 4694, check)
      call createCurrent(P_Hh, P_GPlus, P_ghWm, P_ghAAnti, 3690, check)
      call createCurrent(P_A, P_ghZ, P_WPlus, P_ghWpAnti, 2213, check)
      call createCurrent(P_GQPlus, P_Hl, P_WMinus, P_ZQ, 2063, check)
      call createCurrent(P_ZQ, P_cAnti, P_c, 3270, check)
      call createCurrent(P_Hh, P_ghZ, P_ghZAnti, 380, check)
      call createCurrent(P_sAnti, P_s, P_Hl, 3505, check)
      call createCurrent(P_WPlus, P_GMinus, P_GPlus, P_WMinus, 143, check)
      call createCurrent(P_ghWp, P_GMinus, P_ghAAnti, 1065, check)
      call createCurrent(P_GMinus, P_GPlus, P_GMinus, P_GPlus, 2868, check)
      call createCurrent(P_g, P_sAnti, P_s, 1905, check)
      call createCurrent(P_u, P_uAnti, P_G0, 1564, check)
      call createCurrent(P_GQPlus, P_Hh, P_ghZAnti, P_ghWm, 4557, check)
      call createCurrent(P_G0, P_ghZAnti, P_ghZ, P_G0, 3817, check)
      call createCurrent(P_ghWmAnti, P_ghZ, P_G0, P_GQMinus, 4330, check)
      call createCurrent(P_Hl, P_GMinus, P_ghZ, P_ghWmAnti, 2094, check)
      call createCurrent(P_HlQ, P_muMinus, P_muPlus, 1667, check)
      call createCurrent(P_ghWmAnti, P_ghWm, P_Z, P_AQ, 1018, check)
      call createCurrent(P_ghWm, P_ghAAnti, P_GPlus, P_HhQ, 4797, check)
      call createCurrent(P_ghZAnti, P_GMinus, P_ghA, P_GQPlus, 1342, check)
      call createCurrent(P_WMinus, P_WPlus, P_ghA, P_ghAAnti, 2945, check)
      call createCurrent(P_GQMinus, P_ghA, P_G0, P_ghWmAnti, 4241, check)
      call createCurrent(P_ghZAnti, P_WPlus, P_ghWm, P_Z, 4725, check)
      call createCurrent(P_t, P_G0, P_tAnti, 3667, check)
      call createCurrent(P_g, P_Hl, P_g, 5224, check)
      call createCurrent(P_GPlus, P_WMinus, P_A, P_Hh, 2371, check)
      call createCurrent(P_WQPlus, P_WMinus, P_ghWmAnti, P_ghWm, 1446, check)
      call createCurrent(P_ZQ, P_GPlus, P_WQMinus, 2812, check)
      call createCurrent(P_ghAAnti, P_GMinus, P_ghWp, P_HlQ, 1846, check)
      call createCurrent(P_ghZ, P_Hl, P_ghWpAnti, P_GPlus, 438, check)
      call createCurrent(P_Hl, P_GMinus, P_ghA, P_ghWmAnti, 1799, check)
      call createCurrent(P_A, P_GMinus, P_WPlus, P_Hh, 1604, check)
      call createCurrent(P_ghAAnti, P_GPlus, P_GMinus, P_ghA, 2965, check)
      call createCurrent(P_ghWp, P_Hl, P_ghZAnti, P_GMinus, 3431, check)
      call createCurrent(P_HlQ, P_G0, P_G0, P_HlQ, 2755, check)
      call createCurrent(P_ghA, P_ghWpAnti, P_Z, P_WPlus, 562, check)
      call createCurrent(P_G0, P_GPlus, P_ghZAnti, P_ghWm, 3645, check)
      call createCurrent(P_GQMinus, P_ghWmAnti, P_Hh, P_ghZ, 4452, check)
      call createCurrent(P_GPlus, P_ghWpAnti, P_ghZ, P_Hl, 3226, check)
      call createCurrent(P_GMinus, P_Hl, P_ghZ, P_ghWmAnti, 3916, check)
      call createCurrent(P_ghA, P_A, P_ghWpAnti, P_WQPlus, 4511, check)
      call createCurrent(P_Hh, P_ghZ, P_ghZAnti, P_Hl, 3164, check)
      call createCurrent(P_WPlus, P_Z, P_WMinus, 2125, check)
      call createCurrent(P_G0, P_ghAAnti, P_ghWm, P_GPlus, 68, check)
      call createCurrent(P_Z, P_ghWpAnti, P_WPlus, P_ghZ, 3798, check)
      call createCurrent(P_WPlus, P_tauMinus, P_nu_tauAnti, 3159, check)
      call createCurrent(P_WMinus, P_ghWmAnti, P_Z, P_ghZ, 2490, check)
      call createCurrent(P_ghWpAnti, P_ghWp, P_Hh, P_Hh, 38, check)
      call createCurrent(P_GQ0, P_Hh, P_WMinus, P_WQPlus, 3318, check)
      call createCurrent(P_GPlus, P_ghZAnti, P_Hh, P_ghWm, 4528, check)
      call createCurrent(P_HlQ, P_G0, P_ghWpAnti, P_ghWp, 564, check)
      call createCurrent(P_Hl, P_g, P_g, P_Hh, 5144, check)
      call createCurrent(P_u, P_A, P_uAnti, 3676, check)
      call createCurrent(P_ghZAnti, P_WPlus, P_ghWm, 1538, check)
      call createCurrent(P_Z, P_A, P_Hh, 5092, check)
      call createCurrent(P_ghZ, P_ghWmAnti, P_WMinus, 3411, check)
      call createCurrent(P_uAnti, P_u, P_GQ0, 4949, check)
      call createCurrent(P_ghWm, P_WPlus, P_ghAAnti, P_ZQ, 635, check)
      call createCurrent(P_WQPlus, P_WMinus, P_A, P_ZQ, 3626, check)
      call createCurrent(P_ghZAnti, P_ghWp, P_WQMinus, 2611, check)
      call createCurrent(P_G0, P_ghWm, P_ghAAnti, P_GPlus, 287, check)
      call createCurrent(P_WPlus, P_ghA, P_ghAAnti, P_WMinus, 972, check)
      call createCurrent(P_G0, P_WMinus, P_GPlus, 3635, check)
      call createCurrent(P_uAnti, P_d, P_GQPlus, 4891, check)
      call createCurrent(P_d, P_dAnti, P_ZQ, 621, check)
      call createCurrent(P_Hl, P_ghZAnti, P_Hl, P_ghZ, 1894, check)
      call createCurrent(P_ghWp, P_GPlus, P_GMinus, P_ghWpAnti, 3539, check)
      call createCurrent(P_HlQ, P_ghWm, P_G0, P_ghWmAnti, 2212, check)
      call createCurrent(P_ghWm, P_ghWmAnti, P_GPlus, P_GMinus, 4266, check)
      call createCurrent(P_GPlus, P_ghWpAnti, P_Hh, P_ghA, 266, check)
      call createCurrent(P_ZQ, P_Hl, P_Hh, P_ZQ, 4892, check)
      call createCurrent(P_G0, P_WMinus, P_G0, P_WPlus, 2447, check)
      call createCurrent(P_A, P_ghZAnti, P_WMinus, P_ghWp, 3569, check)
      call createCurrent(P_ghZ, P_Hh, P_ghWmAnti, P_GQMinus, 2629, check)
      call createCurrent(P_ZQ, P_GPlus, P_A, P_GQMinus, 844, check)
      call createCurrent(P_ghWmAnti, P_ghWm, P_A, P_ZQ, 777, check)
      call createCurrent(P_Hl, P_ghWm, P_ghAAnti, P_GPlus, 227, check)
      call createCurrent(P_WPlus, P_Z, P_GMinus, P_Hh, 1378, check)
      call createCurrent(P_GPlus, P_WMinus, P_Z, 3503, check)
      call createCurrent(P_Z, P_WPlus, P_Hl, P_GMinus, 1558, check)
      call createCurrent(P_WQPlus, P_GMinus, P_ZQ, 3580, check)
      call createCurrent(P_Z, P_Hl, P_A, P_Hl, 5082, check)
      call createCurrent(P_GPlus, P_Hl, P_ghWpAnti, P_ghZ, 2448, check)
      call createCurrent(P_HhQ, P_Hl, P_ghZ, P_ghZAnti, 3809, check)
      call createCurrent(P_Z, P_GMinus, P_WPlus, P_Hh, 2627, check)
      call createCurrent(P_ZQ, P_ghWpAnti, P_ghWp, 409, check)
      call createCurrent(P_ghAAnti, P_WMinus, P_ghWp, P_ZQ, 1486, check)
      call createCurrent(P_GMinus, P_GPlus, P_A, P_Z, 3497, check)
      call createCurrent(P_t, P_GMinus, P_bAnti, 1780, check)
      call createCurrent(P_ghWmAnti, P_ghWm, P_A, P_A, 2608, check)
      call createCurrent(P_ghAAnti, P_ghWp, P_WQMinus, 3917, check)
      call createCurrent(P_AQ, P_WMinus, P_ghZAnti, P_ghWp, 4968, check)
      call createCurrent(P_HlQ, P_ghWpAnti, P_GPlus, P_ghZ, 1455, check)
      call createCurrent(P_WPlus, P_ghWpAnti, P_ghWp, P_WMinus, 868, check)
      call createCurrent(P_GMinus, P_Z, P_Z, P_GPlus, 3282, check)
      call createCurrent(P_ghZ, P_GMinus, P_ghWmAnti, P_GQ0, 3441, check)
      call createCurrent(P_Z, P_A, P_Hh, P_Hh, 5089, check)
      call createCurrent(P_GQMinus, P_GPlus, P_GMinus, P_GQPlus, 3898, check)
      call createCurrent(P_ghWpAnti, P_ghA, P_G0, P_GPlus, 3807, check)
      call createCurrent(P_A, P_Hl, P_A, 5218, check)
      call createCurrent(P_WPlus, P_Z, P_Hh, P_GMinus, 3542, check)
      call createCurrent(P_GPlus, P_Hl, P_ghWm, P_ghAAnti, 2141, check)
      call createCurrent(P_GQPlus, P_Hh, P_Hh, P_GQMinus, 2575, check)
      call createCurrent(P_Hh, P_ghWp, P_GMinus, P_ghZAnti, 722, check)
      call createCurrent(P_A, P_WMinus, P_GPlus, P_Hh, 1512, check)
      call createCurrent(P_Z, P_WPlus, P_GMinus, 4200, check)
      call createCurrent(P_Z, P_Hl, P_Hh, P_Z, 2367, check)
      call createCurrent(P_Hh, P_WMinus, P_GPlus, 3599, check)
      call createCurrent(P_G0, P_WPlus, P_A, P_GMinus, 2470, check)
      call createCurrent(P_Hl, P_Hh, 5020, check)
      call createCurrent(P_ghWp, P_WMinus, P_ghZAnti, 1409, check)
      call createCurrent(P_ghWp, P_ghWpAnti, P_AQ, 3149, check)
      call createCurrent(P_GQ0, P_G0, P_ghZAnti, P_ghZ, 1316, check)
      call createCurrent(P_tAnti, P_t, P_GQ0, 159, check)
      call createCurrent(P_GQPlus, P_ghWpAnti, P_Hl, P_ghZ, 60, check)
      call createCurrent(P_ghWm, P_ghZAnti, P_GPlus, 3685, check)
      call createCurrent(P_GMinus, P_ghWpAnti, P_GPlus, P_ghWp, 1955, check)
      call createCurrent(P_ghZAnti, P_ghZ, P_G0, P_G0, 2065, check)
      call createCurrent(P_HlQ, P_Z, P_GPlus, P_WQMinus, 1097, check)
      call createCurrent(P_GQMinus, P_t, P_bAnti, 2942, check)
      call createCurrent(P_A, P_tauMinus, P_tauPlus, 2788, check)
      call createCurrent(P_GMinus, P_Hh, P_Z, P_WPlus, 885, check)
      call createCurrent(P_AQ, P_A, P_GMinus, P_GQPlus, 3622, check)
      call createCurrent(P_gQ, P_bAnti, P_b, 4355, check)
      call createCurrent(P_nu_e, P_GMinus, P_ePlus, 4651, check)
      call createCurrent(P_G0, P_ghWm, P_G0, P_ghWmAnti, 935, check)
      call createCurrent(P_GPlus, P_G0, P_ghWm, P_ghAAnti, 1198, check)
      call createCurrent(P_A, P_u, P_uAnti, 493, check)
      call createCurrent(P_Hl, P_Hh, P_Hh, P_Hh, 474, check)
      call createCurrent(P_ghZAnti, P_ghWp, P_A, P_WMinus, 1922, check)
      call createCurrent(P_WQPlus, P_GMinus, P_Hh, P_AQ, 951, check)
      call createCurrent(P_Hl, P_ghWpAnti, P_Hh, P_ghWp, 71, check)
      call createCurrent(P_ghWm, P_ghZAnti, P_WQPlus, 1161, check)
      call createCurrent(P_GQ0, P_G0, P_ghWpAnti, P_ghWp, 2328, check)
      call createCurrent(P_ghWpAnti, P_ghZ, P_WPlus, 2283, check)
      call createCurrent(P_WPlus, P_Hl, P_WMinus, P_Hh, 3526, check)
      call createCurrent(P_ghWm, P_ghZAnti, P_GPlus, P_HlQ, 4399, check)
      call createCurrent(P_ghZ, P_ghWpAnti, P_WPlus, 4131, check)
      call createCurrent(P_ghWpAnti, P_Z, P_A, P_ghWp, 1890, check)
      call createCurrent(P_GPlus, P_A, P_G0, P_WMinus, 927, check)
      call createCurrent(P_WPlus, P_GMinus, 5075, check)
      call createCurrent(P_Hl, P_WPlus, P_WMinus, P_Hl, 913, check)
      call createCurrent(P_ghA, P_ghWpAnti, P_GPlus, 2894, check)
      call createCurrent(P_Z, P_GPlus, P_GMinus, 3162, check)
      call createCurrent(P_WQPlus, P_A, P_WMinus, P_AQ, 4652, check)
      call createCurrent(P_gQ, P_g, P_ghGAnti, P_ghG, 1828, check)
      call createCurrent(P_WPlus, P_GMinus, P_Hl, 3827, check)
      call createCurrent(P_G0, P_ghAAnti, P_GMinus, P_ghWp, 3169, check)
      call createCurrent(P_GMinus, P_Hh, P_GPlus, P_Hl, 352, check)
      call createCurrent(P_GQPlus, P_G0, P_WMinus, P_AQ, 321, check)
      call createCurrent(P_GQ0, P_ghWm, P_G0, P_ghWmAnti, 3669, check)
      call createCurrent(P_GMinus, P_ghAAnti, P_GPlus, P_ghA, 4161, check)
      call createCurrent(P_dAnti, P_GMinus, P_u, 1600, check)
      call createCurrent(P_bAnti, P_Hl, P_b, 3680, check)
      call createCurrent(P_Hl, P_GMinus, P_ghWmAnti, P_ghZ, 1581, check)
      call createCurrent(P_ghA, P_ghWpAnti, P_WQPlus, 4011, check)
      call createCurrent(P_WPlus, P_GMinus, P_Z, P_G0, 599, check)
      call createCurrent(P_ghWp, P_ghAAnti, P_WMinus, P_ZQ, 404, check)
      call createCurrent(P_g, P_A, P_g, P_g, 5185, check)
      call createCurrent(P_GQ0, P_Hl, P_WMinus, P_WQPlus, 3633, check)
      call createCurrent(P_ghWmAnti, P_G0, P_GMinus, P_ghA, 4510, check)
      call createCurrent(P_ghWp, P_ghZAnti, P_A, P_WMinus, 2390, check)
      call createCurrent(P_GPlus, P_Hh, P_GMinus, P_Hh, 491, check)
      call createCurrent(P_A, P_GPlus, P_GMinus, P_Z, 1457, check)
      call createCurrent(P_A, P_WPlus, P_WMinus, 1552, check)
      call createCurrent(P_Hl, P_GMinus, P_WPlus, P_Z, 2543, check)
      call createCurrent(P_GQMinus, P_G0, P_ghZAnti, P_ghWp, 3055, check)
      call createCurrent(P_WQMinus, P_WPlus, P_ghAAnti, P_ghA, 1941, check)
      call createCurrent(P_Z, P_Hl, P_Hl, P_A, 5093, check)
      call createCurrent(P_GQPlus, P_Hh, P_ghWpAnti, P_ghA, 281, check)
      call createCurrent(P_WPlus, P_A, P_GMinus, P_Hl, 4870, check)
      call createCurrent(P_WMinus, P_Z, P_WPlus, P_A, 4092, check)
      call createCurrent(P_G0, P_muMinus, P_muPlus, 4895, check)
      call createCurrent(P_HlQ, P_GPlus, P_ghWm, P_ghAAnti, 4518, check)
      call createCurrent(P_HlQ, P_Hl, P_GPlus, P_GQMinus, 2280, check)
      call createCurrent(P_GPlus, P_Hh, P_Hh, P_GMinus, 2158, check)
      call createCurrent(P_GQPlus, P_ghWmAnti, P_GMinus, P_ghWm, 2674, check)
      call createCurrent(P_d, P_dAnti, P_Z, 471, check)
      call createCurrent(P_Hh, P_ePlus, P_eMinus, 1298, check)
      call createCurrent(P_nu_mu, P_muPlus, P_WMinus, 1009, check)
      call createCurrent(P_g, P_g, P_ghGAnti, P_ghG, 845, check)
      call createCurrent(P_Z, P_ghWm, P_ghAAnti, P_WPlus, 1798, check)
      call createCurrent(P_ghA, P_ghWmAnti, P_Hl, P_GQMinus, 2433, check)
      call createCurrent(P_WMinus, P_WPlus, P_A, P_Z, 4782, check)
      call createCurrent(P_ghA, P_ghWpAnti, P_GPlus, P_G0, 3712, check)
      call createCurrent(P_Hl, P_WPlus, P_WMinus, P_Hh, 2018, check)
      call createCurrent(P_Hh, P_A, P_Hl, P_Z, 5021, check)
      call createCurrent(P_GQMinus, P_Hl, P_GPlus, P_HlQ, 432, check)
      call createCurrent(P_Hh, P_ghAAnti, P_ghWm, P_GPlus, 2831, check)
      call createCurrent(P_ghZ, P_WPlus, P_A, P_ghWpAnti, 4335, check)
      call createCurrent(P_ghWp, P_G0, P_ghZAnti, P_GQMinus, 591, check)
      call createCurrent(P_ghWm, P_GPlus, P_ghZAnti, P_Hh, 4689, check)
      call createCurrent(P_ghWpAnti, P_WPlus, P_ghZ, P_A, 3417, check)
      call createCurrent(P_GQMinus, P_Hl, P_WPlus, P_ZQ, 2529, check)
      call createCurrent(P_GQMinus, P_Hh, P_WPlus, P_AQ, 717, check)
      call createCurrent(P_WPlus, P_ghWm, P_Z, P_ghAAnti, 3336, check)
      call createCurrent(P_ghAAnti, P_Hh, P_GMinus, P_ghWp, 2981, check)
      call createCurrent(P_ghWpAnti, P_Z, P_ghWp, P_ZQ, 3739, check)
      call createCurrent(P_WQPlus, P_ghWpAnti, P_Z, P_ghA, 2278, check)
      call createCurrent(P_g, P_g, P_Hh, P_Hh, 5163, check)
      call createCurrent(P_WPlus, P_GMinus, P_Z, P_Hl, 625, check)
      call createCurrent(P_GPlus, P_G0, P_G0, P_GMinus, 2695, check)
      call createCurrent(P_ghA, P_GMinus, P_ghAAnti, P_GPlus, 253, check)
      call createCurrent(P_GQMinus, P_A, P_WPlus, P_HlQ, 2717, check)
      call createCurrent(P_sAnti, P_c, P_WQMinus, 2833, check)
      call createCurrent(P_GQPlus, P_Hl, P_ghZAnti, P_ghWm, 4728, check)
      call createCurrent(P_ghWm, P_ghAAnti, P_WPlus, P_Z, 903, check)
      call createCurrent(P_ghA, P_GPlus, P_ghWpAnti, P_G0, 1465, check)
      call createCurrent(P_GQ0, P_cAnti, P_c, 802, check)
      call createCurrent(P_WQMinus, P_WPlus, P_G0, P_GQ0, 2494, check)
      call createCurrent(P_Hh, P_tauPlus, P_tauMinus, 896, check)
      call createCurrent(P_nu_muAnti, P_muMinus, P_WPlus, 1505, check)
      call createCurrent(P_WPlus, P_A, P_ghAAnti, P_ghWm, 1832, check)
      call createCurrent(P_ghZ, P_ghAAnti, P_GMinus, P_GQPlus, 875, check)
      call createCurrent(P_HhQ, P_ghAAnti, P_GPlus, P_ghWm, 2352, check)
      call createCurrent(P_GQMinus, P_Hh, P_Z, P_WQPlus, 306, check)
      call createCurrent(P_c, P_sAnti, P_GQMinus, 666, check)
      call createCurrent(P_tauMinus, P_tauPlus, P_A, 4128, check)
      call createCurrent(P_GQPlus, P_GMinus, P_Hl, P_GQ0, 693, check)
      call createCurrent(P_ghWmAnti, P_ghZ, P_GMinus, P_Hl, 4621, check)
      call createCurrent(P_ghA, P_ghWpAnti, P_G0, P_GPlus, 214, check)
      call createCurrent(P_WMinus, P_ghZAnti, P_ghA, P_WPlus, 965, check)
      call createCurrent(P_ghWmAnti, P_ghA, P_Hl, P_GQMinus, 1869, check)
      call createCurrent(P_ghWpAnti, P_Z, P_WPlus, P_ghZ, 3661, check)
      call createCurrent(P_GQPlus, P_ghZAnti, P_G0, P_ghWm, 418, check)
      call createCurrent(P_ghZ, P_ghWpAnti, P_A, P_WPlus, 2903, check)
      call createCurrent(P_HlQ, P_GPlus, P_WQMinus, 4581, check)
      call createCurrent(P_ghWm, P_ghWmAnti, P_Hl, P_HhQ, 3830, check)
      call createCurrent(P_A, P_A, P_WPlus, P_WMinus, 4871, check)
      call createCurrent(P_GQMinus, P_G0, P_G0, P_GQPlus, 4304, check)
      call createCurrent(P_c, P_Hl, P_cAnti, 659, check)
      call createCurrent(P_ghWpAnti, P_WPlus, P_ghA, P_Z, 2404, check)
      call createCurrent(P_ZQ, P_WPlus, P_WMinus, P_ZQ, 3094, check)
      call createCurrent(P_A, P_Hh, P_Hh, P_A, 5216, check)
      call createCurrent(P_HlQ, P_ghWp, P_ghWpAnti, 4660, check)
      call createCurrent(P_ghWmAnti, P_GMinus, P_ghZ, P_HlQ, 2327, check)
      call createCurrent(P_GQ0, P_Hh, P_G0, P_HhQ, 4855, check)
      call createCurrent(P_WPlus, P_ghZ, P_ghZAnti, P_WMinus, 2710, check)
      call createCurrent(P_Hl, P_Hl, P_g, P_g, 5128, check)
      call createCurrent(P_Hl, P_ghZAnti, P_GPlus, P_ghWm, 3067, check)
      call createCurrent(P_ghA, P_GMinus, P_Hl, P_ghWmAnti, 3248, check)
      call createCurrent(P_GMinus, P_Z, P_GPlus, 1491, check)
      call createCurrent(P_GPlus, P_muMinus, P_nu_muAnti, 309, check)
      call createCurrent(P_WPlus, P_ghWm, P_WMinus, P_ghWmAnti, 2943, check)
      call createCurrent(P_ZQ, P_WPlus, P_ghAAnti, P_ghWm, 145, check)
      call createCurrent(P_g, P_g, P_Z, P_g, 5137, check)
      call createCurrent(P_GPlus, P_G0, P_GMinus, P_G0, 2325, check)
      call createCurrent(P_GQPlus, P_ghZ, P_G0, P_ghWpAnti, 3564, check)
      call createCurrent(P_WQPlus, P_ghA, P_WMinus, P_ghAAnti, 1852, check)
      call createCurrent(P_WMinus, P_WPlus, P_ghZAnti, P_ghZ, 4520, check)
      call createCurrent(P_WPlus, P_GMinus, P_A, 4376, check)
      call createCurrent(P_muPlus, P_muMinus, P_AQ, 2261, check)
      call createCurrent(P_Z, P_GPlus, P_Hh, P_WMinus, 2891, check)
      call createCurrent(P_WQPlus, P_GMinus, P_G0, P_ZQ, 4274, check)
      call createCurrent(P_ZQ, P_ghZAnti, P_WPlus, P_ghWm, 3068, check)
      call createCurrent(P_ghWpAnti, P_Z, P_ghWp, P_Z, 4294, check)
      call createCurrent(P_Hl, P_Hl, P_ghWm, P_ghWmAnti, 3491, check)
      call createCurrent(P_WPlus, P_ghWm, P_Z, P_ghZAnti, 2432, check)
      call createCurrent(P_ghAAnti, P_GPlus, P_GMinus, P_ghZ, 3416, check)
      call createCurrent(P_WQPlus, P_Hl, P_WMinus, P_GQ0, 1595, check)
      call createCurrent(P_GMinus, P_Hh, P_ghZ, P_ghWmAnti, 2036, check)
      call createCurrent(P_Hh, P_Hl, P_Z, P_Z, 3222, check)
      call createCurrent(P_Hl, P_Hl, P_ghWp, P_ghWpAnti, 4309, check)
      call createCurrent(P_GMinus, P_Hl, P_GPlus, 4966, check)
      call createCurrent(P_ghZAnti, P_Hl, P_GPlus, P_ghWm, 4252, check)
      call createCurrent(P_Z, P_GMinus, P_GPlus, 4903, check)
      call createCurrent(P_GQMinus, P_Hh, P_WPlus, P_ZQ, 3334, check)
      call createCurrent(P_WQMinus, P_GPlus, P_Hl, P_AQ, 2901, check)
      call createCurrent(P_Hl, P_tauPlus, P_tauMinus, 2320, check)
      call createCurrent(P_WPlus, P_WMinus, P_Z, P_Z, 4889, check)
      call createCurrent(P_GQPlus, P_nu_tauAnti, P_tauMinus, 4572, check)
      call createCurrent(P_ghZ, P_ghZAnti, P_Hl, P_Hh, 3769, check)
      call createCurrent(P_ghZ, P_GPlus, P_ghWpAnti, 673, check)
      call createCurrent(P_GQ0, P_GMinus, P_G0, P_GQPlus, 2929, check)
      call createCurrent(P_GQMinus, P_GPlus, P_ghZ, P_ghZAnti, 3027, check)
      call createCurrent(P_GQMinus, P_GPlus, P_A, P_AQ, 16, check)
      call createCurrent(P_Hh, P_GMinus, P_ghZAnti, P_ghWp, 699, check)
      call createCurrent(P_A, P_ghWmAnti, P_WMinus, P_ghZ, 2373, check)
      call createCurrent(P_AQ, P_A, P_WPlus, P_WQMinus, 37, check)
      call createCurrent(P_ZQ, P_muMinus, P_muPlus, 3371, check)
      call createCurrent(P_GPlus, P_GMinus, P_Hl, P_Hh, 426, check)
      call createCurrent(P_ePlus, P_WMinus, P_nu_e, 2045, check)
      call createCurrent(P_WQMinus, P_ghA, P_A, P_ghWmAnti, 4282, check)
      call createCurrent(P_uAnti, P_Hh, P_u, 864, check)
      call createCurrent(P_Hl, P_ghWmAnti, P_GMinus, P_ghA, 3158, check)
      call createCurrent(P_ghAAnti, P_WPlus, P_ghWm, P_Z, 74, check)
      call createCurrent(P_Z, P_Hh, P_GMinus, P_WPlus, 920, check)
      call createCurrent(P_WQMinus, P_WPlus, P_ZQ, 171, check)
      call createCurrent(P_ghZAnti, P_Hh, P_GPlus, P_ghWm, 1633, check)
      call createCurrent(P_GQMinus, P_Z, P_WPlus, P_HlQ, 63, check)
      call createCurrent(P_ghZAnti, P_G0, P_ghZ, P_G0, 4765, check)
      call createCurrent(P_WMinus, P_WPlus, P_Hh, P_Hl, 1640, check)
      call createCurrent(P_AQ, P_bAnti, P_b, 1750, check)
      call createCurrent(P_ghWp, P_WMinus, P_WMinus, P_ghWmAnti, 312, check)
      call createCurrent(P_Hl, P_ghWpAnti, P_ghZ, P_GPlus, 1858, check)
      call createCurrent(P_A, P_WMinus, P_WPlus, P_A, 529, check)
      call createCurrent(P_GMinus, P_Hl, P_Hl, P_GPlus, 4043, check)
      call createCurrent(P_ghZ, P_Hh, P_ghZAnti, P_Hh, 4869, check)
      call createCurrent(P_WQPlus, P_WMinus, P_ghA, P_ghZAnti, 692, check)
      call createCurrent(P_A, P_ghWpAnti, P_ghWp, P_Z, 4103, check)
      call createCurrent(P_WMinus, P_WPlus, P_g, P_g, 5237, check)
      call createCurrent(P_WQMinus, P_Hh, P_Hl, P_WQPlus, 560, check)
      call createCurrent(P_ghZ, P_ghWmAnti, P_Z, P_WQMinus, 2353, check)
      call createCurrent(P_ghAAnti, P_G0, P_ghWm, P_GPlus, 2392, check)
      call createCurrent(P_ghWmAnti, P_GMinus, P_ghA, 2044, check)
      call createCurrent(P_GQ0, P_G0, P_Z, P_ZQ, 500, check)
      call createCurrent(P_ZQ, P_WMinus, P_ghAAnti, P_ghWp, 685, check)
      call createCurrent(P_ghWpAnti, P_ghA, P_GPlus, P_Hl, 1788, check)
      call createCurrent(P_Z, P_cAnti, P_c, 3207, check)
      call createCurrent(P_ghWm, P_Hh, P_ghWmAnti, P_Hh, 4237, check)
      call createCurrent(P_G0, P_g, P_G0, P_g, 5149, check)
      call createCurrent(P_GQ0, P_s, P_sAnti, 3048, check)
      call createCurrent(P_ghZ, P_ghWpAnti, P_Hh, P_GPlus, 1081, check)
      call createCurrent(P_t, P_tAnti, P_GQ0, 2697, check)
      call createCurrent(P_GMinus, P_A, P_Hh, P_WPlus, 2311, check)
      call createCurrent(P_HlQ, P_GMinus, P_GPlus, P_HhQ, 3205, check)
      call createCurrent(P_nu_mu, P_nu_muAnti, 5048, check)
      call createCurrent(P_A, P_ghWp, P_A, P_ghWpAnti, 4503, check)
      call createCurrent(P_ghWp, P_WMinus, P_ghWmAnti, P_WMinus, 4566, check)
      call createCurrent(P_cAnti, P_Hh, P_c, 3134, check)
      call createCurrent(P_ghZAnti, P_ghWp, P_WMinus, P_Z, 2231, check)
      call createCurrent(P_GPlus, P_A, P_Hl, P_WMinus, 2713, check)
      call createCurrent(P_GQMinus, P_WPlus, P_Z, P_GQ0, 4703, check)
      call createCurrent(P_ghZAnti, P_Hh, P_ghZ, P_Hl, 555, check)
      call createCurrent(P_AQ, P_Hl, P_GPlus, P_WQMinus, 644, check)
      call createCurrent(P_GQMinus, P_GPlus, P_ghZAnti, P_ghZ, 3106, check)
      call createCurrent(P_WQMinus, P_WPlus, P_ghZ, P_ghAAnti, 28, check)
      call createCurrent(P_ghWm, P_Hl, P_Hl, P_ghWmAnti, 2437, check)
      call createCurrent(P_ghZ, P_ghWmAnti, P_GMinus, P_Hl, 1169, check)
      call createCurrent(P_A, P_Hl, P_GPlus, P_WMinus, 1155, check)
      call createCurrent(P_HhQ, P_Z, P_GPlus, P_WQMinus, 4319, check)
      call createCurrent(P_Z, P_ghWmAnti, P_ghZ, P_WMinus, 2038, check)
      call createCurrent(P_WPlus, P_ghZ, P_ghWpAnti, P_Z, 4715, check)
      call createCurrent(P_nu_eAnti, P_A, P_nu_e, 5052, check)
      call createCurrent(P_WQPlus, P_WMinus, P_ZQ, 117, check)
      call createCurrent(P_GMinus, P_ghWp, P_Hh, P_ghZAnti, 4418, check)
      call createCurrent(P_nu_tauAnti, P_WPlus, P_tauMinus, 3558, check)
      call createCurrent(P_ghWp, P_Hl, P_ghWpAnti, 2917, check)
      call createCurrent(P_GQ0, P_Hl, P_Hh, P_GQ0, 3020, check)
      call createCurrent(P_ghWp, P_ghWpAnti, P_Z, P_ZQ, 4877, check)
      call createCurrent(P_A, P_ghZ, P_WMinus, P_ghWmAnti, 2661, check)
      call createCurrent(P_WPlus, P_A, P_ghA, P_ghWpAnti, 3024, check)
      call createCurrent(P_GQMinus, P_ghWmAnti, P_Hh, P_ghA, 2008, check)
      call createCurrent(P_ghWm, P_Z, P_ghAAnti, P_WPlus, 3446, check)
      call createCurrent(P_c, P_g, P_cAnti, 747, check)
      call createCurrent(P_GQMinus, P_GPlus, P_ghA, P_ghAAnti, 4736, check)
      call createCurrent(P_HhQ, P_A, P_GPlus, P_WQMinus, 1554, check)
      call createCurrent(P_ghZ, P_ghWmAnti, P_GMinus, P_HlQ, 1937, check)
      call createCurrent(P_nu_tau, P_WMinus, P_tauPlus, 2953, check)
      call createCurrent(P_c, P_cAnti, P_Z, 619, check)
      call createCurrent(P_HhQ, P_uAnti, P_u, 1105, check)
      call createCurrent(P_GQPlus, P_GMinus, P_ghA, P_ghAAnti, 4861, check)
      call createCurrent(P_GQPlus, P_Hl, P_ghA, P_ghWpAnti, 855, check)
      call createCurrent(P_Z, P_GPlus, P_A, P_GMinus, 3866, check)
      call createCurrent(P_ghWmAnti, P_ghA, P_WMinus, P_Z, 4055, check)
      call createCurrent(P_Hl, P_ghZ, P_ghWpAnti, P_GPlus, 869, check)
      call createCurrent(P_WMinus, P_ghZ, P_A, P_ghWmAnti, 558, check)
      call createCurrent(P_ghZ, P_ghZAnti, P_WMinus, P_WQPlus, 3953, check)
      call createCurrent(P_GPlus, P_Hl, P_GMinus, P_Hh, 3135, check)
      call createCurrent(P_GPlus, P_GMinus, P_WMinus, P_WPlus, 1584, check)
      call createCurrent(P_tauPlus, P_tauMinus, P_Hh, 2046, check)
      call createCurrent(P_ghWm, P_GPlus, P_ghZAnti, P_HlQ, 4496, check)
      call createCurrent(P_ghWpAnti, P_ghWp, P_Hh, P_GQ0, 3692, check)
      call createCurrent(P_GMinus, P_ghWmAnti, P_ghZ, P_G0, 103, check)
      call createCurrent(P_WQMinus, P_tauPlus, P_nu_tau, 2522, check)
      call createCurrent(P_GMinus, P_Hh, P_ghWp, P_ghAAnti, 1643, check)
      call createCurrent(P_GMinus, P_Hl, P_Hh, P_GPlus, 58, check)
      call createCurrent(P_HhQ, P_ghZAnti, P_ghZ, 828, check)
      call createCurrent(P_ZQ, P_GPlus, P_Z, P_GQMinus, 4015, check)
      call createCurrent(P_ghA, P_Z, P_WMinus, P_ghWmAnti, 3841, check)
      call createCurrent(P_GQPlus, P_muMinus, P_nu_muAnti, 1617, check)
      call createCurrent(P_A, P_WMinus, P_ghZAnti, P_ghWp, 3266, check)
      call createCurrent(P_ghWpAnti, P_Z, P_ghWp, P_A, 216, check)
      call createCurrent(P_GQMinus, P_Hl, P_ghZAnti, P_ghWp, 1309, check)
      call createCurrent(P_HlQ, P_WMinus, P_WPlus, P_HlQ, 1700, check)
      call createCurrent(P_dAnti, P_Z, P_d, 3908, check)
      call createCurrent(P_AQ, P_GMinus, P_WQPlus, 3781, check)
      call createCurrent(P_GPlus, P_G0, P_WMinus, P_A, 2444, check)
      call createCurrent(P_WQPlus, P_Hh, P_Hl, P_WQMinus, 2361, check)
      call createCurrent(P_d, P_dAnti, P_HlQ, 2749, check)
      call createCurrent(P_ghZ, P_WPlus, P_ghAAnti, P_WQMinus, 4955, check)
      call createCurrent(P_WQMinus, P_bAnti, P_t, 998, check)
      call createCurrent(P_ghWpAnti, P_GPlus, P_Hh, P_ghA, 1702, check)
      call createCurrent(P_ghZ, P_A, P_ghWmAnti, P_WMinus, 4007, check)
      call createCurrent(P_g, P_ghG, P_ghGAnti, 3550, check)
      call createCurrent(P_ghZAnti, P_WPlus, P_Z, P_ghWm, 342, check)
      call createCurrent(P_AQ, P_uAnti, P_u, 2152, check)
      call createCurrent(P_Hh, P_ghWm, P_Hh, P_ghWmAnti, 4403, check)
      call createCurrent(P_ZQ, P_Z, P_HhQ, 4678, check)
      call createCurrent(P_g, P_WPlus, P_g, P_WMinus, 5249, check)
      call createCurrent(P_GQPlus, P_ghA, P_Hl, P_ghWpAnti, 543, check)
      call createCurrent(P_Hl, P_GPlus, P_ghWm, P_ghZAnti, 441, check)
      call createCurrent(P_ghA, P_A, P_ghWmAnti, P_WMinus, 2939, check)
      call createCurrent(P_ZQ, P_ghWp, P_A, P_ghWpAnti, 3862, check)
      call createCurrent(P_GQ0, P_G0, P_Hl, P_HlQ, 1654, check)
      call createCurrent(P_A, P_WPlus, P_GMinus, P_G0, 3203, check)
      call createCurrent(P_Z, P_GPlus, P_GMinus, P_Z, 3778, check)
      call createCurrent(P_sAnti, P_WMinus, P_c, 2284, check)
      call createCurrent(P_ghA, P_G0, P_ghWmAnti, P_GMinus, 4606, check)
      call createCurrent(P_dAnti, P_d, P_AQ, 4172, check)
      call createCurrent(P_uAnti, P_u, P_G0, 2554, check)
      call createCurrent(P_ghWpAnti, P_GPlus, P_G0, P_ghA, 3015, check)
      call createCurrent(P_GQ0, P_GPlus, P_ghWpAnti, P_ghZ, 2253, check)
      call createCurrent(P_HlQ, P_Hh, P_Hl, P_HlQ, 1333, check)
      call createCurrent(P_ghZAnti, P_Hh, P_ghWp, P_GQMinus, 3546, check)
      call createCurrent(P_A, P_ghWmAnti, P_ghWm, P_A, 522, check)
      call createCurrent(P_ghWm, P_ghZAnti, P_Hl, P_GQPlus, 4850, check)
      call createCurrent(P_GPlus, P_ghA, P_Hl, P_ghWpAnti, 4167, check)
      call createCurrent(P_GMinus, P_Hl, P_GPlus, P_Hl, 3225, check)
      call createCurrent(P_G0, P_GPlus, P_WMinus, P_A, 3733, check)
      call createCurrent(P_WPlus, P_GMinus, P_Z, 4657, check)
      call createCurrent(P_WMinus, P_Z, P_ghWp, P_ghAAnti, 4456, check)
      call createCurrent(P_WPlus, P_ghA, P_WMinus, P_ghZAnti, 1300, check)
      call createCurrent(P_WMinus, P_GPlus, P_Z, P_Hl, 233, check)
      call createCurrent(P_HlQ, P_G0, P_GPlus, P_GQMinus, 191, check)
      call createCurrent(P_GMinus, P_ghWp, P_ghWpAnti, P_GPlus, 970, check)
      call createCurrent(P_Hh, P_GPlus, P_A, P_WMinus, 1414, check)
      call createCurrent(P_ghZ, P_WPlus, P_ghWpAnti, 364, check)
      call createCurrent(P_WQPlus, P_ghWpAnti, P_WPlus, P_ghWm, 975, check)
      call createCurrent(P_WQPlus, P_GMinus, P_G0, P_AQ, 1912, check)
      call createCurrent(P_WQMinus, P_nu_mu, P_muPlus, 1430, check)
      call createCurrent(P_WMinus, P_GPlus, P_Hh, P_A, 3561, check)
      call createCurrent(P_Z, P_ghWp, P_ghWpAnti, P_Z, 3658, check)
      call createCurrent(P_WMinus, P_WPlus, P_ghWp, P_ghWpAnti, 1162, check)
      call createCurrent(P_ghWpAnti, P_ghWp, P_A, P_A, 818, check)
      call createCurrent(P_Z, P_GPlus, P_Z, P_GMinus, 2651, check)
      call createCurrent(P_ghWm, P_Hl, P_Hh, P_ghWmAnti, 1871, check)
      call createCurrent(P_ghA, P_Hh, P_GPlus, P_ghWpAnti, 1900, check)
      call createCurrent(P_GQPlus, P_ghZ, P_Hh, P_ghWpAnti, 1111, check)
      call createCurrent(P_Hl, P_ghWpAnti, P_ghWp, P_Hh, 3683, check)
      call createCurrent(P_AQ, P_ghWp, P_ghWpAnti, 2023, check)
      call createCurrent(P_ghAAnti, P_ghWp, P_WMinus, P_A, 1008, check)
      call createCurrent(P_tAnti, P_t, P_Hl, 1743, check)
      call createCurrent(P_WQMinus, P_GPlus, P_HlQ, 1479, check)
      call createCurrent(P_GQMinus, P_A, P_GPlus, P_ZQ, 1467, check)
      call createCurrent(P_G0, P_G0, P_Hh, P_Hl, 1885, check)
      call createCurrent(P_AQ, P_ghZAnti, P_WPlus, P_ghWm, 2898, check)
      call createCurrent(P_Hl, P_ghWp, P_ghWpAnti, P_Hh, 248, check)
      call createCurrent(P_s, P_sAnti, P_ZQ, 3815, check)
      call createCurrent(P_HlQ, P_Hl, P_ghZ, P_ghZAnti, 3356, check)
      call createCurrent(P_ghZ, P_ghZAnti, P_WPlus, P_WQMinus, 138, check)
      call createCurrent(P_Z, P_t, P_tAnti, 4426, check)
      call createCurrent(P_ghWmAnti, P_G0, P_ghZ, P_GMinus, 3421, check)
      call createCurrent(P_WMinus, P_ghZ, P_WPlus, P_ghZAnti, 4443, check)
      call createCurrent(P_dAnti, P_G0, P_d, 4504, check)
      call createCurrent(P_ghZ, P_ghZAnti, P_G0, P_GQ0, 1531, check)
      call createCurrent(P_WMinus, P_WPlus, P_ghA, P_ghZAnti, 2126, check)
      call createCurrent(P_Hh, P_A, P_Z, P_Hh, 5026, check)
      call createCurrent(P_GPlus, P_ghWpAnti, P_ghA, P_Hh, 1591, check)
      call createCurrent(P_HhQ, P_ghZAnti, P_Hl, P_ghZ, 3940, check)
      call createCurrent(P_WQMinus, P_WPlus, P_ghZAnti, P_ghZ, 507, check)
      call createCurrent(P_ghZAnti, P_ghWm, P_GPlus, P_GQ0, 4570, check)
      call createCurrent(P_ghZ, P_ghWpAnti, P_WPlus, P_Z, 2246, check)
      call createCurrent(P_GPlus, P_Hh, P_Z, P_WMinus, 2394, check)
      call createCurrent(P_Hl, P_ghWpAnti, P_ghWp, P_Hl, 1555, check)
      call createCurrent(P_GQMinus, P_ghZ, P_ghWmAnti, 4227, check)
      call createCurrent(P_GMinus, P_GPlus, P_Z, P_A, 4975, check)
      call createCurrent(P_GQMinus, P_GPlus, P_G0, P_GQ0, 419, check)
      call createCurrent(P_ghZAnti, P_ghZ, P_GMinus, P_GPlus, 0, check)
      call createCurrent(P_ghWmAnti, P_ghZ, P_GMinus, P_HhQ, 2381, check)
      call createCurrent(P_HhQ, P_GMinus, P_GQPlus, 3026, check)
      call createCurrent(P_Hh, P_WMinus, P_Z, P_GPlus, 1028, check)
      call createCurrent(P_GQMinus, P_ghA, P_GPlus, P_ghZAnti, 2480, check)
      call createCurrent(P_AQ, P_c, P_cAnti, 1627, check)
      call createCurrent(P_Hl, P_Hl, P_Hh, P_Hl, 3514, check)
      call createCurrent(P_WMinus, P_Z, P_Z, P_WPlus, 1368, check)
      call createCurrent(P_Hh, P_ghWmAnti, P_Hh, P_ghWm, 1022, check)
      call createCurrent(P_GMinus, P_ghWmAnti, P_GPlus, P_ghWm, 1443, check)
      call createCurrent(P_WQMinus, P_Hh, P_WPlus, P_HlQ, 258, check)
      call createCurrent(P_GQPlus, P_G0, P_ghZ, P_ghWpAnti, 3886, check)
      call createCurrent(P_Hl, P_Hh, P_A, P_Z, 5009, check)
      call createCurrent(P_WPlus, P_g, P_g, P_WMinus, 5174, check)
      call createCurrent(P_GMinus, P_Hh, P_Hh, P_GPlus, 4390, check)
      call createCurrent(P_ghWmAnti, P_WMinus, P_ghWm, P_WPlus, 2368, check)
      call createCurrent(P_Hl, P_Hh, P_G0, P_G0, 4777, check)
      call createCurrent(P_WQMinus, P_dAnti, P_u, 4244, check)
      call createCurrent(P_s, P_cAnti, P_GPlus, 3500, check)
      call createCurrent(P_WPlus, P_GMinus, P_G0, 3176, check)
      call createCurrent(P_WQMinus, P_A, P_GPlus, P_GQ0, 2602, check)
      call createCurrent(P_WQMinus, P_WPlus, P_GMinus, P_GQPlus, 4737, check)
      call createCurrent(P_ghZ, P_Hh, P_Hl, P_ghZAnti, 1882, check)
      call createCurrent(P_uAnti, P_u, P_ZQ, 2438, check)
      call createCurrent(P_WPlus, P_muMinus, P_nu_muAnti, 1715, check)
      call createCurrent(P_ghAAnti, P_ghWm, P_GPlus, P_HlQ, 129, check)
      call createCurrent(P_GQ0, P_GPlus, P_WMinus, P_ZQ, 4130, check)
      call createCurrent(P_GQPlus, P_GMinus, P_HlQ, 4482, check)
      call createCurrent(P_g, P_Z, P_g, P_Z, 5169, check)
      call createCurrent(P_GQMinus, P_GPlus, P_ZQ, 2222, check)
      call createCurrent(P_ghWpAnti, P_GMinus, P_GPlus, P_ghWp, 4429, check)
      call createCurrent(P_ZQ, P_GMinus, P_GPlus, P_ZQ, 2954, check)
      call createCurrent(P_WMinus, P_GMinus, P_WPlus, P_GPlus, 3216, check)
      call createCurrent(P_Hh, P_Hl, P_A, P_A, 5168, check)
      call createCurrent(P_muPlus, P_nu_mu, P_GQMinus, 4386, check)
      call createCurrent(P_ghZAnti, P_Hh, P_ghWm, P_GPlus, 622, check)
      call createCurrent(P_A, P_ghWmAnti, P_A, P_ghWm, 3981, check)
      call createCurrent(P_dAnti, P_d, P_gQ, 1755, check)
      call createCurrent(P_ZQ, P_GPlus, P_WMinus, P_HlQ, 2556, check)
      call createCurrent(P_GPlus, P_ghWm, P_G0, P_ghAAnti, 1091, check)
      call createCurrent(P_GMinus, P_GPlus, P_Hh, 4772, check)
      call createCurrent(P_WPlus, P_Hh, P_GMinus, P_A, 3374, check)
      call createCurrent(P_Hl, P_Hl, P_ghZ, P_ghZAnti, 2493, check)
      call createCurrent(P_ghWm, P_ghWmAnti, P_A, P_A, 759, check)
      call createCurrent(P_GMinus, P_GPlus, P_A, 77, check)
      call createCurrent(P_WQPlus, P_Z, P_G0, P_GQMinus, 3252, check)
      call createCurrent(P_A, P_G0, P_G0, P_A, 5255, check)
      call createCurrent(P_eMinus, P_Z, P_ePlus, 1721, check)
      call createCurrent(P_ghA, P_ghZAnti, P_GMinus, P_GQPlus, 980, check)
      call createCurrent(P_ghWpAnti, P_GPlus, P_Hl, P_ghA, 3812, check)
      call createCurrent(P_AQ, P_Hh, P_GPlus, P_WQMinus, 1388, check)
      call createCurrent(P_GQPlus, P_Hh, P_ghA, P_ghWpAnti, 3213, check)
      call createCurrent(P_WQMinus, P_WPlus, P_HlQ, 3835, check)
      call createCurrent(P_ghWp, P_G0, P_ghAAnti, P_GMinus, 1214, check)
      call createCurrent(P_ghZAnti, P_ghWp, P_Hl, P_GMinus, 1586, check)
      call createCurrent(P_ghAAnti, P_WPlus, P_ghWm, 545, check)
      call createCurrent(P_ghZAnti, P_ghZ, P_G0, P_GQ0, 3880, check)
      call createCurrent(P_ghWp, P_Z, P_ghWpAnti, 3304, check)
      call createCurrent(P_ghZAnti, P_GMinus, P_ghWp, P_HhQ, 1336, check)
      call createCurrent(P_GQMinus, P_WPlus, P_ZQ, 4147, check)
      call createCurrent(P_Hl, P_tAnti, P_t, 554, check)
      call createCurrent(P_A, P_eMinus, P_ePlus, 720, check)
      call createCurrent(P_sAnti, P_s, P_Z, 2601, check)
      call createCurrent(P_GQ0, P_Hl, P_ghWpAnti, P_ghWp, 4277, check)
      call createCurrent(P_GQ0, P_Hl, P_GQ0, 2709, check)
      call createCurrent(P_AQ, P_GPlus, P_G0, P_WQMinus, 4230, check)
      call createCurrent(P_WMinus, P_A, P_WPlus, 776, check)
      call createCurrent(P_Hh, P_muPlus, P_muMinus, 3332, check)
      call createCurrent(P_Hh, P_Hl, P_ghZAnti, P_ghZ, 4486, check)
      call createCurrent(P_ghZAnti, P_WPlus, P_ghWm, P_AQ, 2582, check)
      call createCurrent(P_HlQ, P_tAnti, P_t, 4918, check)
      call createCurrent(P_WQPlus, P_muMinus, P_nu_muAnti, 112, check)
      call createCurrent(P_GQPlus, P_ghZ, P_GMinus, P_ghAAnti, 4942, check)
      call createCurrent(P_HlQ, P_Hl, P_Z, P_ZQ, 1536, check)
      call createCurrent(P_ghWp, P_ghAAnti, P_GMinus, P_HlQ, 4842, check)
      call createCurrent(P_ghWmAnti, P_ghWm, P_A, P_Z, 384, check)
      call createCurrent(P_ghZAnti, P_ghZ, P_Hh, P_Hl, 2824, check)
      call createCurrent(P_ghWp, P_ghAAnti, P_GMinus, P_Hl, 1060, check)
      call createCurrent(P_G0, P_ghWp, P_GMinus, P_ghAAnti, 1304, check)
      call createCurrent(P_GQ0, P_Hh, P_GMinus, P_GQPlus, 1661, check)
      call createCurrent(P_ghWp, P_Hl, P_ghWpAnti, P_Hh, 4549, check)
      call createCurrent(P_A, P_WPlus, P_GMinus, P_Hh, 2251, check)
      call createCurrent(P_WPlus, P_ghWpAnti, P_ghZ, 3280, check)
      call createCurrent(P_WPlus, P_GMinus, P_Hl, P_A, 2886, check)
      call createCurrent(P_GMinus, P_ghZ, P_ghAAnti, P_GPlus, 1731, check)
      call createCurrent(P_Z, P_sAnti, P_s, 132, check)
      call createCurrent(P_A, P_ghWp, P_ghWpAnti, 2765, check)
      call createCurrent(P_ghWpAnti, P_WPlus, P_ghWm, P_WQPlus, 4178, check)
      call createCurrent(P_ghWmAnti, P_ghA, P_G0, P_GQMinus, 70, check)
      call createCurrent(P_GQPlus, P_A, P_GQMinus, 3243, check)
      call createCurrent(P_GQMinus, P_nu_tau, P_tauPlus, 4567, check)
      call createCurrent(P_GQ0, P_Hl, P_ZQ, 1265, check)
      call createCurrent(P_G0, P_WMinus, P_A, P_GPlus, 1212, check)
      call createCurrent(P_eMinus, P_nu_eAnti, P_WQPlus, 1150, check)
      call createCurrent(P_WQMinus, P_WMinus, P_ghWmAnti, P_ghWp, 2532, check)
      call createCurrent(P_GMinus, P_ghA, P_ghAAnti, P_GPlus, 2858, check)
      call createCurrent(P_WPlus, P_WMinus, P_ghZAnti, P_ghA, 1381, check)
      call createCurrent(P_ghWp, P_ghWpAnti, P_HlQ, 2294, check)
      call createCurrent(P_ZQ, P_Hh, P_GMinus, P_WQPlus, 1134, check)
      call createCurrent(P_GQ0, P_Hh, P_GPlus, P_GQMinus, 3197, check)
      call createCurrent(P_WMinus, P_ghWp, P_WMinus, P_ghWmAnti, 2793, check)
      call createCurrent(P_ghWmAnti, P_ghWm, P_Hh, P_Hh, 3706, check)
      call createCurrent(P_HhQ, P_Z, P_Z, P_HhQ, 4582, check)
      call createCurrent(P_cAnti, P_c, P_HhQ, 6, check)
      call createCurrent(P_Z, P_G0, P_G0, P_Z, 2496, check)
      call createCurrent(P_GPlus, P_A, P_GMinus, P_Z, 2644, check)
      call createCurrent(P_ghZAnti, P_Hl, P_ghWm, P_GPlus, 3165, check)
      call createCurrent(P_ghWmAnti, P_GMinus, P_Hh, P_ghZ, 541, check)
      call createCurrent(P_HlQ, P_Hl, P_ghWmAnti, P_ghWm, 1488, check)
      call createCurrent(P_ghWp, P_Z, P_A, P_ghWpAnti, 1042, check)
      call createCurrent(P_ghWpAnti, P_ghWp, P_GPlus, P_GQMinus, 4107, check)
      call createCurrent(P_WQMinus, P_WPlus, P_Hl, P_HhQ, 1881, check)
      call createCurrent(P_ghWmAnti, P_Z, P_ghWm, P_Z, 1895, check)
      call createCurrent(P_WQPlus, P_WMinus, P_Hh, P_HlQ, 3824, check)
      call createCurrent(P_A, P_ghWm, P_ghWmAnti, P_Z, 1268, check)
      call createCurrent(P_Hh, P_WPlus, P_WMinus, P_Hl, 270, check)
      call createCurrent(P_ghZ, P_GPlus, P_ghWpAnti, P_HhQ, 3355, check)
      call createCurrent(P_WQMinus, P_WPlus, P_Z, P_ZQ, 2298, check)
      call createCurrent(P_G0, P_G0, P_ghWp, P_ghWpAnti, 2084, check)
      call createCurrent(P_GQMinus, P_Hl, P_WPlus, P_AQ, 114, check)
      call createCurrent(P_ghWm, P_ghAAnti, P_WPlus, P_AQ, 3756, check)
      call createCurrent(P_ghWpAnti, P_Hh, P_ghA, P_GQPlus, 3709, check)
      call createCurrent(P_Hl, P_eMinus, P_ePlus, 1183, check)
      call createCurrent(P_ghWpAnti, P_WPlus, P_ghWp, P_WMinus, 150, check)
      call createCurrent(P_ghWp, P_WMinus, P_WPlus, P_ghWpAnti, 4552, check)
      call createCurrent(P_HlQ, P_Hh, P_Hl, P_HhQ, 3053, check)
      call createCurrent(P_ghWpAnti, P_WPlus, P_ghZ, P_Z, 2616, check)
      call createCurrent(P_Hh, P_tauMinus, P_tauPlus, 2932, check)
      call createCurrent(P_Hh, P_ghZAnti, P_ghZ, P_Hl, 3727, check)
      call createCurrent(P_WPlus, P_GMinus, P_G0, P_A, 1445, check)
      call createCurrent(P_G0, P_A, P_G0, P_A, 5262, check)
      call createCurrent(P_Hl, P_WMinus, P_GPlus, P_A, 367, check)
      call createCurrent(P_GQPlus, P_WMinus, P_Z, P_HlQ, 4201, check)
      call createCurrent(P_ghWm, P_A, P_ghWmAnti, P_ZQ, 135, check)
      call createCurrent(P_A, P_ghWpAnti, P_ghZ, P_WPlus, 180, check)
      call createCurrent(P_G0, P_G0, P_GMinus, P_GPlus, 1722, check)
      call createCurrent(P_ghWm, P_WPlus, P_ghZAnti, P_AQ, 2771, check)
      call createCurrent(P_GQPlus, P_A, P_Z, P_GQMinus, 1525, check)
      call createCurrent(P_G0, P_Z, P_WMinus, P_GPlus, 3485, check)
      call createCurrent(P_WPlus, P_WMinus, P_Hh, P_Hh, 1461, check)
      call createCurrent(P_ZQ, P_c, P_cAnti, 4954, check)
      call createCurrent(P_WMinus, P_Z, P_GPlus, P_Hl, 1058, check)
      call createCurrent(P_GMinus, P_ghWm, P_ghWmAnti, P_GPlus, 2347, check)
      call createCurrent(P_GPlus, P_nu_eAnti, P_eMinus, 2007, check)
      call createCurrent(P_ghWm, P_G0, P_ghWmAnti, P_HhQ, 4805, check)
      call createCurrent(P_WQPlus, P_WPlus, P_ghWm, P_ghWpAnti, 1282, check)
      call createCurrent(P_WMinus, P_GPlus, P_G0, 2099, check)
      call createCurrent(P_A, P_Hh, P_WPlus, P_GMinus, 2047, check)
      call createCurrent(P_HhQ, P_t, P_tAnti, 1064, check)
      call createCurrent(P_WMinus, P_g, P_g, P_WPlus, 5152, check)
      call createCurrent(P_WMinus, P_G0, P_GPlus, P_A, 3909, check)
      call createCurrent(P_Hh, P_g, P_g, P_Hh, 5267, check)
      call createCurrent(P_ghA, P_Z, P_ghWpAnti, P_WPlus, 4264, check)
      call createCurrent(P_ghWpAnti, P_GPlus, P_Hh, P_ghZ, 4207, check)
      call createCurrent(P_GQMinus, P_WPlus, P_Hl, P_ZQ, 4550, check)
      call createCurrent(P_tAnti, P_t, P_HlQ, 256, check)
      call createCurrent(P_ghZAnti, P_WMinus, P_WPlus, P_ghA, 4767, check)
      call createCurrent(P_Hl, P_GPlus, P_ghAAnti, P_ghWm, 1122, check)
      call createCurrent(P_WMinus, P_Z, P_WPlus, P_Z, 167, check)
      call createCurrent(P_Z, P_WMinus, P_ghWmAnti, P_ghZ, 4937, check)
      call createCurrent(P_GQ0, P_Hl, P_ghWp, P_ghWpAnti, 2338, check)
      call createCurrent(P_WMinus, P_Z, P_G0, P_GPlus, 1354, check)
      call createCurrent(P_sAnti, P_s, P_AQ, 3056, check)
      call createCurrent(P_GMinus, P_Z, P_G0, P_WPlus, 2440, check)
      call createCurrent(P_ghAAnti, P_ghWm, P_WPlus, P_AQ, 3220, check)
      call createCurrent(P_WQPlus, P_WPlus, P_WMinus, P_WQMinus, 1314, check)
      call createCurrent(P_WMinus, P_ghZAnti, P_WPlus, P_ghZ, 2001, check)
      call createCurrent(P_AQ, P_A, P_ghWmAnti, P_ghWm, 4677, check)
      call createCurrent(P_WMinus, P_ghWp, P_ghAAnti, P_A, 2247, check)
      call createCurrent(P_ghZAnti, P_ghZ, P_WMinus, P_WQPlus, 2912, check)
      call createCurrent(P_A, P_ghAAnti, P_ghWm, P_WPlus, 1224, check)
      call createCurrent(P_G0, P_Hl, P_Hh, P_G0, 4571, check)
      call createCurrent(P_c, P_GMinus, P_sAnti, 1240, check)
      call createCurrent(P_WQPlus, P_Hh, P_GMinus, P_AQ, 4148, check)
      call createCurrent(P_A, P_A, P_g, P_g, 5264, check)
      call createCurrent(P_WQPlus, P_ghWmAnti, P_WMinus, P_ghWm, 3378, check)
      call createCurrent(P_Hh, P_Z, P_Hh, P_Z, 2349, check)
      call createCurrent(P_Hh, P_GPlus, P_Z, P_WMinus, 3960, check)
      call createCurrent(P_GQ0, P_ghZAnti, P_GPlus, P_ghWm, 1736, check)
      call createCurrent(P_A, P_WMinus, P_ghA, P_ghWmAnti, 995, check)
      call createCurrent(P_WPlus, P_s, P_cAnti, 2198, check)
      call createCurrent(P_HlQ, P_ghAAnti, P_GMinus, P_ghWp, 2012, check)
      call createCurrent(P_ghWpAnti, P_WMinus, P_WPlus, P_ghWp, 4917, check)
      call createCurrent(P_WMinus, P_WPlus, 5094, check)
      call createCurrent(P_HhQ, P_WPlus, P_GMinus, P_ZQ, 469, check)
      call createCurrent(P_Hh, P_ghZ, P_Hl, P_ghZAnti, 3405, check)
      call createCurrent(P_GMinus, P_Hh, P_ghA, P_ghWmAnti, 3287, check)
      call createCurrent(P_GPlus, P_GMinus, P_Hh, 4583, check)
      call createCurrent(P_GQMinus, P_ghZ, P_Hh, P_ghWmAnti, 1688, check)
      call createCurrent(P_HhQ, P_ghWm, P_Hh, P_ghWmAnti, 1793, check)
      call createCurrent(P_ghA, P_Hh, P_ghWpAnti, P_GQPlus, 1782, check)
      call createCurrent(P_WPlus, P_Hh, P_Hl, P_WMinus, 2033, check)
      call createCurrent(P_WMinus, P_WPlus, P_ghWmAnti, P_ghWm, 4827, check)
      call createCurrent(P_ghZAnti, P_ghWm, P_Hh, P_GQPlus, 4886, check)
      call createCurrent(P_ghZAnti, P_ghZ, P_Hl, 1685, check)
      call createCurrent(P_Hh, P_A, P_WPlus, P_GMinus, 2378, check)
      call createCurrent(P_ghWp, P_ghAAnti, P_G0, P_GMinus, 734, check)
      call createCurrent(P_G0, P_GMinus, P_G0, P_GPlus, 2276, check)
      call createCurrent(P_Hh, P_Hl, P_ghWpAnti, P_ghWp, 3484, check)
      call createCurrent(P_ghZAnti, P_ghWm, P_WPlus, P_ZQ, 446, check)
      call createCurrent(P_WQPlus, P_ghWpAnti, P_A, P_ghA, 940, check)
      call createCurrent(P_ghWp, P_GMinus, P_G0, P_ghAAnti, 4908, check)
      call createCurrent(P_GQMinus, P_A, P_GQPlus, 2689, check)
      call createCurrent(P_HlQ, P_ghWp, P_Hl, P_ghWpAnti, 4755, check)
      call createCurrent(P_G0, P_ghAAnti, P_ghWp, P_GMinus, 2073, check)
      call createCurrent(P_nu_e, P_ePlus, P_GQMinus, 641, check)
      call createCurrent(P_G0, P_GPlus, P_ghWpAnti, P_ghA, 860, check)
      call createCurrent(P_ghWpAnti, P_GPlus, P_ghZ, P_HlQ, 2424, check)
      call createCurrent(P_d, P_dAnti, P_Hh, 1006, check)
      call createCurrent(P_Hl, P_WPlus, P_GMinus, P_A, 847, check)
      call createCurrent(P_ghWpAnti, P_ghZ, P_WQPlus, 401, check)
      call createCurrent(P_GMinus, P_ghWmAnti, P_ghA, P_Hh, 2752, check)
      call createCurrent(P_G0, P_GPlus, P_GMinus, P_G0, 1255, check)
      call createCurrent(P_HlQ, P_ghZAnti, P_GMinus, P_ghWp, 423, check)
      call createCurrent(P_WMinus, P_ghZAnti, P_ghZ, P_WPlus, 3593, check)
      call createCurrent(P_GQ0, P_GPlus, P_ghAAnti, P_ghWm, 1129, check)
      call createCurrent(P_ghZ, P_GMinus, P_G0, P_ghWmAnti, 637, check)
      call createCurrent(P_eMinus, P_G0, P_ePlus, 1313, check)
      call createCurrent(P_GPlus, P_WMinus, P_Z, P_Hh, 2542, check)
      call createCurrent(P_HhQ, P_GMinus, P_Z, P_WQPlus, 3584, check)
      call createCurrent(P_ghA, P_ghWmAnti, P_G0, P_GQMinus, 4323, check)
      call createCurrent(P_ghWpAnti, P_Z, P_ghZ, P_WQPlus, 1425, check)
      call createCurrent(P_ghWmAnti, P_Hh, P_ghZ, P_GMinus, 206, check)
      call createCurrent(P_GPlus, P_WMinus, P_GMinus, P_WPlus, 106, check)
      call createCurrent(P_ghAAnti, P_ghWm, P_Hl, P_GPlus, 3552, check)
      call createCurrent(P_A, P_WPlus, P_ghA, P_ghWpAnti, 2148, check)
      call createCurrent(P_WPlus, P_WMinus, P_A, 4749, check)
      call createCurrent(P_G0, P_WPlus, P_G0, P_WMinus, 1346, check)
      call createCurrent(P_ghWm, P_GPlus, P_Hl, P_ghZAnti, 3033, check)
      call createCurrent(P_Z, P_Hh, P_Hl, P_Z, 798, check)
      call createCurrent(P_c, P_A, P_cAnti, 1236, check)
      call createCurrent(P_ghZ, P_ghWmAnti, P_G0, P_GQMinus, 5, check)
      call createCurrent(P_ghZAnti, P_G0, P_GMinus, P_ghWp, 1800, check)
      call createCurrent(P_AQ, P_WMinus, P_ghWp, P_ghZAnti, 1814, check)
      call createCurrent(P_GPlus, P_Z, P_G0, P_WMinus, 3269, check)
      call createCurrent(P_ghA, P_WMinus, P_ghZAnti, P_WPlus, 4668, check)
      call createCurrent(P_GPlus, P_ghWpAnti, P_G0, P_ghA, 3932, check)
      call createCurrent(P_GMinus, P_G0, P_ghZ, P_ghWmAnti, 848, check)
      call createCurrent(P_ghWpAnti, P_Hh, P_Hl, P_ghWp, 3534, check)
      call createCurrent(P_WMinus, P_WPlus, P_Z, P_A, 943, check)
      call createCurrent(P_WPlus, P_Z, P_ghZ, P_ghWpAnti, 2893, check)
      call createCurrent(P_WQPlus, P_G0, P_WMinus, P_HlQ, 556, check)
      call createCurrent(P_Hl, P_t, P_tAnti, 142, check)
      call createCurrent(P_tauPlus, P_Z, P_tauMinus, 4916, check)
      call createCurrent(P_ghWm, P_G0, P_ghAAnti, P_GPlus, 4626, check)
      call createCurrent(P_HlQ, P_Hl, P_Hh, P_HlQ, 3354, check)
      call createCurrent(P_GQMinus, P_ghWp, P_Hh, P_ghZAnti, 4409, check)
      call createCurrent(P_HhQ, P_Hl, P_HhQ, 2482, check)
      call createCurrent(P_ghWmAnti, P_GMinus, P_G0, P_ghZ, 2029, check)
      call createCurrent(P_GPlus, P_GMinus, P_G0, P_G0, 3085, check)
      call createCurrent(P_A, P_GMinus, P_Hl, P_WPlus, 2471, check)
      call createCurrent(P_c, P_Hh, P_cAnti, 4236, check)
      call createCurrent(P_HlQ, P_WMinus, P_Hh, P_WQPlus, 3360, check)
      call createCurrent(P_A, P_G0, P_GPlus, P_WMinus, 2977, check)
      call createCurrent(P_Z, P_WMinus, P_A, P_WPlus, 226, check)
      call createCurrent(P_A, P_WPlus, P_ghZ, P_ghWpAnti, 398, check)
      call createCurrent(P_HlQ, P_WPlus, P_GQMinus, 1341, check)
      call createCurrent(P_bAnti, P_b, 5051, check)
      call createCurrent(P_A, P_GPlus, P_A, P_GMinus, 1303, check)
      call createCurrent(P_ghZ, P_ghWpAnti, P_GPlus, 1267, check)
      call createCurrent(P_ghZAnti, P_WPlus, P_ghA, P_WQMinus, 2473, check)
      call createCurrent(P_ghA, P_ghWmAnti, P_WMinus, 1037, check)
      call createCurrent(P_GQPlus, P_A, P_WMinus, P_HhQ, 3325, check)
      call createCurrent(P_A, P_tauPlus, P_tauMinus, 4818, check)
      call createCurrent(P_ghWmAnti, P_Hl, P_ghWm, P_HhQ, 4911, check)
      call createCurrent(P_ghWmAnti, P_GMinus, P_ghWm, P_GQPlus, 383, check)
      call createCurrent(P_WMinus, P_ePlus, P_nu_e, 4876, check)
      call createCurrent(P_ghWmAnti, P_ghWm, P_Hh, P_HlQ, 4516, check)
      call createCurrent(P_cAnti, P_c, P_GQ0, 3793, check)
      call createCurrent(P_uAnti, P_u, P_gQ, 1958, check)
      call createCurrent(P_WMinus, P_ghWmAnti, P_Z, P_ghA, 78, check)
      call createCurrent(P_Hh, P_s, P_sAnti, 3018, check)
      call createCurrent(P_ghA, P_ghAAnti, P_GMinus, P_GQPlus, 3193, check)
      call createCurrent(P_ghWpAnti, P_GPlus, P_ghZ, P_Hh, 1328, check)
      call createCurrent(P_GQ0, P_G0, P_HhQ, 402, check)
      call createCurrent(P_WMinus, P_A, P_ghWp, P_ghAAnti, 4843, check)
      call createCurrent(P_G0, P_A, P_Z, P_G0, 5106, check)
      call createCurrent(P_nu_tauAnti, P_tauMinus, P_WQPlus, 459, check)
      call createCurrent(P_ghWpAnti, P_ghWp, P_Hl, P_HlQ, 1261, check)
      call createCurrent(P_ghZ, P_GMinus, P_ghWmAnti, 1424, check)
      call createCurrent(P_ghAAnti, P_Hh, P_ghWm, P_GPlus, 1541, check)
      call createCurrent(P_ghWmAnti, P_Hh, P_GMinus, P_ghZ, 732, check)
      call createCurrent(P_A, P_WMinus, P_ghWmAnti, P_ghZ, 4524, check)
      call createCurrent(P_G0, P_GPlus, P_ghA, P_ghWpAnti, 3047, check)
      call createCurrent(P_ghA, P_ghWmAnti, P_A, P_WQMinus, 1067, check)
      call createCurrent(P_WQPlus, P_Hh, P_WMinus, P_HlQ, 4880, check)
      call createCurrent(P_ghAAnti, P_WMinus, P_ghA, P_WPlus, 2318, check)
      call createCurrent(P_nu_tau, P_tauPlus, P_WMinus, 3188, check)
      call createCurrent(P_HhQ, P_Hl, P_Hh, P_HhQ, 871, check)
      call createCurrent(P_Hl, P_GMinus, P_ghWp, P_ghZAnti, 1925, check)
      call createCurrent(P_Hl, P_ghWmAnti, P_ghWm, P_Hl, 3747, check)
      call createCurrent(P_GMinus, P_Hl, P_ghAAnti, P_ghWp, 1045, check)
      call createCurrent(P_Hl, P_WMinus, P_GPlus, P_Z, 4526, check)
      call createCurrent(P_GMinus, P_Z, P_WPlus, P_G0, 4354, check)
      call createCurrent(P_ghZAnti, P_WPlus, P_ghWm, P_A, 2169, check)
      call createCurrent(P_ghWmAnti, P_ghZ, P_Z, P_WMinus, 96, check)
      call createCurrent(P_A, P_Hh, P_Z, 4995, check)
      call createCurrent(P_ghZ, P_ghZAnti, P_Hh, P_HhQ, 4462, check)
      call createCurrent(P_d, P_A, P_dAnti, 778, check)
      call createCurrent(P_HhQ, P_ghWmAnti, P_Hh, P_ghWm, 3686, check)
      call createCurrent(P_GQMinus, P_A, P_WPlus, P_GQ0, 4162, check)
      call createCurrent(P_Hl, P_GPlus, P_WMinus, P_A, 2678, check)
      call createCurrent(P_Z, P_nu_e, P_nu_eAnti, 4799, check)
      call createCurrent(P_GQ0, P_Hh, P_GQ0, 535, check)
      call createCurrent(P_b, P_bAnti, P_Z, 4806, check)
      call createCurrent(P_ghZAnti, P_ghZ, P_Hh, P_HhQ, 707, check)
      call createCurrent(P_tAnti, P_Hh, P_t, 3970, check)
      call createCurrent(P_WPlus, P_ghWmAnti, P_WMinus, P_ghWm, 4025, check)
      call createCurrent(P_A, P_muMinus, P_muPlus, 748, check)
      call createCurrent(P_GMinus, P_ghWp, P_Hl, P_ghAAnti, 238, check)
      call createCurrent(P_ghWm, P_WPlus, P_ghZAnti, P_ZQ, 2270, check)
      call createCurrent(P_GMinus, P_GPlus, P_ghA, P_ghZAnti, 683, check)
      call createCurrent(P_ghWp, P_Hl, P_GMinus, P_ghZAnti, 1056, check)
      call createCurrent(P_Hh, P_ghA, P_ghWpAnti, P_GPlus, 1706, check)
      call createCurrent(P_HhQ, P_ghWp, P_ghWpAnti, 1494, check)
      call createCurrent(P_ePlus, P_eMinus, P_AQ, 939, check)
      call createCurrent(P_WMinus, P_Z, P_WPlus, 915, check)
      call createCurrent(P_GPlus, P_Hl, P_ghWpAnti, P_ghA, 39, check)
      call createCurrent(P_ghWmAnti, P_ghWm, P_Z, P_A, 2884, check)
      call createCurrent(P_ghA, P_WMinus, P_ghAAnti, P_WPlus, 907, check)
      call createCurrent(P_Hl, P_ghAAnti, P_ghWp, P_GMinus, 1235, check)
      call createCurrent(P_GPlus, P_Hh, P_ghZ, P_ghWpAnti, 313, check)
      call createCurrent(P_Hh, P_A, P_A, P_Hl, 5204, check)
      call createCurrent(P_WQMinus, P_GPlus, P_Z, P_HhQ, 247, check)
      call createCurrent(P_GQMinus, P_Hh, P_ghZAnti, P_ghWp, 4812, check)
      call createCurrent(P_Hh, P_Hh, P_Hh, 276, check)
      call createCurrent(P_GQMinus, P_WPlus, P_Hl, P_AQ, 3949, check)
      call createCurrent(P_ghAAnti, P_Hh, P_GPlus, P_ghWm, 4159, check)
      call createCurrent(P_ghWpAnti, P_Hl, P_ghWp, 2140, check)
      call createCurrent(P_ZQ, P_b, P_bAnti, 3303, check)
      call createCurrent(P_WMinus, P_WPlus, P_ghWpAnti, P_ghWp, 4967, check)
      call createCurrent(P_WPlus, P_ghZ, P_WMinus, P_ghAAnti, 2659, check)
      call createCurrent(P_ghA, P_G0, P_GMinus, P_ghWmAnti, 2919, check)
      call createCurrent(P_A, P_Z, P_g, P_g, 5181, check)
      call createCurrent(P_ghWmAnti, P_G0, P_ghA, P_GMinus, 2642, check)
      call createCurrent(P_Z, P_WPlus, P_ghWpAnti, P_ghA, 1090, check)
      call createCurrent(P_ZQ, P_WPlus, P_GQMinus, 701, check)
      call createCurrent(P_ghZAnti, P_ghWp, P_WMinus, P_ZQ, 1840, check)
      call createCurrent(P_ghZAnti, P_ghZ, P_Hl, P_Hl, 4558, check)
      call createCurrent(P_ZQ, P_WMinus, P_GPlus, P_GQ0, 4163, check)
      call createCurrent(P_WPlus, P_eMinus, P_nu_eAnti, 3380, check)
      call createCurrent(P_WMinus, P_ghAAnti, P_A, P_ghWp, 2557, check)
      call createCurrent(P_ghZ, P_G0, P_ghWmAnti, P_GQMinus, 2639, check)
      call createCurrent(P_AQ, P_Z, P_ghWm, P_ghWmAnti, 750, check)
      call createCurrent(P_ghWmAnti, P_ghWm, P_Hl, P_HhQ, 3980, check)
      call createCurrent(P_GMinus, P_GPlus, P_Hh, P_Hl, 297, check)
      call createCurrent(P_ghZAnti, P_ghZ, P_GPlus, P_GMinus, 1830, check)
      call createCurrent(P_GMinus, P_ghWmAnti, P_ghA, 4081, check)
      call createCurrent(P_ghWmAnti, P_Hh, P_Hl, P_ghWm, 1545, check)
      call createCurrent(P_GMinus, P_ghWmAnti, P_ghZ, 2159, check)
      call createCurrent(P_G0, P_ghWm, P_ghWmAnti, P_G0, 760, check)
      call createCurrent(P_b, P_bAnti, P_GQ0, 1718, check)
      call createCurrent(P_gQ, P_cAnti, P_c, 947, check)
      call createCurrent(P_Z, P_ghWm, P_WPlus, P_ghAAnti, 3373, check)
      call createCurrent(P_ghZAnti, P_GMinus, P_GPlus, P_ghZ, 4754, check)
      call createCurrent(P_ghWm, P_ghWmAnti, P_Hh, P_Hl, 3496, check)
      call createCurrent(P_HhQ, P_WMinus, P_Z, P_GQPlus, 4927, check)
      call createCurrent(P_WQPlus, P_GMinus, P_Z, P_GQ0, 628, check)
      call createCurrent(P_ghWm, P_ghZAnti, P_GPlus, P_Hl, 3099, check)
      call createCurrent(P_HhQ, P_Hh, P_ghWp, P_ghWpAnti, 2144, check)
      call createCurrent(P_HlQ, P_WPlus, P_Hl, P_WQMinus, 1726, check)
      call createCurrent(P_WQPlus, P_WMinus, P_Z, P_AQ, 4521, check)
      call createCurrent(P_nu_e, P_Z, P_nu_eAnti, 358, check)
      call createCurrent(P_G0, P_Hh, P_A, 5079, check)
      call createCurrent(P_GQPlus, P_GMinus, P_A, P_AQ, 1993, check)
      call createCurrent(P_GMinus, P_A, P_WPlus, P_Hl, 4502, check)
      call createCurrent(P_dAnti, P_u, P_WMinus, 1459, check)
      call createCurrent(P_A, P_G0, P_Hl, 5123, check)
      call createCurrent(P_GPlus, P_WMinus, P_Hl, 2728, check)
      call createCurrent(P_s, P_sAnti, P_G0, 1439, check)
      call createCurrent(P_GQMinus, P_nu_mu, P_muPlus, 3447, check)
      call createCurrent(P_Hl, P_Z, P_GPlus, P_WMinus, 49, check)
      call createCurrent(P_g, P_g, P_GPlus, P_GMinus, 5159, check)
      call createCurrent(P_u, P_uAnti, P_Hl, 2189, check)
      call createCurrent(P_HhQ, P_GMinus, P_ghAAnti, P_ghWp, 3549, check)
      call createCurrent(P_ghZ, P_ghAAnti, P_WMinus, P_WQPlus, 3036, check)
      call createCurrent(P_Hh, P_Hh, P_Hh, P_Hh, 3610, check)
      call createCurrent(P_HlQ, P_GMinus, P_G0, P_GQPlus, 3786, check)
      call createCurrent(P_tauMinus, P_tauPlus, P_HhQ, 4833, check)
      call createCurrent(P_Hl, P_uAnti, P_u, 4344, check)
      call createCurrent(P_bAnti, P_b, P_GQ0, 1951, check)
      call createCurrent(P_HhQ, P_Z, P_ZQ, 289, check)
      call createCurrent(P_GQMinus, P_ghZAnti, P_G0, P_ghWp, 3011, check)
      call createCurrent(P_GQ0, P_ghWp, P_Hl, P_ghWpAnti, 1717, check)
      call createCurrent(P_ghWm, P_Z, P_ghWmAnti, P_Z, 4137, check)
      call createCurrent(P_eMinus, P_nu_eAnti, P_GPlus, 1778, check)
      call createCurrent(P_GQMinus, P_ghWmAnti, P_G0, P_ghA, 3427, check)
      call createCurrent(P_muPlus, P_WMinus, P_nu_mu, 2333, check)
      call createCurrent(P_nu_muAnti, P_WPlus, P_muMinus, 2181, check)
      call createCurrent(P_ZQ, P_G0, P_GMinus, P_WQPlus, 751, check)
      call createCurrent(P_ghWmAnti, P_GMinus, P_ghA, P_Hh, 3819, check)
      call createCurrent(P_HhQ, P_Hl, P_GMinus, P_GQPlus, 3163, check)
      call createCurrent(P_b, P_bAnti, 4987, check)
      call createCurrent(P_G0, P_ghWmAnti, P_GMinus, P_ghZ, 1164, check)
      call createCurrent(P_GQ0, P_GPlus, P_GMinus, P_GQ0, 290, check)
      call createCurrent(P_Z, P_ghZ, P_ghWmAnti, P_WMinus, 2946, check)
      call createCurrent(P_ghWp, P_Hh, P_Hh, P_ghWpAnti, 1728, check)
      call createCurrent(P_G0, P_G0, P_ghWpAnti, P_ghWp, 2435, check)
      call createCurrent(P_GMinus, P_Hl, P_ghWp, P_ghAAnti, 2355, check)
      call createCurrent(P_ghZ, P_ghZAnti, P_Hl, P_HhQ, 914, check)
      call createCurrent(P_GPlus, P_WMinus, P_G0, P_Z, 1738, check)
      call createCurrent(P_WMinus, P_ghA, P_ghAAnti, P_WPlus, 225, check)
      call createCurrent(P_nu_e, P_ePlus, P_GMinus, 2758, check)
      call createCurrent(P_HhQ, P_G0, P_ZQ, 2631, check)
      call createCurrent(P_GQ0, P_Hh, P_ghWmAnti, P_ghWm, 4120, check)
      call createCurrent(P_ghWpAnti, P_GPlus, P_G0, P_ghZ, 2190, check)
      call createCurrent(P_WPlus, P_ghZAnti, P_Z, P_ghWm, 2606, check)
      call createCurrent(P_ghZ, P_ghZAnti, P_Hh, 2235, check)
      call createCurrent(P_WQPlus, P_ghWm, P_WMinus, P_ghWmAnti, 3412, check)
      call createCurrent(P_GQMinus, P_GPlus, P_ghA, P_ghZAnti, 2923, check)
      call createCurrent(P_WQMinus, P_G0, P_GPlus, P_ZQ, 4487, check)
      call createCurrent(P_Z, P_Z, P_ghWm, P_ghWmAnti, 3694, check)
      call createCurrent(P_GMinus, P_ghWm, P_GPlus, P_ghWmAnti, 1142, check)
      call createCurrent(P_ePlus, P_eMinus, P_Hl, 3834, check)
      call createCurrent(P_Hh, P_Hl, P_WMinus, P_WPlus, 3208, check)
      call createCurrent(P_GPlus, P_GMinus, P_ghWmAnti, P_ghWm, 4235, check)
      call createCurrent(P_WQMinus, P_ghWp, P_WMinus, P_ghWmAnti, 3408, check)
      call createCurrent(P_tAnti, P_b, P_GPlus, 3046, check)
      call createCurrent(P_muPlus, P_Hl, P_muMinus, 67, check)
      call createCurrent(P_ghWm, P_ghZAnti, P_WPlus, P_AQ, 391, check)
      call createCurrent(P_GMinus, P_G0, P_ghA, P_ghWmAnti, 1024, check)
      call createCurrent(P_g, P_g, P_Hh, P_Hl, 5164, check)
      call createCurrent(P_GMinus, P_ghAAnti, P_ghWp, 3016, check)
      call createCurrent(P_G0, P_A, P_Hl, 4998, check)
      call createCurrent(P_Z, P_Hl, P_Z, P_Hl, 3456, check)
      call createCurrent(P_WQPlus, P_ghZ, P_A, P_ghWpAnti, 2037, check)
      call createCurrent(P_ghWpAnti, P_ghZ, P_Z, P_WPlus, 1102, check)
      call createCurrent(P_gQ, P_t, P_tAnti, 2909, check)
      call createCurrent(P_ghWp, P_Hh, P_ghZAnti, P_GMinus, 3112, check)
      call createCurrent(P_ghWmAnti, P_ghA, P_GMinus, P_Hl, 1296, check)
      call createCurrent(P_ghWp, P_ghWpAnti, P_A, P_Z, 518, check)
      call createCurrent(P_ghAAnti, P_GPlus, P_ghWm, P_HlQ, 992, check)
      call createCurrent(P_b, P_g, P_bAnti, 2670, check)
      call createCurrent(P_Hh, P_Hh, P_GPlus, P_GMinus, 3288, check)
      call createCurrent(P_GPlus, P_Z, P_WMinus, P_Hl, 427, check)
      call createCurrent(P_gQ, P_g, P_ghG, P_ghGAnti, 4104, check)
      call createCurrent(P_G0, P_ghWpAnti, P_GPlus, P_ghZ, 4425, check)
      call createCurrent(P_ghA, P_WMinus, P_ghWmAnti, P_Z, 3657, check)
      call createCurrent(P_ghA, P_GPlus, P_Hh, P_ghWpAnti, 3425, check)
      call createCurrent(P_WQMinus, P_Z, P_WPlus, P_AQ, 3551, check)
      call createCurrent(P_dAnti, P_WMinus, P_u, 272, check)
      call createCurrent(P_ZQ, P_WPlus, P_GMinus, P_GQ0, 1689, check)
      call createCurrent(P_ghA, P_GMinus, P_ghWmAnti, 4716, check)
      call createCurrent(P_ghAAnti, P_ghWp, P_GMinus, P_HlQ, 1610, check)
      call createCurrent(P_ghG, P_g, P_ghGAnti, P_gQ, 317, check)
      call createCurrent(P_ePlus, P_G0, P_eMinus, 675, check)
      call createCurrent(P_WQMinus, P_GPlus, P_A, P_HlQ, 2387, check)
      call createCurrent(P_ghWp, P_WMinus, P_ghAAnti, P_A, 3511, check)
      call createCurrent(P_GQ0, P_WMinus, P_Z, P_GQPlus, 182, check)
      call createCurrent(P_WMinus, P_A, P_ghWmAnti, P_ghA, 116, check)
      call createCurrent(P_GMinus, P_G0, P_ghAAnti, P_ghWp, 3931, check)
      call createCurrent(P_HlQ, P_GMinus, P_ghZAnti, P_ghWp, 4243, check)
      call createCurrent(P_ghWpAnti, P_A, P_ghWp, P_ZQ, 2610, check)
      call createCurrent(P_GQPlus, P_GMinus, P_Hh, P_GQ0, 746, check)
      call createCurrent(P_GQMinus, P_GPlus, P_Hl, P_HlQ, 1666, check)
      call createCurrent(P_Hl, P_GPlus, P_WMinus, 4057, check)
      call createCurrent(P_ghWm, P_ghWmAnti, P_Z, 2451, check)
      call createCurrent(P_WQPlus, P_d, P_uAnti, 874, check)
      call createCurrent(P_WMinus, P_tauPlus, P_nu_tau, 1770, check)
      call createCurrent(P_ghZ, P_A, P_ghWmAnti, P_WQMinus, 4887, check)
      call createCurrent(P_ghWm, P_GPlus, P_ghAAnti, P_Hh, 4900, check)
      call createCurrent(P_G0, P_ghWm, P_GPlus, P_ghZAnti, 3302, check)
      call createCurrent(P_WPlus, P_nu_tauAnti, P_tauMinus, 1594, check)
      call createCurrent(P_ghZ, P_ghWpAnti, P_GPlus, P_HhQ, 1889, check)
      call createCurrent(P_HhQ, P_G0, P_WMinus, P_WQPlus, 3757, check)
      call createCurrent(P_ZQ, P_WMinus, P_GQPlus, 1935, check)
      call createCurrent(P_GQMinus, P_Hh, P_WQPlus, 1435, check)
      call createCurrent(P_AQ, P_cAnti, P_c, 235, check)
      call createCurrent(P_GQMinus, P_Hl, P_Hh, P_GQPlus, 2234, check)
      call createCurrent(P_ghWpAnti, P_ghWp, P_Hh, P_HlQ, 836, check)
      call createCurrent(P_ghWmAnti, P_ghWp, P_WMinus, P_WQMinus, 4883, check)
      call createCurrent(P_GQPlus, P_Z, P_Hh, P_WQMinus, 801, check)
      call createCurrent(P_Hl, P_WPlus, P_GMinus, P_Z, 3286, check)
      call createCurrent(P_HhQ, P_ghWmAnti, P_ghWm, 3276, check)
      call createCurrent(P_WQPlus, P_WMinus, P_HhQ, 1568, check)
      call createCurrent(P_GPlus, P_ghWpAnti, P_ghZ, P_Hh, 475, check)
      call createCurrent(P_Hl, P_ghWm, P_GPlus, P_ghZAnti, 1523, check)
      call createCurrent(P_GQ0, P_ghWp, P_G0, P_ghWpAnti, 3740, check)
      call createCurrent(P_HhQ, P_Hl, P_Hh, P_HlQ, 653, check)
      call createCurrent(P_AQ, P_dAnti, P_d, 4142, check)
      call createCurrent(P_ghZ, P_ghWpAnti, P_Hh, P_GQPlus, 1901, check)
      call createCurrent(P_GMinus, P_ghA, P_Hh, P_ghWmAnti, 1433, check)
      call createCurrent(P_GPlus, P_WMinus, P_WPlus, P_GMinus, 3864, check)
      call createCurrent(P_GMinus, P_A, P_Z, P_GPlus, 2746, check)
      call createCurrent(P_ghWp, P_Hh, P_GMinus, P_ghAAnti, 326, check)
      call createCurrent(P_tAnti, P_t, P_gQ, 1222, check)
      call createCurrent(P_GMinus, P_ghA, P_ghWmAnti, 1526, check)
      call createCurrent(P_GQMinus, P_Hh, P_GQPlus, 34, check)
      call createCurrent(P_ghWpAnti, P_ghWp, P_Hh, P_Hl, 2845, check)
      call createCurrent(P_ghWmAnti, P_GMinus, P_ghZ, 1398, check)
      call createCurrent(P_ghZ, P_ghZAnti, P_Hl, P_Hl, 1243, check)
      call createCurrent(P_HhQ, P_ghZAnti, P_GMinus, P_ghWp, 3481, check)
      call createCurrent(P_Hh, P_ghAAnti, P_GMinus, P_ghWp, 1015, check)
      call createCurrent(P_ghWm, P_ghAAnti, P_GPlus, P_Hl, 1384, check)
      call createCurrent(P_ZQ, P_Z, P_Hl, P_HlQ, 4209, check)
      call createCurrent(P_Hl, P_ghWmAnti, P_ghZ, P_GMinus, 2011, check)
      call createCurrent(P_Hh, P_ghWpAnti, P_GPlus, P_ghA, 328, check)
      call createCurrent(P_GMinus, P_Hl, P_WPlus, P_Z, 1110, check)
      call createCurrent(P_GQPlus, P_WMinus, P_Hh, P_ZQ, 2359, check)
      call createCurrent(P_ghAAnti, P_ghZ, P_WPlus, P_WQMinus, 2402, check)
      call createCurrent(P_ghZ, P_GPlus, P_ghWpAnti, P_HlQ, 2202, check)
      call createCurrent(P_AQ, P_A, P_GPlus, P_GQMinus, 3096, check)
      call createCurrent(P_WPlus, P_G0, P_GMinus, P_A, 514, check)
      call createCurrent(P_WQPlus, P_uAnti, P_d, 4234, check)
      call createCurrent(P_ghZ, P_Hl, P_ghWmAnti, P_GMinus, 1932, check)
      call createCurrent(P_G0, P_ghZ, P_GMinus, P_ghWmAnti, 109, check)
      call createCurrent(P_A, P_Hh, P_Hl, P_Z, 5046, check)
      call createCurrent(P_WPlus, P_Z, P_ghWm, P_ghAAnti, 1415, check)
      call createCurrent(P_ZQ, P_G0, P_GPlus, P_WQMinus, 1068, check)
      call createCurrent(P_WMinus, P_ghAAnti, P_ghA, P_WPlus, 1854, check)
      call createCurrent(P_ghZ, P_Hh, P_ghZAnti, 2655, check)
      call createCurrent(P_G0, P_ghZ, P_ghZAnti, P_G0, 2458, check)
      call createCurrent(P_HlQ, P_ghZ, P_Hh, P_ghZAnti, 4679, check)
      call createCurrent(P_GQ0, P_dAnti, P_d, 1473, check)
      call createCurrent(P_ghWm, P_ghWmAnti, P_G0, P_GQ0, 2725, check)
      call createCurrent(P_ghWm, P_WMinus, P_ghWmAnti, P_WQPlus, 151, check)
      call createCurrent(P_A, P_WMinus, P_ghWp, P_ghAAnti, 3782, check)
      call createCurrent(P_Hl, P_GPlus, P_Z, P_WMinus, 1305, check)
      call createCurrent(P_GQMinus, P_GPlus, P_ghWpAnti, P_ghWp, 374, check)
      call createCurrent(P_WPlus, P_Hh, P_GMinus, 2428, check)
      call createCurrent(P_ZQ, P_ghAAnti, P_WMinus, P_ghWp, 2441, check)
      call createCurrent(P_ghZAnti, P_ghZ, P_WPlus, P_WQMinus, 2638, check)
      call createCurrent(P_AQ, P_WPlus, P_GQMinus, 1450, check)
      call createCurrent(P_WMinus, P_ghWpAnti, P_WPlus, P_ghWp, 1246, check)
      call createCurrent(P_GMinus, P_GPlus, P_ghWmAnti, P_ghWm, 2591, check)
      call createCurrent(P_Z, P_GMinus, P_WPlus, P_Hl, 769, check)
      call createCurrent(P_muPlus, P_muMinus, P_Z, 3837, check)
      call createCurrent(P_tauMinus, P_nu_tauAnti, P_GPlus, 4285, check)
      call createCurrent(P_GQPlus, P_GMinus, P_ghZ, P_ghAAnti, 4455, check)
      call createCurrent(P_WPlus, P_WMinus, P_ghWm, P_ghWmAnti, 976, check)
      call createCurrent(P_GQ0, P_ghWmAnti, P_Hh, P_ghWm, 1877, check)
      call createCurrent(P_ZQ, P_ghWm, P_WPlus, P_ghAAnti, 1427, check)
      call createCurrent(P_ZQ, P_Hh, P_Hl, P_ZQ, 2586, check)
      call createCurrent(P_Hl, P_Hl, P_Hl, P_Hh, 4483, check)
      call createCurrent(P_ZQ, P_GMinus, P_GQPlus, 1848, check)
      call createCurrent(P_ghWpAnti, P_ghWp, P_Z, P_Z, 2548, check)
      call createCurrent(P_ghZAnti, P_GPlus, P_ghA, P_GQMinus, 2136, check)
      call createCurrent(P_Hl, P_Z, P_A, 5029, check)
      call createCurrent(P_HhQ, P_ghWmAnti, P_G0, P_ghWm, 2630, check)
      call createCurrent(P_WPlus, P_ghWmAnti, P_ghWm, P_WMinus, 2096, check)
      call createCurrent(P_ghWm, P_Hh, P_ghWmAnti, P_GQ0, 4144, check)
      call createCurrent(P_ghWmAnti, P_ghWm, P_Z, P_Z, 486, check)
      call createCurrent(P_WQPlus, P_tauMinus, P_nu_tauAnti, 3934, check)
      call createCurrent(P_Hh, P_ghWp, P_ghWpAnti, P_Hl, 1761, check)
      call createCurrent(P_GPlus, P_ghWpAnti, P_Hh, P_ghZ, 4388, check)
      call createCurrent(P_GMinus, P_t, P_bAnti, 795, check)
      call createCurrent(P_GQ0, P_GPlus, P_ghZ, P_ghWpAnti, 3946, check)
      call createCurrent(P_HhQ, P_b, P_bAnti, 4447, check)
      call createCurrent(P_Hl, P_Hh, P_WPlus, P_WMinus, 2841, check)
      call createCurrent(P_d, P_Z, P_dAnti, 155, check)
      call createCurrent(P_HhQ, P_GPlus, P_G0, P_GQMinus, 1428, check)
      call createCurrent(P_ghZAnti, P_Hl, P_ghWp, P_GMinus, 4298, check)
      call createCurrent(P_Z, P_ghWpAnti, P_WPlus, P_ghA, 2228, check)
      call createCurrent(P_bAnti, P_GMinus, P_t, 1893, check)
      call createCurrent(P_Z, P_Z, P_WMinus, P_WPlus, 1818, check)
      call createCurrent(P_WMinus, P_ghWpAnti, P_ghWp, P_WPlus, 964, check)
      call createCurrent(P_Hl, P_GMinus, P_WPlus, 4542, check)
      call createCurrent(P_t, P_A, P_tAnti, 2955, check)
      call createCurrent(P_ghWp, P_ghWpAnti, P_GPlus, P_GQMinus, 2760, check)
      call createCurrent(P_ghWp, P_Hh, P_ghWpAnti, P_HhQ, 3905, check)
      call createCurrent(P_ghWp, P_G0, P_GMinus, P_ghZAnti, 2207, check)
      call createCurrent(P_ghWp, P_GMinus, P_ghAAnti, P_Hh, 3166, check)
      call createCurrent(P_G0, P_Z, P_G0, P_A, 5055, check)
      call createCurrent(P_WMinus, P_Hl, P_Hl, P_WPlus, 4780, check)
      call createCurrent(P_A, P_Hl, P_G0, 5066, check)
      call createCurrent(P_cAnti, P_c, P_Z, 232, check)
      call createCurrent(P_GMinus, P_G0, P_ghWp, P_ghAAnti, 3842, check)
      call createCurrent(P_WQPlus, P_WMinus, P_GQ0, 3628, check)
      call createCurrent(P_Hh, P_GMinus, P_Hh, P_GPlus, 4050, check)
      call createCurrent(P_ghWp, P_Hl, P_ghWpAnti, P_Hl, 1677, check)
      call createCurrent(P_ghWp, P_ghWpAnti, P_Hl, P_GQ0, 1745, check)
      call createCurrent(P_GMinus, P_sAnti, P_c, 1416, check)
      call createCurrent(P_WPlus, P_Z, P_GMinus, P_Hl, 1603, check)
      call createCurrent(P_ghZ, P_ghZAnti, P_HhQ, 4454, check)
      call createCurrent(P_Hl, P_Hh, P_Hh, P_Hl, 89, check)
      call createCurrent(P_A, P_ghWp, P_ghWpAnti, P_A, 4068, check)
      call createCurrent(P_ghA, P_Hh, P_ghWmAnti, P_GQMinus, 2768, check)
      call createCurrent(P_WPlus, P_Z, P_Z, P_WMinus, 881, check)
      call createCurrent(P_GQMinus, P_GPlus, P_GPlus, P_GQMinus, 2636, check)
      call createCurrent(P_GQ0, P_Hl, P_Hl, P_GQ0, 1085, check)
      call createCurrent(P_HhQ, P_GMinus, P_WPlus, P_ZQ, 2941, check)
      call createCurrent(P_Hl, P_ePlus, P_eMinus, 2737, check)
      call createCurrent(P_WQPlus, P_Hh, P_WMinus, P_GQ0, 2705, check)
      call createCurrent(P_HlQ, P_ghWmAnti, P_Hl, P_ghWm, 930, check)
      call createCurrent(P_WPlus, P_Hl, P_WMinus, P_Hl, 3625, check)
      call createCurrent(P_HhQ, P_ghWmAnti, P_Hl, P_ghWm, 4642, check)
      call createCurrent(P_HhQ, P_ghWm, P_GPlus, P_ghZAnti, 1241, check)
      call createCurrent(P_ghWp, P_GMinus, P_ghAAnti, P_HlQ, 1140, check)
      call createCurrent(P_GPlus, P_ghAAnti, P_ghA, P_GMinus, 4718, check)
      call createCurrent(P_WQPlus, P_Z, P_GMinus, P_GQ0, 588, check)
      call createCurrent(P_WPlus, P_A, P_GMinus, P_Hh, 3839, check)
      call createCurrent(P_G0, P_GPlus, P_ghWm, P_ghAAnti, 2967, check)
      call createCurrent(P_WMinus, P_GPlus, P_Z, P_G0, 4340, check)
      call createCurrent(P_GPlus, P_WMinus, P_Hl, P_A, 1504, check)
      call createCurrent(P_ZQ, P_WMinus, P_Hh, P_GQPlus, 403, check)
      call createCurrent(P_ghAAnti, P_GPlus, P_G0, P_ghWm, 3745, check)
      call createCurrent(P_A, P_G0, P_GMinus, P_WPlus, 2149, check)
      call createCurrent(P_WPlus, P_Z, P_ghAAnti, P_ghWm, 3404, check)
      call createCurrent(P_ghZAnti, P_A, P_ghWm, P_WPlus, 2209, check)
      call createCurrent(P_AQ, P_Hh, P_WMinus, P_GQPlus, 2060, check)
      call createCurrent(P_GQPlus, P_GMinus, P_ghWm, P_ghWmAnti, 3426, check)
      call createCurrent(P_ghWp, P_ghZAnti, P_Hl, P_GQMinus, 3066, check)
      call createCurrent(P_WPlus, P_WMinus, P_ghZ, P_ghZAnti, 2026, check)
      call createCurrent(P_tauPlus, P_tauMinus, P_AQ, 3516, check)
      call createCurrent(P_G0, P_ePlus, P_eMinus, 315, check)
      call createCurrent(P_HlQ, P_Hl, P_ghWp, P_ghWpAnti, 2740, check)
      call createCurrent(P_G0, P_Z, P_A, P_G0, 5035, check)
      call createCurrent(P_AQ, P_WPlus, P_Hh, P_GQMinus, 2510, check)
      call createCurrent(P_GMinus, P_Z, P_GPlus, P_A, 3801, check)
      call createCurrent(P_WQMinus, P_Z, P_Hl, P_GQPlus, 4371, check)
      call createCurrent(P_GQPlus, P_GMinus, P_ghWmAnti, P_ghWm, 2687, check)
      call createCurrent(P_HhQ, P_WMinus, P_WPlus, P_HhQ, 1671, check)
      call createCurrent(P_Hl, P_Hh, P_GMinus, P_GPlus, 4841, check)
      call createCurrent(P_GQPlus, P_Z, P_G0, P_WQMinus, 933, check)
      call createCurrent(P_G0, P_WPlus, P_GMinus, 2566, check)
      call createCurrent(P_ghWmAnti, P_WMinus, P_ghWm, P_WQPlus, 3180, check)
      call createCurrent(P_GQMinus, P_ghZ, P_G0, P_ghWmAnti, 958, check)
      call createCurrent(P_HlQ, P_ghZAnti, P_ghZ, 4655, check)
      call createCurrent(P_ghWm, P_ghAAnti, P_A, P_WPlus, 2069, check)
      call createCurrent(P_WQMinus, P_A, P_ghWmAnti, P_ghA, 2860, check)
      call createCurrent(P_ePlus, P_eMinus, P_HlQ, 2312, check)
      call createCurrent(P_GMinus, P_Hh, P_A, P_WPlus, 1658, check)
      call createCurrent(P_ghZ, P_ghAAnti, P_GPlus, P_GQMinus, 4049, check)
      call createCurrent(P_Hl, P_Z, P_Hl, P_A, 5091, check)
      call createCurrent(P_ghWm, P_Z, P_ghWmAnti, P_ZQ, 580, check)
      call createCurrent(P_GQPlus, P_b, P_tAnti, 4548, check)
      call createCurrent(P_GQPlus, P_WMinus, P_AQ, 1609, check)
      call createCurrent(P_ghWmAnti, P_Hh, P_Hh, P_ghWm, 443, check)
      call createCurrent(P_GQMinus, P_Hh, P_ghZ, P_ghWmAnti, 1767, check)
      call createCurrent(P_HhQ, P_ghZ, P_Hl, P_ghZAnti, 646, check)
      call createCurrent(P_tauPlus, P_tauMinus, P_Z, 768, check)
      call createCurrent(P_WMinus, P_Hh, P_WPlus, 3570, check)
      call createCurrent(P_ghA, P_Hl, P_GMinus, P_ghWmAnti, 3571, check)
      call createCurrent(P_WQMinus, P_ghZAnti, P_WPlus, P_ghZ, 4519, check)
      call createCurrent(P_g, P_ghGAnti, P_ghG, 3591, check)
      call createCurrent(P_ghWmAnti, P_G0, P_ghWm, P_HlQ, 3681, check)
      call createCurrent(P_ghWm, P_WPlus, P_A, P_ghAAnti, 1956, check)
      call createCurrent(P_ghA, P_ghWpAnti, P_WPlus, 4701, check)
      call createCurrent(P_GMinus, P_Hl, P_ghWmAnti, P_ghA, 2322, check)
      call createCurrent(P_Hh, P_A, P_GPlus, P_WMinus, 4381, check)
      call createCurrent(P_muMinus, P_muPlus, P_Z, 347, check)
      call createCurrent(P_ghZAnti, P_GMinus, P_G0, P_ghWp, 4251, check)
      call createCurrent(P_ghWmAnti, P_ghA, P_Hh, P_GMinus, 1686, check)
      call createCurrent(P_ghZ, P_Hl, P_Hh, P_ghZAnti, 3013, check)
      call createCurrent(P_GQMinus, P_G0, P_WPlus, P_AQ, 691, check)
      call createCurrent(P_GQPlus, P_WPlus, P_GMinus, P_WQMinus, 1206, check)
      call createCurrent(P_ghWmAnti, P_Z, P_ghWm, P_AQ, 4858, check)
      call createCurrent(P_GQPlus, P_Hl, P_GQMinus, 2461, check)
      call createCurrent(P_WPlus, P_cAnti, P_s, 3070, check)
      call createCurrent(P_HlQ, P_GPlus, P_WMinus, P_ZQ, 376, check)
      call createCurrent(P_ghA, P_ghWmAnti, P_WQMinus, 4067, check)
      call createCurrent(P_ghWp, P_WPlus, P_ghWpAnti, P_WMinus, 3890, check)
      call createCurrent(P_HhQ, P_ghWp, P_Hh, P_ghWpAnti, 2551, check)
      call createCurrent(P_Hl, P_tauMinus, P_tauPlus, 3545, check)
      call createCurrent(P_G0, P_GMinus, P_Z, P_WPlus, 3524, check)
      call createCurrent(P_ghWmAnti, P_ghZ, P_GMinus, P_G0, 3730, check)
      call createCurrent(P_HlQ, P_Z, P_Z, P_HlQ, 3292, check)
      call createCurrent(P_Hh, P_t, P_tAnti, 4819, check)
      call createCurrent(P_uAnti, P_u, P_Hh, 2070, check)
      call createCurrent(P_tAnti, P_g, P_t, 3102, check)
      call createCurrent(P_cAnti, P_G0, P_c, 857, check)
      call createCurrent(P_ZQ, P_A, P_GPlus, P_GQMinus, 158, check)
      call createCurrent(P_HhQ, P_Hh, P_ghZ, P_ghZAnti, 3123, check)
      call createCurrent(P_Hl, P_GPlus, P_ghZ, P_ghWpAnti, 224, check)
      call createCurrent(P_AQ, P_WPlus, P_WMinus, P_ZQ, 3893, check)
      call createCurrent(P_ePlus, P_nu_e, P_GQMinus, 690, check)
      call createCurrent(P_AQ, P_WMinus, P_WPlus, P_AQ, 4632, check)
      call createCurrent(P_ghWpAnti, P_G0, P_ghWp, P_GQ0, 3532, check)
      call createCurrent(P_ghZAnti, P_WMinus, P_ghA, P_WQPlus, 3554, check)
      call createCurrent(P_ghWm, P_ghWmAnti, P_G0, P_G0, 3432, check)
      call createCurrent(P_ghAAnti, P_WMinus, P_Z, P_ghWp, 4052, check)
      call createCurrent(P_WQPlus, P_ghWpAnti, P_ghA, 2326, check)
      call createCurrent(P_GQPlus, P_Z, P_Hl, P_WQMinus, 1112, check)
      call createCurrent(P_WMinus, P_WMinus, P_WPlus, P_WPlus, 495, check)
      call createCurrent(P_g, P_Hl, P_Hl, P_g, 5182, check)
      call createCurrent(P_b, P_bAnti, P_ZQ, 4534, check)
      call createCurrent(P_tAnti, P_t, P_Hh, 4065, check)
      call createCurrent(P_ghWpAnti, P_A, P_ghZ, P_WQPlus, 2173, check)
      call createCurrent(P_ghWmAnti, P_ghWm, P_Hh, P_Hl, 1569, check)
      call createCurrent(P_HhQ, P_GPlus, P_Z, P_WQMinus, 1732, check)
      call createCurrent(P_WMinus, P_ghWp, P_ghAAnti, P_Z, 4867, check)
      call createCurrent(P_GPlus, P_Z, P_Hl, P_WMinus, 667, check)
      call createCurrent(P_ghZAnti, P_WMinus, P_A, P_ghWp, 737, check)
      call createCurrent(P_u, P_Z, P_uAnti, 1205, check)
      call createCurrent(P_GMinus, P_GPlus, P_Hh, P_Hh, 4149, check)
      call createCurrent(P_c, P_cAnti, P_ZQ, 381, check)
      call createCurrent(P_HhQ, P_c, P_cAnti, 1626, check)
      call createCurrent(P_ghWmAnti, P_G0, P_ghA, P_GQMinus, 2027, check)
      call createCurrent(P_GMinus, P_ghWmAnti, P_Hl, P_ghZ, 4863, check)
      call createCurrent(P_GPlus, P_GMinus, P_Z, P_A, 1575, check)
      call createCurrent(P_cAnti, P_c, P_AQ, 4680, check)
      call createCurrent(P_WQPlus, P_ghA, P_A, P_ghWpAnti, 2859, check)
      call createCurrent(P_ghWmAnti, P_ghWm, P_Hl, 647, check)
      call createCurrent(P_ghAAnti, P_ghWm, P_GPlus, 3349, check)
      call createCurrent(P_HhQ, P_ghWp, P_GMinus, P_ghAAnti, 629, check)
      call createCurrent(P_GQ0, P_G0, P_ghWmAnti, P_ghWm, 4189, check)
      call createCurrent(P_ghWm, P_ghWmAnti, P_Hh, 378, check)
      call createCurrent(P_tAnti, P_b, P_GQPlus, 4363, check)
      call createCurrent(P_Hh, P_Hl, P_G0, P_G0, 3299, check)
      call createCurrent(P_GPlus, P_Z, P_WMinus, P_Hh, 544, check)
      call createCurrent(P_ghA, P_WMinus, P_Z, P_ghWmAnti, 1071, check)
      call createCurrent(P_GMinus, P_ghWp, P_ghZAnti, P_G0, 4561, check)
      call createCurrent(P_A, P_WPlus, P_A, P_WMinus, 3161, check)
      call createCurrent(P_ghWpAnti, P_ghWp, P_G0, P_HlQ, 4412, check)
      call createCurrent(P_GPlus, P_ghZ, P_G0, P_ghWpAnti, 2109, check)
      call createCurrent(P_GMinus, P_ghZAnti, P_ghWp, P_Hh, 509, check)
      call createCurrent(P_ghWmAnti, P_Z, P_ghA, P_WQMinus, 4231, check)
      call createCurrent(P_Hl, P_Hl, P_ghWpAnti, P_ghWp, 4039, check)
      call createCurrent(P_ghA, P_ghWpAnti, P_Hl, P_GQPlus, 4531, check)
      call createCurrent(P_GPlus, P_ghAAnti, P_ghWm, 1391, check)
      call createCurrent(P_GMinus, P_GPlus, P_WMinus, P_WPlus, 3045, check)
      call createCurrent(P_AQ, P_GMinus, P_GPlus, P_AQ, 4688, check)
      call createCurrent(P_ZQ, P_WMinus, P_Hl, P_GQPlus, 4122, check)
      call createCurrent(P_g, P_Hh, P_Hh, P_g, 5138, check)
      call createCurrent(P_GQMinus, P_Hl, P_ghZ, P_ghWmAnti, 932, check)
      call createCurrent(P_GQPlus, P_GMinus, P_ghAAnti, P_ghZ, 2239, check)
      call createCurrent(P_WMinus, P_Hl, P_GPlus, P_Z, 1264, check)
      call createCurrent(P_GQMinus, P_GMinus, P_GPlus, P_GQPlus, 2119, check)
      call createCurrent(P_WQPlus, P_GMinus, P_A, P_HhQ, 4279, check)
      call createCurrent(P_ZQ, P_G0, P_WPlus, P_GQMinus, 3642, check)
      call createCurrent(P_ghWmAnti, P_ghZ, P_A, P_WQMinus, 3993, check)
      call createCurrent(P_GPlus, P_GMinus, P_Hl, P_Hl, 311, check)
      call createCurrent(P_ghZ, P_Hh, P_ghWpAnti, P_GQPlus, 22, check)
      call createCurrent(P_GPlus, P_ghZAnti, P_ghZ, P_GMinus, 3428, check)
      call createCurrent(P_Hh, P_WPlus, P_WMinus, 4739, check)
      call createCurrent(P_ghAAnti, P_WPlus, P_A, P_ghWm, 1462, check)
      call createCurrent(P_ghZ, P_ghAAnti, P_GPlus, P_GMinus, 3191, check)
      call createCurrent(P_GPlus, P_ghZAnti, P_ghWm, P_Hh, 2583, check)
      call createCurrent(P_ghAAnti, P_GMinus, P_ghWp, P_Hl, 3963, check)
      call createCurrent(P_WMinus, P_A, P_WPlus, P_Z, 4820, check)
      call createCurrent(P_t, P_bAnti, P_WQMinus, 437, check)
      call createCurrent(P_HlQ, P_ghWpAnti, P_Hh, P_ghWp, 2645, check)
      call createCurrent(P_ghWmAnti, P_Z, P_WMinus, P_ghZ, 652, check)
      call createCurrent(P_G0, P_ghZ, P_ghWmAnti, P_GMinus, 950, check)
      call createCurrent(P_muMinus, P_muPlus, P_HlQ, 4076, check)
      call createCurrent(P_ghZ, P_ghWmAnti, P_Hh, P_GQMinus, 813, check)
      call createCurrent(P_Hl, P_muPlus, P_muMinus, 512, check)
      call createCurrent(P_g, P_A, P_Z, P_g, 5199, check)
      call createCurrent(P_ghZ, P_Hh, P_ghZAnti, P_Hl, 1906, check)
      call createCurrent(P_GQMinus, P_GPlus, P_ghZ, P_ghAAnti, 3878, check)
      call createCurrent(P_HhQ, P_GPlus, P_Hl, P_GQMinus, 4603, check)
      call createCurrent(P_WMinus, P_ghWm, P_WPlus, P_ghWmAnti, 3744, check)
      call createCurrent(P_GQ0, P_GMinus, P_Z, P_WQPlus, 2334, check)
      call createCurrent(P_g, P_g, P_A, P_A, 5196, check)
      call createCurrent(P_A, P_WPlus, P_ghZAnti, P_ghWm, 2762, check)
      call createCurrent(P_WQMinus, P_ghZAnti, P_ghWp, 1295, check)
      call createCurrent(P_ghAAnti, P_ghWp, P_A, P_WMinus, 97, check)
      call createCurrent(P_Hl, P_GPlus, P_ghZAnti, P_ghWm, 1055, check)
    end subroutine createCurrents

    subroutine check_vertices_mdl()
      call createCurrents(.true.)
    end subroutine check_vertices_mdl

    subroutine get_vertex_lorentz_rank_mdl(ty,cc,mr)
      integer, intent(in) :: ty
      logical, intent(in) :: cc(0:)
      integer, intent(out) :: mr
      select case(ty)
      case(5)
        if (cc(0) .or. cc(1)) then
          mr = 1
        else
          mr = 0
        end if 
      case(6)
        if (cc(0)) then
          mr = 1
        else
          mr = 0
        end if 
      case(12)
        if (cc(0)) then
          mr = 1
        else
          mr = 0
        end if 
      case(13)
        if (cc(0)) then
          mr = 1
        else
          mr = 0
        end if 
      case(23)
        if (cc(0) .or. cc(1)) then
          mr = 1
        else
          mr = 0
        end if 
      case(24)
        if (cc(0)) then
          mr = 1
        else
          mr = 0
        end if 
      case(25)
        if (cc(0) .or. cc(1)) then
          mr = 1
        else
          mr = 0
        end if 
      case(26)
        if (cc(0)) then
          mr = 1
        else
          mr = 0
        end if 
      case(28)
        if (cc(0) .or. cc(1)) then
          mr = 1
        else
          mr = 0
        end if 
      case(29)
        if (cc(0)) then
          mr = 1
        else
          mr = 0
        end if 
      case(30)
        if (cc(0)) then
          mr = 1
        else
          mr = 0
        end if 
      case(33)
        if (cc(0)) then
          mr = 1
        else
          mr = 0
        end if 
      case(34)
        if (cc(0) .or. cc(1)) then
          mr = 1
        else
          mr = 0
        end if 
      case(36)
        if (cc(0)) then
          mr = 1
        else
          mr = 0
        end if 
      case(41)
        if (cc(0)) then
          mr = 1
        else
          mr = 0
        end if 
      case(42)
        if (cc(0) .or. cc(1)) then
          mr = 1
        else
          mr = 0
        end if 
      case(44)
        if (cc(0)) then
          mr = 1
        else
          mr = 0
        end if 
      case(45)
        if (cc(0)) then
          mr = 1
        else
          mr = 0
        end if 
      case(68)
        if (cc(0) .or. cc(1)) then
          mr = 1
        else
          mr = 0
        end if 
      case(69)
        if (cc(0)) then
          mr = 1
        else
          mr = 0
        end if 
      case(70)
        if (cc(0)) then
          mr = 1
        else
          mr = 0
        end if 
      case(71)
        if (cc(0)) then
          mr = 1
        else
          mr = 0
        end if 
      case(72)
        if (cc(0)) then
          mr = 1
        else
          mr = 0
        end if 
      case(73)
        if (cc(0) .or. cc(1)) then
          mr = 1
        else
          mr = 0
        end if 
      case(74)
        if (cc(0)) then
          mr = 1
        else
          mr = 0
        end if 
      case(75)
        if (cc(0)) then
          mr = 1
        else
          mr = 0
        end if 
      case(79)
        if (cc(0) .or. cc(1)) then
          mr = 1
        else
          mr = 0
        end if 
      case(80)
        if (cc(0)) then
          mr = 1
        else
          mr = 0
        end if 
      case(81)
        if (cc(0)) then
          mr = 1
        else
          mr = 0
        end if 
      case(82)
        if (cc(0) .or. cc(1)) then
          mr = 1
        else
          mr = 0
        end if 
      case(83)
        if (cc(0)) then
          mr = 1
        else
          mr = 0
        end if 
      case(87)
        if (cc(0)) then
          mr = 1
        else
          mr = 0
        end if 
      case(88)
        if (cc(0)) then
          mr = 1
        else
          mr = 0
        end if 
      case(89)
        if (cc(0)) then
          mr = 1
        else
          mr = 0
        end if 
      case(96)
        if (cc(0)) then
          mr = 1
        else
          mr = 0
        end if 
      case(97)
        if (cc(0)) then
          mr = 1
        else
          mr = 0
        end if 
      case(98)
        if (cc(0)) then
          mr = 1
        else
          mr = 0
        end if 
      case(103)
        if (cc(0)) then
          mr = 1
        else
          mr = 0
        end if 
      case(109)
        if (cc(0) .or. cc(1)) then
          mr = 1
        else
          mr = 0
        end if 
      case(110)
        if (cc(0)) then
          mr = 1
        else
          mr = 0
        end if 
      case(113)
        if (cc(0)) then
          mr = 1
        else
          mr = 0
        end if 
      case(114)
        if (cc(0)) then
          mr = 1
        else
          mr = 0
        end if 
      case default
        mr = 0
      end select 
    end subroutine get_vertex_lorentz_rank_mdl
end module class_vertices
